Class: HubSpotSDK::Client
Constant Summary
collapse
- DEFAULT_MAX_RETRIES =
Default max number of retries to attempt after a failed retryable request.
2
- DEFAULT_TIMEOUT_IN_SECONDS =
Default per-request timeout.
60.0
- DEFAULT_INITIAL_RETRY_DELAY =
Default initial retry delay in seconds. Overall delay is calculated using exponential backoff + jitter.
0.5
- DEFAULT_MAX_RETRY_DELAY =
Default max retry delay in seconds.
8.0
Internal::Transport::BaseClient::MAX_REDIRECTS, Internal::Transport::BaseClient::PLATFORM_HEADERS
Instance Attribute Summary collapse
#base_url, #headers, #idempotency_header, #initial_retry_delay, #max_retries, #max_retry_delay, #requester, #timeout
Instance Method Summary
collapse
follow_redirect, #inspect, reap_connection!, #request, #send_request, should_retry?, validate!
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(access_token: nil, developer_api_key: nil, base_url: ENV["HUBSPOT_BASE_URL"], max_retries: self.class::DEFAULT_MAX_RETRIES, timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS, initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY, max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY) ⇒ Client
Creates and returns a new client for interacting with the API.
‘“api.example.com/v2/”`. Defaults to `ENV`
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
|
# File 'lib/hubspot_sdk/client.rb', line 101
def initialize(
access_token: nil,
developer_api_key: nil,
base_url: ENV["HUBSPOT_BASE_URL"],
max_retries: self.class::DEFAULT_MAX_RETRIES,
timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS,
initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY,
max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY
)
base_url ||= "https://api.hubapi.com"
@access_token = access_token&.to_s
@developer_api_key = developer_api_key&.to_s
super(
base_url: base_url,
timeout: timeout,
max_retries: max_retries,
initial_retry_delay: initial_retry_delay,
max_retry_delay: max_retry_delay
)
@account = HubSpotSDK::Resources::Account.new(client: self)
@auth = HubSpotSDK::Resources::Auth.new(client: self)
@automation = HubSpotSDK::Resources::Automation.new(client: self)
@business_units = HubSpotSDK::Resources::BusinessUnits.new(client: self)
@cms = HubSpotSDK::Resources::Cms.new(client: self)
@communication_preferences = HubSpotSDK::Resources::CommunicationPreferences.new(client: self)
@conversations = HubSpotSDK::Resources::Conversations.new(client: self)
@crm = HubSpotSDK::Resources::Crm.new(client: self)
@events = HubSpotSDK::Resources::Events.new(client: self)
@files = HubSpotSDK::Resources::Files.new(client: self)
@marketing = HubSpotSDK::Resources::Marketing.new(client: self)
@meta = HubSpotSDK::Resources::Meta.new(client: self)
@scheduler = HubSpotSDK::Resources::Scheduler.new(client: self)
@settings = HubSpotSDK::Resources::Settings.new(client: self)
@webhooks = HubSpotSDK::Resources::Webhooks.new(client: self)
end
|
Instance Attribute Details
#access_token ⇒ String?
19
20
21
|
# File 'lib/hubspot_sdk/client.rb', line 19
def access_token
@access_token
end
|
25
26
27
|
# File 'lib/hubspot_sdk/client.rb', line 25
def account
@account
end
|
28
29
30
|
# File 'lib/hubspot_sdk/client.rb', line 28
def auth
@auth
end
|
31
32
33
|
# File 'lib/hubspot_sdk/client.rb', line 31
def automation
@automation
end
|
34
35
36
|
# File 'lib/hubspot_sdk/client.rb', line 34
def business_units
@business_units
end
|
37
38
39
|
# File 'lib/hubspot_sdk/client.rb', line 37
def cms
@cms
end
|
40
41
42
|
# File 'lib/hubspot_sdk/client.rb', line 40
def communication_preferences
@communication_preferences
end
|
43
44
45
|
# File 'lib/hubspot_sdk/client.rb', line 43
def conversations
@conversations
end
|
46
47
48
|
# File 'lib/hubspot_sdk/client.rb', line 46
def crm
@crm
end
|
#developer_api_key ⇒ String?
22
23
24
|
# File 'lib/hubspot_sdk/client.rb', line 22
def developer_api_key
@developer_api_key
end
|
49
50
51
|
# File 'lib/hubspot_sdk/client.rb', line 49
def events
@events
end
|
52
53
54
|
# File 'lib/hubspot_sdk/client.rb', line 52
def files
@files
end
|
55
56
57
|
# File 'lib/hubspot_sdk/client.rb', line 55
def marketing
@marketing
end
|
58
59
60
|
# File 'lib/hubspot_sdk/client.rb', line 58
def meta
@meta
end
|
61
62
63
|
# File 'lib/hubspot_sdk/client.rb', line 61
def scheduler
@scheduler
end
|
64
65
66
|
# File 'lib/hubspot_sdk/client.rb', line 64
def settings
@settings
end
|
67
68
69
|
# File 'lib/hubspot_sdk/client.rb', line 67
def webhooks
@webhooks
end
|