Class: HubSpotSDK::Models::Account::ActingUser
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Account::ActingUser
- Defined in:
- lib/hubspot_sdk/models/account/acting_user.rb
Instance Attribute Summary collapse
-
#user_email ⇒ String?
The email address of the user who performed the action.
-
#user_id ⇒ Integer
The user’s unique ID.
Instance Method Summary collapse
- #initialize(user_id:, user_email: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(user_id:, user_email: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/account/acting_user.rb', line 19
|
Instance Attribute Details
#user_email ⇒ String?
The email address of the user who performed the action.
17 |
# File 'lib/hubspot_sdk/models/account/acting_user.rb', line 17 optional :user_email, String, api_name: :userEmail |
#user_id ⇒ Integer
The user’s unique ID.
11 |
# File 'lib/hubspot_sdk/models/account/acting_user.rb', line 11 required :user_id, Integer, api_name: :userId |