Class: HubSpotSDK::Models::Account::ActivityListAuditLogsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(acting_user_id: nil, after: nil, fill_final_timestamp: nil, limit: nil, occurred_after: nil, occurred_before: nil, sort: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Account::ActivityListAuditLogsParams for more details.

Parameters:

  • acting_user_id (Array<Integer>) (defaults to: nil)
  • after (String) (defaults to: nil)

    The paging cursor token of the last successfully read resource will be returned

  • fill_final_timestamp (Boolean) (defaults to: nil)
  • limit (Integer) (defaults to: nil)

    The maximum number of results to display per page.

  • occurred_after (Time) (defaults to: nil)
  • occurred_before (Time) (defaults to: nil)
  • sort (Array<String>) (defaults to: nil)
  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb', line 50

Instance Attribute Details

#acting_user_idArray<Integer>?

Returns:

  • (Array<Integer>, nil)


14
# File 'lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb', line 14

optional :acting_user_id, HubSpotSDK::Internal::Type::ArrayOf[Integer]

#afterString?

The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.

Returns:

  • (String, nil)


22
# File 'lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb', line 22

optional :after, String

#fill_final_timestampBoolean?

Returns:

  • (Boolean, nil)


27
# File 'lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb', line 27

optional :fill_final_timestamp, HubSpotSDK::Internal::Type::Boolean

#limitInteger?

The maximum number of results to display per page.

Returns:

  • (Integer, nil)


33
# File 'lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb', line 33

optional :limit, Integer

#occurred_afterTime?

Returns:

  • (Time, nil)


38
# File 'lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb', line 38

optional :occurred_after, Time

#occurred_beforeTime?

Returns:

  • (Time, nil)


43
# File 'lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb', line 43

optional :occurred_before, Time

#sortArray<String>?

Returns:

  • (Array<String>, nil)


48
# File 'lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb', line 48

optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String]