Class: HubSpotSDK::Models::Account::HydratedCriticalAction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/account/hydrated_critical_action.rb

Overview

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, type:, user_id:, acting_user: nil, country_code: nil, info_url: nil, ip_address: nil, location: nil, object_id_: nil, region_code: nil) ⇒ Object

Parameters:

  • id (String)

    The activity’s unique ID.

  • created_at (Time)

    The time the activity took place.

  • type (Symbol, HubSpotSDK::Models::Account::HydratedCriticalAction::Type)

    The type of activity.

  • user_id (Integer)

    The user’s unique ID.

  • acting_user (String) (defaults to: nil)

    Email address of the user associated with the activity.

  • country_code (String) (defaults to: nil)

    The approximate country code

  • info_url (String) (defaults to: nil)

    A link to the URL where the action was taken in the account.

  • ip_address (String) (defaults to: nil)

    IP address where the activity originated.

  • location (String) (defaults to: nil)

    The approximate location where the activity took place.

  • object_id_ (String) (defaults to: nil)

    The ID of the affected object.

  • region_code (String) (defaults to: nil)

    The approximate region code



# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 74

Instance Attribute Details

#acting_userString?

Email address of the user associated with the activity.

Returns:

  • (String, nil)


36
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 36

optional :acting_user, String, api_name: :actingUser

#country_codeString?

The approximate country code

Returns:

  • (String, nil)


42
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 42

optional :country_code, String, api_name: :countryCode

#created_atTime

The time the activity took place.

Returns:

  • (Time)


18
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 18

required :created_at, Time, api_name: :createdAt

#idString

The activity’s unique ID.

Returns:

  • (String)


12
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 12

required :id, String

#info_urlString?

A link to the URL where the action was taken in the account.

Returns:

  • (String, nil)


48
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 48

optional :info_url, String, api_name: :infoUrl

#ip_addressString?

IP address where the activity originated.

Returns:

  • (String, nil)


54
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 54

optional :ip_address, String, api_name: :ipAddress

#locationString?

The approximate location where the activity took place.

Returns:

  • (String, nil)


60
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 60

optional :location, String

#object_id_String?

The ID of the affected object.

Returns:

  • (String, nil)


66
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 66

optional :object_id_, String, api_name: :objectId

#region_codeString?

The approximate region code

Returns:

  • (String, nil)


72
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 72

optional :region_code, String, api_name: :regionCode

#typeSymbol, HubSpotSDK::Models::Account::HydratedCriticalAction::Type

The type of activity.



24
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 24

required :type, enum: -> { HubSpotSDK::Account::HydratedCriticalAction::Type }

#user_idInteger

The user’s unique ID.

Returns:

  • (Integer)


30
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 30

required :user_id, Integer, api_name: :userId