Class: HubSpotSDK::Models::ActionResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/action_response.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(completed_at:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::ActionResponse for more details.

Parameters:

  • completed_at (Time)

    The timestamp indicating when the action was completed.

  • started_at (Time)

    The timestamp indicating when the action was started.

  • status (Symbol, HubSpotSDK::Models::ActionResponse::Status)

    The current status of the action, with possible values: CANCELED, COMPLETE, PEND

  • links (Hash{Symbol=>String}) (defaults to: nil)

    A map of link names to associated URIs containing documentation about the error

  • requested_at (Time) (defaults to: nil)

    The timestamp indicating when the action was requested.



# File 'lib/hubspot_sdk/models/action_response.rb', line 38

Instance Attribute Details

#completed_atTime

The timestamp indicating when the action was completed.

Returns:

  • (Time)


10
# File 'lib/hubspot_sdk/models/action_response.rb', line 10

required :completed_at, Time, api_name: :completedAt

A map of link names to associated URIs containing documentation about the error or recommended remediation steps

Returns:

  • (Hash{Symbol=>String}, nil)


30
# File 'lib/hubspot_sdk/models/action_response.rb', line 30

optional :links, HubSpotSDK::Internal::Type::HashOf[String]

#requested_atTime?

The timestamp indicating when the action was requested.

Returns:

  • (Time, nil)


36
# File 'lib/hubspot_sdk/models/action_response.rb', line 36

optional :requested_at, Time, api_name: :requestedAt

#started_atTime

The timestamp indicating when the action was started.

Returns:

  • (Time)


16
# File 'lib/hubspot_sdk/models/action_response.rb', line 16

required :started_at, Time, api_name: :startedAt

#statusSymbol, HubSpotSDK::Models::ActionResponse::Status

The current status of the action, with possible values: CANCELED, COMPLETE, PENDING, PROCESSING.



23
# File 'lib/hubspot_sdk/models/action_response.rb', line 23

required :status, enum: -> { HubSpotSDK::ActionResponse::Status }