Class: HubSpotSDK::Models::AssociationDefinition

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/association_definition.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, from_object_type_id:, to_object_type_id:, created_at: nil, name: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::AssociationDefinition for more details.

The definition of an association

Parameters:

  • id (String)

    The unique ID of the associated object (e.g., a contact ID).

  • from_object_type_id (String)

    The ID of the source object type (e.g., 0-1 for contacts).

  • to_object_type_id (String)

    The ID of the destination object type (e.g., 0-3 for deals).

  • created_at (Time) (defaults to: nil)

    The timestamp when the association was created, in ISO 8601 format.

  • name (String) (defaults to: nil)

    For labeled association types, the internal name of the association.

  • updated_at (Time) (defaults to: nil)

    The timestamp when the last update was made to an association, in ISO 8601 forma



# File 'lib/hubspot_sdk/models/association_definition.rb', line 43

Instance Attribute Details

#created_atTime?

The timestamp when the association was created, in ISO 8601 format.

Returns:

  • (Time, nil)


28
# File 'lib/hubspot_sdk/models/association_definition.rb', line 28

optional :created_at, Time, api_name: :createdAt

#from_object_type_idString

The ID of the source object type (e.g., 0-1 for contacts).

Returns:

  • (String)


16
# File 'lib/hubspot_sdk/models/association_definition.rb', line 16

required :from_object_type_id, String, api_name: :fromObjectTypeId

#idString

The unique ID of the associated object (e.g., a contact ID).

Returns:

  • (String)


10
# File 'lib/hubspot_sdk/models/association_definition.rb', line 10

required :id, String

#nameString?

For labeled association types, the internal name of the association.

Returns:

  • (String, nil)


34
# File 'lib/hubspot_sdk/models/association_definition.rb', line 34

optional :name, String

#to_object_type_idString

The ID of the destination object type (e.g., 0-3 for deals).

Returns:

  • (String)


22
# File 'lib/hubspot_sdk/models/association_definition.rb', line 22

required :to_object_type_id, String, api_name: :toObjectTypeId

#updated_atTime?

The timestamp when the last update was made to an association, in ISO 8601 format.

Returns:

  • (Time, nil)


41
# File 'lib/hubspot_sdk/models/association_definition.rb', line 41

optional :updated_at, Time, api_name: :updatedAt