Class: HubSpotSDK::Models::AssociationSpec
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::AssociationSpec
- Defined in:
- lib/hubspot_sdk/models/association_spec.rb
Defined Under Namespace
Modules: AssociationCategory
Instance Attribute Summary collapse
-
#association_category ⇒ Symbol, HubSpotSDK::Models::AssociationSpec::AssociationCategory
The category of the association, such as “HUBSPOT_DEFINED”.
-
#association_type_id ⇒ Integer
The ID representing the specific type of association.
Instance Method Summary collapse
-
#initialize(association_category:, association_type_id:) ⇒ Object
constructor
Defines the type, direction, and details of the relationship between two CRM objects.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(association_category:, association_type_id:) ⇒ Object
Defines the type, direction, and details of the relationship between two CRM objects.
|
|
# File 'lib/hubspot_sdk/models/association_spec.rb', line 20
|
Instance Attribute Details
#association_category ⇒ Symbol, HubSpotSDK::Models::AssociationSpec::AssociationCategory
The category of the association, such as “HUBSPOT_DEFINED”.
10 11 12 |
# File 'lib/hubspot_sdk/models/association_spec.rb', line 10 required :association_category, enum: -> { HubSpotSDK::AssociationSpec::AssociationCategory }, api_name: :associationCategory |
#association_type_id ⇒ Integer
The ID representing the specific type of association.
18 |
# File 'lib/hubspot_sdk/models/association_spec.rb', line 18 required :association_type_id, Integer, api_name: :associationTypeId |