Class: HubSpotSDK::Models::Automation::ActionExecutionIndexIdentifier

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/automation/action_execution_index_identifier.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(action_execution_index:, enrollment_id:) ⇒ Object

Parameters:

  • action_execution_index (Integer)

    The index number representing the execution order of the action.

  • enrollment_id (Integer)

    The ID associated with the enrollment process.



# File 'lib/hubspot_sdk/models/automation/action_execution_index_identifier.rb', line 19

Instance Attribute Details

#action_execution_indexInteger

The index number representing the execution order of the action.

Returns:

  • (Integer)


11
# File 'lib/hubspot_sdk/models/automation/action_execution_index_identifier.rb', line 11

required :action_execution_index, Integer, api_name: :actionExecutionIndex

#enrollment_idInteger

The ID associated with the enrollment process.

Returns:

  • (Integer)


17
# File 'lib/hubspot_sdk/models/automation/action_execution_index_identifier.rb', line 17

required :enrollment_id, Integer, api_name: :enrollmentId