Class: HubSpotSDK::Models::Automation::AgentRequestContext

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/automation/agent_request_context.rb

Defined Under Namespace

Modules: Source

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_id:, chirp_ai_context_object:, source:, trajectory_id: nil) ⇒ Object

Parameters:



# File 'lib/hubspot_sdk/models/automation/agent_request_context.rb', line 32

Instance Attribute Details

#agent_idInteger

The unique identifier for the agent making the request.

Returns:

  • (Integer)


11
# File 'lib/hubspot_sdk/models/automation/agent_request_context.rb', line 11

required :agent_id, Integer, api_name: :agentId

#chirp_ai_context_objectHubSpotSDK::Models::Automation::ChirpAIContextObject



16
17
18
# File 'lib/hubspot_sdk/models/automation/agent_request_context.rb', line 16

required :chirp_ai_context_object,
-> { HubSpotSDK::Automation::ChirpAIContextObject },
api_name: :chirpAiContextObject

#sourceSymbol, HubSpotSDK::Models::Automation::AgentRequestContext::Source

Indicates the source of the request, with the default value being ‘AGENTS’.



24
# File 'lib/hubspot_sdk/models/automation/agent_request_context.rb', line 24

required :source, enum: -> { HubSpotSDK::Automation::AgentRequestContext::Source }

#trajectory_idString?

The unique identifier for the trajectory associated with the agent request.

Returns:

  • (String, nil)


30
# File 'lib/hubspot_sdk/models/automation/agent_request_context.rb', line 30

optional :trajectory_id, String, api_name: :trajectoryId