Class: HubSpotSDK::Models::Automation::ArrayFieldSchema
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::ArrayFieldSchema
- Defined in:
- lib/hubspot_sdk/models/automation/array_field_schema.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#items ⇒ HubSpotSDK::Models::Automation::IntegerFieldSchema, ...
Defines the type of elements contained within the array, which can be an integer, long, double, string, boolean, another array, or an object.
-
#type ⇒ Symbol, HubSpotSDK::Models::Automation::ArrayFieldSchema::Type
Specifies that the field is of type ‘ARRAY’.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(items:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ArrayFieldSchema for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(items:, type:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Automation::ArrayFieldSchema for more details.
|
|
# File 'lib/hubspot_sdk/models/automation/array_field_schema.rb', line 20
|
Instance Attribute Details
#items ⇒ HubSpotSDK::Models::Automation::IntegerFieldSchema, ...
Defines the type of elements contained within the array, which can be an integer, long, double, string, boolean, another array, or an object.
12 |
# File 'lib/hubspot_sdk/models/automation/array_field_schema.rb', line 12 required :items, union: -> { HubSpotSDK::Automation::ArrayFieldSchema::Items } |
#type ⇒ Symbol, HubSpotSDK::Models::Automation::ArrayFieldSchema::Type
Specifies that the field is of type ‘ARRAY’.
18 |
# File 'lib/hubspot_sdk/models/automation/array_field_schema.rb', line 18 required :type, enum: -> { HubSpotSDK::Automation::ArrayFieldSchema::Type } |
Class Method Details
.variants ⇒ Array(HubSpotSDK::Models::Automation::IntegerFieldSchema, HubSpotSDK::Models::Automation::LongFieldSchema, HubSpotSDK::Models::Automation::DoubleFieldSchema, HubSpotSDK::Models::Automation::StringFieldSchema, HubSpotSDK::Models::Automation::BooleanFieldSchema, HubSpotSDK::Models::Automation::ArrayFieldSchema, HubSpotSDK::Models::Automation::ObjectFieldSchema)
|
|
# File 'lib/hubspot_sdk/models/automation/array_field_schema.rb', line 49
|