Class: HubSpotSDK::Models::Automation::BooleanFieldSchema
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::BooleanFieldSchema
- Defined in:
- lib/hubspot_sdk/models/automation/boolean_field_schema.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#type ⇒ Symbol, HubSpotSDK::Models::Automation::BooleanFieldSchema::Type
Specifies the field type as BOOLEAN, indicating that the field can hold a true or false value.
Instance Method Summary collapse
-
#initialize(type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BooleanFieldSchema for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Automation::BooleanFieldSchema for more details.
|
|
# File 'lib/hubspot_sdk/models/automation/boolean_field_schema.rb', line 14
|
Instance Attribute Details
#type ⇒ Symbol, HubSpotSDK::Models::Automation::BooleanFieldSchema::Type
Specifies the field type as BOOLEAN, indicating that the field can hold a true or false value.
12 |
# File 'lib/hubspot_sdk/models/automation/boolean_field_schema.rb', line 12 required :type, enum: -> { HubSpotSDK::Automation::BooleanFieldSchema::Type } |