Class: HubSpotSDK::Models::Automation::CallbackCompletionRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::CallbackCompletionRequest
- Defined in:
- lib/hubspot_sdk/models/automation/callback_completion_request.rb
Direct Known Subclasses
Defined Under Namespace
Modules: RequestContext
Instance Attribute Summary collapse
-
#failure_reason_type ⇒ String?
Indicates the reason for the failure of a callback completion.
-
#output_fields ⇒ Hash{Symbol=>String}
Contains the output fields associated with the callback, with each field represented as a key-value pair.
-
#request_context ⇒ HubSpotSDK::Models::Automation::WorkflowsRequestContext, ...
Specifies the context in which the request is made, which can be one of several predefined contexts.
-
#typed_outputs ⇒ Object
Holds the typed outputs related to the callback, structured as an object.
Instance Method Summary collapse
-
#initialize(output_fields:, typed_outputs:, failure_reason_type: nil, request_context: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CallbackCompletionRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(output_fields:, typed_outputs:, failure_reason_type: nil, request_context: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Automation::CallbackCompletionRequest for more details.
|
|
# File 'lib/hubspot_sdk/models/automation/callback_completion_request.rb', line 35
|
Instance Attribute Details
#failure_reason_type ⇒ String?
Indicates the reason for the failure of a callback completion.
24 |
# File 'lib/hubspot_sdk/models/automation/callback_completion_request.rb', line 24 optional :failure_reason_type, String, api_name: :failureReasonType |
#output_fields ⇒ Hash{Symbol=>String}
Contains the output fields associated with the callback, with each field represented as a key-value pair.
12 |
# File 'lib/hubspot_sdk/models/automation/callback_completion_request.rb', line 12 required :output_fields, HubSpotSDK::Internal::Type::HashOf[String], api_name: :outputFields |
#request_context ⇒ HubSpotSDK::Models::Automation::WorkflowsRequestContext, ...
Specifies the context in which the request is made, which can be one of several predefined contexts.
31 32 33 |
# File 'lib/hubspot_sdk/models/automation/callback_completion_request.rb', line 31 optional :request_context, union: -> { HubSpotSDK::Automation::CallbackCompletionRequest::RequestContext }, api_name: :requestContext |
#typed_outputs ⇒ Object
Holds the typed outputs related to the callback, structured as an object.
18 |
# File 'lib/hubspot_sdk/models/automation/callback_completion_request.rb', line 18 required :typed_outputs, HubSpotSDK::Internal::Type::Unknown, api_name: :typedOutputs |