Class: HubSpotSDK::Models::Automation::ChirpAIContextObject

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb

Defined Under Namespace

Modules: UnstructuredSource

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel

Instance Attribute Details

#application_groupString

The group to which the application belongs.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 11

required :application_group, String, api_name: :applicationGroup

#application_idString

The identifier for the application associated with the context.

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 17

required :application_id, String, api_name: :applicationId

#compliance_idsHubSpotSDK::Models::Automation::ComplianceIDs?



50
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 50

optional :compliance_ids, -> { HubSpotSDK::Automation::ComplianceIDs }, api_name: :complianceIds

#conversation_idString?

Returns:

  • (String, nil)


55
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 55

optional :conversation_id, String, api_name: :conversationId

#feature_idString?

The identifier for the feature associated with the context.

Returns:

  • (String, nil)


61
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 61

optional :feature_id, String, api_name: :featureId

#inference_idString?

The identifier for the inference associated with the context.

Returns:

  • (String, nil)


67
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 67

optional :inference_id, String, api_name: :inferenceId

#is_privateBoolean

Returns:

  • (Boolean)


22
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 22

required :is_private, HubSpotSDK::Internal::Type::Boolean, api_name: :isPrivate

#metadataHash{Symbol=>String}

Additional metadata related to the context, represented as key-value pairs.

Returns:

  • (Hash{Symbol=>String})


28
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 28

required :metadata, HubSpotSDK::Internal::Type::HashOf[String]

#otel_context_holderHash{Symbol=>String}

Holds OpenTelemetry context information as key-value pairs.

Returns:

  • (Hash{Symbol=>String})


34
35
36
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 34

required :otel_context_holder,
HubSpotSDK::Internal::Type::HashOf[String],
api_name: :otelContextHolder

#trajectory_idString?

The identifier for the trajectory, formatted as a UUID.

Returns:

  • (String, nil)


73
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 73

optional :trajectory_id, String, api_name: :trajectoryId

#unstructured_sourcesArray<Symbol, HubSpotSDK::Models::Automation::ChirpAIContextObject::UnstructuredSource>



41
42
43
44
45
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 41

required :unstructured_sources,
-> {
  HubSpotSDK::Internal::Type::ArrayOf[enum: HubSpotSDK::Automation::ChirpAIContextObject::UnstructuredSource]
},
api_name: :unstructuredSources