Module: HubSpotSDK::Models::Automation::ChirpAIContextObject::UnstructuredSource

Extended by:
Internal::Type::Enum
Defined in:
lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb

Constant Summary collapse

NONE =
:NONE
USER_INPUT =
:USER_INPUT
LOGGED_EMAIL =
:LOGGED_EMAIL
VIDEO_CALL =
:VIDEO_CALL
AUDIO_CALL =
:AUDIO_CALL
CALL_TRANSCRIPT =
:CALL_TRANSCRIPT
MEETING_TRANSCRIPT =
:MEETING_TRANSCRIPT
FORMS =
:FORMS
FEEDBACK_SURVEY =
:FEEDBACK_SURVEY
PDF =
:PDF
QUOTE =
:QUOTE
INVOICE =
:INVOICE
OTHER_ATTACHMENT_DOC =
:OTHER_ATTACHMENT_DOC
WHATSAPP =
:WHATSAPP
SMS =
:SMS
CHAT =
:CHAT
FACEBOOK_MESSENGER =
:FACEBOOK_MESSENGER
CUSTOM_CHANNEL_OR_API =
:CUSTOM_CHANNEL_OR_API
MANY =
:MANY
NOTE =
:NOTE
DERIVED =
:DERIVED

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 109

Instance Method Details

#initialize(application_group:, application_id:, metadata:, otel_context_holder:, unstructured_sources:, compliance_ids: nil, feature_id: nil, inference_id: nil, trajectory_id: nil) ⇒ Object

Parameters:

  • application_group (String)

    The group to which the application belongs.

  • application_id (String)

    The identifier for the application associated with the context.

  • metadata (Hash{Symbol=>String})

    Additional metadata related to the context, represented as key-value pairs.

  • otel_context_holder (Hash{Symbol=>String})

    Holds OpenTelemetry context information as key-value pairs.

  • unstructured_sources (Array<Symbol, HubSpotSDK::Models::Automation::ChirpAIContextObject::UnstructuredSource>)
  • compliance_ids (HubSpotSDK::Models::Automation::ComplianceIDs) (defaults to: nil)
  • feature_id (String) (defaults to: nil)

    The identifier for the feature associated with the context.

  • inference_id (String) (defaults to: nil)

    The identifier for the inference associated with the context.

  • trajectory_id (String) (defaults to: nil)

    The identifier for the trajectory, formatted as a UUID.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 84

module UnstructuredSource
  extend HubSpotSDK::Internal::Type::Enum

  NONE = :NONE
  USER_INPUT = :USER_INPUT
  LOGGED_EMAIL = :LOGGED_EMAIL
  VIDEO_CALL = :VIDEO_CALL
  AUDIO_CALL = :AUDIO_CALL
  CALL_TRANSCRIPT = :CALL_TRANSCRIPT
  MEETING_TRANSCRIPT = :MEETING_TRANSCRIPT
  FORMS = :FORMS
  FEEDBACK_SURVEY = :FEEDBACK_SURVEY
  PDF = :PDF
  QUOTE = :QUOTE
  INVOICE = :INVOICE
  OTHER_ATTACHMENT_DOC = :OTHER_ATTACHMENT_DOC
  WHATSAPP = :WHATSAPP
  SMS = :SMS
  CHAT = :CHAT
  FACEBOOK_MESSENGER = :FACEBOOK_MESSENGER
  CUSTOM_CHANNEL_OR_API = :CUSTOM_CHANNEL_OR_API
  MANY = :MANY
  NOTE = :NOTE
  DERIVED = :DERIVED

  # @!method self.values
  #   @return [Array<Symbol>]
end