Class: HubSpotSDK::Models::Automation::FieldTypeDefinition

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/automation/field_type_definition.rb

Defined Under Namespace

Modules: FieldType, ReferencedObjectType, Schema, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(external_options:, name:, options:, schema:, type:, use_chirp:, description: nil, external_options_reference_type: nil, field_type: nil, help_text: nil, label: nil, options_url: nil, referenced_object_type: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Automation::FieldTypeDefinition for more details.

Parameters:



# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 92

Instance Attribute Details

#descriptionString?

A detailed explanation of the field’s purpose and usage.

Returns:

  • (String, nil)


47
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 47

optional :description, String

#external_optionsBoolean

Indicates whether the field’s options are sourced externally.

Returns:

  • (Boolean)


11
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 11

required :external_options, HubSpotSDK::Internal::Type::Boolean, api_name: :externalOptions

#external_options_reference_typeString?

Specifies the type of external reference for options.

Returns:

  • (String, nil)


53
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 53

optional :external_options_reference_type, String, api_name: :externalOptionsReferenceType

#field_typeSymbol, ...

Describes the field’s type in the UI, with accepted values like booleancheckbox, calculation_equation, checkbox, date, file, html, number, phonenumber, radio, select, text, textarea, unknown.



61
62
63
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 61

optional :field_type,
enum: -> { HubSpotSDK::Automation::FieldTypeDefinition::FieldType },
api_name: :fieldType

#help_textString?

Additional information or guidance about the field.

Returns:

  • (String, nil)


69
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 69

optional :help_text, String, api_name: :helpText

#labelString?

The user-friendly label for the field.

Returns:

  • (String, nil)


75
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 75

optional :label, String

#nameString

The unique identifier for the field.

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 17

required :name, String

#optionsArray<HubSpotSDK::Models::AutomationActionsOption>



22
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 22

required :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::AutomationActionsOption] }

#options_urlString?

A URL that provides options for the field.

Returns:

  • (String, nil)


81
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 81

optional :options_url, String, api_name: :optionsUrl

#referenced_object_typeSymbol, ...

Indicates the type of object that the field references, with accepted values like OWNER.



88
89
90
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 88

optional :referenced_object_type,
enum: -> { HubSpotSDK::Automation::FieldTypeDefinition::ReferencedObjectType },
api_name: :referencedObjectType

#typeSymbol, HubSpotSDK::Models::Automation::FieldTypeDefinition::Type

Specifies the data type of the field, with accepted values like bool, date, datetime, enumeration, json, number, object_coordinates, phone_number, string.



35
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 35

required :type, enum: -> { HubSpotSDK::Automation::FieldTypeDefinition::Type }

#use_chirpBoolean

Specifies whether the field uses the Chirp feature.

Returns:

  • (Boolean)


41
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 41

required :use_chirp, HubSpotSDK::Internal::Type::Boolean, api_name: :useChirp