Class: HubSpotSDK::Models::Automation::ObjectFieldSchema
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::ObjectFieldSchema
- Defined in:
- lib/hubspot_sdk/models/automation/object_field_schema.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#properties ⇒ Object
Contains the properties of the object.
-
#type ⇒ Symbol, HubSpotSDK::Models::Automation::ObjectFieldSchema::Type
Specifies the type of the field, which is ‘OBJECT’ by default.
Instance Method Summary collapse
- #initialize(properties:, type:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(properties:, type:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/automation/object_field_schema.rb', line 19
|
Instance Attribute Details
#properties ⇒ Object
Contains the properties of the object.
11 |
# File 'lib/hubspot_sdk/models/automation/object_field_schema.rb', line 11 required :properties, HubSpotSDK::Internal::Type::Unknown |
#type ⇒ Symbol, HubSpotSDK::Models::Automation::ObjectFieldSchema::Type
Specifies the type of the field, which is ‘OBJECT’ by default.
17 |
# File 'lib/hubspot_sdk/models/automation/object_field_schema.rb', line 17 required :type, enum: -> { HubSpotSDK::Automation::ObjectFieldSchema::Type } |