Class: HubSpotSDK::Models::Automation::PublicActionFunction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/automation/public_action_function.rb

Defined Under Namespace

Modules: FunctionType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(function_source:, function_type:, id: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Automation::PublicActionFunction for more details.

Parameters:

  • function_source (String)

    The source code or script that defines the function’s behavior.

  • function_type (Symbol, HubSpotSDK::Models::Automation::PublicActionFunction::FunctionType)

    The type of function, with accepted values: POST_ACTION_EXECUTION, POST_FETCH_OP

  • id (String) (defaults to: nil)

    The unique identifier for the action function.



# File 'lib/hubspot_sdk/models/automation/public_action_function.rb', line 28

Instance Attribute Details

#function_sourceString

The source code or script that defines the function’s behavior.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/automation/public_action_function.rb', line 11

required :function_source, String, api_name: :functionSource

#function_typeSymbol, HubSpotSDK::Models::Automation::PublicActionFunction::FunctionType

The type of function, with accepted values: POST_ACTION_EXECUTION, POST_FETCH_OPTIONS, PRE_ACTION_EXECUTION, PRE_FETCH_OPTIONS.



18
19
20
# File 'lib/hubspot_sdk/models/automation/public_action_function.rb', line 18

required :function_type,
enum: -> { HubSpotSDK::Automation::PublicActionFunction::FunctionType },
api_name: :functionType

#idString?

The unique identifier for the action function.

Returns:

  • (String, nil)


26
# File 'lib/hubspot_sdk/models/automation/public_action_function.rb', line 26

optional :id, String