Class: HubSpotSDK::Models::Automation::PublicConditionalSingleFieldDependency
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::PublicConditionalSingleFieldDependency
- Defined in:
- lib/hubspot_sdk/models/automation/public_conditional_single_field_dependency.rb
Defined Under Namespace
Modules: DependencyType
Instance Attribute Summary collapse
-
#controlling_field_name ⇒ String
The name of the field that determines the dependency.
-
#controlling_field_value ⇒ String
The value of the controlling field that triggers the dependency.
-
#dependency_type ⇒ Symbol, HubSpotSDK::Models::Automation::PublicConditionalSingleFieldDependency::DependencyType
The type of dependency, with the default value being CONDITIONAL_SINGLE_FIELD.
- #dependent_field_names ⇒ Array<String>
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(controlling_field_name:, controlling_field_value:, dependency_type:, dependent_field_names:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/automation/public_conditional_single_field_dependency.rb', line 34
|
Instance Attribute Details
#controlling_field_name ⇒ String
The name of the field that determines the dependency.
11 |
# File 'lib/hubspot_sdk/models/automation/public_conditional_single_field_dependency.rb', line 11 required :controlling_field_name, String, api_name: :controllingFieldName |
#controlling_field_value ⇒ String
The value of the controlling field that triggers the dependency.
17 |
# File 'lib/hubspot_sdk/models/automation/public_conditional_single_field_dependency.rb', line 17 required :controlling_field_value, String, api_name: :controllingFieldValue |
#dependency_type ⇒ Symbol, HubSpotSDK::Models::Automation::PublicConditionalSingleFieldDependency::DependencyType
The type of dependency, with the default value being CONDITIONAL_SINGLE_FIELD.
23 24 25 |
# File 'lib/hubspot_sdk/models/automation/public_conditional_single_field_dependency.rb', line 23 required :dependency_type, enum: -> { HubSpotSDK::Automation::PublicConditionalSingleFieldDependency::DependencyType }, api_name: :dependencyType |
#dependent_field_names ⇒ Array<String>
30 31 32 |
# File 'lib/hubspot_sdk/models/automation/public_conditional_single_field_dependency.rb', line 30 required :dependent_field_names, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :dependentFieldNames |