Class: HubSpotSDK::Models::Automation::PublicEmailPatternResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/automation/public_email_pattern_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, template_id:, updated_at:, thread_email_to_step_order: nil) ⇒ Object

Parameters:

  • id (String)

    The unique identifier of the email pattern.

  • created_at (Time)

    The date and time when the email pattern was created.

  • template_id (String)

    The unique identifier of the email template associated with the pattern.

  • updated_at (Time)

    The date and time when the email pattern was last updated.

  • thread_email_to_step_order (Integer) (defaults to: nil)

    The order identifying the previous step to which the email thread is linked.



# File 'lib/hubspot_sdk/models/automation/public_email_pattern_response.rb', line 37

Instance Attribute Details

#created_atTime

The date and time when the email pattern was created.

Returns:

  • (Time)


17
# File 'lib/hubspot_sdk/models/automation/public_email_pattern_response.rb', line 17

required :created_at, Time, api_name: :createdAt

#idString

The unique identifier of the email pattern.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/automation/public_email_pattern_response.rb', line 11

required :id, String

#template_idString

The unique identifier of the email template associated with the pattern.

Returns:

  • (String)


23
# File 'lib/hubspot_sdk/models/automation/public_email_pattern_response.rb', line 23

required :template_id, String, api_name: :templateId

#thread_email_to_step_orderInteger?

The order identifying the previous step to which the email thread is linked.

Returns:

  • (Integer, nil)


35
# File 'lib/hubspot_sdk/models/automation/public_email_pattern_response.rb', line 35

optional :thread_email_to_step_order, Integer, api_name: :threadEmailToStepOrder

#updated_atTime

The date and time when the email pattern was last updated.

Returns:

  • (Time)


29
# File 'lib/hubspot_sdk/models/automation/public_email_pattern_response.rb', line 29

required :updated_at, Time, api_name: :updatedAt