Class: HubSpotSDK::Models::Automation::PublicFieldTypeDefinition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::PublicFieldTypeDefinition
- Defined in:
- lib/hubspot_sdk/models/automation/public_field_type_definition.rb
Defined Under Namespace
Modules: FieldType, ReferencedObjectType, Type
Instance Attribute Summary collapse
-
#description ⇒ String?
A detailed explanation of the field’s purpose.
-
#field_type ⇒ Symbol, ...
The type of field, with accepted values including booleancheckbox, calculation_equation, checkbox, date, file, html, number, phonenumber, radio, select, text, and textarea.
-
#help_text ⇒ String?
Additional information or guidance about the field.
-
#label ⇒ String?
A user-friendly name for the field.
-
#name ⇒ String
The internal name used to identify the field.
- #options ⇒ Array<HubSpotSDK::Models::Automation::PublicOption>
-
#options_url ⇒ String?
A URL that provides options for the field.
-
#referenced_object_type ⇒ Symbol, ...
The type of object that the field references, with accepted values including OWNER.
-
#type ⇒ Symbol, HubSpotSDK::Models::Automation::PublicFieldTypeDefinition::Type
The data type of the field, with accepted values including bool, date, datetime, enumeration, json, number, object_coordinates, phone_number, and string.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name:, options:, type:, description: nil, field_type: nil, help_text: nil, label: nil, options_url: nil, referenced_object_type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicFieldTypeDefinition for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, options:, type:, description: nil, field_type: nil, help_text: nil, label: nil, options_url: nil, referenced_object_type: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Automation::PublicFieldTypeDefinition for more details.
|
|
# File 'lib/hubspot_sdk/models/automation/public_field_type_definition.rb', line 68
|
Instance Attribute Details
#description ⇒ String?
A detailed explanation of the field’s purpose.
29 |
# File 'lib/hubspot_sdk/models/automation/public_field_type_definition.rb', line 29 optional :description, String |
#field_type ⇒ Symbol, ...
The type of field, with accepted values including booleancheckbox, calculation_equation, checkbox, date, file, html, number, phonenumber, radio, select, text, and textarea.
37 38 39 |
# File 'lib/hubspot_sdk/models/automation/public_field_type_definition.rb', line 37 optional :field_type, enum: -> { HubSpotSDK::Automation::PublicFieldTypeDefinition::FieldType }, api_name: :fieldType |
#help_text ⇒ String?
Additional information or guidance about the field.
45 |
# File 'lib/hubspot_sdk/models/automation/public_field_type_definition.rb', line 45 optional :help_text, String, api_name: :helpText |
#label ⇒ String?
A user-friendly name for the field.
51 |
# File 'lib/hubspot_sdk/models/automation/public_field_type_definition.rb', line 51 optional :label, String |
#name ⇒ String
The internal name used to identify the field.
11 |
# File 'lib/hubspot_sdk/models/automation/public_field_type_definition.rb', line 11 required :name, String |
#options ⇒ Array<HubSpotSDK::Models::Automation::PublicOption>
16 |
# File 'lib/hubspot_sdk/models/automation/public_field_type_definition.rb', line 16 required :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Automation::PublicOption] } |
#options_url ⇒ String?
A URL that provides options for the field.
57 |
# File 'lib/hubspot_sdk/models/automation/public_field_type_definition.rb', line 57 optional :options_url, String, api_name: :optionsUrl |
#referenced_object_type ⇒ Symbol, ...
The type of object that the field references, with accepted values including OWNER.
64 65 66 |
# File 'lib/hubspot_sdk/models/automation/public_field_type_definition.rb', line 64 optional :referenced_object_type, enum: -> { HubSpotSDK::Automation::PublicFieldTypeDefinition::ReferencedObjectType }, api_name: :referencedObjectType |
#type ⇒ Symbol, HubSpotSDK::Models::Automation::PublicFieldTypeDefinition::Type
The data type of the field, with accepted values including bool, date, datetime, enumeration, json, number, object_coordinates, phone_number, and string.
23 |
# File 'lib/hubspot_sdk/models/automation/public_field_type_definition.rb', line 23 required :type, enum: -> { HubSpotSDK::Automation::PublicFieldTypeDefinition::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/automation/public_field_type_definition.rb', line 107
|