Class: HubSpotSDK::Models::Automation::PublicOption
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::PublicOption
- Defined in:
- lib/hubspot_sdk/models/automation/public_option.rb
Instance Attribute Summary collapse
-
#description ⇒ String?
A description of the option.
-
#display_order ⇒ Integer?
The position of the option relative to others in the list.
-
#label ⇒ String
A user-friendly label that identifies the option.
-
#value ⇒ String
The actual value of the option.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(label:, value:, description: nil, display_order: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/automation/public_option.rb', line 31
|
Instance Attribute Details
#description ⇒ String?
A description of the option.
23 |
# File 'lib/hubspot_sdk/models/automation/public_option.rb', line 23 optional :description, String |
#display_order ⇒ Integer?
The position of the option relative to others in the list.
29 |
# File 'lib/hubspot_sdk/models/automation/public_option.rb', line 29 optional :display_order, Integer, api_name: :displayOrder |
#label ⇒ String
A user-friendly label that identifies the option.
11 |
# File 'lib/hubspot_sdk/models/automation/public_option.rb', line 11 required :label, String |
#value ⇒ String
The actual value of the option.
17 |
# File 'lib/hubspot_sdk/models/automation/public_option.rb', line 17 required :value, String |