Class: HubSpotSDK::Models::Automation::PublicSequenceEnrollmentLiteResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/automation/public_sequence_enrollment_lite_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, enrolled_at:, to_email:, updated_at:) ⇒ Object

Parameters:

  • id (String)

    The unique identifier for the sequence enrollment.

  • enrolled_at (Time)

    The date and time when the contact was enrolled in the sequence.

  • to_email (String)

    The email address of the contact enrolled in the sequence.

  • updated_at (Time)

    The date and time when the sequence enrollment was last updated.



# File 'lib/hubspot_sdk/models/automation/public_sequence_enrollment_lite_response.rb', line 32

Instance Attribute Details

#enrolled_atTime

The date and time when the contact was enrolled in the sequence.

Returns:

  • (Time)


18
# File 'lib/hubspot_sdk/models/automation/public_sequence_enrollment_lite_response.rb', line 18

required :enrolled_at, Time, api_name: :enrolledAt

#idString

The unique identifier for the sequence enrollment.

Returns:

  • (String)


12
# File 'lib/hubspot_sdk/models/automation/public_sequence_enrollment_lite_response.rb', line 12

required :id, String

#to_emailString

The email address of the contact enrolled in the sequence.

Returns:

  • (String)


24
# File 'lib/hubspot_sdk/models/automation/public_sequence_enrollment_lite_response.rb', line 24

required :to_email, String, api_name: :toEmail

#updated_atTime

The date and time when the sequence enrollment was last updated.

Returns:

  • (Time)


30
# File 'lib/hubspot_sdk/models/automation/public_sequence_enrollment_lite_response.rb', line 30

required :updated_at, Time, api_name: :updatedAt