Class: HubSpotSDK::Models::Automation::PublicSequenceEnrollmentRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/automation/public_sequence_enrollment_request.rb

Direct Known Subclasses

SequenceCreateEnrollmentParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(contact_id:, sender_email:, sequence_id:, sender_alias_address: nil) ⇒ Object

Parameters:

  • contact_id (String)

    The unique identifier of the contact to be enrolled in the sequence.

  • sender_email (String)

    The email address of the sender enrolling the contact in the sequence.

  • sequence_id (String)

    The unique identifier of the sequence in which the contact will be enrolled.

  • sender_alias_address (String) (defaults to: nil)

    The alias email address used by the sender when enrolling the contact.



# File 'lib/hubspot_sdk/models/automation/public_sequence_enrollment_request.rb', line 31

Instance Attribute Details

#contact_idString

The unique identifier of the contact to be enrolled in the sequence.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/automation/public_sequence_enrollment_request.rb', line 11

required :contact_id, String, api_name: :contactId

#sender_alias_addressString?

The alias email address used by the sender when enrolling the contact.

Returns:

  • (String, nil)


29
# File 'lib/hubspot_sdk/models/automation/public_sequence_enrollment_request.rb', line 29

optional :sender_alias_address, String, api_name: :senderAliasAddress

#sender_emailString

The email address of the sender enrolling the contact in the sequence.

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/automation/public_sequence_enrollment_request.rb', line 17

required :sender_email, String, api_name: :senderEmail

#sequence_idString

The unique identifier of the sequence in which the contact will be enrolled.

Returns:

  • (String)


23
# File 'lib/hubspot_sdk/models/automation/public_sequence_enrollment_request.rb', line 23

required :sequence_id, String, api_name: :sequenceId