Class: HubSpotSDK::Models::Automation::PublicSequenceLiteResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/automation/public_sequence_lite_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, name:, updated_at:, user_id:, folder_id: nil) ⇒ Object

Parameters:

  • id (String)

    The unique identifier of the sequence.

  • created_at (Time)

    The date and time when the sequence was created.

  • name (String)

    The name of the sequence.

  • updated_at (Time)

    The date and time when the sequence was last updated.

  • user_id (String)

    The ID of the user associated with the sequence.

  • folder_id (String) (defaults to: nil)

    The ID of the folder containing the sequence.



# File 'lib/hubspot_sdk/models/automation/public_sequence_lite_response.rb', line 44

Instance Attribute Details

#created_atTime

The date and time when the sequence was created.

Returns:

  • (Time)


18
# File 'lib/hubspot_sdk/models/automation/public_sequence_lite_response.rb', line 18

required :created_at, Time, api_name: :createdAt

#folder_idString?

The ID of the folder containing the sequence.

Returns:

  • (String, nil)


42
# File 'lib/hubspot_sdk/models/automation/public_sequence_lite_response.rb', line 42

optional :folder_id, String, api_name: :folderId

#idString

The unique identifier of the sequence.

Returns:

  • (String)


12
# File 'lib/hubspot_sdk/models/automation/public_sequence_lite_response.rb', line 12

required :id, String

#nameString

The name of the sequence.

Returns:

  • (String)


24
# File 'lib/hubspot_sdk/models/automation/public_sequence_lite_response.rb', line 24

required :name, String

#updated_atTime

The date and time when the sequence was last updated.

Returns:

  • (Time)


30
# File 'lib/hubspot_sdk/models/automation/public_sequence_lite_response.rb', line 30

required :updated_at, Time, api_name: :updatedAt

#user_idString

The ID of the user associated with the sequence.

Returns:

  • (String)


36
# File 'lib/hubspot_sdk/models/automation/public_sequence_lite_response.rb', line 36

required :user_id, String, api_name: :userId