Class: HubSpotSDK::Models::Automation::PublicSequenceSettingsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/automation/public_sequence_settings_response.rb

Defined Under Namespace

Modules: EligibleFollowUpDays, SellingStrategy

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, eligible_follow_up_days:, individual_task_reminders_enabled:, selling_strategy:, send_window_end_minute:, send_window_start_minute:, task_reminder_minute:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Automation::PublicSequenceSettingsResponse for more details.

Parameters:

  • id (String)

    The unique identifier for the sequence settings.

  • created_at (Time)

    The timestamp of when the sequence settings were created.

  • eligible_follow_up_days (Symbol, HubSpotSDK::Models::Automation::PublicSequenceSettingsResponse::EligibleFollowUpDays)

    Specifies the days on which follow-up actions are allowed.

  • individual_task_reminders_enabled (Boolean)

    Indicates whether individual task reminders are enabled.

  • selling_strategy (Symbol, HubSpotSDK::Models::Automation::PublicSequenceSettingsResponse::SellingStrategy)

    (deprecated) Defines the unenrollment strategy, with accepted values being ACCOU

  • send_window_end_minute (Integer)

    Indicates the end minute of the time window during which automated emails can be

  • send_window_start_minute (Integer)

    Indicates the start minute of the time window during which automated emails can

  • task_reminder_minute (Integer)

    Specifies the minute of day at which task reminders are triggered.

  • updated_at (Time)

    The timestamp of when the sequence settings were last updated.



# File 'lib/hubspot_sdk/models/automation/public_sequence_settings_response.rb', line 72

Instance Attribute Details

#created_atTime

The timestamp of when the sequence settings were created.

Returns:

  • (Time)


17
# File 'lib/hubspot_sdk/models/automation/public_sequence_settings_response.rb', line 17

required :created_at, Time, api_name: :createdAt

#eligible_follow_up_daysSymbol, HubSpotSDK::Models::Automation::PublicSequenceSettingsResponse::EligibleFollowUpDays

Specifies the days on which follow-up actions are allowed.



23
24
25
# File 'lib/hubspot_sdk/models/automation/public_sequence_settings_response.rb', line 23

required :eligible_follow_up_days,
enum: -> { HubSpotSDK::Automation::PublicSequenceSettingsResponse::EligibleFollowUpDays },
api_name: :eligibleFollowUpDays

#idString

The unique identifier for the sequence settings.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/automation/public_sequence_settings_response.rb', line 11

required :id, String

#individual_task_reminders_enabledBoolean

Indicates whether individual task reminders are enabled.

Returns:

  • (Boolean)


31
32
33
# File 'lib/hubspot_sdk/models/automation/public_sequence_settings_response.rb', line 31

required :individual_task_reminders_enabled,
HubSpotSDK::Internal::Type::Boolean,
api_name: :individualTaskRemindersEnabled

#selling_strategySymbol, HubSpotSDK::Models::Automation::PublicSequenceSettingsResponse::SellingStrategy

(deprecated) Defines the unenrollment strategy, with accepted values being ACCOUNT_BASED or LEAD_BASED. If ACCOUNT_BASED is used, all contacts associated with the same company will be unenrolled if one contact meets any of the unenrollment criteria.



42
43
44
# File 'lib/hubspot_sdk/models/automation/public_sequence_settings_response.rb', line 42

required :selling_strategy,
enum: -> { HubSpotSDK::Automation::PublicSequenceSettingsResponse::SellingStrategy },
api_name: :sellingStrategy

#send_window_end_minuteInteger

Indicates the end minute of the time window during which automated emails can be sent.

Returns:

  • (Integer)


51
# File 'lib/hubspot_sdk/models/automation/public_sequence_settings_response.rb', line 51

required :send_window_end_minute, Integer, api_name: :sendWindowEndMinute

#send_window_start_minuteInteger

Indicates the start minute of the time window during which automated emails can be sent.

Returns:

  • (Integer)


58
# File 'lib/hubspot_sdk/models/automation/public_sequence_settings_response.rb', line 58

required :send_window_start_minute, Integer, api_name: :sendWindowStartMinute

#task_reminder_minuteInteger

Specifies the minute of day at which task reminders are triggered.

Returns:

  • (Integer)


64
# File 'lib/hubspot_sdk/models/automation/public_sequence_settings_response.rb', line 64

required :task_reminder_minute, Integer, api_name: :taskReminderMinute

#updated_atTime

The timestamp of when the sequence settings were last updated.

Returns:

  • (Time)


70
# File 'lib/hubspot_sdk/models/automation/public_sequence_settings_response.rb', line 70

required :updated_at, Time, api_name: :updatedAt

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/automation/public_sequence_settings_response.rb', line 105