Class: HubSpotSDK::Models::Automation::PublicSequenceStepDependencyResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::PublicSequenceStepDependencyResponse
- Defined in:
- lib/hubspot_sdk/models/automation/public_sequence_step_dependency_response.rb
Defined Under Namespace
Modules: DependencyType
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time when the step dependency was created.
-
#dependency_type ⇒ Symbol, HubSpotSDK::Models::Automation::PublicSequenceStepDependencyResponse::DependencyType
The type of dependency between sequence steps with accepted values being TASK_COMPLETION or MANUAL_PAUSE.
-
#id ⇒ String
The unique identifier of the step dependency.
-
#relies_on_sequence_step_id ⇒ String
The unique identifier of the sequence step that is responsible for creating and resolving this dependency.
-
#relies_on_step_order ⇒ Integer
The order number of the step that is responsible for creating and resolving this dependency.
-
#required_by_sequence_step_id ⇒ String
The unique identifier of the sequence step that requires this dependency.
-
#required_by_step_order ⇒ Integer
The order number of the step that requires this dependency.
-
#updated_at ⇒ Time
The date and time when the step dependency was last updated.
Instance Method Summary collapse
-
#initialize(id:, created_at:, dependency_type:, relies_on_sequence_step_id:, relies_on_step_order:, required_by_sequence_step_id:, required_by_step_order:, updated_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicSequenceStepDependencyResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, dependency_type:, relies_on_sequence_step_id:, relies_on_step_order:, required_by_sequence_step_id:, required_by_step_order:, updated_at:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Automation::PublicSequenceStepDependencyResponse for more details.
|
|
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_dependency_response.rb', line 60
|
Instance Attribute Details
#created_at ⇒ Time
The date and time when the step dependency was created.
17 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_dependency_response.rb', line 17 required :created_at, Time, api_name: :createdAt |
#dependency_type ⇒ Symbol, HubSpotSDK::Models::Automation::PublicSequenceStepDependencyResponse::DependencyType
The type of dependency between sequence steps with accepted values being TASK_COMPLETION or MANUAL_PAUSE.
24 25 26 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_dependency_response.rb', line 24 required :dependency_type, enum: -> { HubSpotSDK::Automation::PublicSequenceStepDependencyResponse::DependencyType }, api_name: :dependencyType |
#id ⇒ String
The unique identifier of the step dependency.
11 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_dependency_response.rb', line 11 required :id, String |
#relies_on_sequence_step_id ⇒ String
The unique identifier of the sequence step that is responsible for creating and resolving this dependency.
33 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_dependency_response.rb', line 33 required :relies_on_sequence_step_id, String, api_name: :reliesOnSequenceStepId |
#relies_on_step_order ⇒ Integer
The order number of the step that is responsible for creating and resolving this dependency.
40 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_dependency_response.rb', line 40 required :relies_on_step_order, Integer, api_name: :reliesOnStepOrder |
#required_by_sequence_step_id ⇒ String
The unique identifier of the sequence step that requires this dependency.
46 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_dependency_response.rb', line 46 required :required_by_sequence_step_id, String, api_name: :requiredBySequenceStepId |
#required_by_step_order ⇒ Integer
The order number of the step that requires this dependency.
52 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_dependency_response.rb', line 52 required :required_by_step_order, Integer, api_name: :requiredByStepOrder |
#updated_at ⇒ Time
The date and time when the step dependency was last updated.
58 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_dependency_response.rb', line 58 required :updated_at, Time, api_name: :updatedAt |