Class: HubSpotSDK::Models::Automation::PublicSequenceStepResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::PublicSequenceStepResponse
- Defined in:
- lib/hubspot_sdk/models/automation/public_sequence_step_response.rb
Defined Under Namespace
Modules: ActionType
Instance Attribute Summary collapse
-
#action_type ⇒ Symbol, HubSpotSDK::Models::Automation::PublicSequenceStepResponse::ActionType
The type of action to be performed in the sequence step.
-
#created_at ⇒ Time
The date and time when the sequence step was created.
-
#delay_millis ⇒ Integer
The delay in milliseconds before the sequence step is executed.
- #email_pattern ⇒ HubSpotSDK::Models::Automation::PublicEmailPatternResponse?
-
#id ⇒ String
The unique identifier of the sequence step.
-
#step_order ⇒ Integer
The order of the step within the sequence.
- #task_pattern ⇒ HubSpotSDK::Models::Automation::PublicTaskPatternResponse?
-
#updated_at ⇒ Time
The date and time when the sequence step was last updated.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, action_type:, created_at:, delay_millis:, step_order:, updated_at:, email_pattern: nil, task_pattern: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_response.rb', line 61
|
Instance Attribute Details
#action_type ⇒ Symbol, HubSpotSDK::Models::Automation::PublicSequenceStepResponse::ActionType
The type of action to be performed in the sequence step.
17 18 19 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_response.rb', line 17 required :action_type, enum: -> { HubSpotSDK::Automation::PublicSequenceStepResponse::ActionType }, api_name: :actionType |
#created_at ⇒ Time
The date and time when the sequence step was created.
25 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_response.rb', line 25 required :created_at, Time, api_name: :createdAt |
#delay_millis ⇒ Integer
The delay in milliseconds before the sequence step is executed.
31 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_response.rb', line 31 required :delay_millis, Integer, api_name: :delayMillis |
#email_pattern ⇒ HubSpotSDK::Models::Automation::PublicEmailPatternResponse?
48 49 50 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_response.rb', line 48 optional :email_pattern, -> { HubSpotSDK::Automation::PublicEmailPatternResponse }, api_name: :emailPattern |
#id ⇒ String
The unique identifier of the sequence step.
11 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_response.rb', line 11 required :id, String |
#step_order ⇒ Integer
The order of the step within the sequence.
37 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_response.rb', line 37 required :step_order, Integer, api_name: :stepOrder |
#task_pattern ⇒ HubSpotSDK::Models::Automation::PublicTaskPatternResponse?
55 56 57 58 59 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_response.rb', line 55 optional :task_pattern, -> { HubSpotSDK::Automation::PublicTaskPatternResponse }, api_name: :taskPattern |
#updated_at ⇒ Time
The date and time when the sequence step was last updated.
43 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_step_response.rb', line 43 required :updated_at, Time, api_name: :updatedAt |