Class: HubSpotSDK::Models::Automation::PublicSingleFieldDependency

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/automation/public_single_field_dependency.rb

Defined Under Namespace

Modules: DependencyType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(controlling_field_name:, dependency_type:, dependent_field_names:) ⇒ Object

Parameters:



# File 'lib/hubspot_sdk/models/automation/public_single_field_dependency.rb', line 28

Instance Attribute Details

#controlling_field_nameString

The name of the field that controls the dependency.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/automation/public_single_field_dependency.rb', line 11

required :controlling_field_name, String, api_name: :controllingFieldName

#dependency_typeSymbol, HubSpotSDK::Models::Automation::PublicSingleFieldDependency::DependencyType

The type of dependency, with the default value being ‘SINGLE_FIELD’.



17
18
19
# File 'lib/hubspot_sdk/models/automation/public_single_field_dependency.rb', line 17

required :dependency_type,
enum: -> { HubSpotSDK::Automation::PublicSingleFieldDependency::DependencyType },
api_name: :dependencyType

#dependent_field_namesArray<String>

Returns:

  • (Array<String>)


24
25
26
# File 'lib/hubspot_sdk/models/automation/public_single_field_dependency.rb', line 24

required :dependent_field_names,
HubSpotSDK::Internal::Type::ArrayOf[String],
api_name: :dependentFieldNames