Class: HubSpotSDK::Models::Automation::PublicTaskPatternResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/automation/public_task_pattern_response.rb

Defined Under Namespace

Modules: TaskPriority, TaskType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, task_priority:, task_type:, updated_at:, notes: nil, queue_id: nil, subject: nil, template_id: nil, thread_email_to_step_order: nil) ⇒ Object

Parameters:

  • id (String)

    The unique identifier for the task pattern.

  • created_at (Time)

    The date and time when the task pattern was created.

  • task_priority (Symbol, HubSpotSDK::Models::Automation::PublicTaskPatternResponse::TaskPriority)

    The priority level assigned to the task.

  • task_type (Symbol, HubSpotSDK::Models::Automation::PublicTaskPatternResponse::TaskType)

    The type of task, such as an email or call.

  • updated_at (Time)

    The date and time when the task pattern was last updated.

  • notes (String) (defaults to: nil)

    Additional notes or comments associated with the task.

  • queue_id (Integer) (defaults to: nil)

    The identifier for the queue associated with the task.

  • subject (String) (defaults to: nil)

    The subject line of the task.

  • template_id (Integer) (defaults to: nil)

    The identifier for the template used in the task.

  • thread_email_to_step_order (Integer) (defaults to: nil)

    The order of the step to which the email thread is related.



# File 'lib/hubspot_sdk/models/automation/public_task_pattern_response.rb', line 71

Instance Attribute Details

#created_atTime

The date and time when the task pattern was created.

Returns:

  • (Time)


17
# File 'lib/hubspot_sdk/models/automation/public_task_pattern_response.rb', line 17

required :created_at, Time, api_name: :createdAt

#idString

The unique identifier for the task pattern.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/automation/public_task_pattern_response.rb', line 11

required :id, String

#notesString?

Additional notes or comments associated with the task.

Returns:

  • (String, nil)


45
# File 'lib/hubspot_sdk/models/automation/public_task_pattern_response.rb', line 45

optional :notes, String

#queue_idInteger?

The identifier for the queue associated with the task.

Returns:

  • (Integer, nil)


51
# File 'lib/hubspot_sdk/models/automation/public_task_pattern_response.rb', line 51

optional :queue_id, Integer, api_name: :queueId

#subjectString?

The subject line of the task.

Returns:

  • (String, nil)


57
# File 'lib/hubspot_sdk/models/automation/public_task_pattern_response.rb', line 57

optional :subject, String

#task_prioritySymbol, HubSpotSDK::Models::Automation::PublicTaskPatternResponse::TaskPriority

The priority level assigned to the task.



23
24
25
# File 'lib/hubspot_sdk/models/automation/public_task_pattern_response.rb', line 23

required :task_priority,
enum: -> { HubSpotSDK::Automation::PublicTaskPatternResponse::TaskPriority },
api_name: :taskPriority

#task_typeSymbol, HubSpotSDK::Models::Automation::PublicTaskPatternResponse::TaskType

The type of task, such as an email or call.



31
32
33
# File 'lib/hubspot_sdk/models/automation/public_task_pattern_response.rb', line 31

required :task_type,
enum: -> { HubSpotSDK::Automation::PublicTaskPatternResponse::TaskType },
api_name: :taskType

#template_idInteger?

The identifier for the template used in the task.

Returns:

  • (Integer, nil)


63
# File 'lib/hubspot_sdk/models/automation/public_task_pattern_response.rb', line 63

optional :template_id, Integer, api_name: :templateId

#thread_email_to_step_orderInteger?

The order of the step to which the email thread is related.

Returns:

  • (Integer, nil)


69
# File 'lib/hubspot_sdk/models/automation/public_task_pattern_response.rb', line 69

optional :thread_email_to_step_order, Integer, api_name: :threadEmailToStepOrder

#updated_atTime

The date and time when the task pattern was last updated.

Returns:

  • (Time)


39
# File 'lib/hubspot_sdk/models/automation/public_task_pattern_response.rb', line 39

required :updated_at, Time, api_name: :updatedAt

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/automation/public_task_pattern_response.rb', line 103