Class: HubSpotSDK::Models::Automation::StandaloneRequestContext
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::StandaloneRequestContext
- Defined in:
- lib/hubspot_sdk/models/automation/standalone_request_context.rb
Defined Under Namespace
Modules: Source
Instance Attribute Summary collapse
- #chirp_ai_context_object ⇒ HubSpotSDK::Models::Automation::ChirpAIContextObject
-
#source ⇒ Symbol, HubSpotSDK::Models::Automation::StandaloneRequestContext::Source
Indicates the source of the request, with the default value being ‘STANDALONE’.
-
#trajectory_id ⇒ String?
A unique identifier for tracking the trajectory of the request.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(chirp_ai_context_object:, source:, trajectory_id: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/automation/standalone_request_context.rb', line 26
|
Instance Attribute Details
#chirp_ai_context_object ⇒ HubSpotSDK::Models::Automation::ChirpAIContextObject
10 11 12 |
# File 'lib/hubspot_sdk/models/automation/standalone_request_context.rb', line 10 required :chirp_ai_context_object, -> { HubSpotSDK::Automation::ChirpAIContextObject }, api_name: :chirpAiContextObject |
#source ⇒ Symbol, HubSpotSDK::Models::Automation::StandaloneRequestContext::Source
Indicates the source of the request, with the default value being ‘STANDALONE’.
18 |
# File 'lib/hubspot_sdk/models/automation/standalone_request_context.rb', line 18 required :source, enum: -> { HubSpotSDK::Automation::StandaloneRequestContext::Source } |
#trajectory_id ⇒ String?
A unique identifier for tracking the trajectory of the request.
24 |
# File 'lib/hubspot_sdk/models/automation/standalone_request_context.rb', line 24 optional :trajectory_id, String, api_name: :trajectoryId |