Class: HubSpotSDK::Models::Automation::StringFieldSchema
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::StringFieldSchema
- Defined in:
- lib/hubspot_sdk/models/automation/string_field_schema.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#format_ ⇒ Symbol, ...
Specifies the format of the string, with accepted values: DATE, DATE_TIME, OBJECT_COORDINATE, TIME, URI.
-
#type ⇒ Symbol, HubSpotSDK::Models::Automation::StringFieldSchema::Type
Indicates that the type is a string, with the default value being STRING.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(type:, format_: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see StringFieldSchema for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type:, format_: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Automation::StringFieldSchema for more details.
|
|
# File 'lib/hubspot_sdk/models/automation/string_field_schema.rb', line 20
|
Instance Attribute Details
#format_ ⇒ Symbol, ...
Specifies the format of the string, with accepted values: DATE, DATE_TIME, OBJECT_COORDINATE, TIME, URI.
18 |
# File 'lib/hubspot_sdk/models/automation/string_field_schema.rb', line 18 optional :format_, enum: -> { HubSpotSDK::Automation::StringFieldSchema::Format }, api_name: :format |
#type ⇒ Symbol, HubSpotSDK::Models::Automation::StringFieldSchema::Type
Indicates that the type is a string, with the default value being STRING.
11 |
# File 'lib/hubspot_sdk/models/automation/string_field_schema.rb', line 11 required :type, enum: -> { HubSpotSDK::Automation::StringFieldSchema::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/automation/string_field_schema.rb', line 36
|