Class: HubSpotSDK::Models::Automation::WorkflowsRequestContext
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::WorkflowsRequestContext
- Defined in:
- lib/hubspot_sdk/models/automation/workflows_request_context.rb
Defined Under Namespace
Modules: Source
Instance Attribute Summary collapse
- #action_execution_index_identifier ⇒ HubSpotSDK::Models::Automation::ActionExecutionIndexIdentifier?
-
#action_id ⇒ Integer?
The ID of the action within the workflow context.
-
#source ⇒ Symbol, HubSpotSDK::Models::Automation::WorkflowsRequestContext::Source
Indicates the source of the request, with the default value being WORKFLOWS.
-
#workflow_id ⇒ Integer
The ID of the workflow associated with the request context.
Instance Method Summary collapse
- #initialize(source:, workflow_id:, action_execution_index_identifier: nil, action_id: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(source:, workflow_id:, action_execution_index_identifier: nil, action_id: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/automation/workflows_request_context.rb', line 32
|
Instance Attribute Details
#action_execution_index_identifier ⇒ HubSpotSDK::Models::Automation::ActionExecutionIndexIdentifier?
22 23 24 |
# File 'lib/hubspot_sdk/models/automation/workflows_request_context.rb', line 22 optional :action_execution_index_identifier, -> { HubSpotSDK::Automation::ActionExecutionIndexIdentifier }, api_name: :actionExecutionIndexIdentifier |
#action_id ⇒ Integer?
The ID of the action within the workflow context.
30 |
# File 'lib/hubspot_sdk/models/automation/workflows_request_context.rb', line 30 optional :action_id, Integer, api_name: :actionId |
#source ⇒ Symbol, HubSpotSDK::Models::Automation::WorkflowsRequestContext::Source
Indicates the source of the request, with the default value being WORKFLOWS.
11 |
# File 'lib/hubspot_sdk/models/automation/workflows_request_context.rb', line 11 required :source, enum: -> { HubSpotSDK::Automation::WorkflowsRequestContext::Source } |
#workflow_id ⇒ Integer
The ID of the workflow associated with the request context.
17 |
# File 'lib/hubspot_sdk/models/automation/workflows_request_context.rb', line 17 required :workflow_id, Integer, api_name: :workflowId |