Class: HubSpotSDK::Models::AutomationActionsOption

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/automation_actions_option.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(description:, display_order:, double_data:, hidden:, label:, read_only:, value:) ⇒ Object

A HubSpot property option

Parameters:

  • description (String)

    A description of the option.

  • display_order (Integer)

    The position of the item relative to others in the list.

  • double_data (Float)

    A numerical value associated with the option.

  • hidden (Boolean)

    Whether the option is displayed in HubSpot’s UI.

  • label (String)

    A user-friendly label that identifies the option.

  • read_only (Boolean)

    Whether the option is read-only.

  • value (String)

    The actual value of the option.



# File 'lib/hubspot_sdk/models/automation_actions_option.rb', line 48

Instance Attribute Details

#descriptionString

A description of the option.

Returns:

  • (String)


10
# File 'lib/hubspot_sdk/models/automation_actions_option.rb', line 10

required :description, String

#display_orderInteger

The position of the item relative to others in the list.

Returns:

  • (Integer)


16
# File 'lib/hubspot_sdk/models/automation_actions_option.rb', line 16

required :display_order, Integer, api_name: :displayOrder

#double_dataFloat

A numerical value associated with the option.

Returns:

  • (Float)


22
# File 'lib/hubspot_sdk/models/automation_actions_option.rb', line 22

required :double_data, Float, api_name: :doubleData

#hiddenBoolean

Whether the option is displayed in HubSpot’s UI.

Returns:

  • (Boolean)


28
# File 'lib/hubspot_sdk/models/automation_actions_option.rb', line 28

required :hidden, HubSpotSDK::Internal::Type::Boolean

#labelString

A user-friendly label that identifies the option.

Returns:

  • (String)


34
# File 'lib/hubspot_sdk/models/automation_actions_option.rb', line 34

required :label, String

#read_onlyBoolean

Whether the option is read-only.

Returns:

  • (Boolean)


40
# File 'lib/hubspot_sdk/models/automation_actions_option.rb', line 40

required :read_only, HubSpotSDK::Internal::Type::Boolean, api_name: :readOnly

#valueString

The actual value of the option.

Returns:

  • (String)


46
# File 'lib/hubspot_sdk/models/automation_actions_option.rb', line 46

required :value, String