Class: HubSpotSDK::Models::Cms::AbTestEndRequestVNext

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/ab_test_end_request_v_next.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ab_test_id:, winner_id:) ⇒ Object

Parameters:

  • ab_test_id (String)

    ID of the test to end.

  • winner_id (String)

    ID of the object to designate as the test winner.



# File 'lib/hubspot_sdk/models/cms/ab_test_end_request_v_next.rb', line 19

Instance Attribute Details

#ab_test_idString

ID of the test to end.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/cms/ab_test_end_request_v_next.rb', line 11

required :ab_test_id, String, api_name: :abTestId

#winner_idString

ID of the object to designate as the test winner.

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/cms/ab_test_end_request_v_next.rb', line 17

required :winner_id, String, api_name: :winnerId