Class: HubSpotSDK::Models::Cms::AssetFileMetadata

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/asset_file_metadata.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, folder:, name:, updated_at:, archived_at: nil, children: nil, hash_: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::AssetFileMetadata for more details.

Parameters:

  • id (String)

    The path of the file in the CMS Developer File System.

  • created_at (Integer)

    Timestamp of when the object was first created.

  • folder (Boolean)

    Determines whether or not this path points to a folder.

  • name (String)

    The name of the file.

  • updated_at (Integer)

    Timestamp of when the object was last updated.

  • archived_at (Integer) (defaults to: nil)

    Timestamp of when the object was archived (deleted).

  • children (Array<String>) (defaults to: nil)

    If the object is a folder, contains the filenames of the files within the folder

  • hash_ (String) (defaults to: nil)

    A unique identifier for the file’s content, used to verify data integrity.



# File 'lib/hubspot_sdk/models/cms/asset_file_metadata.rb', line 56

Instance Attribute Details

#archived_atInteger?

Timestamp of when the object was archived (deleted).

Returns:

  • (Integer, nil)


41
# File 'lib/hubspot_sdk/models/cms/asset_file_metadata.rb', line 41

optional :archived_at, Integer, api_name: :archivedAt

#childrenArray<String>?

If the object is a folder, contains the filenames of the files within the folder.

Returns:

  • (Array<String>, nil)


48
# File 'lib/hubspot_sdk/models/cms/asset_file_metadata.rb', line 48

optional :children, HubSpotSDK::Internal::Type::ArrayOf[String]

#created_atInteger

Timestamp of when the object was first created.

Returns:

  • (Integer)


17
# File 'lib/hubspot_sdk/models/cms/asset_file_metadata.rb', line 17

required :created_at, Integer, api_name: :createdAt

#folderBoolean

Determines whether or not this path points to a folder.

Returns:

  • (Boolean)


23
# File 'lib/hubspot_sdk/models/cms/asset_file_metadata.rb', line 23

required :folder, HubSpotSDK::Internal::Type::Boolean

#hash_String?

A unique identifier for the file’s content, used to verify data integrity.

Returns:

  • (String, nil)


54
# File 'lib/hubspot_sdk/models/cms/asset_file_metadata.rb', line 54

optional :hash_, String, api_name: :hash

#idString

The path of the file in the CMS Developer File System.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/cms/asset_file_metadata.rb', line 11

required :id, String

#nameString

The name of the file.

Returns:

  • (String)


29
# File 'lib/hubspot_sdk/models/cms/asset_file_metadata.rb', line 29

required :name, String

#updated_atInteger

Timestamp of when the object was last updated.

Returns:

  • (Integer)


35
# File 'lib/hubspot_sdk/models/cms/asset_file_metadata.rb', line 35

required :updated_at, Integer, api_name: :updatedAt