Class: HubSpotSDK::Models::Cms::AttachToLangPrimaryRequestVNext

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/attach_to_lang_primary_request_v_next.rb

Defined Under Namespace

Modules: Language, PrimaryLanguage

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, language:, primary_id:, primary_language: nil) ⇒ Object

Parameters:



# File 'lib/hubspot_sdk/models/cms/attach_to_lang_primary_request_v_next.rb', line 33

Instance Attribute Details

#idString

ID of the object to add to a multi-language group.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/cms/attach_to_lang_primary_request_v_next.rb', line 11

required :id, String

#languageSymbol, HubSpotSDK::Models::Cms::AttachToLangPrimaryRequestVNext::Language

Designated language of the object to add to a multi-language group.



17
# File 'lib/hubspot_sdk/models/cms/attach_to_lang_primary_request_v_next.rb', line 17

required :language, enum: -> { HubSpotSDK::Cms::AttachToLangPrimaryRequestVNext::Language }

#primary_idString

ID of primary language object in multi-language group.

Returns:

  • (String)


23
# File 'lib/hubspot_sdk/models/cms/attach_to_lang_primary_request_v_next.rb', line 23

required :primary_id, String, api_name: :primaryId

#primary_languageSymbol, ...

Primary language of the multi-language group.



29
30
31
# File 'lib/hubspot_sdk/models/cms/attach_to_lang_primary_request_v_next.rb', line 29

optional :primary_language,
enum: -> { HubSpotSDK::Cms::AttachToLangPrimaryRequestVNext::PrimaryLanguage },
api_name: :primaryLanguage

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/cms/attach_to_lang_primary_request_v_next.rb', line 892