Class: HubSpotSDK::Models::Cms::AuditLogListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/cms/audit_log_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after: nil, before: nil, event_type: nil, limit: nil, object_id_: nil, object_type: nil, sort: nil, user_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::AuditLogListParams for more details.

Parameters:

  • after (String) (defaults to: nil)

    The paging cursor token of the last successfully read resource will be returned

  • before (String) (defaults to: nil)
  • event_type (Array<String>) (defaults to: nil)
  • limit (Integer) (defaults to: nil)

    The maximum number of results to display per page.

  • object_id_ (Array<String>) (defaults to: nil)
  • object_type (Array<String>) (defaults to: nil)
  • sort (Array<String>) (defaults to: nil)
  • user_id (Array<String>) (defaults to: nil)
  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/cms/audit_log_list_params.rb', line 55

Instance Attribute Details

#afterString?

The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.

Returns:

  • (String, nil)


17
# File 'lib/hubspot_sdk/models/cms/audit_log_list_params.rb', line 17

optional :after, String

#beforeString?

Returns:

  • (String, nil)


22
# File 'lib/hubspot_sdk/models/cms/audit_log_list_params.rb', line 22

optional :before, String

#event_typeArray<String>?

Returns:

  • (Array<String>, nil)


27
# File 'lib/hubspot_sdk/models/cms/audit_log_list_params.rb', line 27

optional :event_type, HubSpotSDK::Internal::Type::ArrayOf[String]

#limitInteger?

The maximum number of results to display per page.

Returns:

  • (Integer, nil)


33
# File 'lib/hubspot_sdk/models/cms/audit_log_list_params.rb', line 33

optional :limit, Integer

#object_id_Array<String>?

Returns:

  • (Array<String>, nil)


38
# File 'lib/hubspot_sdk/models/cms/audit_log_list_params.rb', line 38

optional :object_id_, HubSpotSDK::Internal::Type::ArrayOf[String]

#object_typeArray<String>?

Returns:

  • (Array<String>, nil)


43
# File 'lib/hubspot_sdk/models/cms/audit_log_list_params.rb', line 43

optional :object_type, HubSpotSDK::Internal::Type::ArrayOf[String]

#sortArray<String>?

Returns:

  • (Array<String>, nil)


48
# File 'lib/hubspot_sdk/models/cms/audit_log_list_params.rb', line 48

optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String]

#user_idArray<String>?

Returns:

  • (Array<String>, nil)


53
# File 'lib/hubspot_sdk/models/cms/audit_log_list_params.rb', line 53

optional :user_id, HubSpotSDK::Internal::Type::ArrayOf[String]