Class: HubSpotSDK::Models::Cms::Blogs::AuthorGetCursorParams
Overview
Instance Attribute Summary collapse
#request_options
Instance Method Summary
collapse
-
#initialize(after: nil, archived: nil, created_after: nil, created_at: nil, created_before: nil, limit: nil, property: nil, sort: nil, updated_after: nil, updated_at: nil, updated_before: nil, request_options: {}) ⇒ Object
constructor
dump_request
included
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, archived: nil, created_after: nil, created_at: nil, created_before: nil, limit: nil, property: nil, sort: nil, updated_after: nil, updated_at: nil, updated_before: nil, request_options: {}) ⇒ Object
|
# File 'lib/hubspot_sdk/models/cms/blogs/author_get_cursor_params.rb', line 72
|
Instance Attribute Details
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
18
|
# File 'lib/hubspot_sdk/models/cms/blogs/author_get_cursor_params.rb', line 18
optional :after, String
|
#archived ⇒ Boolean?
Whether to return only results that have been archived.
#created_after ⇒ Time?
29
|
# File 'lib/hubspot_sdk/models/cms/blogs/author_get_cursor_params.rb', line 29
optional :created_after, Time
|
#created_at ⇒ Time?
34
|
# File 'lib/hubspot_sdk/models/cms/blogs/author_get_cursor_params.rb', line 34
optional :created_at, Time
|
#created_before ⇒ Time?
39
|
# File 'lib/hubspot_sdk/models/cms/blogs/author_get_cursor_params.rb', line 39
optional :created_before, Time
|
#limit ⇒ Integer?
The maximum number of results to display per page.
45
|
# File 'lib/hubspot_sdk/models/cms/blogs/author_get_cursor_params.rb', line 45
optional :limit, Integer
|
#property ⇒ String?
50
|
# File 'lib/hubspot_sdk/models/cms/blogs/author_get_cursor_params.rb', line 50
optional :property, String
|
#updated_after ⇒ Time?
60
|
# File 'lib/hubspot_sdk/models/cms/blogs/author_get_cursor_params.rb', line 60
optional :updated_after, Time
|
#updated_at ⇒ Time?
65
|
# File 'lib/hubspot_sdk/models/cms/blogs/author_get_cursor_params.rb', line 65
optional :updated_at, Time
|
#updated_before ⇒ Time?
70
|
# File 'lib/hubspot_sdk/models/cms/blogs/author_get_cursor_params.rb', line 70
optional :updated_before, Time
|