Class: HubSpotSDK::Models::Cms::Blogs::AuthorListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/cms/blogs/author_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after: nil, archived: nil, created_after: nil, created_at: nil, created_before: nil, limit: nil, property: nil, sort: nil, updated_after: nil, updated_at: nil, updated_before: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::Blogs::AuthorListParams for more details.

Parameters:

  • after (String) (defaults to: nil)

    The paging cursor token of the last successfully read resource will be returned

  • archived (Boolean) (defaults to: nil)

    Whether to return only results that have been archived.

  • created_after (Time) (defaults to: nil)
  • created_at (Time) (defaults to: nil)
  • created_before (Time) (defaults to: nil)
  • limit (Integer) (defaults to: nil)

    The maximum number of results to display per page.

  • property (String) (defaults to: nil)
  • sort (Array<String>) (defaults to: nil)
  • updated_after (Time) (defaults to: nil)
  • updated_at (Time) (defaults to: nil)
  • updated_before (Time) (defaults to: nil)
  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/cms/blogs/author_list_params.rb', line 72

Instance Attribute Details

#afterString?

The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.

Returns:

  • (String, nil)


18
# File 'lib/hubspot_sdk/models/cms/blogs/author_list_params.rb', line 18

optional :after, String

#archivedBoolean?

Whether to return only results that have been archived.

Returns:

  • (Boolean, nil)


24
# File 'lib/hubspot_sdk/models/cms/blogs/author_list_params.rb', line 24

optional :archived, HubSpotSDK::Internal::Type::Boolean

#created_afterTime?

Returns:

  • (Time, nil)


29
# File 'lib/hubspot_sdk/models/cms/blogs/author_list_params.rb', line 29

optional :created_after, Time

#created_atTime?

Returns:

  • (Time, nil)


34
# File 'lib/hubspot_sdk/models/cms/blogs/author_list_params.rb', line 34

optional :created_at, Time

#created_beforeTime?

Returns:

  • (Time, nil)


39
# File 'lib/hubspot_sdk/models/cms/blogs/author_list_params.rb', line 39

optional :created_before, Time

#limitInteger?

The maximum number of results to display per page.

Returns:

  • (Integer, nil)


45
# File 'lib/hubspot_sdk/models/cms/blogs/author_list_params.rb', line 45

optional :limit, Integer

#propertyString?

Returns:

  • (String, nil)


50
# File 'lib/hubspot_sdk/models/cms/blogs/author_list_params.rb', line 50

optional :property, String

#sortArray<String>?

Returns:

  • (Array<String>, nil)


55
# File 'lib/hubspot_sdk/models/cms/blogs/author_list_params.rb', line 55

optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String]

#updated_afterTime?

Returns:

  • (Time, nil)


60
# File 'lib/hubspot_sdk/models/cms/blogs/author_list_params.rb', line 60

optional :updated_after, Time

#updated_atTime?

Returns:

  • (Time, nil)


65
# File 'lib/hubspot_sdk/models/cms/blogs/author_list_params.rb', line 65

optional :updated_at, Time

#updated_beforeTime?

Returns:

  • (Time, nil)


70
# File 'lib/hubspot_sdk/models/cms/blogs/author_list_params.rb', line 70

optional :updated_before, Time