Class: HubSpotSDK::Models::Cms::Blogs::AuthorUpdateParams
- Inherits:
-
BlogAuthor
- Object
- Internal::Type::BaseModel
- BlogAuthor
- HubSpotSDK::Models::Cms::Blogs::AuthorUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/cms/blogs/author_update_params.rb
Overview
Instance Attribute Summary collapse
-
#archived ⇒ Boolean?
Whether to return only results that have been archived.
- #object_id_ ⇒ String
Attributes included from Internal::Type::RequestParameters
Attributes inherited from BlogAuthor
#avatar, #bio, #created, #deleted_at, #display_name, #email, #facebook, #full_name, #id, #language, #linkedin, #name, #slug, #translated_from_id, #twitter, #updated, #website
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(object_id_:, archived: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/cms/blogs/author_update_params.rb', line 23
|
Instance Attribute Details
#archived ⇒ Boolean?
Whether to return only results that have been archived.
21 |
# File 'lib/hubspot_sdk/models/cms/blogs/author_update_params.rb', line 21 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#object_id_ ⇒ String
15 |
# File 'lib/hubspot_sdk/models/cms/blogs/author_update_params.rb', line 15 required :object_id_, String |