Class: HubSpotSDK::Models::Cms::Blogs::BlogAuthor

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/blogs/blog_author.rb

Direct Known Subclasses

AuthorCreateParams, AuthorUpdateParams

Defined Under Namespace

Modules: Language

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, avatar:, bio:, created:, deleted_at:, display_name:, email:, facebook:, full_name:, language:, linkedin:, name:, slug:, translated_from_id:, twitter:, updated:, website:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::Blogs::BlogAuthor for more details.

Parameters:

  • id (String)

    The unique ID of the Blog Author.

  • avatar (String)

    URL to the blog author’s avatar, if supplying a custom one.

  • bio (String)

    A short biography of the blog author.

  • created (Time)

    The timestamp (ISO8601 format) when this Blog Author was created.

  • deleted_at (Time)

    The timestamp (ISO8601 format) when this Blog Author was deleted.

  • display_name (String)

    The full name of the Blog Author to be displayed.

  • email (String)

    Email address of the Blog Author.

  • facebook (String)

    URL to the Blog Author’s Facebook page.

  • full_name (String)

    The full, unabbreviated name of the blog author, typically their first and last

  • language (Symbol, HubSpotSDK::Models::Cms::Blogs::BlogAuthor::Language)

    The explicitly defined ISO 639 language code of the blog author.

  • linkedin (String)

    URL to the blog author’s LinkedIn page.

  • name (String)

    The name field for the blog author. (This appears to be a shorter or alternative

  • slug (String)

    A URL-friendly identifier for the blog author that can be used to reference the

  • translated_from_id (Integer)

    ID of the primary blog author this object was translated from.

  • twitter (String)

    URL or username of the Twitter account associated with the Blog Author. This wil

  • updated (Time)

    The timestamp (ISO8601 format) when this Blog Author was updated.

  • website (String)

    URL to the website of the Blog Author.



# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 115

Instance Attribute Details

#avatarString

URL to the blog author’s avatar, if supplying a custom one.

Returns:

  • (String)


18
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 18

required :avatar, String

#bioString

A short biography of the blog author.

Returns:

  • (String)


24
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 24

required :bio, String

#createdTime

The timestamp (ISO8601 format) when this Blog Author was created.

Returns:

  • (Time)


30
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 30

required :created, Time

#deleted_atTime

The timestamp (ISO8601 format) when this Blog Author was deleted.

Returns:

  • (Time)


36
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 36

required :deleted_at, Time, api_name: :deletedAt

#display_nameString

The full name of the Blog Author to be displayed.

Returns:

  • (String)


42
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 42

required :display_name, String, api_name: :displayName

#emailString

Email address of the Blog Author.

Returns:

  • (String)


48
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 48

required :email, String

#facebookString

URL to the Blog Author’s Facebook page.

Returns:

  • (String)


54
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 54

required :facebook, String

#full_nameString

The full, unabbreviated name of the blog author, typically their first and last name combined.

Returns:

  • (String)


61
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 61

required :full_name, String, api_name: :fullName

#idString

The unique ID of the Blog Author.

Returns:

  • (String)


12
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 12

required :id, String

#languageSymbol, HubSpotSDK::Models::Cms::Blogs::BlogAuthor::Language

The explicitly defined ISO 639 language code of the blog author.



67
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 67

required :language, enum: -> { HubSpotSDK::Cms::Blogs::BlogAuthor::Language }

#linkedinString

URL to the blog author’s LinkedIn page.

Returns:

  • (String)


73
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 73

required :linkedin, String

#nameString

The name field for the blog author. (This appears to be a shorter or alternative name field compared to fullName.)

Returns:

  • (String)


80
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 80

required :name, String

#slugString

A URL-friendly identifier for the blog author that can be used to reference the author in URLs. Typically generated from the author’s name and contains lowercase letters, hyphens, and underscores.

Returns:

  • (String)


88
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 88

required :slug, String

#translated_from_idInteger

ID of the primary blog author this object was translated from.

Returns:

  • (Integer)


94
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 94

required :translated_from_id, Integer, api_name: :translatedFromId

#twitterString

URL or username of the Twitter account associated with the Blog Author. This will be normalized into the Twitter url for said user.

Returns:

  • (String)


101
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 101

required :twitter, String

#updatedTime

The timestamp (ISO8601 format) when this Blog Author was updated.

Returns:

  • (Time)


107
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 107

required :updated, Time

#websiteString

URL to the website of the Blog Author.

Returns:

  • (String)


113
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 113

required :website, String