Class: HubSpotSDK::Models::Cms::Blogs::PostUpdateParams

Inherits:
BlogPost show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/cms/blogs/post_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from BlogPost

#ab_status, #ab_test_id, #archived_at, #archived_in_dashboard, #attached_stylesheets, #author_name, #blog_author_id, #campaign, #category_id, #content_group_id, #content_type_category, #created, #created_by_id, #current_state, #currently_published, #domain, #dynamic_page_data_source_id, #dynamic_page_data_source_type, #dynamic_page_hub_db_table_id, #enable_domain_stylesheets, #enable_google_amp_output_override, #enable_layout_stylesheets, #featured_image, #featured_image_alt_text, #folder_id, #footer_html, #head_html, #html_title, #id, #include_default_custom_css, #language, #layout_sections, #link_rel_canonical_url, #mab_experiment_id, #meta_description, #name, #page_expiry_date, #page_expiry_enabled, #page_expiry_redirect_id, #page_expiry_redirect_url, #password, #post_body, #post_summary, #public_access_rules, #public_access_rules_enabled, #publish_date, #publish_immediately, #rss_body, #rss_summary, #slug, #state, #tag_ids, #theme_settings_values, #translated_from_id, #translations, #updated, #updated_by_id, #url, #use_featured_image, #widget_containers, #widgets

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from BlogPost

values

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(object_id_:, archived: nil, request_options: {}) ⇒ Object

Parameters:

  • object_id_ (String)
  • archived (Boolean) (defaults to: nil)

    Whether to return only results that have been archived.

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/cms/blogs/post_update_params.rb', line 23

Instance Attribute Details

#archivedBoolean?

Whether to return only results that have been archived.

Returns:

  • (Boolean, nil)


21
# File 'lib/hubspot_sdk/models/cms/blogs/post_update_params.rb', line 21

optional :archived, HubSpotSDK::Internal::Type::Boolean

#object_id_String

Returns:

  • (String)


15
# File 'lib/hubspot_sdk/models/cms/blogs/post_update_params.rb', line 15

required :object_id_, String