Class: HubSpotSDK::Models::Cms::Blogs::SettingListRevisionsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/cms/blogs/setting_list_revisions_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(blog_id:, after: nil, before: nil, limit: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::Blogs::SettingListRevisionsParams for more details.

Parameters:

  • blog_id (String)
  • after (String) (defaults to: nil)

    The paging cursor token of the last successfully read resource will be returned

  • before (String) (defaults to: nil)
  • limit (Integer) (defaults to: nil)

    The maximum number of results to display per page.

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/cms/blogs/setting_list_revisions_params.rb', line 36

Instance Attribute Details

#afterString?

The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.

Returns:

  • (String, nil)


23
# File 'lib/hubspot_sdk/models/cms/blogs/setting_list_revisions_params.rb', line 23

optional :after, String

#beforeString?

Returns:

  • (String, nil)


28
# File 'lib/hubspot_sdk/models/cms/blogs/setting_list_revisions_params.rb', line 28

optional :before, String

#blog_idString

Returns:

  • (String)


15
# File 'lib/hubspot_sdk/models/cms/blogs/setting_list_revisions_params.rb', line 15

required :blog_id, String

#limitInteger?

The maximum number of results to display per page.

Returns:

  • (Integer, nil)


34
# File 'lib/hubspot_sdk/models/cms/blogs/setting_list_revisions_params.rb', line 34

optional :limit, Integer