Class: HubSpotSDK::Models::Cms::Blogs::Tag

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/blogs/tag.rb

Direct Known Subclasses

TagCreateParams, TagUpdateParams

Defined Under Namespace

Modules: Language

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created:, deleted_at:, language:, name:, slug:, translated_from_id:, updated:) ⇒ Object

Parameters:

  • id (String)

    The unique ID of the Blog Tag.

  • created (Time)

    The timestamp (ISO8601 format) when this Blog Tag was created.

  • deleted_at (Time)

    The timestamp (ISO8601 format) when this Blog Tag was deleted.

  • language (Symbol, HubSpotSDK::Models::Cms::Blogs::Tag::Language)

    The explicitly defined ISO 639 language code of the tag.

  • name (String)

    The name of the tag.

  • slug (String)
  • translated_from_id (Integer)

    ID of the primary tag this object was translated from.

  • updated (Time)

    The timestamp (ISO8601 format) when this Blog Tag was updated.



# File 'lib/hubspot_sdk/models/cms/blogs/tag.rb', line 55

Instance Attribute Details

#createdTime

The timestamp (ISO8601 format) when this Blog Tag was created.

Returns:

  • (Time)


18
# File 'lib/hubspot_sdk/models/cms/blogs/tag.rb', line 18

required :created, Time

#deleted_atTime

The timestamp (ISO8601 format) when this Blog Tag was deleted.

Returns:

  • (Time)


24
# File 'lib/hubspot_sdk/models/cms/blogs/tag.rb', line 24

required :deleted_at, Time, api_name: :deletedAt

#idString

The unique ID of the Blog Tag.

Returns:

  • (String)


12
# File 'lib/hubspot_sdk/models/cms/blogs/tag.rb', line 12

required :id, String

#languageSymbol, HubSpotSDK::Models::Cms::Blogs::Tag::Language

The explicitly defined ISO 639 language code of the tag.



30
# File 'lib/hubspot_sdk/models/cms/blogs/tag.rb', line 30

required :language, enum: -> { HubSpotSDK::Cms::Blogs::Tag::Language }

#nameString

The name of the tag.

Returns:

  • (String)


36
# File 'lib/hubspot_sdk/models/cms/blogs/tag.rb', line 36

required :name, String

#slugString

Returns:

  • (String)


41
# File 'lib/hubspot_sdk/models/cms/blogs/tag.rb', line 41

required :slug, String

#translated_from_idInteger

ID of the primary tag this object was translated from.

Returns:

  • (Integer)


47
# File 'lib/hubspot_sdk/models/cms/blogs/tag.rb', line 47

required :translated_from_id, Integer, api_name: :translatedFromId

#updatedTime

The timestamp (ISO8601 format) when this Blog Tag was updated.

Returns:

  • (Time)


53
# File 'lib/hubspot_sdk/models/cms/blogs/tag.rb', line 53

required :updated, Time