Class: HubSpotSDK::Models::Cms::ColumnRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/column_request.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, label:, name:, options:, type:, foreign_column_id: nil, foreign_table_id: nil, max_number_of_characters: nil, max_number_of_options: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::ColumnRequest for more details.

Parameters:

  • id (Integer)

    Column Id

  • label (String)

    Label of the column

  • name (String)

    Name of the column

  • options (Array<HubSpotSDK::Models::Cms::Option>)

    Options to choose for select and multi-select columns

  • type (Symbol, HubSpotSDK::Models::Cms::ColumnRequest::Type)

    Type of the column

  • foreign_column_id (Integer) (defaults to: nil)

    The id of the column from another table to which the column refers/points to.

  • foreign_table_id (Integer) (defaults to: nil)

    The id of another table to which the column refers/points to.

  • max_number_of_characters (Integer) (defaults to: nil)

    Defines the maximum number of characters allowed in the column.

  • max_number_of_options (Integer) (defaults to: nil)

    Specifies the maximum number of options that can be set for select and multi-sel



# File 'lib/hubspot_sdk/models/cms/column_request.rb', line 62

Instance Attribute Details

#foreign_column_idInteger?

The id of the column from another table to which the column refers/points to.

Returns:

  • (Integer, nil)


41
# File 'lib/hubspot_sdk/models/cms/column_request.rb', line 41

optional :foreign_column_id, Integer, api_name: :foreignColumnId

#foreign_table_idInteger?

The id of another table to which the column refers/points to.

Returns:

  • (Integer, nil)


47
# File 'lib/hubspot_sdk/models/cms/column_request.rb', line 47

optional :foreign_table_id, Integer, api_name: :foreignTableId

#idInteger

Column Id

Returns:

  • (Integer)


11
# File 'lib/hubspot_sdk/models/cms/column_request.rb', line 11

required :id, Integer

#labelString

Label of the column

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/cms/column_request.rb', line 17

required :label, String

#max_number_of_charactersInteger?

Defines the maximum number of characters allowed in the column.

Returns:

  • (Integer, nil)


53
# File 'lib/hubspot_sdk/models/cms/column_request.rb', line 53

optional :max_number_of_characters, Integer, api_name: :maxNumberOfCharacters

#max_number_of_optionsInteger?

Specifies the maximum number of options that can be set for select and multi-select columns.

Returns:

  • (Integer, nil)


60
# File 'lib/hubspot_sdk/models/cms/column_request.rb', line 60

optional :max_number_of_options, Integer, api_name: :maxNumberOfOptions

#nameString

Name of the column

Returns:

  • (String)


23
# File 'lib/hubspot_sdk/models/cms/column_request.rb', line 23

required :name, String

#optionsArray<HubSpotSDK::Models::Cms::Option>

Options to choose for select and multi-select columns



29
# File 'lib/hubspot_sdk/models/cms/column_request.rb', line 29

required :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Cms::Option] }

#typeSymbol, HubSpotSDK::Models::Cms::ColumnRequest::Type

Type of the column



35
# File 'lib/hubspot_sdk/models/cms/column_request.rb', line 35

required :type, enum: -> { HubSpotSDK::Cms::ColumnRequest::Type }