Class: HubSpotSDK::Models::Cms::ContentLanguageVariation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/content_language_variation.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, archived_in_dashboard:, author_name:, campaign:, campaign_name:, created:, name:, password:, public_access_rules:, public_access_rules_enabled:, publish_date:, slug:, state:, updated:, tag_ids: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::ContentLanguageVariation for more details.

Parameters:

  • id (Integer)

    ID of object to set as primary in multi-language group.

  • archived_in_dashboard (Boolean)

    If True, the variant will not show up in your dashboard, although the post could

  • author_name (String)

    The name of the user who last published the blog post. For posts that haven’t be

  • campaign (String)

    The GUID of the marketing campaign this page is a part of.

  • campaign_name (String)

    Name of the associated marketing campaign.

  • created (Time)

    The timestamp (ISO8601 format) when this Blog Post was created.

  • name (String)

    The internal name of the content language variation.

  • password (String)

    Set this to create a password protected page. Entering the password will be requ

  • public_access_rules (Array<Object>)
  • public_access_rules_enabled (Boolean)

    Boolean to determine whether or not to respect publicAccessRules.

  • publish_date (Time)

    The date (ISO8601 format) the page is to be published at.

  • slug (String)

    The path of the this page. This field is appended to the domain to construct the

  • state (String)

    An ENUM describing the current state of this page.

  • updated (Time)

    The timestamp (ISO8601 format) when this Blog Post was updated.

  • tag_ids (Array<Integer>) (defaults to: nil)


# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 106

Instance Attribute Details

#archived_in_dashboardBoolean

If True, the variant will not show up in your dashboard, although the post could still be live.

Returns:

  • (Boolean)


18
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 18

required :archived_in_dashboard, HubSpotSDK::Internal::Type::Boolean, api_name: :archivedInDashboard

#author_nameString

The name of the user who last published the blog post. For posts that haven’t been published yet, this property will reflect the user who initially created the draft.

Returns:

  • (String)


26
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 26

required :author_name, String, api_name: :authorName

#campaignString

The GUID of the marketing campaign this page is a part of.

Returns:

  • (String)


32
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 32

required :campaign, String

#campaign_nameString

Name of the associated marketing campaign.

Returns:

  • (String)


38
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 38

required :campaign_name, String, api_name: :campaignName

#createdTime

The timestamp (ISO8601 format) when this Blog Post was created.

Returns:

  • (Time)


44
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 44

required :created, Time

#idInteger

ID of object to set as primary in multi-language group.

Returns:

  • (Integer)


11
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 11

required :id, Integer

#nameString

The internal name of the content language variation.

Returns:

  • (String)


50
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 50

required :name, String

#passwordString

Set this to create a password protected page. Entering the password will be required to view the page.

Returns:

  • (String)


57
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 57

required :password, String

#public_access_rulesArray<Object>

Returns:

  • (Array<Object>)


62
63
64
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 62

required :public_access_rules,
HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Internal::Type::Unknown],
api_name: :publicAccessRules

#public_access_rules_enabledBoolean

Boolean to determine whether or not to respect publicAccessRules.

Returns:

  • (Boolean)


70
71
72
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 70

required :public_access_rules_enabled,
HubSpotSDK::Internal::Type::Boolean,
api_name: :publicAccessRulesEnabled

#publish_dateTime

The date (ISO8601 format) the page is to be published at.

Returns:

  • (Time)


78
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 78

required :publish_date, Time, api_name: :publishDate

#slugString

The path of the this page. This field is appended to the domain to construct the url of this page.

Returns:

  • (String)


85
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 85

required :slug, String

#stateString

An ENUM describing the current state of this page.

Maximum string length: 25

Returns:

  • (String)


93
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 93

required :state, String

#tag_idsArray<Integer>?

Returns:

  • (Array<Integer>, nil)


104
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 104

optional :tag_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :tagIds

#updatedTime

The timestamp (ISO8601 format) when this Blog Post was updated.

Returns:

  • (Time)


99
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 99

required :updated, Time