Class: HubSpotSDK::Models::Cms::ContentScheduleRequestVNext

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/content_schedule_request_v_next.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, publish_date:) ⇒ Object

Parameters:

  • id (String)

    The ID of the object to be scheduled.

  • publish_date (Time)

    The date the object should transition from scheduled to published.



# File 'lib/hubspot_sdk/models/cms/content_schedule_request_v_next.rb', line 19

Instance Attribute Details

#idString

The ID of the object to be scheduled.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/cms/content_schedule_request_v_next.rb', line 11

required :id, String

#publish_dateTime

The date the object should transition from scheduled to published.

Returns:

  • (Time)


17
# File 'lib/hubspot_sdk/models/cms/content_schedule_request_v_next.rb', line 17

required :publish_date, Time, api_name: :publishDate