Class: HubSpotSDK::Models::Cms::ContentSearchResult

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/content_search_result.rb

Defined Under Namespace

Modules: Language, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, domain:, score:, type:, url:, author_full_name: nil, category: nil, combined_id: nil, content_type: nil, description: nil, featured_image_url: nil, in_beta: nil, is_private: nil, language: nil, published_date: nil, row_id: nil, subcategory: nil, table_id: nil, tags: nil, title: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::ContentSearchResult for more details.

‘LISTING_

Parameters:

  • id (Integer)

    The ID of the content.

  • domain (String)

    The domain the document is hosted on.

  • score (Float)

    The matching score of the document.

  • type (Symbol, HubSpotSDK::Models::Cms::ContentSearchResult::Type)

    The type of document. Can be ‘SITE_PAGE`, `LANDING_PAGE`, `BLOG_POST`,

  • url (String)

    The url of the document.

  • author_full_name (String) (defaults to: nil)

    Name of the author.

  • category (String) (defaults to: nil)

    The error category

  • combined_id (String) (defaults to: nil)

    The ID of the document in HubSpot.

  • content_type (String) (defaults to: nil)
  • description (String) (defaults to: nil)

    The result’s description. The content will be determined by the value of ‘length

  • featured_image_url (String) (defaults to: nil)

    URL of the featured image.

  • in_beta (Boolean) (defaults to: nil)
  • is_private (Boolean) (defaults to: nil)
  • language (Symbol, HubSpotSDK::Models::Cms::ContentSearchResult::Language) (defaults to: nil)

    The document’s language.

  • published_date (Integer) (defaults to: nil)

    The date the content was published.

  • row_id (Integer) (defaults to: nil)

    If a dynamic page, the row ID in the HubDB table.

  • subcategory (String) (defaults to: nil)

    For knowledge articles, the subcategory of the article.

  • table_id (Integer) (defaults to: nil)

    If a dynamic page, the ID of the HubDB table.

  • tags (Array<String>) (defaults to: nil)

    If a blog post, the tags associated with it.

  • title (String) (defaults to: nil)

    The title of the returned document.



# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 126

Instance Attribute Details

#author_full_nameString?

Name of the author.

Returns:

  • (String, nil)


42
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 42

optional :author_full_name, String, api_name: :authorFullName

#categoryString?

The error category

Returns:

  • (String, nil)


48
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 48

optional :category, String

#combined_idString?

The ID of the document in HubSpot.

Returns:

  • (String, nil)


54
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 54

optional :combined_id, String, api_name: :combinedId

#content_typeString?

Returns:

  • (String, nil)


59
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 59

optional :content_type, String, api_name: :contentType

#descriptionString?

The result’s description. The content will be determined by the value of ‘length` in the request.

Returns:

  • (String, nil)


66
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 66

optional :description, String

#domainString

The domain the document is hosted on.

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 17

required :domain, String

URL of the featured image.

Returns:

  • (String, nil)


72
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 72

optional :featured_image_url, String, api_name: :featuredImageUrl

#idInteger

The ID of the content.

Returns:

  • (Integer)


11
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 11

required :id, Integer

#in_betaBoolean?

Returns:

  • (Boolean, nil)


77
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 77

optional :in_beta, HubSpotSDK::Internal::Type::Boolean, api_name: :inBeta

#is_privateBoolean?

Returns:

  • (Boolean, nil)


82
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 82

optional :is_private, HubSpotSDK::Internal::Type::Boolean, api_name: :isPrivate

#languageSymbol, ...

The document’s language.



88
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 88

optional :language, enum: -> { HubSpotSDK::Cms::ContentSearchResult::Language }

#published_dateInteger?

The date the content was published.

Returns:

  • (Integer, nil)


94
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 94

optional :published_date, Integer, api_name: :publishedDate

#row_idInteger?

If a dynamic page, the row ID in the HubDB table.

Returns:

  • (Integer, nil)


100
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 100

optional :row_id, Integer, api_name: :rowId

#scoreFloat

The matching score of the document.

Returns:

  • (Float)


23
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 23

required :score, Float

#subcategoryString?

For knowledge articles, the subcategory of the article.

Returns:

  • (String, nil)


106
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 106

optional :subcategory, String

#table_idInteger?

If a dynamic page, the ID of the HubDB table.

Returns:

  • (Integer, nil)


112
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 112

optional :table_id, Integer, api_name: :tableId

#tagsArray<String>?

If a blog post, the tags associated with it.

Returns:

  • (Array<String>, nil)


118
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 118

optional :tags, HubSpotSDK::Internal::Type::ArrayOf[String]

#titleString?

The title of the returned document.

Returns:

  • (String, nil)


124
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 124

optional :title, String

#typeSymbol, HubSpotSDK::Models::Cms::ContentSearchResult::Type

The type of document. Can be ‘SITE_PAGE`, `LANDING_PAGE`, `BLOG_POST`, `LISTING_PAGE`, or `KNOWLEDGE_ARTICLE`.



30
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 30

required :type, enum: -> { HubSpotSDK::Cms::ContentSearchResult::Type }

#urlString

The url of the document.

Returns:

  • (String)


36
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 36

required :url, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 185