Class: HubSpotSDK::Models::Cms::FileExtractRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::FileExtractRequest
- Defined in:
- lib/hubspot_sdk/models/cms/file_extract_request.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#path ⇒ String
The file system location where the zip file is to be extracted.
Instance Method Summary collapse
- #initialize(path:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(path:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/cms/file_extract_request.rb', line 13
|
Instance Attribute Details
#path ⇒ String
The file system location where the zip file is to be extracted.
11 |
# File 'lib/hubspot_sdk/models/cms/file_extract_request.rb', line 11 required :path, String |