Class: HubSpotSDK::Models::Cms::HubDBTableRowV3

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/hub_db_table_row_v3.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, child_table_id:, created_at:, name:, path:, published_at:, updated_at:, values:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::HubDBTableRowV3 for more details.

Parameters:

  • id (String)

    The id of the table row

  • child_table_id (String)

    Specifies the value for the column child table id

  • created_at (Time)

    Timestamp at which the row is created

  • name (String)

    Specifies the value for ‘hs_name` column, which will be used as title in the dyn

  • path (String)

    Specifies the value for ‘hs_path` column, which will be used as slug in the dyna

  • published_at (Time)

    The timestamp indicating when the row was last published, in date-time format.

  • updated_at (Time)

    Timestamp at which the row is updated last time

  • values (Hash{Symbol=>Object})

    List of key value pairs with the column name and column value



# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3.rb', line 57

Instance Attribute Details

#child_table_idString

Specifies the value for the column child table id

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3.rb', line 17

required :child_table_id, String, api_name: :childTableId

#created_atTime

Timestamp at which the row is created

Returns:

  • (Time)


23
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3.rb', line 23

required :created_at, Time, api_name: :createdAt

#idString

The id of the table row

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3.rb', line 11

required :id, String

#nameString

Specifies the value for ‘hs_name` column, which will be used as title in the dynamic pages

Returns:

  • (String)


30
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3.rb', line 30

required :name, String

#pathString

Specifies the value for ‘hs_path` column, which will be used as slug in the dynamic pages

Returns:

  • (String)


37
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3.rb', line 37

required :path, String

#published_atTime

The timestamp indicating when the row was last published, in date-time format.

Returns:

  • (Time)


43
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3.rb', line 43

required :published_at, Time, api_name: :publishedAt

#updated_atTime

Timestamp at which the row is updated last time

Returns:

  • (Time)


49
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3.rb', line 49

required :updated_at, Time, api_name: :updatedAt

#valuesHash{Symbol=>Object}

List of key value pairs with the column name and column value

Returns:

  • (Hash{Symbol=>Object})


55
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3.rb', line 55

required :values, HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown]