Class: HubSpotSDK::Models::Cms::HubDBTableRowV3Request

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/hub_db_table_row_v3_request.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(child_table_id:, display_index:, values:, name: nil, path: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::HubDBTableRowV3Request for more details.

Parameters:

  • child_table_id (Integer)

    Specifies the value for the column child table id

  • display_index (Integer)

    The index position for displaying the row within the table.

  • values (Hash{Symbol=>Object})

    List of key value pairs with the column name and column value

  • name (String) (defaults to: nil)

    Specifies the value for ‘hs_name` column, which will be used as title in the dyn

  • path (String) (defaults to: nil)

    Specifies the value for ‘hs_path` column, which will be used as slug in the dyna



# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3_request.rb', line 39

Instance Attribute Details

#child_table_idInteger

Specifies the value for the column child table id

Returns:

  • (Integer)


11
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3_request.rb', line 11

required :child_table_id, Integer, api_name: :childTableId

#display_indexInteger

The index position for displaying the row within the table.

Returns:

  • (Integer)


17
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3_request.rb', line 17

required :display_index, Integer, api_name: :displayIndex

#nameString?

Specifies the value for ‘hs_name` column, which will be used as title in the dynamic pages

Returns:

  • (String, nil)


30
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3_request.rb', line 30

optional :name, String

#pathString?

Specifies the value for ‘hs_path` column, which will be used as slug in the dynamic pages

Returns:

  • (String, nil)


37
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3_request.rb', line 37

optional :path, String

#valuesHash{Symbol=>Object}

List of key value pairs with the column name and column value

Returns:

  • (Hash{Symbol=>Object})


23
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3_request.rb', line 23

required :values, HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown]