Class: HubSpotSDK::Models::Cms::HubDBTableV3

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/hub_db_table_v3.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, allow_child_tables:, allow_public_api_access:, column_count:, columns:, created_at:, deleted:, deleted_at:, dynamic_meta_tags:, enable_child_table_pages:, label:, name:, published:, published_at:, row_count:, updated_at:, use_for_pages:, created_by: nil, is_ordered_manually: nil, updated_by: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::HubDBTableV3 for more details.

Parameters:

  • id (String)

    Id of the table

  • allow_child_tables (Boolean)

    Specifies whether child tables can be created

  • allow_public_api_access (Boolean)

    Specifies whether the table can be read by public without authorization

  • column_count (Integer)

    Number of columns including deleted

  • columns (Array<HubSpotSDK::Models::Cms::Column>)

    List of columns in the table

  • created_at (Time)

    Timestamp at which the table is created

  • deleted (Boolean)

    Specifies whether the table is marked as deleted.

  • deleted_at (Time)

    The timestamp indicating when the table was deleted.

  • dynamic_meta_tags (Hash{Symbol=>Integer})

    Specifies the key value pairs of the [metadata fields](developers.hubspo

  • enable_child_table_pages (Boolean)

    Specifies creation of multi-level dynamic pages using child tables

  • label (String)

    Label of the table

  • name (String)

    Name of the table

  • published (Boolean)

    Indicates whether the table is currently published.

  • published_at (Time)

    Timestamp at which the table is published recently

  • row_count (Integer)

    Number of rows in the table

  • updated_at (Time)

    Timestamp at which the table is updated recently

  • use_for_pages (Boolean)

    Specifies whether the table can be used for creation of dynamic pages

  • created_by (HubSpotSDK::Models::Cms::SimpleUser) (defaults to: nil)
  • is_ordered_manually (Boolean) (defaults to: nil)

    Indicates whether the table rows are ordered manually.

  • updated_by (HubSpotSDK::Models::Cms::SimpleUser) (defaults to: nil)


# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 131

Instance Attribute Details

#allow_child_tablesBoolean

Specifies whether child tables can be created

Returns:

  • (Boolean)


17
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 17

required :allow_child_tables, HubSpotSDK::Internal::Type::Boolean, api_name: :allowChildTables

#allow_public_api_accessBoolean

Specifies whether the table can be read by public without authorization

Returns:

  • (Boolean)


23
24
25
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 23

required :allow_public_api_access,
HubSpotSDK::Internal::Type::Boolean,
api_name: :allowPublicApiAccess

#column_countInteger

Number of columns including deleted

Returns:

  • (Integer)


31
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 31

required :column_count, Integer, api_name: :columnCount

#columnsArray<HubSpotSDK::Models::Cms::Column>

List of columns in the table



37
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 37

required :columns, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Cms::Column] }

#created_atTime

Timestamp at which the table is created

Returns:

  • (Time)


43
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 43

required :created_at, Time, api_name: :createdAt

#created_byHubSpotSDK::Models::Cms::SimpleUser?



118
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 118

optional :created_by, -> { HubSpotSDK::Cms::SimpleUser }, api_name: :createdBy

#deletedBoolean

Specifies whether the table is marked as deleted.

Returns:

  • (Boolean)


49
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 49

required :deleted, HubSpotSDK::Internal::Type::Boolean

#deleted_atTime

The timestamp indicating when the table was deleted.

Returns:

  • (Time)


55
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 55

required :deleted_at, Time, api_name: :deletedAt

#dynamic_meta_tagsHash{Symbol=>Integer}

Specifies the key value pairs of the [metadata fields](developers.hubspot.com/docs/cms/guides/dynamic-pages/hubdb#dynamic-pages) with the associated column IDs.

Returns:

  • (Hash{Symbol=>Integer})


63
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 63

required :dynamic_meta_tags, HubSpotSDK::Internal::Type::HashOf[Integer], api_name: :dynamicMetaTags

#enable_child_table_pagesBoolean

Specifies creation of multi-level dynamic pages using child tables

Returns:

  • (Boolean)


69
70
71
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 69

required :enable_child_table_pages,
HubSpotSDK::Internal::Type::Boolean,
api_name: :enableChildTablePages

#idString

Id of the table

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 11

required :id, String

#is_ordered_manuallyBoolean?

Indicates whether the table rows are ordered manually.

Returns:

  • (Boolean, nil)


124
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 124

optional :is_ordered_manually, HubSpotSDK::Internal::Type::Boolean, api_name: :isOrderedManually

#labelString

Label of the table

Returns:

  • (String)


77
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 77

required :label, String

#nameString

Name of the table

Returns:

  • (String)


83
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 83

required :name, String

#publishedBoolean

Indicates whether the table is currently published.

Returns:

  • (Boolean)


89
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 89

required :published, HubSpotSDK::Internal::Type::Boolean

#published_atTime

Timestamp at which the table is published recently

Returns:

  • (Time)


95
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 95

required :published_at, Time, api_name: :publishedAt

#row_countInteger

Number of rows in the table

Returns:

  • (Integer)


101
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 101

required :row_count, Integer, api_name: :rowCount

#updated_atTime

Timestamp at which the table is updated recently

Returns:

  • (Time)


107
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 107

required :updated_at, Time, api_name: :updatedAt

#updated_byHubSpotSDK::Models::Cms::SimpleUser?



129
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 129

optional :updated_by, -> { HubSpotSDK::Cms::SimpleUser }, api_name: :updatedBy

#use_for_pagesBoolean

Specifies whether the table can be used for creation of dynamic pages

Returns:

  • (Boolean)


113
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3.rb', line 113

required :use_for_pages, HubSpotSDK::Internal::Type::Boolean, api_name: :useForPages