Class: HubSpotSDK::Models::Cms::Hubdb::RowListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(table_id_or_name:, after: nil, archived: nil, limit: nil, offset: nil, properties: nil, sort: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::Hubdb::RowListParams for more details.

Parameters:

  • table_id_or_name (String)
  • after (String) (defaults to: nil)

    The paging cursor token of the last successfully read resource will be returned

  • archived (Boolean) (defaults to: nil)

    Whether to return only results that have been archived.

  • limit (Integer) (defaults to: nil)

    The maximum number of results to display per page.

  • offset (Integer) (defaults to: nil)
  • properties (Array<String>) (defaults to: nil)
  • sort (Array<String>) (defaults to: nil)
  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb', line 52

Instance Attribute Details

#afterString?

The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.

Returns:

  • (String, nil)


23
# File 'lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb', line 23

optional :after, String

#archivedBoolean?

Whether to return only results that have been archived.

Returns:

  • (Boolean, nil)


29
# File 'lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb', line 29

optional :archived, HubSpotSDK::Internal::Type::Boolean

#limitInteger?

The maximum number of results to display per page.

Returns:

  • (Integer, nil)


35
# File 'lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb', line 35

optional :limit, Integer

#offsetInteger?

Returns:

  • (Integer, nil)


40
# File 'lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb', line 40

optional :offset, Integer

#propertiesArray<String>?

Returns:

  • (Array<String>, nil)


45
# File 'lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb', line 45

optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String]

#sortArray<String>?

Returns:

  • (Array<String>, nil)


50
# File 'lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb', line 50

optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String]

#table_id_or_nameString

Returns:

  • (String)


15
# File 'lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb', line 15

required :table_id_or_name, String