Class: HubSpotSDK::Models::Cms::Hubdb::TableListParams
Overview
Instance Attribute Summary collapse
#request_options
Instance Method Summary
collapse
-
#initialize(after: nil, archived: nil, content_type: nil, created_after: nil, created_at: nil, created_before: nil, is_get_localized_schema: nil, limit: nil, sort: nil, updated_after: nil, updated_at: nil, updated_before: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TableListParams for more details.
dump_request
included
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, archived: nil, content_type: nil, created_after: nil, created_at: nil, created_before: nil, is_get_localized_schema: nil, limit: nil, sort: nil, updated_after: nil, updated_at: nil, updated_before: nil, request_options: {}) ⇒ Object
|
# File 'lib/hubspot_sdk/models/cms/hubdb/table_list_params.rb', line 77
|
Instance Attribute Details
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
18
|
# File 'lib/hubspot_sdk/models/cms/hubdb/table_list_params.rb', line 18
optional :after, String
|
#archived ⇒ Boolean?
Whether to return only results that have been archived.
#content_type ⇒ String?
29
|
# File 'lib/hubspot_sdk/models/cms/hubdb/table_list_params.rb', line 29
optional :content_type, String
|
#created_after ⇒ Time?
34
|
# File 'lib/hubspot_sdk/models/cms/hubdb/table_list_params.rb', line 34
optional :created_after, Time
|
#created_at ⇒ Time?
39
|
# File 'lib/hubspot_sdk/models/cms/hubdb/table_list_params.rb', line 39
optional :created_at, Time
|
#created_before ⇒ Time?
44
|
# File 'lib/hubspot_sdk/models/cms/hubdb/table_list_params.rb', line 44
optional :created_before, Time
|
#is_get_localized_schema ⇒ Boolean?
49
|
# File 'lib/hubspot_sdk/models/cms/hubdb/table_list_params.rb', line 49
optional :is_get_localized_schema, HubSpotSDK::Internal::Type::Boolean
|
#limit ⇒ Integer?
The maximum number of results to display per page.
55
|
# File 'lib/hubspot_sdk/models/cms/hubdb/table_list_params.rb', line 55
optional :limit, Integer
|
#updated_after ⇒ Time?
65
|
# File 'lib/hubspot_sdk/models/cms/hubdb/table_list_params.rb', line 65
optional :updated_after, Time
|
#updated_at ⇒ Time?
70
|
# File 'lib/hubspot_sdk/models/cms/hubdb/table_list_params.rb', line 70
optional :updated_at, Time
|
#updated_before ⇒ Time?
75
|
# File 'lib/hubspot_sdk/models/cms/hubdb/table_list_params.rb', line 75
optional :updated_before, Time
|