Class: HubSpotSDK::Models::Cms::MediaBridgeListPropertiesParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::MediaBridgeListPropertiesParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/cms/media_bridge_list_properties_params.rb
Overview
Instance Attribute Summary collapse
- #app_id ⇒ Integer
-
#archived ⇒ Boolean?
Whether to return only results that have been archived.
- #object_type ⇒ String
- #properties ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(app_id:, object_type:, archived: nil, properties: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(app_id:, object_type:, archived: nil, properties: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/cms/media_bridge_list_properties_params.rb', line 32
|
Instance Attribute Details
#app_id ⇒ Integer
14 |
# File 'lib/hubspot_sdk/models/cms/media_bridge_list_properties_params.rb', line 14 required :app_id, Integer |
#archived ⇒ Boolean?
Whether to return only results that have been archived.
25 |
# File 'lib/hubspot_sdk/models/cms/media_bridge_list_properties_params.rb', line 25 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#object_type ⇒ String
19 |
# File 'lib/hubspot_sdk/models/cms/media_bridge_list_properties_params.rb', line 19 required :object_type, String |
#properties ⇒ String?
30 |
# File 'lib/hubspot_sdk/models/cms/media_bridge_list_properties_params.rb', line 30 optional :properties, String |