Class: HubSpotSDK::Models::Cms::MediaPlayedPercentageEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/media_played_percentage_event.rb

Overview

Defined Under Namespace

Modules: ExternalPlayContext, MediaType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(contact_id:, media_bridge_id:, media_bridge_object_coordinates:, media_bridge_object_type_id:, media_name:, media_type:, occurred_timestamp:, played_percent:, portal_id:, provider_id:, session_id:, external_play_context: nil, media_url: nil, page_id: nil, page_name: nil, page_object_coordinates: nil, page_url: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::MediaPlayedPercentageEvent for more details.

Parameters:

  • contact_id (Integer)

    The ID of the contact in HubSpot’s system that consumed the media. This can be f

  • media_bridge_id (Integer)
  • media_bridge_object_coordinates (String)
  • media_bridge_object_type_id (String)
  • media_name (String)
  • media_type (Symbol, HubSpotSDK::Models::Cms::MediaPlayedPercentageEvent::MediaType)
  • occurred_timestamp (Integer)
  • played_percent (Integer)
  • portal_id (Integer)

    The ID of the HubSpot account.

  • provider_id (Integer)
  • session_id (String)
  • external_play_context (Symbol, HubSpotSDK::Models::Cms::MediaPlayedPercentageEvent::ExternalPlayContext) (defaults to: nil)
  • media_url (String) (defaults to: nil)
  • page_id (Integer) (defaults to: nil)

    The content ID of the page that an event happened on, for HubSpot pages. Require

  • page_name (String) (defaults to: nil)

    The name or title of the page that an event happened on. Required for non-HubSpo

  • page_object_coordinates (String) (defaults to: nil)
  • page_url (String) (defaults to: nil)

    The URL of the page that an event happened on. Required for non-HubSpot pages.



# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 107

Instance Attribute Details

#contact_idInteger

The ID of the contact in HubSpot’s system that consumed the media. This can be fetched using HubSpot’s Get contact by usertoken (utk) API. The API also supports supplying a usertoken, and will handle converting this into a contact ID automatically.

Returns:

  • (Integer)


15
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 15

required :contact_id, Integer, api_name: :contactId

#external_play_contextSymbol, ...



73
74
75
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 73

optional :external_play_context,
enum: -> { HubSpotSDK::Cms::MediaPlayedPercentageEvent::ExternalPlayContext },
api_name: :externalPlayContext

#media_bridge_idInteger

Returns:

  • (Integer)


20
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 20

required :media_bridge_id, Integer, api_name: :mediaBridgeId

#media_bridge_object_coordinatesString

Returns:

  • (String)


25
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 25

required :media_bridge_object_coordinates, String, api_name: :mediaBridgeObjectCoordinates

#media_bridge_object_type_idString

Returns:

  • (String)


30
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 30

required :media_bridge_object_type_id, String, api_name: :mediaBridgeObjectTypeId

#media_nameString

Returns:

  • (String)


35
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 35

required :media_name, String, api_name: :mediaName

#media_typeSymbol, HubSpotSDK::Models::Cms::MediaPlayedPercentageEvent::MediaType



40
41
42
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 40

required :media_type,
enum: -> { HubSpotSDK::Cms::MediaPlayedPercentageEvent::MediaType },
api_name: :mediaType

#media_urlString?

Returns:

  • (String, nil)


80
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 80

optional :media_url, String, api_name: :mediaUrl

#occurred_timestampInteger

Returns:

  • (Integer)


47
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 47

required :occurred_timestamp, Integer, api_name: :occurredTimestamp

#page_idInteger?

The content ID of the page that an event happened on, for HubSpot pages. Required if the page is a HubSpot page.

Returns:

  • (Integer, nil)


87
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 87

optional :page_id, Integer, api_name: :pageId

#page_nameString?

The name or title of the page that an event happened on. Required for non-HubSpot pages.

Returns:

  • (String, nil)


94
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 94

optional :page_name, String, api_name: :pageName

#page_object_coordinatesString?

Returns:

  • (String, nil)


99
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 99

optional :page_object_coordinates, String, api_name: :pageObjectCoordinates

#page_urlString?

The URL of the page that an event happened on. Required for non-HubSpot pages.

Returns:

  • (String, nil)


105
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 105

optional :page_url, String, api_name: :pageUrl

#played_percentInteger

Returns:

  • (Integer)


52
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 52

required :played_percent, Integer, api_name: :playedPercent

#portal_idInteger

The ID of the HubSpot account.

Returns:

  • (Integer)


58
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 58

required :portal_id, Integer, api_name: :portalId

#provider_idInteger

Returns:

  • (Integer)


63
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 63

required :provider_id, Integer, api_name: :providerId

#session_idString

Returns:

  • (String)


68
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 68

required :session_id, String, api_name: :sessionId

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 155