Class: HubSpotSDK::Models::Cms::Option

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/option.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, label:, name:, order:, type:, updated_at:, created_by: nil, created_by_user_id: nil, updated_by: nil, updated_by_user_id: nil) ⇒ Object

A HubSpot property option

Parameters:

  • id (String)

    The unique ID of the option.

  • created_at (Time)

    The timestamp when the option was created, in ISO 8601 format.

  • label (String)

    A user-friendly label that identifies the option.

  • name (String)

    An internal name assigned to the option, distinct from the label.

  • order (Integer)

    The order in which the option appears, represented as an integer.

  • type (String)

    Indicates the category or data type of the option (e.g., string, number).

  • updated_at (Time)

    The timestamp when the option was last updated, in ISO 8601 format.

  • created_by (HubSpotSDK::Models::Cms::SimpleUser) (defaults to: nil)
  • created_by_user_id (Integer) (defaults to: nil)

    The ID of the user who created the option.

  • updated_by (HubSpotSDK::Models::Cms::SimpleUser) (defaults to: nil)
  • updated_by_user_id (Integer) (defaults to: nil)

    The ID of the user who last updated the option.



# File 'lib/hubspot_sdk/models/cms/option.rb', line 71

Instance Attribute Details

#created_atTime

The timestamp when the option was created, in ISO 8601 format.

Returns:

  • (Time)


17
# File 'lib/hubspot_sdk/models/cms/option.rb', line 17

required :created_at, Time, api_name: :createdAt

#created_byHubSpotSDK::Models::Cms::SimpleUser?



52
# File 'lib/hubspot_sdk/models/cms/option.rb', line 52

optional :created_by, -> { HubSpotSDK::Cms::SimpleUser }, api_name: :createdBy

#created_by_user_idInteger?

The ID of the user who created the option.

Returns:

  • (Integer, nil)


58
# File 'lib/hubspot_sdk/models/cms/option.rb', line 58

optional :created_by_user_id, Integer, api_name: :createdByUserId

#idString

The unique ID of the option.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/cms/option.rb', line 11

required :id, String

#labelString

A user-friendly label that identifies the option.

Returns:

  • (String)


23
# File 'lib/hubspot_sdk/models/cms/option.rb', line 23

required :label, String

#nameString

An internal name assigned to the option, distinct from the label.

Returns:

  • (String)


29
# File 'lib/hubspot_sdk/models/cms/option.rb', line 29

required :name, String

#orderInteger

The order in which the option appears, represented as an integer.

Returns:

  • (Integer)


35
# File 'lib/hubspot_sdk/models/cms/option.rb', line 35

required :order, Integer

#typeString

Indicates the category or data type of the option (e.g., string, number).

Returns:

  • (String)


41
# File 'lib/hubspot_sdk/models/cms/option.rb', line 41

required :type, String

#updated_atTime

The timestamp when the option was last updated, in ISO 8601 format.

Returns:

  • (Time)


47
# File 'lib/hubspot_sdk/models/cms/option.rb', line 47

required :updated_at, Time, api_name: :updatedAt

#updated_byHubSpotSDK::Models::Cms::SimpleUser?



63
# File 'lib/hubspot_sdk/models/cms/option.rb', line 63

optional :updated_by, -> { HubSpotSDK::Cms::SimpleUser }, api_name: :updatedBy

#updated_by_user_idInteger?

The ID of the user who last updated the option.

Returns:

  • (Integer, nil)


69
# File 'lib/hubspot_sdk/models/cms/option.rb', line 69

optional :updated_by_user_id, Integer, api_name: :updatedByUserId