Class: HubSpotSDK::Models::Cms::PageData

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/page_data.rb

Overview

Defined Under Namespace

Modules: AbStatus, ContentTypeCategory, CurrentState, Language

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, ab_status:, ab_test_id:, archived_at:, archived_in_dashboard:, attached_stylesheets:, author_name:, campaign:, category_id:, content_group_id:, content_type_category:, created:, created_by_id:, currently_published:, current_state:, domain:, dynamic_page_data_source_id:, dynamic_page_data_source_type:, dynamic_page_hub_db_table_id:, enable_domain_stylesheets:, enable_layout_stylesheets:, featured_image:, featured_image_alt_text:, folder_id:, footer_html:, head_html:, html_title:, include_default_custom_css:, language:, layout_sections:, link_rel_canonical_url:, mab_experiment_id:, meta_description:, name:, page_expiry_date:, page_expiry_enabled:, page_expiry_redirect_id:, page_expiry_redirect_url:, page_redirected:, password:, public_access_rules:, public_access_rules_enabled:, publish_date:, publish_immediately:, slug:, state:, subcategory:, template_path:, theme_settings_values:, translated_from_id:, translations:, updated:, updated_by_id:, url:, use_featured_image:, widget_containers:, widgets:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::PageData for more details.

Parameters:

  • id (String)

    The unique ID of the page.

  • ab_status (Symbol, HubSpotSDK::Models::Cms::PageData::AbStatus)

    The status of the AB test associated with this page, if applicable

  • ab_test_id (String)

    The ID of the AB test associated with this page, if applicable

  • archived_at (Time)

    The timestamp (ISO8601 format) when this page was deleted.

  • archived_in_dashboard (Boolean)

    If True, the page will not show up in your dashboard, although the page could st

  • attached_stylesheets (Array<Hash{Symbol=>Object}>)

    List of stylesheets to attach to this page. These stylesheets are attached to ju

  • author_name (String)

    The name of the user that updated this page.

  • campaign (String)

    The GUID of the marketing campaign this page is a part of.

  • category_id (Integer)

    ID of the type of object this is. Should always .

  • content_group_id (String)

    The unique identifier for the content group associated with the page.

  • content_type_category (Symbol, HubSpotSDK::Models::Cms::PageData::ContentTypeCategory)

    An ENUM descibing the type of this object. Should be either LANDING_PAGE or SITE

  • created (Time)

    The timestamp indicating when the page was created.

  • created_by_id (String)

    The ID of the user that created this page.

  • currently_published (Boolean)

    Indicates whether the page is currently published.

  • current_state (Symbol, HubSpotSDK::Models::Cms::PageData::CurrentState)

    A generated ENUM descibing the current state of this page.

  • domain (String)

    The domain this page will resolve to. If null, the page will default to the prim

  • dynamic_page_data_source_id (String)

    The identifier for the data source used by the dynamic page.

  • dynamic_page_data_source_type (Integer)

    The type of data source used by the dynamic page.

  • dynamic_page_hub_db_table_id (String)

    The ID of the HubDB table this page references, if applicable

  • enable_domain_stylesheets (Boolean)

    Boolean to determine whether or not the styles from the template should be appli

  • enable_layout_stylesheets (Boolean)

    Boolean to determine whether or not the styles from the template should be appli

  • featured_image (String)

    The featuredImage of this page.

  • featured_image_alt_text (String)

    Alt Text of the featuredImage.

  • folder_id (String)

    The ID of the associated folder this landing page is organized under in the app

  • footer_html (String)

    Custom HTML for embed codes, javascript that should be placed before the </body>

  • head_html (String)

    Custom HTML for embed codes, javascript, etc. that goes in the <head> tag of the

  • html_title (String)

    The html title of this page.

  • include_default_custom_css (Boolean)

    Boolean to determine whether or not the Primary CSS Files should be applied.

  • language (Symbol, HubSpotSDK::Models::Cms::PageData::Language)

    The explicitly defined ISO 639 language code of the page. If null, the page will

  • layout_sections (Hash{Symbol=>HubSpotSDK::Models::Cms::LayoutSection})

    A structure detailing the layout sections of the page.

  • link_rel_canonical_url (String)

    Optional override to set the URL to be used in the rel=canonical link tag on the

  • mab_experiment_id (String)

    The ID of the MAB test (or dynamic test) associated with this page, if applicabl

  • meta_description (String)

    A description that goes in <meta> tag on the page.

  • name (String)

    The internal name of the page.

  • page_expiry_date (Integer)

    The date at which this page should expire and begin redirecting to another url o

  • page_expiry_enabled (Boolean)

    Boolean describing if the page expiration feature is enabled for this page

  • page_expiry_redirect_id (Integer)

    The ID of another page this page’s url should redirect to once this page expires

  • page_expiry_redirect_url (String)

    The URL this page’s url should redirect to once this page expires. Should only s

  • page_redirected (Boolean)

    A generated Boolean describing whether or not this page is currently expired and

  • password (String)

    Set this to create a password protected page. Entering the password will be requ

  • public_access_rules (Array<Object>)

    Rules for require member registration to access private content.

  • public_access_rules_enabled (Boolean)

    Boolean to determine whether or not to respect publicAccessRules.

  • publish_date (Time)

    The date (ISO8601 format) the page is to be published at.

  • publish_immediately (Boolean)

    Set this to true if you want to be published immediately when the schedule publi

  • slug (String)

    The path of the this page. This field is appended to the domain to construct the

  • state (String)

    An ENUM descibing the current state of this page.

  • subcategory (String)

    Details the type of page this is. Should always be landing_page or site_page

  • template_path (String)

    String detailing the path of the template used for this page.

  • theme_settings_values (Hash{Symbol=>Object})

    A collection of settings specific to the theme applied to the page.

  • translated_from_id (String)

    ID of the primary page this object was translated from.

  • translations (Hash{Symbol=>HubSpotSDK::Models::Cms::ContentLanguageVariation})

    A map of translations for the page, each associated with a specific language var

  • updated (Time)

    The timestamp indicating when the page was last updated.

  • updated_by_id (String)

    The ID of the user that updated this page.

  • url (String)

    A generated field representing the URL of this page.

  • use_featured_image (Boolean)

    Boolean to determine if this page should use a featuredImage.

  • widget_containers (Hash{Symbol=>Object})

    A data structure containing the data for all the modules inside the containers f

  • widgets (Hash{Symbol=>Object})

    A data structure containing the data for all the modules for this page.



# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 392

Instance Attribute Details

#ab_statusSymbol, HubSpotSDK::Models::Cms::PageData::AbStatus

The status of the AB test associated with this page, if applicable



18
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 18

required :ab_status, enum: -> { HubSpotSDK::Cms::PageData::AbStatus }, api_name: :abStatus

#ab_test_idString

The ID of the AB test associated with this page, if applicable

Returns:

  • (String)


24
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 24

required :ab_test_id, String, api_name: :abTestId

#archived_atTime

The timestamp (ISO8601 format) when this page was deleted.

Returns:

  • (Time)


30
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 30

required :archived_at, Time, api_name: :archivedAt

#archived_in_dashboardBoolean

If True, the page will not show up in your dashboard, although the page could still be live.

Returns:

  • (Boolean)


37
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 37

required :archived_in_dashboard, HubSpotSDK::Internal::Type::Boolean, api_name: :archivedInDashboard

#attached_stylesheetsArray<Hash{Symbol=>Object}>

List of stylesheets to attach to this page. These stylesheets are attached to just this page. Order of precedence is bottom to top, just like in the HTML.

Returns:

  • (Array<Hash{Symbol=>Object}>)


44
45
46
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 44

required :attached_stylesheets,
HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown]],
api_name: :attachedStylesheets

#author_nameString

The name of the user that updated this page.

Returns:

  • (String)


52
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 52

required :author_name, String, api_name: :authorName

#campaignString

The GUID of the marketing campaign this page is a part of.

Returns:

  • (String)


58
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 58

required :campaign, String

#category_idInteger

ID of the type of object this is. Should always .

Returns:

  • (Integer)


64
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 64

required :category_id, Integer, api_name: :categoryId

#content_group_idString

The unique identifier for the content group associated with the page.

Returns:

  • (String)


70
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 70

required :content_group_id, String, api_name: :contentGroupId

#content_type_categorySymbol, HubSpotSDK::Models::Cms::PageData::ContentTypeCategory

An ENUM descibing the type of this object. Should be either LANDING_PAGE or SITE_PAGE.



77
78
79
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 77

required :content_type_category,
enum: -> { HubSpotSDK::Cms::PageData::ContentTypeCategory },
api_name: :contentTypeCategory

#createdTime

The timestamp indicating when the page was created.

Returns:

  • (Time)


85
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 85

required :created, Time

#created_by_idString

The ID of the user that created this page.

Returns:

  • (String)


91
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 91

required :created_by_id, String, api_name: :createdById

#current_stateSymbol, HubSpotSDK::Models::Cms::PageData::CurrentState

A generated ENUM descibing the current state of this page.



103
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 103

required :current_state, enum: -> { HubSpotSDK::Cms::PageData::CurrentState }, api_name: :currentState

#currently_publishedBoolean

Indicates whether the page is currently published.

Returns:

  • (Boolean)


97
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 97

required :currently_published, HubSpotSDK::Internal::Type::Boolean, api_name: :currentlyPublished

#domainString

The domain this page will resolve to. If null, the page will default to the primary domain for this content type.

Returns:

  • (String)


110
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 110

required :domain, String

#dynamic_page_data_source_idString

The identifier for the data source used by the dynamic page.

Returns:

  • (String)


116
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 116

required :dynamic_page_data_source_id, String, api_name: :dynamicPageDataSourceId

#dynamic_page_data_source_typeInteger

The type of data source used by the dynamic page.

Returns:

  • (Integer)


122
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 122

required :dynamic_page_data_source_type, Integer, api_name: :dynamicPageDataSourceType

#dynamic_page_hub_db_table_idString

The ID of the HubDB table this page references, if applicable

Returns:

  • (String)


128
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 128

required :dynamic_page_hub_db_table_id, String, api_name: :dynamicPageHubDbTableId

#enable_domain_stylesheetsBoolean

Boolean to determine whether or not the styles from the template should be applied.

Returns:

  • (Boolean)


135
136
137
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 135

required :enable_domain_stylesheets,
HubSpotSDK::Internal::Type::Boolean,
api_name: :enableDomainStylesheets

#enable_layout_stylesheetsBoolean

Boolean to determine whether or not the styles from the template should be applied.

Returns:

  • (Boolean)


144
145
146
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 144

required :enable_layout_stylesheets,
HubSpotSDK::Internal::Type::Boolean,
api_name: :enableLayoutStylesheets

The featuredImage of this page.

Returns:

  • (String)


152
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 152

required :featured_image, String, api_name: :featuredImage

Alt Text of the featuredImage.

Returns:

  • (String)


158
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 158

required :featured_image_alt_text, String, api_name: :featuredImageAltText

#folder_idString

The ID of the associated folder this landing page is organized under in the app dashboard.

Returns:

  • (String)


165
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 165

required :folder_id, String, api_name: :folderId

Custom HTML for embed codes, javascript that should be placed before the </body> tag of the page.

Returns:

  • (String)


172
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 172

required :footer_html, String, api_name: :footerHtml

#head_htmlString

Custom HTML for embed codes, javascript, etc. that goes in the <head> tag of the page.

Returns:

  • (String)


179
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 179

required :head_html, String, api_name: :headHtml

#html_titleString

The html title of this page.

Returns:

  • (String)


185
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 185

required :html_title, String, api_name: :htmlTitle

#idString

The unique ID of the page.

Returns:

  • (String)


12
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 12

required :id, String

#include_default_custom_cssBoolean

Boolean to determine whether or not the Primary CSS Files should be applied.

Returns:

  • (Boolean)


191
192
193
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 191

required :include_default_custom_css,
HubSpotSDK::Internal::Type::Boolean,
api_name: :includeDefaultCustomCss

#languageSymbol, HubSpotSDK::Models::Cms::PageData::Language

The explicitly defined ISO 639 language code of the page. If null, the page will default to the language of the Domain.



200
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 200

required :language, enum: -> { HubSpotSDK::Cms::PageData::Language }

#layout_sectionsHash{Symbol=>HubSpotSDK::Models::Cms::LayoutSection}

A structure detailing the layout sections of the page.

Returns:



206
207
208
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 206

required :layout_sections,
-> { HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Cms::LayoutSection] },
api_name: :layoutSections

Optional override to set the URL to be used in the rel=canonical link tag on the page.

Returns:

  • (String)


215
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 215

required :link_rel_canonical_url, String, api_name: :linkRelCanonicalUrl

#mab_experiment_idString

The ID of the MAB test (or dynamic test) associated with this page, if applicable

Returns:

  • (String)


222
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 222

required :mab_experiment_id, String, api_name: :mabExperimentId

#meta_descriptionString

A description that goes in <meta> tag on the page.

Returns:

  • (String)


228
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 228

required :meta_description, String, api_name: :metaDescription

#nameString

The internal name of the page.

Returns:

  • (String)


234
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 234

required :name, String

#page_expiry_dateInteger

The date at which this page should expire and begin redirecting to another url or page.

Returns:

  • (Integer)


241
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 241

required :page_expiry_date, Integer, api_name: :pageExpiryDate

#page_expiry_enabledBoolean

Boolean describing if the page expiration feature is enabled for this page

Returns:

  • (Boolean)


247
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 247

required :page_expiry_enabled, HubSpotSDK::Internal::Type::Boolean, api_name: :pageExpiryEnabled

#page_expiry_redirect_idInteger

The ID of another page this page’s url should redirect to once this page expires. Should only set this or pageExpiryRedirectUrl.

Returns:

  • (Integer)


254
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 254

required :page_expiry_redirect_id, Integer, api_name: :pageExpiryRedirectId

#page_expiry_redirect_urlString

The URL this page’s url should redirect to once this page expires. Should only set this or pageExpiryRedirectId.

Returns:

  • (String)


261
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 261

required :page_expiry_redirect_url, String, api_name: :pageExpiryRedirectUrl

#page_redirectedBoolean

A generated Boolean describing whether or not this page is currently expired and being redirected.

Returns:

  • (Boolean)


268
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 268

required :page_redirected, HubSpotSDK::Internal::Type::Boolean, api_name: :pageRedirected

#passwordString

Set this to create a password protected page. Entering the password will be required to view the page.

Returns:

  • (String)


275
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 275

required :password, String

#public_access_rulesArray<Object>

Rules for require member registration to access private content.

Returns:

  • (Array<Object>)


281
282
283
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 281

required :public_access_rules,
HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Internal::Type::Unknown],
api_name: :publicAccessRules

#public_access_rules_enabledBoolean

Boolean to determine whether or not to respect publicAccessRules.

Returns:

  • (Boolean)


289
290
291
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 289

required :public_access_rules_enabled,
HubSpotSDK::Internal::Type::Boolean,
api_name: :publicAccessRulesEnabled

#publish_dateTime

The date (ISO8601 format) the page is to be published at.

Returns:

  • (Time)


297
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 297

required :publish_date, Time, api_name: :publishDate

#publish_immediatelyBoolean

Set this to true if you want to be published immediately when the schedule publish endpoint is called, and to ignore the publish_date setting.

Returns:

  • (Boolean)


304
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 304

required :publish_immediately, HubSpotSDK::Internal::Type::Boolean, api_name: :publishImmediately

#slugString

The path of the this page. This field is appended to the domain to construct the url of this page.

Returns:

  • (String)


311
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 311

required :slug, String

#stateString

An ENUM descibing the current state of this page.

Returns:

  • (String)


317
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 317

required :state, String

#subcategoryString

Details the type of page this is. Should always be landing_page or site_page

Returns:

  • (String)


323
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 323

required :subcategory, String

#template_pathString

String detailing the path of the template used for this page.

Returns:

  • (String)


329
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 329

required :template_path, String, api_name: :templatePath

#theme_settings_valuesHash{Symbol=>Object}

A collection of settings specific to the theme applied to the page.

Returns:

  • (Hash{Symbol=>Object})


335
336
337
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 335

required :theme_settings_values,
HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown],
api_name: :themeSettingsValues

#translated_from_idString

ID of the primary page this object was translated from.

Returns:

  • (String)


343
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 343

required :translated_from_id, String, api_name: :translatedFromId

#translationsHash{Symbol=>HubSpotSDK::Models::Cms::ContentLanguageVariation}

A map of translations for the page, each associated with a specific language variation.



350
351
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 350

required :translations,
-> { HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Cms::ContentLanguageVariation] }

#updatedTime

The timestamp indicating when the page was last updated.

Returns:

  • (Time)


357
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 357

required :updated, Time

#updated_by_idString

The ID of the user that updated this page.

Returns:

  • (String)


363
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 363

required :updated_by_id, String, api_name: :updatedById

#urlString

A generated field representing the URL of this page.

Returns:

  • (String)


369
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 369

required :url, String

Boolean to determine if this page should use a featuredImage.

Returns:

  • (Boolean)


375
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 375

required :use_featured_image, HubSpotSDK::Internal::Type::Boolean, api_name: :useFeaturedImage

#widget_containersHash{Symbol=>Object}

A data structure containing the data for all the modules inside the containers for this page. This will only be populated if the page has widget containers.

Returns:

  • (Hash{Symbol=>Object})


382
383
384
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 382

required :widget_containers,
HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown],
api_name: :widgetContainers

#widgetsHash{Symbol=>Object}

A data structure containing the data for all the modules for this page.

Returns:

  • (Hash{Symbol=>Object})


390
# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 390

required :widgets, HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown]

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/cms/page_data.rb', line 525