Class: HubSpotSDK::Models::Cms::Pages::WebsitePageListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after: nil, archived: nil, created_after: nil, created_at: nil, created_before: nil, limit: nil, property: nil, sort: nil, updated_after: nil, updated_at: nil, updated_before: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::Pages::WebsitePageListParams for more details.

Parameters:

  • after (String) (defaults to: nil)

    The paging cursor token of the last successfully read resource will be returned

  • archived (Boolean) (defaults to: nil)

    Whether to return only results that have been archived.

  • created_after (Time) (defaults to: nil)

    Filter pages created after a specific date and time.

  • created_at (Time) (defaults to: nil)

    Filter pages by the exact creation timestamp. Format is date-time.

  • created_before (Time) (defaults to: nil)

    Filter pages created before a specific date-time.

  • limit (Integer) (defaults to: nil)

    The maximum number of results to display per page.

  • property (String) (defaults to: nil)

    Specify properties to include in the response.

  • sort (Array<String>) (defaults to: nil)

    Specify the order of results. Accepts an array of field names to sort by.

  • updated_after (Time) (defaults to: nil)

    Filter pages updated after the specified date-time.

  • updated_at (Time) (defaults to: nil)

    Filter pages by their exact update timestamp in ISO 8601 format.

  • updated_before (Time) (defaults to: nil)

    Filter pages updated before a specific date and time. Format should be date-time

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 81

Instance Attribute Details

#afterString?

The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.

Returns:

  • (String, nil)


18
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 18

optional :after, String

#archivedBoolean?

Whether to return only results that have been archived.

Returns:

  • (Boolean, nil)


24
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 24

optional :archived, HubSpotSDK::Internal::Type::Boolean

#created_afterTime?

Filter pages created after a specific date and time.

Returns:

  • (Time, nil)


30
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 30

optional :created_after, Time

#created_atTime?

Filter pages by the exact creation timestamp. Format is date-time.

Returns:

  • (Time, nil)


36
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 36

optional :created_at, Time

#created_beforeTime?

Filter pages created before a specific date-time.

Returns:

  • (Time, nil)


42
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 42

optional :created_before, Time

#limitInteger?

The maximum number of results to display per page.

Returns:

  • (Integer, nil)


48
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 48

optional :limit, Integer

#propertyString?

Specify properties to include in the response.

Returns:

  • (String, nil)


54
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 54

optional :property, String

#sortArray<String>?

Specify the order of results. Accepts an array of field names to sort by.

Returns:

  • (Array<String>, nil)


60
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 60

optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String]

#updated_afterTime?

Filter pages updated after the specified date-time.

Returns:

  • (Time, nil)


66
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 66

optional :updated_after, Time

#updated_atTime?

Filter pages by their exact update timestamp in ISO 8601 format.

Returns:

  • (Time, nil)


72
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 72

optional :updated_at, Time

#updated_beforeTime?

Filter pages updated before a specific date and time. Format should be date-time.

Returns:

  • (Time, nil)


79
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 79

optional :updated_before, Time