Class: HubSpotSDK::Models::Cms::Property

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/property.rb

Overview

Defined Under Namespace

Modules: DataSensitivity, DateDisplayHint, DisplayMode, NumberDisplayHint, OptionSortStrategy, ReferencedObjectType, SearchTextAnalysisMode, TextDisplayHint, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allowed_object_types:, calculated:, can_archive:, can_restore:, created_at:, created_user_id:, currency_property_name:, data_sensitivity:, date_display_hint:, deleted:, description:, display_mode:, display_order:, enforce_multivalue_uniqueness:, external_options:, external_options_reference_type:, favorited:, favorited_order:, field_type:, form_field:, from_user_id:, group_name:, has_unique_value:, hidden:, hubspot_defined:, is_customized_default:, is_multi_valued:, is_partial:, label:, mutable_definition_not_deletable:, name:, number_display_hint:, options:, options_are_mutable:, option_sort_strategy:, owning_app_id:, portal_id:, read_only_definition:, read_only_value:, referenced_object_type:, searchable_in_global_search:, search_text_analysis_mode:, sensitive_data_categories:, show_currency_symbol:, text_display_hint:, type:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::Property for more details.

A HubSpot property

Parameters:

  • allowed_object_types (Array<HubSpotSDK::Models::Cms::ObjectTypeIDProto>)

    Object types permitted to use this property.

  • calculated (Boolean)

    Whether the property is a calculated field.

  • can_archive (Boolean)
  • can_restore (Boolean)
  • created_at (Integer)

    The timestamp when the property was created, in ISO 8601 format.

  • created_user_id (Integer)

    The ID of the user who created the property.

  • currency_property_name (String)

    The name of the related currency property.

  • data_sensitivity (Symbol, HubSpotSDK::Models::Cms::Property::DataSensitivity)

    Indicates the sensitivity level of the property, such as “non_sensitive”, “sensi

  • date_display_hint (Symbol, HubSpotSDK::Models::Cms::Property::DateDisplayHint)
  • deleted (Boolean)

    Whether the property has been deleted.

  • description (String)

    A summary of the property’s purpose.

  • display_mode (Symbol, HubSpotSDK::Models::Cms::Property::DisplayMode)

    The mode in which the property is displayed. Can be: “current_value” or “all_uni

  • display_order (Integer)

    The position of the item relative to others in the list.

  • enforce_multivalue_uniqueness (Boolean)
  • external_options (Boolean)

    Applicable only for enumeration type properties. Should be set to true with a ‘r

  • external_options_reference_type (String)

    When externalOptions is true, indicates the property’s option values will be pop

  • favorited (Boolean)

    Deprecated. Whether the property is marked as a favorite.

  • favorited_order (Integer)

    Deprecated. The order position when marked as favorited.

  • field_type (String)

    Determines how the property will appear in HubSpot’s UI or on a form. Learn more

  • form_field (Boolean)

    Whether the property can appear on forms.

  • from_user_id (Integer)

    The ID of the user who last updated the property.

  • group_name (String)

    The name of the group to which the property is assigned.

  • has_unique_value (Boolean)

    Whether the property is a unique identifier property.

  • hidden (Boolean)

    Whether or not the property will be hidden from the HubSpot UI. It’s recommended

  • hubspot_defined (Boolean)

    A boolean value set to true for HubSpot default properties.

  • is_customized_default (Boolean)

    For default properties, whether the property has been customized. Equivalent to

  • is_multi_valued (Boolean)

    Whether the property can contain multiple values.

  • is_partial (Boolean)

    For default properties, whether the property has been customized. Equivalent to

  • label (String)

    The display label for the property.

  • mutable_definition_not_deletable (Boolean)

    Whether the property definition can be customized but not deleted.

  • name (String)

    The internal name for the property.

  • number_display_hint (Symbol, HubSpotSDK::Models::Cms::Property::NumberDisplayHint)

    Hint for how a number property is displayed and validated in HubSpot’s UI. Can b

  • options (Array<HubSpotSDK::Models::AutomationActionsOption>)

    A list of valid options for the property. This field is required for enumerated

  • options_are_mutable (Boolean)

    Whether options can be modified after creation.

  • option_sort_strategy (Symbol, HubSpotSDK::Models::Cms::Property::OptionSortStrategy)

    Specifies how to sort property options. Can be either “DISPLAY_ORDER” to defer t

  • owning_app_id (Integer)
  • portal_id (Integer)

    The ID of the HubSpot account where the property is defined.

  • read_only_definition (Boolean)

    Whether the property’s description is read-only.

  • read_only_value (Boolean)

    Indicates if the property’s value is read-only.

  • referenced_object_type (Symbol, HubSpotSDK::Models::Cms::Property::ReferencedObjectType)

    Deprecated. Use externalOptionsReferenceType instead.

  • searchable_in_global_search (Boolean)

    Whether the property is searchable globaly.

  • search_text_analysis_mode (Symbol, HubSpotSDK::Models::Cms::Property::SearchTextAnalysisMode)
  • sensitive_data_categories (Array<String>)

    When sensitiveData is true, lists the type of sensitive data contained in the pr

  • show_currency_symbol (Boolean)

    Whether to show the currency symbol in HubSpot’s UI.

  • text_display_hint (Symbol, HubSpotSDK::Models::Cms::Property::TextDisplayHint)

    Hint for how the text is displayed and validated in HubSpot’s UI. Can be: “unfor

  • type (Symbol, HubSpotSDK::Models::Cms::Property::Type)

    The data type of the property, such as string or number.

  • updated_at (Integer)

    The timestamp when the property was last updated, in ISO 8601 format.



# File 'lib/hubspot_sdk/models/cms/property.rb', line 323

Instance Attribute Details

#allowed_object_typesArray<HubSpotSDK::Models::Cms::ObjectTypeIDProto>

Object types permitted to use this property.



12
13
14
# File 'lib/hubspot_sdk/models/cms/property.rb', line 12

required :allowed_object_types,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Cms::ObjectTypeIDProto] },
api_name: :allowedObjectTypes

#calculatedBoolean

Whether the property is a calculated field.

Returns:

  • (Boolean)


20
# File 'lib/hubspot_sdk/models/cms/property.rb', line 20

required :calculated, HubSpotSDK::Internal::Type::Boolean

#can_archiveBoolean

Returns:

  • (Boolean)


25
# File 'lib/hubspot_sdk/models/cms/property.rb', line 25

required :can_archive, HubSpotSDK::Internal::Type::Boolean, api_name: :canArchive

#can_restoreBoolean

Returns:

  • (Boolean)


30
# File 'lib/hubspot_sdk/models/cms/property.rb', line 30

required :can_restore, HubSpotSDK::Internal::Type::Boolean, api_name: :canRestore

#created_atInteger

The timestamp when the property was created, in ISO 8601 format.

Returns:

  • (Integer)


36
# File 'lib/hubspot_sdk/models/cms/property.rb', line 36

required :created_at, Integer, api_name: :createdAt

#created_user_idInteger

The ID of the user who created the property.

Returns:

  • (Integer)


42
# File 'lib/hubspot_sdk/models/cms/property.rb', line 42

required :created_user_id, Integer, api_name: :createdUserId

#currency_property_nameString

The name of the related currency property.

Returns:

  • (String)


48
# File 'lib/hubspot_sdk/models/cms/property.rb', line 48

required :currency_property_name, String, api_name: :currencyPropertyName

#data_sensitivitySymbol, HubSpotSDK::Models::Cms::Property::DataSensitivity

Indicates the sensitivity level of the property, such as “non_sensitive”, “sensitive”, or “highly_sensitive”.



55
56
57
# File 'lib/hubspot_sdk/models/cms/property.rb', line 55

required :data_sensitivity,
enum: -> { HubSpotSDK::Cms::Property::DataSensitivity },
api_name: :dataSensitivity

#date_display_hintSymbol, HubSpotSDK::Models::Cms::Property::DateDisplayHint



62
63
64
# File 'lib/hubspot_sdk/models/cms/property.rb', line 62

required :date_display_hint,
enum: -> { HubSpotSDK::Cms::Property::DateDisplayHint },
api_name: :dateDisplayHint

#deletedBoolean

Whether the property has been deleted.

Returns:

  • (Boolean)


70
# File 'lib/hubspot_sdk/models/cms/property.rb', line 70

required :deleted, HubSpotSDK::Internal::Type::Boolean

#descriptionString

A summary of the property’s purpose.

Returns:

  • (String)


76
# File 'lib/hubspot_sdk/models/cms/property.rb', line 76

required :description, String

#display_modeSymbol, HubSpotSDK::Models::Cms::Property::DisplayMode

The mode in which the property is displayed. Can be: “current_value” or “all_unique_versions”.



83
# File 'lib/hubspot_sdk/models/cms/property.rb', line 83

required :display_mode, enum: -> { HubSpotSDK::Cms::Property::DisplayMode }, api_name: :displayMode

#display_orderInteger

The position of the item relative to others in the list.

Returns:

  • (Integer)


89
# File 'lib/hubspot_sdk/models/cms/property.rb', line 89

required :display_order, Integer, api_name: :displayOrder

#enforce_multivalue_uniquenessBoolean

Returns:

  • (Boolean)


94
95
96
# File 'lib/hubspot_sdk/models/cms/property.rb', line 94

required :enforce_multivalue_uniqueness,
HubSpotSDK::Internal::Type::Boolean,
api_name: :enforceMultivalueUniqueness

#external_optionsBoolean

Applicable only for enumeration type properties. Should be set to true with a ‘referencedObjectType’ of ‘OWNER’. Otherwise false.

Returns:

  • (Boolean)


103
# File 'lib/hubspot_sdk/models/cms/property.rb', line 103

required :external_options, HubSpotSDK::Internal::Type::Boolean, api_name: :externalOptions

#external_options_reference_typeString

When externalOptions is true, indicates the property’s option values will be populated from other systems (e.g., “OWNER” for the hubspot_owner_id property).

Returns:

  • (String)


110
# File 'lib/hubspot_sdk/models/cms/property.rb', line 110

required :external_options_reference_type, String, api_name: :externalOptionsReferenceType

#favoritedBoolean

Deprecated. Whether the property is marked as a favorite.

Returns:

  • (Boolean)


116
# File 'lib/hubspot_sdk/models/cms/property.rb', line 116

required :favorited, HubSpotSDK::Internal::Type::Boolean

#favorited_orderInteger

Deprecated. The order position when marked as favorited.

Returns:

  • (Integer)


122
# File 'lib/hubspot_sdk/models/cms/property.rb', line 122

required :favorited_order, Integer, api_name: :favoritedOrder

#field_typeString

Determines how the property will appear in HubSpot’s UI or on a form. Learn more in the properties API guide.

Returns:

  • (String)


129
# File 'lib/hubspot_sdk/models/cms/property.rb', line 129

required :field_type, String, api_name: :fieldType

#form_fieldBoolean

Whether the property can appear on forms.

Returns:

  • (Boolean)


135
# File 'lib/hubspot_sdk/models/cms/property.rb', line 135

required :form_field, HubSpotSDK::Internal::Type::Boolean, api_name: :formField

#from_user_idInteger

The ID of the user who last updated the property.

Returns:

  • (Integer)


141
# File 'lib/hubspot_sdk/models/cms/property.rb', line 141

required :from_user_id, Integer, api_name: :fromUserId

#group_nameString

The name of the group to which the property is assigned.

Returns:

  • (String)


147
# File 'lib/hubspot_sdk/models/cms/property.rb', line 147

required :group_name, String, api_name: :groupName

#has_unique_valueBoolean

Whether the property is a unique identifier property.

Returns:

  • (Boolean)


153
# File 'lib/hubspot_sdk/models/cms/property.rb', line 153

required :has_unique_value, HubSpotSDK::Internal::Type::Boolean, api_name: :hasUniqueValue

#hiddenBoolean

Whether or not the property will be hidden from the HubSpot UI. It’s recommended that this be set to false for custom properties.

Returns:

  • (Boolean)


160
# File 'lib/hubspot_sdk/models/cms/property.rb', line 160

required :hidden, HubSpotSDK::Internal::Type::Boolean

#hubspot_definedBoolean

A boolean value set to true for HubSpot default properties.

Returns:

  • (Boolean)


166
# File 'lib/hubspot_sdk/models/cms/property.rb', line 166

required :hubspot_defined, HubSpotSDK::Internal::Type::Boolean, api_name: :hubspotDefined

#is_customized_defaultBoolean

For default properties, whether the property has been customized. Equivalent to the ‘isCustomizedDefault’ field.

Returns:

  • (Boolean)


173
# File 'lib/hubspot_sdk/models/cms/property.rb', line 173

required :is_customized_default, HubSpotSDK::Internal::Type::Boolean, api_name: :isCustomizedDefault

#is_multi_valuedBoolean

Whether the property can contain multiple values.

Returns:

  • (Boolean)


179
# File 'lib/hubspot_sdk/models/cms/property.rb', line 179

required :is_multi_valued, HubSpotSDK::Internal::Type::Boolean, api_name: :isMultiValued

#is_partialBoolean

For default properties, whether the property has been customized. Equivalent to the ‘isCustomizedDefault’ field.

Returns:

  • (Boolean)


186
# File 'lib/hubspot_sdk/models/cms/property.rb', line 186

required :is_partial, HubSpotSDK::Internal::Type::Boolean, api_name: :isPartial

#labelString

The display label for the property.

Returns:

  • (String)


192
# File 'lib/hubspot_sdk/models/cms/property.rb', line 192

required :label, String

#mutable_definition_not_deletableBoolean

Whether the property definition can be customized but not deleted.

Returns:

  • (Boolean)


198
199
200
# File 'lib/hubspot_sdk/models/cms/property.rb', line 198

required :mutable_definition_not_deletable,
HubSpotSDK::Internal::Type::Boolean,
api_name: :mutableDefinitionNotDeletable

#nameString

The internal name for the property.

Returns:

  • (String)


206
# File 'lib/hubspot_sdk/models/cms/property.rb', line 206

required :name, String

#number_display_hintSymbol, HubSpotSDK::Models::Cms::Property::NumberDisplayHint

Hint for how a number property is displayed and validated in HubSpot’s UI. Can be: “unformatted”, “formatted”, “currency”, “percentage”, “duration”, or “probability”.



214
215
216
# File 'lib/hubspot_sdk/models/cms/property.rb', line 214

required :number_display_hint,
enum: -> { HubSpotSDK::Cms::Property::NumberDisplayHint },
api_name: :numberDisplayHint

#option_sort_strategySymbol, HubSpotSDK::Models::Cms::Property::OptionSortStrategy

Specifies how to sort property options. Can be either “DISPLAY_ORDER” to defer to the displayOrder field, or “ALPHABETICAL”.



236
237
238
# File 'lib/hubspot_sdk/models/cms/property.rb', line 236

required :option_sort_strategy,
enum: -> { HubSpotSDK::Cms::Property::OptionSortStrategy },
api_name: :optionSortStrategy

#optionsArray<HubSpotSDK::Models::AutomationActionsOption>

A list of valid options for the property. This field is required for enumerated properties.



223
# File 'lib/hubspot_sdk/models/cms/property.rb', line 223

required :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::AutomationActionsOption] }

#options_are_mutableBoolean

Whether options can be modified after creation.

Returns:

  • (Boolean)


229
# File 'lib/hubspot_sdk/models/cms/property.rb', line 229

required :options_are_mutable, HubSpotSDK::Internal::Type::Boolean, api_name: :optionsAreMutable

#owning_app_idInteger

Returns:

  • (Integer)


243
# File 'lib/hubspot_sdk/models/cms/property.rb', line 243

required :owning_app_id, Integer, api_name: :owningAppId

#portal_idInteger

The ID of the HubSpot account where the property is defined.

Returns:

  • (Integer)


249
# File 'lib/hubspot_sdk/models/cms/property.rb', line 249

required :portal_id, Integer, api_name: :portalId

#read_only_definitionBoolean

Whether the property’s description is read-only.

Returns:

  • (Boolean)


255
# File 'lib/hubspot_sdk/models/cms/property.rb', line 255

required :read_only_definition, HubSpotSDK::Internal::Type::Boolean, api_name: :readOnlyDefinition

#read_only_valueBoolean

Indicates if the property’s value is read-only.

Returns:

  • (Boolean)


261
# File 'lib/hubspot_sdk/models/cms/property.rb', line 261

required :read_only_value, HubSpotSDK::Internal::Type::Boolean, api_name: :readOnlyValue

#referenced_object_typeSymbol, HubSpotSDK::Models::Cms::Property::ReferencedObjectType

Deprecated. Use externalOptionsReferenceType instead.



267
268
269
# File 'lib/hubspot_sdk/models/cms/property.rb', line 267

required :referenced_object_type,
enum: -> { HubSpotSDK::Cms::Property::ReferencedObjectType },
api_name: :referencedObjectType

#search_text_analysis_modeSymbol, HubSpotSDK::Models::Cms::Property::SearchTextAnalysisMode



282
283
284
# File 'lib/hubspot_sdk/models/cms/property.rb', line 282

required :search_text_analysis_mode,
enum: -> { HubSpotSDK::Cms::Property::SearchTextAnalysisMode },
api_name: :searchTextAnalysisMode

#searchable_in_global_searchBoolean

Whether the property is searchable globaly.

Returns:

  • (Boolean)


275
276
277
# File 'lib/hubspot_sdk/models/cms/property.rb', line 275

required :searchable_in_global_search,
HubSpotSDK::Internal::Type::Boolean,
api_name: :searchableInGlobalSearch

#sensitive_data_categoriesArray<String>

When sensitiveData is true, lists the type of sensitive data contained in the property (e.g., “HIPAA”).

Returns:

  • (Array<String>)


291
292
293
# File 'lib/hubspot_sdk/models/cms/property.rb', line 291

required :sensitive_data_categories,
HubSpotSDK::Internal::Type::ArrayOf[String],
api_name: :sensitiveDataCategories

#show_currency_symbolBoolean

Whether to show the currency symbol in HubSpot’s UI.

Returns:

  • (Boolean)


299
# File 'lib/hubspot_sdk/models/cms/property.rb', line 299

required :show_currency_symbol, HubSpotSDK::Internal::Type::Boolean, api_name: :showCurrencySymbol

#text_display_hintSymbol, HubSpotSDK::Models::Cms::Property::TextDisplayHint

Hint for how the text is displayed and validated in HubSpot’s UI. Can be: “unformatted_single_line”, “multi_line”, “email”, “phone_number”, “domain_name”, “ip_address”, “physical_address”, or “postal_code”.



307
308
309
# File 'lib/hubspot_sdk/models/cms/property.rb', line 307

required :text_display_hint,
enum: -> { HubSpotSDK::Cms::Property::TextDisplayHint },
api_name: :textDisplayHint

#typeSymbol, HubSpotSDK::Models::Cms::Property::Type

The data type of the property, such as string or number.



315
# File 'lib/hubspot_sdk/models/cms/property.rb', line 315

required :type, enum: -> { HubSpotSDK::Cms::Property::Type }

#updated_atInteger

The timestamp when the property was last updated, in ISO 8601 format.

Returns:

  • (Integer)


321
# File 'lib/hubspot_sdk/models/cms/property.rb', line 321

required :updated_at, Integer, api_name: :updatedAt

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/cms/property.rb', line 434