Class: HubSpotSDK::Models::Cms::PublicAuditLog

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/public_audit_log.rb

Overview

Defined Under Namespace

Modules: Event, ObjectType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event:, full_name:, meta:, object_id_:, object_name:, object_type:, timestamp:, user_id:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::PublicAuditLog for more details.

Parameters:

  • event (Symbol, HubSpotSDK::Models::Cms::PublicAuditLog::Event)

    The type of event that took place (CREATED, UPDATED, PUBLISHED, DELETED, UNPUBLI

  • full_name (String)

    The name of the user who caused the event.

  • meta (Object)

    Supplementary metadata associated with the audit log entry. It provides addition

  • object_id_ (String)

    The ID of the object.

  • object_name (String)

    The internal name of the object in HubSpot.

  • object_type (Symbol, HubSpotSDK::Models::Cms::PublicAuditLog::ObjectType)

    The type of the object (BLOG, LANDING_PAGE, DOMAIN, HUBDB_TABLE etc.)

  • timestamp (Time)

    The timestamp at which the event occurred.

  • user_id (String)

    The ID of the user who caused the event.



# File 'lib/hubspot_sdk/models/cms/public_audit_log.rb', line 59

Instance Attribute Details

#eventSymbol, HubSpotSDK::Models::Cms::PublicAuditLog::Event

The type of event that took place (CREATED, UPDATED, PUBLISHED, DELETED, UNPUBLISHED).



13
# File 'lib/hubspot_sdk/models/cms/public_audit_log.rb', line 13

required :event, enum: -> { HubSpotSDK::Cms::PublicAuditLog::Event }

#full_nameString

The name of the user who caused the event.

Returns:

  • (String)


19
# File 'lib/hubspot_sdk/models/cms/public_audit_log.rb', line 19

required :full_name, String, api_name: :fullName

#metaObject

Supplementary metadata associated with the audit log entry. It provides additional context about the audited event (ex: rows deleted/updated for a HubDB event, the specific fields that were changed for a Content Settings event).

Returns:

  • (Object)


27
# File 'lib/hubspot_sdk/models/cms/public_audit_log.rb', line 27

required :meta, HubSpotSDK::Internal::Type::Unknown

#object_id_String

The ID of the object.

Returns:

  • (String)


33
# File 'lib/hubspot_sdk/models/cms/public_audit_log.rb', line 33

required :object_id_, String, api_name: :objectId

#object_nameString

The internal name of the object in HubSpot.

Returns:

  • (String)


39
# File 'lib/hubspot_sdk/models/cms/public_audit_log.rb', line 39

required :object_name, String, api_name: :objectName

#object_typeSymbol, HubSpotSDK::Models::Cms::PublicAuditLog::ObjectType

The type of the object (BLOG, LANDING_PAGE, DOMAIN, HUBDB_TABLE etc.)



45
# File 'lib/hubspot_sdk/models/cms/public_audit_log.rb', line 45

required :object_type, enum: -> { HubSpotSDK::Cms::PublicAuditLog::ObjectType }, api_name: :objectType

#timestampTime

The timestamp at which the event occurred.

Returns:

  • (Time)


51
# File 'lib/hubspot_sdk/models/cms/public_audit_log.rb', line 51

required :timestamp, Time

#user_idString

The ID of the user who caused the event.

Returns:

  • (String)


57
# File 'lib/hubspot_sdk/models/cms/public_audit_log.rb', line 57

required :user_id, String, api_name: :userId

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/cms/public_audit_log.rb', line 93