Class: HubSpotSDK::Models::Cms::PublicSearchResults

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/cms/public_search_results.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(limit:, offset:, page:, results:, total:, search_term: nil) ⇒ Object

Parameters:

  • limit (Integer)

    The number of results returned in a single response.

  • offset (Integer)

    The starting point for the next set of results in pagination.

  • page (Integer)

    The current page number in the paginated results.

  • results (Array<HubSpotSDK::Models::Cms::ContentSearchResult>)
  • total (Integer)

    The total number of results found for the search term.

  • search_term (String) (defaults to: nil)

    The term used in the search query.



# File 'lib/hubspot_sdk/models/cms/public_search_results.rb', line 43

Instance Attribute Details

#limitInteger

The number of results returned in a single response.

Returns:

  • (Integer)


12
# File 'lib/hubspot_sdk/models/cms/public_search_results.rb', line 12

required :limit, Integer

#offsetInteger

The starting point for the next set of results in pagination.

Returns:

  • (Integer)


18
# File 'lib/hubspot_sdk/models/cms/public_search_results.rb', line 18

required :offset, Integer

#pageInteger

The current page number in the paginated results.

Returns:

  • (Integer)


24
# File 'lib/hubspot_sdk/models/cms/public_search_results.rb', line 24

required :page, Integer

#resultsArray<HubSpotSDK::Models::Cms::ContentSearchResult>



29
# File 'lib/hubspot_sdk/models/cms/public_search_results.rb', line 29

required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Cms::ContentSearchResult] }

#search_termString?

The term used in the search query.

Returns:

  • (String, nil)


41
# File 'lib/hubspot_sdk/models/cms/public_search_results.rb', line 41

optional :search_term, String, api_name: :searchTerm

#totalInteger

The total number of results found for the search term.

Returns:

  • (Integer)


35
# File 'lib/hubspot_sdk/models/cms/public_search_results.rb', line 35

required :total, Integer