Class: HubSpotSDK::Models::Cms::RandomAccessCollectionResponseWithTotalHubDBTableRowV3
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::RandomAccessCollectionResponseWithTotalHubDBTableRowV3
- Defined in:
- lib/hubspot_sdk/models/cms/random_access_collection_response_with_total_hub_db_table_row_v3.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
- #paging ⇒ HubSpotSDK::Models::Cms::BoundedPaging?
- #results ⇒ Array<Object>
-
#total ⇒ Integer
The total number of rows available in the collection.
-
#type ⇒ Symbol, HubSpotSDK::Models::Cms::RandomAccessCollectionResponseWithTotalHubDBTableRowV3::Type
Indicates the type of response, which is ‘RANDOM_ACCESS’ by default.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(results:, total:, type:, paging: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/cms/random_access_collection_response_with_total_hub_db_table_row_v3.rb', line 29
|
Instance Attribute Details
#paging ⇒ HubSpotSDK::Models::Cms::BoundedPaging?
27 |
# File 'lib/hubspot_sdk/models/cms/random_access_collection_response_with_total_hub_db_table_row_v3.rb', line 27 optional :paging, -> { HubSpotSDK::Cms::BoundedPaging } |
#results ⇒ Array<Object>
10 |
# File 'lib/hubspot_sdk/models/cms/random_access_collection_response_with_total_hub_db_table_row_v3.rb', line 10 required :results, HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Internal::Type::Unknown] |
#total ⇒ Integer
The total number of rows available in the collection.
16 |
# File 'lib/hubspot_sdk/models/cms/random_access_collection_response_with_total_hub_db_table_row_v3.rb', line 16 required :total, Integer |
#type ⇒ Symbol, HubSpotSDK::Models::Cms::RandomAccessCollectionResponseWithTotalHubDBTableRowV3::Type
Indicates the type of response, which is ‘RANDOM_ACCESS’ by default.
22 |
# File 'lib/hubspot_sdk/models/cms/random_access_collection_response_with_total_hub_db_table_row_v3.rb', line 22 required :type, enum: -> { HubSpotSDK::Cms::RandomAccessCollectionResponseWithTotalHubDBTableRowV3::Type } |