Class: HubSpotSDK::Models::Cms::Styles
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::Styles
- Defined in:
- lib/hubspot_sdk/models/cms/styles.rb
Defined Under Namespace
Modules: FlexboxPositioning, VerticalAlignment
Instance Attribute Summary collapse
- #background_color ⇒ HubSpotSDK::Models::Cms::RgbaColor
- #background_gradient ⇒ HubSpotSDK::Models::Cms::Gradient
- #background_image ⇒ HubSpotSDK::Models::Cms::BackgroundImage
-
#breakpoint_styles ⇒ Hash{Symbol=>HubSpotSDK::Models::Cms::BreakpointStyles}?
Breakpoint CSS styles for margin, padding, etc…
-
#flexbox_positioning ⇒ Symbol, HubSpotSDK::Models::Cms::Styles::FlexboxPositioning
Indicates whether flexbox positioning is enabled for the section.
-
#force_full_width_section ⇒ Boolean
Determines if the section should be forced to full width.
-
#max_width_section_centering ⇒ Integer
Defines the maximum width for centering the section.
-
#vertical_alignment ⇒ Symbol, HubSpotSDK::Models::Cms::Styles::VerticalAlignment
Specifies the vertical alignment of elements within the section.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(background_color:, background_gradient:, background_image:, flexbox_positioning:, force_full_width_section:, max_width_section_centering:, vertical_alignment:, breakpoint_styles: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/cms/styles.rb', line 60
|
Instance Attribute Details
#background_color ⇒ HubSpotSDK::Models::Cms::RgbaColor
10 |
# File 'lib/hubspot_sdk/models/cms/styles.rb', line 10 required :background_color, -> { HubSpotSDK::Cms::RgbaColor }, api_name: :backgroundColor |
#background_gradient ⇒ HubSpotSDK::Models::Cms::Gradient
15 |
# File 'lib/hubspot_sdk/models/cms/styles.rb', line 15 required :background_gradient, -> { HubSpotSDK::Cms::Gradient }, api_name: :backgroundGradient |
#background_image ⇒ HubSpotSDK::Models::Cms::BackgroundImage
20 |
# File 'lib/hubspot_sdk/models/cms/styles.rb', line 20 required :background_image, -> { HubSpotSDK::Cms::BackgroundImage }, api_name: :backgroundImage |
#breakpoint_styles ⇒ Hash{Symbol=>HubSpotSDK::Models::Cms::BreakpointStyles}?
Breakpoint CSS styles for margin, padding, etc…
56 57 58 |
# File 'lib/hubspot_sdk/models/cms/styles.rb', line 56 optional :breakpoint_styles, -> { HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Cms::BreakpointStyles] }, api_name: :breakpointStyles |
#flexbox_positioning ⇒ Symbol, HubSpotSDK::Models::Cms::Styles::FlexboxPositioning
Indicates whether flexbox positioning is enabled for the section.
26 27 28 |
# File 'lib/hubspot_sdk/models/cms/styles.rb', line 26 required :flexbox_positioning, enum: -> { HubSpotSDK::Cms::Styles::FlexboxPositioning }, api_name: :flexboxPositioning |
#force_full_width_section ⇒ Boolean
Determines if the section should be forced to full width.
34 35 36 |
# File 'lib/hubspot_sdk/models/cms/styles.rb', line 34 required :force_full_width_section, HubSpotSDK::Internal::Type::Boolean, api_name: :forceFullWidthSection |
#max_width_section_centering ⇒ Integer
Defines the maximum width for centering the section.
42 |
# File 'lib/hubspot_sdk/models/cms/styles.rb', line 42 required :max_width_section_centering, Integer, api_name: :maxWidthSectionCentering |
#vertical_alignment ⇒ Symbol, HubSpotSDK::Models::Cms::Styles::VerticalAlignment
Specifies the vertical alignment of elements within the section.
48 49 50 |
# File 'lib/hubspot_sdk/models/cms/styles.rb', line 48 required :vertical_alignment, enum: -> { HubSpotSDK::Cms::Styles::VerticalAlignment }, api_name: :verticalAlignment |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/cms/styles.rb', line 93
|