Class: HubSpotSDK::Models::Cms::URLRedirectListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::URLRedirectListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/cms/url_redirect_list_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
-
#archived ⇒ Boolean?
Whether to return only results that have been archived.
- #created_after ⇒ Time?
- #created_at ⇒ Time?
- #created_before ⇒ Time?
-
#limit ⇒ Integer?
The maximum number of results to display per page.
- #sort ⇒ Array<String>?
- #updated_after ⇒ Time?
- #updated_at ⇒ Time?
- #updated_before ⇒ Time?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(after: nil, archived: nil, created_after: nil, created_at: nil, created_before: nil, limit: nil, sort: nil, updated_after: nil, updated_at: nil, updated_before: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see URLRedirectListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, archived: nil, created_after: nil, created_at: nil, created_before: nil, limit: nil, sort: nil, updated_after: nil, updated_at: nil, updated_before: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::URLRedirectListParams for more details.
|
|
# File 'lib/hubspot_sdk/models/cms/url_redirect_list_params.rb', line 66
|
Instance Attribute Details
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
17 |
# File 'lib/hubspot_sdk/models/cms/url_redirect_list_params.rb', line 17 optional :after, String |
#archived ⇒ Boolean?
Whether to return only results that have been archived.
23 |
# File 'lib/hubspot_sdk/models/cms/url_redirect_list_params.rb', line 23 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#created_after ⇒ Time?
28 |
# File 'lib/hubspot_sdk/models/cms/url_redirect_list_params.rb', line 28 optional :created_after, Time |
#created_at ⇒ Time?
33 |
# File 'lib/hubspot_sdk/models/cms/url_redirect_list_params.rb', line 33 optional :created_at, Time |
#created_before ⇒ Time?
38 |
# File 'lib/hubspot_sdk/models/cms/url_redirect_list_params.rb', line 38 optional :created_before, Time |
#limit ⇒ Integer?
The maximum number of results to display per page.
44 |
# File 'lib/hubspot_sdk/models/cms/url_redirect_list_params.rb', line 44 optional :limit, Integer |
#sort ⇒ Array<String>?
49 |
# File 'lib/hubspot_sdk/models/cms/url_redirect_list_params.rb', line 49 optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String] |
#updated_after ⇒ Time?
54 |
# File 'lib/hubspot_sdk/models/cms/url_redirect_list_params.rb', line 54 optional :updated_after, Time |
#updated_at ⇒ Time?
59 |
# File 'lib/hubspot_sdk/models/cms/url_redirect_list_params.rb', line 59 optional :updated_at, Time |
#updated_before ⇒ Time?
64 |
# File 'lib/hubspot_sdk/models/cms/url_redirect_list_params.rb', line 64 optional :updated_before, Time |