Class: HubSpotSDK::Models::CommunicationPreferences::ActionResponseWithResultsPublicWideStatus

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/communication_preferences/action_response_with_results_public_wide_status.rb

Overview

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(completed_at:, results:, started_at:, status:, errors: nil, links: nil, num_errors: nil, requested_at: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::CommunicationPreferences::ActionResponseWithResultsPublicWideStatus for more details.

Parameters:

  • completed_at (Time)

    The date and time when the operation was completed.

  • results (Array<HubSpotSDK::Models::CommunicationPreferences::PublicWideStatus>)

    An array containing the results of the operation.

  • started_at (Time)

    The date and time when the operation started.

  • status (Symbol, HubSpotSDK::Models::CommunicationPreferences::ActionResponseWithResultsPublicWideStatus::Status)

    The current status of the operation, which can be PENDING, PROCESSING, CANCELED,

  • errors (Array<HubSpotSDK::Models::StandardError>) (defaults to: nil)

    An array of error objects detailing any issues encountered during the operation.

  • links (Hash{Symbol=>String}) (defaults to: nil)

    An object containing related links, where each key is a link name and each value

  • num_errors (Integer) (defaults to: nil)

    The number of errors encountered during the operation.

  • requested_at (Time) (defaults to: nil)

    The date and time when the request was made.



# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_public_wide_status.rb', line 60

Instance Attribute Details

#completed_atTime

The date and time when the operation was completed.

Returns:

  • (Time)


12
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_public_wide_status.rb', line 12

required :completed_at, Time, api_name: :completedAt

#errorsArray<HubSpotSDK::Models::StandardError>?

An array of error objects detailing any issues encountered during the operation.

Returns:



39
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_public_wide_status.rb', line 39

optional :errors, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::StandardError] }

An object containing related links, where each key is a link name and each value is a URL.

Returns:

  • (Hash{Symbol=>String}, nil)


46
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_public_wide_status.rb', line 46

optional :links, HubSpotSDK::Internal::Type::HashOf[String]

#num_errorsInteger?

The number of errors encountered during the operation.

Returns:

  • (Integer, nil)


52
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_public_wide_status.rb', line 52

optional :num_errors, Integer, api_name: :numErrors

#requested_atTime?

The date and time when the request was made.

Returns:

  • (Time, nil)


58
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_public_wide_status.rb', line 58

optional :requested_at, Time, api_name: :requestedAt

#resultsArray<HubSpotSDK::Models::CommunicationPreferences::PublicWideStatus>

An array containing the results of the operation.



18
19
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_public_wide_status.rb', line 18

required :results,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::CommunicationPreferences::PublicWideStatus] }

#started_atTime

The date and time when the operation started.

Returns:

  • (Time)


25
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_public_wide_status.rb', line 25

required :started_at, Time, api_name: :startedAt

#statusSymbol, HubSpotSDK::Models::CommunicationPreferences::ActionResponseWithResultsPublicWideStatus::Status

The current status of the operation, which can be PENDING, PROCESSING, CANCELED, or COMPLETE.



32
33
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_public_wide_status.rb', line 32

required :status,
enum: -> { HubSpotSDK::CommunicationPreferences::ActionResponseWithResultsPublicWideStatus::Status }