Class: HubSpotSDK::Models::CommunicationPreferences::ActionResponseWithResultsSubscriptionDefinition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::CommunicationPreferences::ActionResponseWithResultsSubscriptionDefinition
- Defined in:
- lib/hubspot_sdk/models/communication_preferences/action_response_with_results_subscription_definition.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The date and time when the operation was completed.
-
#errors ⇒ Array<HubSpotSDK::Models::StandardError>?
An array of errors that occurred during the operation.
-
#links ⇒ Hash{Symbol=>String}?
A collection of related links associated with the operation.
-
#num_errors ⇒ Integer?
The number of errors encountered during the operation.
-
#requested_at ⇒ Time?
The date and time when the operation was requested.
-
#results ⇒ Array<HubSpotSDK::Models::CommunicationPreferences::SubscriptionDefinition>
An array containing the results of the operation.
-
#started_at ⇒ Time
The date and time when the operation started.
-
#status ⇒ Symbol, HubSpotSDK::Models::CommunicationPreferences::ActionResponseWithResultsSubscriptionDefinition::Status
The current status of the operation, which can be PENDING, PROCESSING, CANCELED, or COMPLETE.
Instance Method Summary collapse
-
#initialize(completed_at:, results:, started_at:, status:, errors: nil, links: nil, num_errors: nil, requested_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionResponseWithResultsSubscriptionDefinition for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(completed_at:, results:, started_at:, status:, errors: nil, links: nil, num_errors: nil, requested_at: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::CommunicationPreferences::ActionResponseWithResultsSubscriptionDefinition for more details.
|
|
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_subscription_definition.rb', line 58
|
Instance Attribute Details
#completed_at ⇒ Time
The date and time when the operation was completed.
11 |
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_subscription_definition.rb', line 11 required :completed_at, Time, api_name: :completedAt |
#errors ⇒ Array<HubSpotSDK::Models::StandardError>?
An array of errors that occurred during the operation.
38 |
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_subscription_definition.rb', line 38 optional :errors, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::StandardError] } |
#links ⇒ Hash{Symbol=>String}?
A collection of related links associated with the operation.
44 |
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_subscription_definition.rb', line 44 optional :links, HubSpotSDK::Internal::Type::HashOf[String] |
#num_errors ⇒ Integer?
The number of errors encountered during the operation.
50 |
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_subscription_definition.rb', line 50 optional :num_errors, Integer, api_name: :numErrors |
#requested_at ⇒ Time?
The date and time when the operation was requested.
56 |
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_subscription_definition.rb', line 56 optional :requested_at, Time, api_name: :requestedAt |
#results ⇒ Array<HubSpotSDK::Models::CommunicationPreferences::SubscriptionDefinition>
An array containing the results of the operation.
17 18 |
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_subscription_definition.rb', line 17 required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::CommunicationPreferences::SubscriptionDefinition] } |
#started_at ⇒ Time
The date and time when the operation started.
24 |
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_subscription_definition.rb', line 24 required :started_at, Time, api_name: :startedAt |
#status ⇒ Symbol, HubSpotSDK::Models::CommunicationPreferences::ActionResponseWithResultsSubscriptionDefinition::Status
The current status of the operation, which can be PENDING, PROCESSING, CANCELED, or COMPLETE.
31 32 |
# File 'lib/hubspot_sdk/models/communication_preferences/action_response_with_results_subscription_definition.rb', line 31 required :status, enum: -> { HubSpotSDK::CommunicationPreferences::ActionResponseWithResultsSubscriptionDefinition::Status } |