Class: HubSpotSDK::Models::CommunicationPreferences::BatchResponsePublicStatusBulkResponseWithErrors
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::CommunicationPreferences::BatchResponsePublicStatusBulkResponseWithErrors
- Defined in:
- lib/hubspot_sdk/models/communication_preferences/batch_response_public_status_bulk_response_with_errors.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The date and time when the operation was completed.
-
#errors ⇒ Array<HubSpotSDK::Models::StandardError>?
An array of error objects detailing any issues encountered during the operation.
-
#links ⇒ Hash{Symbol=>String}?
An object containing related links, where each key is a link name and each value is a URL.
-
#num_errors ⇒ Integer?
The number of errors encountered during the operation.
-
#requested_at ⇒ Time?
The date and time when the request was made.
-
#results ⇒ Array<HubSpotSDK::Models::CommunicationPreferences::PublicStatusBulkResponse>
An array containing the results of the operation.
-
#started_at ⇒ Time
The date and time when the operation started.
-
#status ⇒ Symbol, HubSpotSDK::Models::CommunicationPreferences::BatchResponsePublicStatusBulkResponseWithErrors::Status
The current status of the operation, which can be PENDING, PROCESSING, CANCELED, or COMPLETE.
Instance Method Summary collapse
-
#initialize(completed_at:, results:, started_at:, status:, errors: nil, links: nil, num_errors: nil, requested_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BatchResponsePublicStatusBulkResponseWithErrors for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(completed_at:, results:, started_at:, status:, errors: nil, links: nil, num_errors: nil, requested_at: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::CommunicationPreferences::BatchResponsePublicStatusBulkResponseWithErrors for more details.
|
|
# File 'lib/hubspot_sdk/models/communication_preferences/batch_response_public_status_bulk_response_with_errors.rb', line 59
|
Instance Attribute Details
#completed_at ⇒ Time
The date and time when the operation was completed.
11 |
# File 'lib/hubspot_sdk/models/communication_preferences/batch_response_public_status_bulk_response_with_errors.rb', line 11 required :completed_at, Time, api_name: :completedAt |
#errors ⇒ Array<HubSpotSDK::Models::StandardError>?
An array of error objects detailing any issues encountered during the operation.
38 |
# File 'lib/hubspot_sdk/models/communication_preferences/batch_response_public_status_bulk_response_with_errors.rb', line 38 optional :errors, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::StandardError] } |
#links ⇒ Hash{Symbol=>String}?
An object containing related links, where each key is a link name and each value is a URL.
45 |
# File 'lib/hubspot_sdk/models/communication_preferences/batch_response_public_status_bulk_response_with_errors.rb', line 45 optional :links, HubSpotSDK::Internal::Type::HashOf[String] |
#num_errors ⇒ Integer?
The number of errors encountered during the operation.
51 |
# File 'lib/hubspot_sdk/models/communication_preferences/batch_response_public_status_bulk_response_with_errors.rb', line 51 optional :num_errors, Integer, api_name: :numErrors |
#requested_at ⇒ Time?
The date and time when the request was made.
57 |
# File 'lib/hubspot_sdk/models/communication_preferences/batch_response_public_status_bulk_response_with_errors.rb', line 57 optional :requested_at, Time, api_name: :requestedAt |
#results ⇒ Array<HubSpotSDK::Models::CommunicationPreferences::PublicStatusBulkResponse>
An array containing the results of the operation.
17 18 |
# File 'lib/hubspot_sdk/models/communication_preferences/batch_response_public_status_bulk_response_with_errors.rb', line 17 required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::CommunicationPreferences::PublicStatusBulkResponse] } |
#started_at ⇒ Time
The date and time when the operation started.
24 |
# File 'lib/hubspot_sdk/models/communication_preferences/batch_response_public_status_bulk_response_with_errors.rb', line 24 required :started_at, Time, api_name: :startedAt |
#status ⇒ Symbol, HubSpotSDK::Models::CommunicationPreferences::BatchResponsePublicStatusBulkResponseWithErrors::Status
The current status of the operation, which can be PENDING, PROCESSING, CANCELED, or COMPLETE.
31 32 |
# File 'lib/hubspot_sdk/models/communication_preferences/batch_response_public_status_bulk_response_with_errors.rb', line 31 required :status, enum: -> { HubSpotSDK::CommunicationPreferences::BatchResponsePublicStatusBulkResponseWithErrors::Status } |