Class: HubSpotSDK::Models::CommunicationPreferences::CommunicationPreferenceGenerateLinksParams

Inherits:
LinkGenerationRequest show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/communication_preferences/communication_preference_generate_links_params.rb

Overview

Defined Under Namespace

Modules: Channel

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from LinkGenerationRequest

#language, #subscriber_id_string, #subscription_id

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channel:, business_unit_id: nil, request_options: {}) ⇒ Object

Parameters:

  • channel (Symbol, HubSpotSDK::Models::CommunicationPreferences::LinkGenerationRequest::Channel)

    The communication channel for which the links are generated. Must be ‘EMAIL’.

  • business_unit_id (Integer) (defaults to: nil)

    The identifier of the business unit. Defaults to 0 if not specified.

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/communication_preferences/communication_preference_generate_links_params.rb', line 23

Instance Attribute Details

#business_unit_idInteger?

The identifier of the business unit. Defaults to 0 if not specified.

Returns:

  • (Integer, nil)


21
# File 'lib/hubspot_sdk/models/communication_preferences/communication_preference_generate_links_params.rb', line 21

optional :business_unit_id, Integer

#channelSymbol, HubSpotSDK::Models::CommunicationPreferences::LinkGenerationRequest::Channel

The communication channel for which the links are generated. Must be ‘EMAIL’.

Returns:

  • (Symbol, HubSpotSDK::Models::CommunicationPreferences::LinkGenerationRequest::Channel)


15
# File 'lib/hubspot_sdk/models/communication_preferences/communication_preference_generate_links_params.rb', line 15

required :channel, enum: -> { HubSpotSDK::CommunicationPreferences::LinkGenerationRequest::Channel }