Class: HubSpotSDK::Models::CommunicationPreferences::CommunicationPreferenceGetUnsubscribeAllStatusParams

Inherits:
Internal::Type::BaseModel
  • Object
show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/communication_preferences/communication_preference_get_unsubscribe_all_status_params.rb

Overview

Defined Under Namespace

Modules: Channel

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(subscriber_id_string:, channel:, business_unit_id: nil, verbose: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::CommunicationPreferences::CommunicationPreferenceGetUnsubscribeAllStatusParams for more details.

Parameters:



# File 'lib/hubspot_sdk/models/communication_preferences/communication_preference_get_unsubscribe_all_status_params.rb', line 38

Instance Attribute Details

#business_unit_idInteger?

The ID of the business unit to which the subscriber belongs. This is an optional parameter.

Returns:

  • (Integer, nil)


29
# File 'lib/hubspot_sdk/models/communication_preferences/communication_preference_get_unsubscribe_all_status_params.rb', line 29

optional :business_unit_id, Integer

#channelSymbol, HubSpotSDK::Models::CommunicationPreferences::CommunicationPreferenceGetUnsubscribeAllStatusParams::Channel

The communication channel from which to unsubscribe the subscriber. This is a required parameter and must be ‘EMAIL’.



21
22
# File 'lib/hubspot_sdk/models/communication_preferences/communication_preference_get_unsubscribe_all_status_params.rb', line 21

required :channel,
enum: -> { HubSpotSDK::CommunicationPreferences::CommunicationPreferenceGetUnsubscribeAllStatusParams::Channel }

#subscriber_id_stringString

Returns:

  • (String)


14
# File 'lib/hubspot_sdk/models/communication_preferences/communication_preference_get_unsubscribe_all_status_params.rb', line 14

required :subscriber_id_string, String

#verboseBoolean?

A boolean indicating whether to include detailed information in the response. Defaults to false.

Returns:

  • (Boolean, nil)


36
# File 'lib/hubspot_sdk/models/communication_preferences/communication_preference_get_unsubscribe_all_status_params.rb', line 36

optional :verbose, HubSpotSDK::Internal::Type::Boolean