Class: HubSpotSDK::Models::CommunicationPreferences::CommunicationPreferenceUnsubscribeAllParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::CommunicationPreferences::CommunicationPreferenceUnsubscribeAllParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/communication_preferences/communication_preference_unsubscribe_all_params.rb
Overview
Defined Under Namespace
Modules: Channel
Instance Attribute Summary collapse
-
#business_unit_id ⇒ Integer?
The ID of the business unit associated with the request.
-
#channel ⇒ Symbol, HubSpotSDK::Models::CommunicationPreferences::CommunicationPreferenceUnsubscribeAllParams::Channel
The communication channel to unsubscribe from.
- #subscriber_id_string ⇒ String
-
#verbose ⇒ Boolean?
A boolean indicating whether to include detailed information in the response.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(subscriber_id_string:, channel:, business_unit_id: nil, verbose: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CommunicationPreferenceUnsubscribeAllParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(subscriber_id_string:, channel:, business_unit_id: nil, verbose: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::CommunicationPreferences::CommunicationPreferenceUnsubscribeAllParams for more details.
|
|
# File 'lib/hubspot_sdk/models/communication_preferences/communication_preference_unsubscribe_all_params.rb', line 37
|
Instance Attribute Details
#business_unit_id ⇒ Integer?
The ID of the business unit associated with the request. This is an optional integer parameter.
28 |
# File 'lib/hubspot_sdk/models/communication_preferences/communication_preference_unsubscribe_all_params.rb', line 28 optional :business_unit_id, Integer |
#channel ⇒ Symbol, HubSpotSDK::Models::CommunicationPreferences::CommunicationPreferenceUnsubscribeAllParams::Channel
The communication channel to unsubscribe from. Must be ‘EMAIL’.
20 21 |
# File 'lib/hubspot_sdk/models/communication_preferences/communication_preference_unsubscribe_all_params.rb', line 20 required :channel, enum: -> { HubSpotSDK::CommunicationPreferences::CommunicationPreferenceUnsubscribeAllParams::Channel } |
#subscriber_id_string ⇒ String
14 |
# File 'lib/hubspot_sdk/models/communication_preferences/communication_preference_unsubscribe_all_params.rb', line 14 required :subscriber_id_string, String |
#verbose ⇒ Boolean?
A boolean indicating whether to include detailed information in the response. Defaults to false.
35 |
# File 'lib/hubspot_sdk/models/communication_preferences/communication_preference_unsubscribe_all_params.rb', line 35 optional :verbose, HubSpotSDK::Internal::Type::Boolean |