Class: HubSpotSDK::Models::CommunicationPreferences::DefinitionListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/communication_preferences/definition_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(business_unit_id: nil, include_translations: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::CommunicationPreferences::DefinitionListParams for more details.

Parameters:

  • business_unit_id (Integer) (defaults to: nil)

    An integer representing the ID of the business unit for which to retrieve subscr

  • include_translations (Boolean) (defaults to: nil)

    A boolean indicating whether to include translations of the communication prefer

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/communication_preferences/definition_list_params.rb', line 25

Instance Attribute Details

#business_unit_idInteger?

An integer representing the ID of the business unit for which to retrieve subscription definitions.

Returns:

  • (Integer, nil)


16
# File 'lib/hubspot_sdk/models/communication_preferences/definition_list_params.rb', line 16

optional :business_unit_id, Integer

#include_translationsBoolean?

A boolean indicating whether to include translations of the communication preferences definitions in the response.

Returns:

  • (Boolean, nil)


23
# File 'lib/hubspot_sdk/models/communication_preferences/definition_list_params.rb', line 23

optional :include_translations, HubSpotSDK::Internal::Type::Boolean