Class: HubSpotSDK::Models::CommunicationPreferences::LinkGenerationRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/communication_preferences/link_generation_request.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(subscriber_id_string:, language: nil, subscription_id: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::CommunicationPreferences::LinkGenerationRequest for more details.

Parameters:

  • subscriber_id_string (String)

    A string representing the unique identifier of the subscriber. This property is

  • language (String) (defaults to: nil)

    The language in which the generated link should be presented, represented as a s

  • subscription_id (Integer) (defaults to: nil)

    The unique identifier for the subscription, represented as an integer in int64 f



# File 'lib/hubspot_sdk/models/communication_preferences/link_generation_request.rb', line 28

Instance Attribute Details

#languageString?

The language in which the generated link should be presented, represented as a string.

Returns:

  • (String, nil)


19
# File 'lib/hubspot_sdk/models/communication_preferences/link_generation_request.rb', line 19

optional :language, String

#subscriber_id_stringString

A string representing the unique identifier of the subscriber. This property is required.

Returns:

  • (String)


12
# File 'lib/hubspot_sdk/models/communication_preferences/link_generation_request.rb', line 12

required :subscriber_id_string, String, api_name: :subscriberIdString

#subscription_idInteger?

The unique identifier for the subscription, represented as an integer in int64 format.

Returns:

  • (Integer, nil)


26
# File 'lib/hubspot_sdk/models/communication_preferences/link_generation_request.rb', line 26

optional :subscription_id, Integer, api_name: :subscriptionId