Class: HubSpotSDK::Models::CommunicationPreferences::PublicStatus
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::CommunicationPreferences::PublicStatus
- Defined in:
- lib/hubspot_sdk/models/communication_preferences/public_status.rb
Defined Under Namespace
Modules: Channel, LegalBasis, SetStatusSuccessReason, Status
Instance Attribute Summary collapse
-
#business_unit_id ⇒ Integer?
The ID of the business unit associated with the subscription.
-
#channel ⇒ Symbol, HubSpotSDK::Models::CommunicationPreferences::PublicStatus::Channel
The type of communication channel, with ‘EMAIL’ as the only supported option.
-
#legal_basis ⇒ Symbol, ...
The legal basis for communication, with options including ‘LEGITIMATE_INTEREST_PQL’, ‘LEGITIMATE_INTEREST_CLIENT’, ‘PERFORMANCE_OF_CONTRACT’, ‘CONSENT_WITH_NOTICE’, ‘NON_GDPR’, ‘PROCESS_AND_STORE’, and ‘LEGITIMATE_INTEREST_OTHER’.
-
#legal_basis_explanation ⇒ String?
An explanation for the legal basis used for communication.
-
#set_status_success_reason ⇒ Symbol, ...
The reason for the successful change in subscription status, such as ‘RESUBSCRIBE_OCCURRED’ or ‘NO_STATUS_CHANGE’.
-
#source ⇒ String
The origin or method through which the subscription status was set.
-
#status ⇒ Symbol, HubSpotSDK::Models::CommunicationPreferences::PublicStatus::Status
The current subscription status of the contact, which can be ‘SUBSCRIBED’, ‘UNSUBSCRIBED’, or ‘NOT_SPECIFIED’.
-
#subscriber_id_string ⇒ String
The contact’s email address.
-
#subscription_id ⇒ Integer
The unique identifier of the subscription.
-
#subscription_name ⇒ String?
The name of the subscription.
-
#timestamp ⇒ Time
The date and time when the subscription status was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(channel:, source:, status:, subscriber_id_string:, subscription_id:, timestamp:, business_unit_id: nil, legal_basis: nil, legal_basis_explanation: nil, set_status_success_reason: nil, subscription_name: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicStatus for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(channel:, source:, status:, subscriber_id_string:, subscription_id:, timestamp:, business_unit_id: nil, legal_basis: nil, legal_basis_explanation: nil, set_status_success_reason: nil, subscription_name: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::CommunicationPreferences::PublicStatus for more details.
|
|
# File 'lib/hubspot_sdk/models/communication_preferences/public_status.rb', line 82
|
Instance Attribute Details
#business_unit_id ⇒ Integer?
The ID of the business unit associated with the subscription.
48 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_status.rb', line 48 optional :business_unit_id, Integer, api_name: :businessUnitId |
#channel ⇒ Symbol, HubSpotSDK::Models::CommunicationPreferences::PublicStatus::Channel
The type of communication channel, with ‘EMAIL’ as the only supported option.
11 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_status.rb', line 11 required :channel, enum: -> { HubSpotSDK::CommunicationPreferences::PublicStatus::Channel } |
#legal_basis ⇒ Symbol, ...
The legal basis for communication, with options including ‘LEGITIMATE_INTEREST_PQL’, ‘LEGITIMATE_INTEREST_CLIENT’, ‘PERFORMANCE_OF_CONTRACT’, ‘CONSENT_WITH_NOTICE’, ‘NON_GDPR’, ‘PROCESS_AND_STORE’, and ‘LEGITIMATE_INTEREST_OTHER’.
57 58 59 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_status.rb', line 57 optional :legal_basis, enum: -> { HubSpotSDK::CommunicationPreferences::PublicStatus::LegalBasis }, api_name: :legalBasis |
#legal_basis_explanation ⇒ String?
An explanation for the legal basis used for communication.
65 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_status.rb', line 65 optional :legal_basis_explanation, String, api_name: :legalBasisExplanation |
#set_status_success_reason ⇒ Symbol, ...
The reason for the successful change in subscription status, such as ‘RESUBSCRIBE_OCCURRED’ or ‘NO_STATUS_CHANGE’.
72 73 74 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_status.rb', line 72 optional :set_status_success_reason, enum: -> { HubSpotSDK::CommunicationPreferences::PublicStatus::SetStatusSuccessReason }, api_name: :setStatusSuccessReason |
#source ⇒ String
The origin or method through which the subscription status was set.
17 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_status.rb', line 17 required :source, String |
#status ⇒ Symbol, HubSpotSDK::Models::CommunicationPreferences::PublicStatus::Status
The current subscription status of the contact, which can be ‘SUBSCRIBED’, ‘UNSUBSCRIBED’, or ‘NOT_SPECIFIED’.
24 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_status.rb', line 24 required :status, enum: -> { HubSpotSDK::CommunicationPreferences::PublicStatus::Status } |
#subscriber_id_string ⇒ String
The contact’s email address.
30 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_status.rb', line 30 required :subscriber_id_string, String, api_name: :subscriberIdString |
#subscription_id ⇒ Integer
The unique identifier of the subscription.
36 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_status.rb', line 36 required :subscription_id, Integer, api_name: :subscriptionId |
#subscription_name ⇒ String?
The name of the subscription.
80 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_status.rb', line 80 optional :subscription_name, String, api_name: :subscriptionName |
#timestamp ⇒ Time
The date and time when the subscription status was last updated.
42 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_status.rb', line 42 required :timestamp, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/communication_preferences/public_status.rb', line 116
|