Class: HubSpotSDK::Models::CommunicationPreferences::PublicWideStatus
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::CommunicationPreferences::PublicWideStatus
- Defined in:
- lib/hubspot_sdk/models/communication_preferences/public_wide_status.rb
Defined Under Namespace
Modules: Channel, Status, WideStatusType
Instance Attribute Summary collapse
-
#business_unit_id ⇒ Integer?
The ID of the business unit associated with the status.
-
#channel ⇒ Symbol, HubSpotSDK::Models::CommunicationPreferences::PublicWideStatus::Channel
The type of communication channel, with ‘EMAIL’ as the only supported option.
-
#status ⇒ Symbol, HubSpotSDK::Models::CommunicationPreferences::PublicWideStatus::Status
The subscription status of the contact, which can be ‘SUBSCRIBED’, ‘UNSUBSCRIBED’, or ‘NOT_SPECIFIED’.
-
#subscriber_id_string ⇒ String
The email address of the contact.
-
#timestamp ⇒ Time
The date and time when the status was recorded.
-
#wide_status_type ⇒ Symbol, HubSpotSDK::Models::CommunicationPreferences::PublicWideStatus::WideStatusType
The type of wide status, which can be ‘PORTAL_WIDE’ or ‘BUSINESS_UNIT_WIDE’.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(channel:, status:, subscriber_id_string:, timestamp:, wide_status_type:, business_unit_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicWideStatus for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(channel:, status:, subscriber_id_string:, timestamp:, wide_status_type:, business_unit_id: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::CommunicationPreferences::PublicWideStatus for more details.
|
|
# File 'lib/hubspot_sdk/models/communication_preferences/public_wide_status.rb', line 46
|
Instance Attribute Details
#business_unit_id ⇒ Integer?
The ID of the business unit associated with the status.
44 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_wide_status.rb', line 44 optional :business_unit_id, Integer, api_name: :businessUnitId |
#channel ⇒ Symbol, HubSpotSDK::Models::CommunicationPreferences::PublicWideStatus::Channel
The type of communication channel, with ‘EMAIL’ as the only supported option.
11 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_wide_status.rb', line 11 required :channel, enum: -> { HubSpotSDK::CommunicationPreferences::PublicWideStatus::Channel } |
#status ⇒ Symbol, HubSpotSDK::Models::CommunicationPreferences::PublicWideStatus::Status
The subscription status of the contact, which can be ‘SUBSCRIBED’, ‘UNSUBSCRIBED’, or ‘NOT_SPECIFIED’.
18 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_wide_status.rb', line 18 required :status, enum: -> { HubSpotSDK::CommunicationPreferences::PublicWideStatus::Status } |
#subscriber_id_string ⇒ String
The email address of the contact.
24 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_wide_status.rb', line 24 required :subscriber_id_string, String, api_name: :subscriberIdString |
#timestamp ⇒ Time
The date and time when the status was recorded.
30 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_wide_status.rb', line 30 required :timestamp, Time |
#wide_status_type ⇒ Symbol, HubSpotSDK::Models::CommunicationPreferences::PublicWideStatus::WideStatusType
The type of wide status, which can be ‘PORTAL_WIDE’ or ‘BUSINESS_UNIT_WIDE’.
36 37 38 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_wide_status.rb', line 36 required :wide_status_type, enum: -> { HubSpotSDK::CommunicationPreferences::PublicWideStatus::WideStatusType }, api_name: :wideStatusType |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/communication_preferences/public_wide_status.rb', line 71
|