Class: HubSpotSDK::Models::CommunicationPreferences::Statuses::BatchUnsubscribeAllParams

Inherits:
BatchInputString show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/communication_preferences/statuses/batch_unsubscribe_all_params.rb

Overview

Defined Under Namespace

Modules: Channel

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from BatchInputString

#inputs

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channel:, business_unit_id: nil, verbose: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::CommunicationPreferences::Statuses::BatchUnsubscribeAllParams for more details.

Parameters:

  • channel (Symbol, HubSpotSDK::Models::BatchInputString::Channel)

    The communication channel from which subscribers will be unsubscribed. This para

  • business_unit_id (Integer) (defaults to: nil)

    An optional integer representing the business unit ID for which the operation is

  • verbose (Boolean) (defaults to: nil)

    A boolean indicating whether to include detailed information in the response. De

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/communication_preferences/statuses/batch_unsubscribe_all_params.rb', line 33

Instance Attribute Details

#business_unit_idInteger?

An optional integer representing the business unit ID for which the operation is being performed.

Returns:

  • (Integer, nil)


24
# File 'lib/hubspot_sdk/models/communication_preferences/statuses/batch_unsubscribe_all_params.rb', line 24

optional :business_unit_id, Integer

#channelSymbol, HubSpotSDK::Models::BatchInputString::Channel

The communication channel from which subscribers will be unsubscribed. This parameter is required and currently supports only ‘EMAIL’.

Returns:

  • (Symbol, HubSpotSDK::Models::BatchInputString::Channel)


17
# File 'lib/hubspot_sdk/models/communication_preferences/statuses/batch_unsubscribe_all_params.rb', line 17

required :channel, enum: -> { HubSpotSDK::BatchInputString::Channel }

#verboseBoolean?

A boolean indicating whether to include detailed information in the response. Defaults to false.

Returns:

  • (Boolean, nil)


31
# File 'lib/hubspot_sdk/models/communication_preferences/statuses/batch_unsubscribe_all_params.rb', line 31

optional :verbose, HubSpotSDK::Internal::Type::Boolean