Class: HubSpotSDK::Models::Conversations::CustomChannels::ChannelAccountListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb

Overview

Defined Under Namespace

Modules: DeliveryIdentifierType

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel

Instance Attribute Details

#afterString?

The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.

Returns:

  • (String, nil)


23
# File 'lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb', line 23

optional :after, String

#archivedBoolean?

Whether to return only results that have been archived.

Returns:

  • (Boolean, nil)


29
# File 'lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb', line 29

optional :archived, HubSpotSDK::Internal::Type::Boolean

#channel_idInteger

Returns:

  • (Integer)


15
# File 'lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb', line 15

required :channel_id, Integer

#default_page_lengthInteger?

Returns:

  • (Integer, nil)


34
# File 'lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb', line 34

optional :default_page_length, Integer

#delivery_identifier_typeArray<Symbol, HubSpotSDK::Models::Conversations::CustomChannels::ChannelAccountListParams::DeliveryIdentifierType>?



39
40
# File 'lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb', line 39

optional :delivery_identifier_type,
-> { HubSpotSDK::Internal::Type::ArrayOf[enum: HubSpotSDK::Conversations::CustomChannels::ChannelAccountListParams::DeliveryIdentifierType] }

#delivery_identifier_valueArray<String>?

Returns:

  • (Array<String>, nil)


45
# File 'lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb', line 45

optional :delivery_identifier_value, HubSpotSDK::Internal::Type::ArrayOf[String]

#limitInteger?

The maximum number of results to display per page.

Returns:

  • (Integer, nil)


51
# File 'lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb', line 51

optional :limit, Integer

#sortArray<String>?

Returns:

  • (Array<String>, nil)


56
# File 'lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb', line 56

optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String]