Class: HubSpotSDK::Models::Crm::APICollectionResponseJoinTimeAndRecordID
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::APICollectionResponseJoinTimeAndRecordID
- Defined in:
- lib/hubspot_sdk/models/crm/api_collection_response_join_time_and_record_id.rb
Instance Attribute Summary collapse
- #paging ⇒ HubSpotSDK::Models::Paging?
- #results ⇒ Array<HubSpotSDK::Models::Crm::JoinTimeAndRecordID>
-
#total ⇒ Integer?
The total number of records that match the query.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(results:, paging: nil, total: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/api_collection_response_join_time_and_record_id.rb', line 23
|
Instance Attribute Details
#paging ⇒ HubSpotSDK::Models::Paging?
15 |
# File 'lib/hubspot_sdk/models/crm/api_collection_response_join_time_and_record_id.rb', line 15 optional :paging, -> { HubSpotSDK::Paging } |
#results ⇒ Array<HubSpotSDK::Models::Crm::JoinTimeAndRecordID>
10 |
# File 'lib/hubspot_sdk/models/crm/api_collection_response_join_time_and_record_id.rb', line 10 required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::JoinTimeAndRecordID] } |
#total ⇒ Integer?
The total number of records that match the query.
21 |
# File 'lib/hubspot_sdk/models/crm/api_collection_response_join_time_and_record_id.rb', line 21 optional :total, Integer |