Class: HubSpotSDK::Models::Crm::AssociationLabelLimitResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::AssociationLabelLimitResponse
- Defined in:
- lib/hubspot_sdk/models/crm/association_label_limit_response.rb
Instance Attribute Summary collapse
-
#all_labels ⇒ Array<String>
A list of all association labels.
- #from_object_type ⇒ HubSpotSDK::Models::Crm::ObjectTypeDefinition
-
#limit ⇒ Integer
The maximum number of association labels allowed.
-
#percentage ⇒ Float
The percentage of the association label limit that has been used.
- #to_object_type ⇒ HubSpotSDK::Models::Crm::ObjectTypeDefinition
-
#usage ⇒ Integer
The current number of association labels used.
Instance Method Summary collapse
- #initialize(all_labels:, from_object_type:, limit:, percentage:, to_object_type:, usage:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(all_labels:, from_object_type:, limit:, percentage:, to_object_type:, usage:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/association_label_limit_response.rb', line 41
|
Instance Attribute Details
#all_labels ⇒ Array<String>
A list of all association labels.
11 |
# File 'lib/hubspot_sdk/models/crm/association_label_limit_response.rb', line 11 required :all_labels, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :allLabels |
#from_object_type ⇒ HubSpotSDK::Models::Crm::ObjectTypeDefinition
16 |
# File 'lib/hubspot_sdk/models/crm/association_label_limit_response.rb', line 16 required :from_object_type, -> { HubSpotSDK::Crm::ObjectTypeDefinition }, api_name: :fromObjectType |
#limit ⇒ Integer
The maximum number of association labels allowed.
22 |
# File 'lib/hubspot_sdk/models/crm/association_label_limit_response.rb', line 22 required :limit, Integer |
#percentage ⇒ Float
The percentage of the association label limit that has been used.
28 |
# File 'lib/hubspot_sdk/models/crm/association_label_limit_response.rb', line 28 required :percentage, Float |
#to_object_type ⇒ HubSpotSDK::Models::Crm::ObjectTypeDefinition
33 |
# File 'lib/hubspot_sdk/models/crm/association_label_limit_response.rb', line 33 required :to_object_type, -> { HubSpotSDK::Crm::ObjectTypeDefinition }, api_name: :toObjectType |
#usage ⇒ Integer
The current number of association labels used.
39 |
# File 'lib/hubspot_sdk/models/crm/association_label_limit_response.rb', line 39 required :usage, Integer |