Class: HubSpotSDK::Models::Crm::AssociationListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::AssociationListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/crm/association_list_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
-
#limit ⇒ Integer?
The maximum number of results to display per page.
- #object_id_ ⇒ String
- #object_type ⇒ String
- #to_object_type ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(object_type:, object_id_:, to_object_type:, after: nil, limit: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AssociationListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(object_type:, object_id_:, to_object_type:, after: nil, limit: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::AssociationListParams for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/association_list_params.rb', line 40
|
Instance Attribute Details
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
32 |
# File 'lib/hubspot_sdk/models/crm/association_list_params.rb', line 32 optional :after, String |
#limit ⇒ Integer?
The maximum number of results to display per page.
38 |
# File 'lib/hubspot_sdk/models/crm/association_list_params.rb', line 38 optional :limit, Integer |
#object_id_ ⇒ String
19 |
# File 'lib/hubspot_sdk/models/crm/association_list_params.rb', line 19 required :object_id_, String |
#object_type ⇒ String
14 |
# File 'lib/hubspot_sdk/models/crm/association_list_params.rb', line 14 required :object_type, String |
#to_object_type ⇒ String
24 |
# File 'lib/hubspot_sdk/models/crm/association_list_params.rb', line 24 required :to_object_type, String |