Class: HubSpotSDK::Models::Crm::AssociationRecordLimitResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/association_record_limit_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(at_limit_from_record_samples:, limit:, near_limit_from_record_samples:, total_records_at_limit:, total_records_near_limit:) ⇒ Object

Parameters:

  • at_limit_from_record_samples (Array<HubSpotSDK::Models::Crm::AtLimitRecordSample>)
  • limit (Integer)

    The maximum number of associations allowed for records.

  • near_limit_from_record_samples (Array<HubSpotSDK::Models::Crm::NearLimitRecordSample>)
  • total_records_at_limit (Integer)

    The total number of records that have reached their association limit.

  • total_records_near_limit (Integer)

    The total number of records that are approaching their association limit.



# File 'lib/hubspot_sdk/models/crm/association_record_limit_response.rb', line 40

Instance Attribute Details

#at_limit_from_record_samplesArray<HubSpotSDK::Models::Crm::AtLimitRecordSample>



11
12
13
# File 'lib/hubspot_sdk/models/crm/association_record_limit_response.rb', line 11

required :at_limit_from_record_samples,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::AtLimitRecordSample] },
api_name: :atLimitFromRecordSamples

#limitInteger

The maximum number of associations allowed for records.

Returns:

  • (Integer)


19
# File 'lib/hubspot_sdk/models/crm/association_record_limit_response.rb', line 19

required :limit, Integer

#near_limit_from_record_samplesArray<HubSpotSDK::Models::Crm::NearLimitRecordSample>



24
25
26
# File 'lib/hubspot_sdk/models/crm/association_record_limit_response.rb', line 24

required :near_limit_from_record_samples,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::NearLimitRecordSample] },
api_name: :nearLimitFromRecordSamples

#total_records_at_limitInteger

The total number of records that have reached their association limit.

Returns:

  • (Integer)


32
# File 'lib/hubspot_sdk/models/crm/association_record_limit_response.rb', line 32

required :total_records_at_limit, Integer, api_name: :totalRecordsAtLimit

#total_records_near_limitInteger

The total number of records that are approaching their association limit.

Returns:

  • (Integer)


38
# File 'lib/hubspot_sdk/models/crm/association_record_limit_response.rb', line 38

required :total_records_near_limit, Integer, api_name: :totalRecordsNearLimit