Class: HubSpotSDK::Models::Crm::AssociationSpecWithLabel

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/association_spec_with_label.rb

Defined Under Namespace

Modules: Category

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(category:, type_id:, label: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::AssociationSpecWithLabel for more details.

Defines the type, direction, and details of the relationship between two CRM objects.

Parameters:

  • category (Symbol, HubSpotSDK::Models::Crm::AssociationSpecWithLabel::Category)

    Association category. Can be HUBSPOT_DEFINED, USER_DEFINED, INTEGRATOR_DEFINED o

  • type_id (Integer)

    An integer value used to uniquely identify a specific association type within it

  • label (String) (defaults to: nil)

    An optional descriptor that provides additional context about the relationship b



# File 'lib/hubspot_sdk/models/crm/association_spec_with_label.rb', line 28

Instance Attribute Details

#categorySymbol, HubSpotSDK::Models::Crm::AssociationSpecWithLabel::Category

Association category. Can be HUBSPOT_DEFINED, USER_DEFINED, INTEGRATOR_DEFINED or WORK



12
# File 'lib/hubspot_sdk/models/crm/association_spec_with_label.rb', line 12

required :category, enum: -> { HubSpotSDK::Crm::AssociationSpecWithLabel::Category }

#labelString?

An optional descriptor that provides additional context about the relationship between associated records, such as “Mentor” and “Mentee”.

Returns:

  • (String, nil)


26
# File 'lib/hubspot_sdk/models/crm/association_spec_with_label.rb', line 26

optional :label, String

#type_idInteger

An integer value used to uniquely identify a specific association type within its Association Category.

Returns:

  • (Integer)


19
# File 'lib/hubspot_sdk/models/crm/association_spec_with_label.rb', line 19

required :type_id, Integer, api_name: :typeId