Class: HubSpotSDK::Models::Crm::AtLimitRecordSample

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/at_limit_record_sample.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(label:, object_id_:) ⇒ Object

Parameters:

  • label (String)

    The label associated with a record that is at its limit.

  • object_id_ (Integer)

    The objectId of the object that is at its limit.



# File 'lib/hubspot_sdk/models/crm/at_limit_record_sample.rb', line 19

Instance Attribute Details

#labelString

The label associated with a record that is at its limit.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/crm/at_limit_record_sample.rb', line 11

required :label, String

#object_id_Integer

The objectId of the object that is at its limit.

Returns:

  • (Integer)


17
# File 'lib/hubspot_sdk/models/crm/at_limit_record_sample.rb', line 17

required :object_id_, Integer, api_name: :objectId