Class: HubSpotSDK::Models::Crm::BatchReadInputSimplePublicObjectID

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/batch_read_input_simple_public_object_id.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(inputs:, properties:, properties_with_history:, id_property: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::BatchReadInputSimplePublicObjectID for more details.

Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property.

Parameters:

  • inputs (Array<HubSpotSDK::Models::Crm::SimplePublicObjectID>)
  • properties (Array<String>)

    Key-value pairs for setting properties for the new object.

  • properties_with_history (Array<String>)

    Key-value pairs for setting properties for the new object and their histories.

  • id_property (String) (defaults to: nil)

    When using a custom unique value property to retrieve records, the name of the p



# File 'lib/hubspot_sdk/models/crm/batch_read_input_simple_public_object_id.rb', line 33

Instance Attribute Details

#id_propertyString?

When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID.

Returns:

  • (String, nil)


31
# File 'lib/hubspot_sdk/models/crm/batch_read_input_simple_public_object_id.rb', line 31

optional :id_property, String, api_name: :idProperty

#inputsArray<HubSpotSDK::Models::Crm::SimplePublicObjectID>



10
# File 'lib/hubspot_sdk/models/crm/batch_read_input_simple_public_object_id.rb', line 10

required :inputs, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::SimplePublicObjectID] }

#propertiesArray<String>

Key-value pairs for setting properties for the new object.

Returns:

  • (Array<String>)


16
# File 'lib/hubspot_sdk/models/crm/batch_read_input_simple_public_object_id.rb', line 16

required :properties, HubSpotSDK::Internal::Type::ArrayOf[String]

#properties_with_historyArray<String>

Key-value pairs for setting properties for the new object and their histories.

Returns:

  • (Array<String>)


22
23
24
# File 'lib/hubspot_sdk/models/crm/batch_read_input_simple_public_object_id.rb', line 22

required :properties_with_history,
HubSpotSDK::Internal::Type::ArrayOf[String],
api_name: :propertiesWithHistory