Class: HubSpotSDK::Models::Crm::BatchResponseDealToDealSplits

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(completed_at:, results:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::BatchResponseDealToDealSplits for more details.

Parameters:

  • completed_at (Time)

    The timestamp indicating when the batch operation was completed, in date-time fo

  • results (Array<HubSpotSDK::Models::Crm::DealToDealSplits>)

    An array of deal-to-deal split objects representing the results of the batch ope

  • started_at (Time)

    The timestamp indicating when the batch operation started, in date-time format.

  • status (Symbol, HubSpotSDK::Models::Crm::BatchResponseDealToDealSplits::Status)

    The current status of the batch operation, with possible values: CANCELED, COMPL

  • links (Hash{Symbol=>String}) (defaults to: nil)

    A map of link names to associated URIs for additional resources or documentation

  • requested_at (Time) (defaults to: nil)

    The timestamp indicating when the batch operation was requested, in date-time fo



# File 'lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits.rb', line 48

Instance Attribute Details

#completed_atTime

The timestamp indicating when the batch operation was completed, in date-time format.

Returns:

  • (Time)


12
# File 'lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits.rb', line 12

required :completed_at, Time, api_name: :completedAt

A map of link names to associated URIs for additional resources or documentation.

Returns:

  • (Hash{Symbol=>String}, nil)


39
# File 'lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits.rb', line 39

optional :links, HubSpotSDK::Internal::Type::HashOf[String]

#requested_atTime?

The timestamp indicating when the batch operation was requested, in date-time format.

Returns:

  • (Time, nil)


46
# File 'lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits.rb', line 46

optional :requested_at, Time, api_name: :requestedAt

#resultsArray<HubSpotSDK::Models::Crm::DealToDealSplits>

An array of deal-to-deal split objects representing the results of the batch operation.



19
# File 'lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits.rb', line 19

required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::DealToDealSplits] }

#started_atTime

The timestamp indicating when the batch operation started, in date-time format.

Returns:

  • (Time)


25
# File 'lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits.rb', line 25

required :started_at, Time, api_name: :startedAt

#statusSymbol, HubSpotSDK::Models::Crm::BatchResponseDealToDealSplits::Status

The current status of the batch operation, with possible values: CANCELED, COMPLETE, PENDING, PROCESSING.



32
# File 'lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits.rb', line 32

required :status, enum: -> { HubSpotSDK::Crm::BatchResponseDealToDealSplits::Status }