Class: HubSpotSDK::Models::Crm::BatchResponseDealToDealSplitsWithErrors
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::BatchResponseDealToDealSplitsWithErrors
- Defined in:
- lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits_with_errors.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The timestamp indicating when the batch operation was completed, in date-time format.
-
#errors ⇒ Array<HubSpotSDK::Models::StandardError>?
An array of error objects detailing the errors that occurred during the batch operation.
-
#links ⇒ Hash{Symbol=>String}?
A map of link names to associated URIs for additional resources or documentation.
-
#num_errors ⇒ Integer?
The total number of errors encountered during the batch operation.
-
#requested_at ⇒ Time?
The timestamp indicating when the batch operation was requested, in date-time format.
-
#results ⇒ Array<HubSpotSDK::Models::Crm::DealToDealSplits>
An array of deal-to-deal split objects representing the results of the batch operation.
-
#started_at ⇒ Time
The timestamp indicating when the batch operation started, in date-time format.
-
#status ⇒ Symbol, HubSpotSDK::Models::Crm::BatchResponseDealToDealSplitsWithErrors::Status
The current status of the batch operation, with possible values: CANCELED, COMPLETE, PENDING, PROCESSING.
Instance Method Summary collapse
-
#initialize(completed_at:, results:, started_at:, status:, errors: nil, links: nil, num_errors: nil, requested_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BatchResponseDealToDealSplitsWithErrors for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(completed_at:, results:, started_at:, status:, errors: nil, links: nil, num_errors: nil, requested_at: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::BatchResponseDealToDealSplitsWithErrors for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits_with_errors.rb', line 61
|
Instance Attribute Details
#completed_at ⇒ Time
The timestamp indicating when the batch operation was completed, in date-time format.
12 |
# File 'lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits_with_errors.rb', line 12 required :completed_at, Time, api_name: :completedAt |
#errors ⇒ Array<HubSpotSDK::Models::StandardError>?
An array of error objects detailing the errors that occurred during the batch operation.
39 |
# File 'lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits_with_errors.rb', line 39 optional :errors, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::StandardError] } |
#links ⇒ Hash{Symbol=>String}?
A map of link names to associated URIs for additional resources or documentation.
46 |
# File 'lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits_with_errors.rb', line 46 optional :links, HubSpotSDK::Internal::Type::HashOf[String] |
#num_errors ⇒ Integer?
The total number of errors encountered during the batch operation.
52 |
# File 'lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits_with_errors.rb', line 52 optional :num_errors, Integer, api_name: :numErrors |
#requested_at ⇒ Time?
The timestamp indicating when the batch operation was requested, in date-time format.
59 |
# File 'lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits_with_errors.rb', line 59 optional :requested_at, Time, api_name: :requestedAt |
#results ⇒ Array<HubSpotSDK::Models::Crm::DealToDealSplits>
An array of deal-to-deal split objects representing the results of the batch operation.
19 |
# File 'lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits_with_errors.rb', line 19 required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::DealToDealSplits] } |
#started_at ⇒ Time
The timestamp indicating when the batch operation started, in date-time format.
25 |
# File 'lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits_with_errors.rb', line 25 required :started_at, Time, api_name: :startedAt |
#status ⇒ Symbol, HubSpotSDK::Models::Crm::BatchResponseDealToDealSplitsWithErrors::Status
The current status of the batch operation, with possible values: CANCELED, COMPLETE, PENDING, PROCESSING.
32 |
# File 'lib/hubspot_sdk/models/crm/batch_response_deal_to_deal_splits_with_errors.rb', line 32 required :status, enum: -> { HubSpotSDK::Crm::BatchResponseDealToDealSplitsWithErrors::Status } |