Class: HubSpotSDK::Models::Crm::BatchResponseProperty

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/batch_response_property.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(completed_at:, results:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::BatchResponseProperty for more details.

Parameters:

  • completed_at (Time)

    The timestamp indicating when the batch operation was completed.

  • results (Array<HubSpotSDK::Models::Property>)
  • started_at (Time)

    The timestamp indicating when the batch operation began processing.

  • status (Symbol, HubSpotSDK::Models::Crm::BatchResponseProperty::Status)

    The current status of the batch operation, with possible values being CANCELED,

  • links (Hash{Symbol=>String}) (defaults to: nil)

    A collection of URLs linking to documentation or resources related to the batch

  • requested_at (Time) (defaults to: nil)

    The timestamp indicating when the batch operation was requested.



# File 'lib/hubspot_sdk/models/crm/batch_response_property.rb', line 44

Instance Attribute Details

#completed_atTime

The timestamp indicating when the batch operation was completed.

Returns:

  • (Time)


11
# File 'lib/hubspot_sdk/models/crm/batch_response_property.rb', line 11

required :completed_at, Time, api_name: :completedAt

A collection of URLs linking to documentation or resources related to the batch operation.

Returns:

  • (Hash{Symbol=>String}, nil)


36
# File 'lib/hubspot_sdk/models/crm/batch_response_property.rb', line 36

optional :links, HubSpotSDK::Internal::Type::HashOf[String]

#requested_atTime?

The timestamp indicating when the batch operation was requested.

Returns:

  • (Time, nil)


42
# File 'lib/hubspot_sdk/models/crm/batch_response_property.rb', line 42

optional :requested_at, Time, api_name: :requestedAt

#resultsArray<HubSpotSDK::Models::Property>

Returns:



16
# File 'lib/hubspot_sdk/models/crm/batch_response_property.rb', line 16

required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Property] }

#started_atTime

The timestamp indicating when the batch operation began processing.

Returns:

  • (Time)


22
# File 'lib/hubspot_sdk/models/crm/batch_response_property.rb', line 22

required :started_at, Time, api_name: :startedAt

#statusSymbol, HubSpotSDK::Models::Crm::BatchResponseProperty::Status

The current status of the batch operation, with possible values being CANCELED, COMPLETE, PENDING, or PROCESSING.



29
# File 'lib/hubspot_sdk/models/crm/batch_response_property.rb', line 29

required :status, enum: -> { HubSpotSDK::Crm::BatchResponseProperty::Status }