Class: HubSpotSDK::Models::Crm::BatchResponsePublicAssociationMultiWithLabel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::BatchResponsePublicAssociationMultiWithLabel
- Defined in:
- lib/hubspot_sdk/models/crm/batch_response_public_association_multi_with_label.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The timestamp when the batch processing was completed, in ISO 8601 format.
-
#links ⇒ Hash{Symbol=>String}?
An object containing relevant links related to the batch request.
-
#requested_at ⇒ Time?
The timestamp when the batch request was initially made, in ISO 8601 format.
- #results ⇒ Array<HubSpotSDK::Models::Crm::PublicAssociationMultiWithLabel>
-
#started_at ⇒ Time
The timestamp when the batch processing began, in ISO 8601 format.
-
#status ⇒ Symbol, HubSpotSDK::Models::Crm::BatchResponsePublicAssociationMultiWithLabel::Status
The status of the batch processing request: “PENDING”, “PROCESSING”, “CANCELED”, or “COMPLETE”.
Instance Method Summary collapse
-
#initialize(completed_at:, results:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BatchResponsePublicAssociationMultiWithLabel for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(completed_at:, results:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::BatchResponsePublicAssociationMultiWithLabel for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/batch_response_public_association_multi_with_label.rb', line 44
|
Instance Attribute Details
#completed_at ⇒ Time
The timestamp when the batch processing was completed, in ISO 8601 format.
11 |
# File 'lib/hubspot_sdk/models/crm/batch_response_public_association_multi_with_label.rb', line 11 required :completed_at, Time, api_name: :completedAt |
#links ⇒ Hash{Symbol=>String}?
An object containing relevant links related to the batch request.
36 |
# File 'lib/hubspot_sdk/models/crm/batch_response_public_association_multi_with_label.rb', line 36 optional :links, HubSpotSDK::Internal::Type::HashOf[String] |
#requested_at ⇒ Time?
The timestamp when the batch request was initially made, in ISO 8601 format.
42 |
# File 'lib/hubspot_sdk/models/crm/batch_response_public_association_multi_with_label.rb', line 42 optional :requested_at, Time, api_name: :requestedAt |
#results ⇒ Array<HubSpotSDK::Models::Crm::PublicAssociationMultiWithLabel>
16 17 |
# File 'lib/hubspot_sdk/models/crm/batch_response_public_association_multi_with_label.rb', line 16 required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::PublicAssociationMultiWithLabel] } |
#started_at ⇒ Time
The timestamp when the batch processing began, in ISO 8601 format.
23 |
# File 'lib/hubspot_sdk/models/crm/batch_response_public_association_multi_with_label.rb', line 23 required :started_at, Time, api_name: :startedAt |
#status ⇒ Symbol, HubSpotSDK::Models::Crm::BatchResponsePublicAssociationMultiWithLabel::Status
The status of the batch processing request: “PENDING”, “PROCESSING”, “CANCELED”, or “COMPLETE”.
30 |
# File 'lib/hubspot_sdk/models/crm/batch_response_public_association_multi_with_label.rb', line 30 required :status, enum: -> { HubSpotSDK::Crm::BatchResponsePublicAssociationMultiWithLabel::Status } |