Class: HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject
- Defined in:
- lib/hubspot_sdk/models/crm/batch_response_simple_public_upsert_object.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The timestamp when the batch process was completed, in ISO 8601 format.
-
#links ⇒ Hash{Symbol=>String}?
An object containing relevant links related to the batch request.
-
#requested_at ⇒ Time?
The timestamp when the batch process was initiated, in ISO 8601 format.
- #results ⇒ Array<HubSpotSDK::Models::Crm::SimplePublicUpsertObject>
-
#started_at ⇒ Time
The timestamp when the batch process began execution, in ISO 8601 format.
-
#status ⇒ Symbol, HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject::Status
The status of the batch processing request.
Instance Method Summary collapse
-
#initialize(completed_at:, results:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BatchResponseSimplePublicUpsertObject for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(completed_at:, results:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject for more details.
Represents the result of a batch upsert operation, including the operation’s status, timestamps, and a list of successfully created or updated objects.
|
|
# File 'lib/hubspot_sdk/models/crm/batch_response_simple_public_upsert_object.rb', line 43
|
Instance Attribute Details
#completed_at ⇒ Time
The timestamp when the batch process was completed, in ISO 8601 format.
11 |
# File 'lib/hubspot_sdk/models/crm/batch_response_simple_public_upsert_object.rb', line 11 required :completed_at, Time, api_name: :completedAt |
#links ⇒ Hash{Symbol=>String}?
An object containing relevant links related to the batch request.
35 |
# File 'lib/hubspot_sdk/models/crm/batch_response_simple_public_upsert_object.rb', line 35 optional :links, HubSpotSDK::Internal::Type::HashOf[String] |
#requested_at ⇒ Time?
The timestamp when the batch process was initiated, in ISO 8601 format.
41 |
# File 'lib/hubspot_sdk/models/crm/batch_response_simple_public_upsert_object.rb', line 41 optional :requested_at, Time, api_name: :requestedAt |
#results ⇒ Array<HubSpotSDK::Models::Crm::SimplePublicUpsertObject>
16 |
# File 'lib/hubspot_sdk/models/crm/batch_response_simple_public_upsert_object.rb', line 16 required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::SimplePublicUpsertObject] } |
#started_at ⇒ Time
The timestamp when the batch process began execution, in ISO 8601 format.
22 |
# File 'lib/hubspot_sdk/models/crm/batch_response_simple_public_upsert_object.rb', line 22 required :started_at, Time, api_name: :startedAt |
#status ⇒ Symbol, HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject::Status
The status of the batch processing request. Can be: “PENDING”, “PROCESSING”, “CANCELED”, or “COMPLETE”.
29 |
# File 'lib/hubspot_sdk/models/crm/batch_response_simple_public_upsert_object.rb', line 29 required :status, enum: -> { HubSpotSDK::Crm::BatchResponseSimplePublicUpsertObject::Status } |