Class: HubSpotSDK::Models::Crm::CalculatedPropertyLimitResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::CalculatedPropertyLimitResponse
- Defined in:
- lib/hubspot_sdk/models/crm/calculated_property_limit_response.rb
Overview
Instance Attribute Summary collapse
- #by_object_type ⇒ Array<HubSpotSDK::Models::Crm::UsageForObjectType>
-
#overall_limit ⇒ Integer
The maximum number of calculated properties allowed.
-
#overall_percentage ⇒ Float
The percentage of the overall limit that is currently being used for calculated properties.
-
#overall_usage ⇒ Integer
The total number of calculated properties currently in use.
Instance Method Summary collapse
-
#initialize(by_object_type:, overall_limit:, overall_percentage:, overall_usage:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CalculatedPropertyLimitResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(by_object_type:, overall_limit:, overall_percentage:, overall_usage:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::CalculatedPropertyLimitResponse for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/calculated_property_limit_response.rb', line 34
|
Instance Attribute Details
#by_object_type ⇒ Array<HubSpotSDK::Models::Crm::UsageForObjectType>
11 12 13 |
# File 'lib/hubspot_sdk/models/crm/calculated_property_limit_response.rb', line 11 required :by_object_type, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::UsageForObjectType] }, api_name: :byObjectType |
#overall_limit ⇒ Integer
The maximum number of calculated properties allowed.
19 |
# File 'lib/hubspot_sdk/models/crm/calculated_property_limit_response.rb', line 19 required :overall_limit, Integer, api_name: :overallLimit |
#overall_percentage ⇒ Float
The percentage of the overall limit that is currently being used for calculated properties.
26 |
# File 'lib/hubspot_sdk/models/crm/calculated_property_limit_response.rb', line 26 required :overall_percentage, Float, api_name: :overallPercentage |
#overall_usage ⇒ Integer
The total number of calculated properties currently in use.
32 |
# File 'lib/hubspot_sdk/models/crm/calculated_property_limit_response.rb', line 32 required :overall_usage, Integer, api_name: :overallUsage |