Class: HubSpotSDK::Models::Crm::CustomObjectLimitResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::CustomObjectLimitResponse
- Defined in:
- lib/hubspot_sdk/models/crm/custom_object_limit_response.rb
Overview
Instance Attribute Summary collapse
-
#limit ⇒ Integer
The maximum number of custom objects allowed.
-
#percentage ⇒ Float
The percentage of the custom object limit that is currently used.
-
#usage ⇒ Integer
The current number of custom objects used.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(limit:, percentage:, usage:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/custom_object_limit_response.rb', line 26
|
Instance Attribute Details
#limit ⇒ Integer
The maximum number of custom objects allowed.
12 |
# File 'lib/hubspot_sdk/models/crm/custom_object_limit_response.rb', line 12 required :limit, Integer |
#percentage ⇒ Float
The percentage of the custom object limit that is currently used.
18 |
# File 'lib/hubspot_sdk/models/crm/custom_object_limit_response.rb', line 18 required :percentage, Float |
#usage ⇒ Integer
The current number of custom objects used.
24 |
# File 'lib/hubspot_sdk/models/crm/custom_object_limit_response.rb', line 24 required :usage, Integer |