Class: HubSpotSDK::Models::Crm::CustomPropertyLimitResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/custom_property_limit_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(by_object_type:, overall_limit:, overall_percentage:, overall_usage:) ⇒ Object

Parameters:

  • by_object_type (Array<HubSpotSDK::Models::Crm::LimitAndUsageForObjectType>)
  • overall_limit (Integer)

    The total limit for custom properties across all objects.

  • overall_percentage (Float)

    The percentage of the overall custom property limit that has been used.

  • overall_usage (Integer)

    The total number of custom properties currently in use across all objects.



# File 'lib/hubspot_sdk/models/crm/custom_property_limit_response.rb', line 33

Instance Attribute Details

#by_object_typeArray<HubSpotSDK::Models::Crm::LimitAndUsageForObjectType>



11
12
13
# File 'lib/hubspot_sdk/models/crm/custom_property_limit_response.rb', line 11

required :by_object_type,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::LimitAndUsageForObjectType] },
api_name: :byObjectType

#overall_limitInteger

The total limit for custom properties across all objects.

Returns:

  • (Integer)


19
# File 'lib/hubspot_sdk/models/crm/custom_property_limit_response.rb', line 19

required :overall_limit, Integer, api_name: :overallLimit

#overall_percentageFloat

The percentage of the overall custom property limit that has been used.

Returns:

  • (Float)


25
# File 'lib/hubspot_sdk/models/crm/custom_property_limit_response.rb', line 25

required :overall_percentage, Float, api_name: :overallPercentage

#overall_usageInteger

The total number of custom properties currently in use across all objects.

Returns:

  • (Integer)


31
# File 'lib/hubspot_sdk/models/crm/custom_property_limit_response.rb', line 31

required :overall_usage, Integer, api_name: :overallUsage