Class: HubSpotSDK::Models::Crm::Extensions::ActionConfirmationBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Extensions::ActionConfirmationBody
- Defined in:
- lib/hubspot_sdk/models/crm/extensions/action_confirmation_body.rb
Instance Attribute Summary collapse
-
#cancel_button_label ⇒ String
The label for the button that cancels the action.
-
#confirm_button_label ⇒ String
The label for the button that confirms the action.
-
#prompt ⇒ String
The message displayed to the user to confirm the action.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cancel_button_label:, confirm_button_label:, prompt:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/extensions/action_confirmation_body.rb', line 26
|
Instance Attribute Details
#cancel_button_label ⇒ String
The label for the button that cancels the action.
12 |
# File 'lib/hubspot_sdk/models/crm/extensions/action_confirmation_body.rb', line 12 required :cancel_button_label, String, api_name: :cancelButtonLabel |
#confirm_button_label ⇒ String
The label for the button that confirms the action.
18 |
# File 'lib/hubspot_sdk/models/crm/extensions/action_confirmation_body.rb', line 18 required :confirm_button_label, String, api_name: :confirmButtonLabel |
#prompt ⇒ String
The message displayed to the user to confirm the action.
24 |
# File 'lib/hubspot_sdk/models/crm/extensions/action_confirmation_body.rb', line 24 required :prompt, String |