Class: HubSpotSDK::Models::Crm::Extensions::ActionHookActionBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Extensions::ActionHookActionBody
- Defined in:
- lib/hubspot_sdk/models/crm/extensions/action_hook_action_body.rb
Defined Under Namespace
Modules: HTTPMethod, Type
Instance Attribute Summary collapse
- #confirmation ⇒ HubSpotSDK::Models::Crm::Extensions::ActionConfirmationBody?
-
#http_method ⇒ Symbol, HubSpotSDK::Models::Crm::Extensions::ActionHookActionBody::HTTPMethod
The HTTP method to be used when making the call, which can be set to GET, POST, PUT, DELETE, or PATCH.
-
#label ⇒ String?
The label for this property as you’d like it displayed to users.
-
#property_names_included ⇒ Array<String>
A list of property names that will be included on the action.
-
#type ⇒ Symbol, HubSpotSDK::Models::Crm::Extensions::ActionHookActionBody::Type
The type of status.
-
#url ⇒ String
The URL endpoint that will be called when the action is triggered.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(http_method:, property_names_included:, type:, url:, confirmation: nil, label: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionHookActionBody for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(http_method:, property_names_included:, type:, url:, confirmation: nil, label: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Extensions::ActionHookActionBody for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/extensions/action_hook_action_body.rb', line 49
|
Instance Attribute Details
#confirmation ⇒ HubSpotSDK::Models::Crm::Extensions::ActionConfirmationBody?
41 |
# File 'lib/hubspot_sdk/models/crm/extensions/action_hook_action_body.rb', line 41 optional :confirmation, -> { HubSpotSDK::Crm::Extensions::ActionConfirmationBody } |
#http_method ⇒ Symbol, HubSpotSDK::Models::Crm::Extensions::ActionHookActionBody::HTTPMethod
The HTTP method to be used when making the call, which can be set to GET, POST, PUT, DELETE, or PATCH. If using GET or DELETE
13 14 15 |
# File 'lib/hubspot_sdk/models/crm/extensions/action_hook_action_body.rb', line 13 required :http_method, enum: -> { HubSpotSDK::Crm::Extensions::ActionHookActionBody::HTTPMethod }, api_name: :httpMethod |
#label ⇒ String?
The label for this property as you’d like it displayed to users.
47 |
# File 'lib/hubspot_sdk/models/crm/extensions/action_hook_action_body.rb', line 47 optional :label, String |
#property_names_included ⇒ Array<String>
A list of property names that will be included on the action. See the documentation for more information
22 23 24 |
# File 'lib/hubspot_sdk/models/crm/extensions/action_hook_action_body.rb', line 22 required :property_names_included, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :propertyNamesIncluded |
#type ⇒ Symbol, HubSpotSDK::Models::Crm::Extensions::ActionHookActionBody::Type
The type of status.
30 |
# File 'lib/hubspot_sdk/models/crm/extensions/action_hook_action_body.rb', line 30 required :type, enum: -> { HubSpotSDK::Crm::Extensions::ActionHookActionBody::Type } |
#url ⇒ String
The URL endpoint that will be called when the action is triggered.
36 |
# File 'lib/hubspot_sdk/models/crm/extensions/action_hook_action_body.rb', line 36 required :url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/crm/extensions/action_hook_action_body.rb', line 82
|