Class: HubSpotSDK::Models::Crm::Extensions::CardActions

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/extensions/card_actions.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(base_urls:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Extensions::CardActions for more details.

Parameters:

  • base_urls (Array<String>)

    A list of URL prefixes that will be accepted for card action URLs. If your data



# File 'lib/hubspot_sdk/models/crm/extensions/card_actions.rb', line 16

Instance Attribute Details

#base_urlsArray<String>

A list of URL prefixes that will be accepted for card action URLs. If your data fetch response includes an action URL that doesn’t begin with one of these values, it will result in an error and the card will not be displayed.

Returns:

  • (Array<String>)


14
# File 'lib/hubspot_sdk/models/crm/extensions/card_actions.rb', line 14

required :base_urls, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :baseUrls