Class: HubSpotSDK::Models::Crm::Extensions::CardAuditResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Extensions::CardAuditResponse
- Defined in:
- lib/hubspot_sdk/models/crm/extensions/card_audit_response.rb
Defined Under Namespace
Modules: ActionType, AuthSource
Instance Attribute Summary collapse
-
#action_type ⇒ Symbol, HubSpotSDK::Models::Crm::Extensions::CardAuditResponse::ActionType
The type of action performed, with possible values: CREATE, DELETE, UPDATE.
-
#application_id ⇒ Integer
The ID of the application associated with the card.
-
#auth_source ⇒ Symbol, HubSpotSDK::Models::Crm::Extensions::CardAuditResponse::AuthSource
The source of authentication for the action, with possible values: APP, EXTERNAL, INTERNAL.
-
#changed_at ⇒ Integer
The timestamp indicating when the change occurred.
-
#initiating_user_id ⇒ Integer
The ID of the user who initiated the action.
-
#object_type_id ⇒ Integer
The ID of the card.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(action_type:, application_id:, auth_source:, changed_at:, initiating_user_id:, object_type_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CardAuditResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(action_type:, application_id:, auth_source:, changed_at:, initiating_user_id:, object_type_id:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Extensions::CardAuditResponse for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/extensions/card_audit_response.rb', line 49
|
Instance Attribute Details
#action_type ⇒ Symbol, HubSpotSDK::Models::Crm::Extensions::CardAuditResponse::ActionType
The type of action performed, with possible values: CREATE, DELETE, UPDATE.
12 13 14 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_audit_response.rb', line 12 required :action_type, enum: -> { HubSpotSDK::Crm::Extensions::CardAuditResponse::ActionType }, api_name: :actionType |
#application_id ⇒ Integer
The ID of the application associated with the card.
20 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_audit_response.rb', line 20 required :application_id, Integer, api_name: :applicationId |
#auth_source ⇒ Symbol, HubSpotSDK::Models::Crm::Extensions::CardAuditResponse::AuthSource
The source of authentication for the action, with possible values: APP, EXTERNAL, INTERNAL.
27 28 29 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_audit_response.rb', line 27 required :auth_source, enum: -> { HubSpotSDK::Crm::Extensions::CardAuditResponse::AuthSource }, api_name: :authSource |
#changed_at ⇒ Integer
The timestamp indicating when the change occurred.
35 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_audit_response.rb', line 35 required :changed_at, Integer, api_name: :changedAt |
#initiating_user_id ⇒ Integer
The ID of the user who initiated the action.
41 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_audit_response.rb', line 41 required :initiating_user_id, Integer, api_name: :initiatingUserId |
#object_type_id ⇒ Integer
The ID of the card.
47 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_audit_response.rb', line 47 required :object_type_id, Integer, api_name: :objectTypeId |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/crm/extensions/card_audit_response.rb', line 75
|