Class: HubSpotSDK::Models::Crm::Extensions::CardDisplayProperty
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Extensions::CardDisplayProperty
- Defined in:
- lib/hubspot_sdk/models/crm/extensions/card_display_property.rb
Defined Under Namespace
Modules: DataType
Instance Attribute Summary collapse
-
#data_type ⇒ Symbol, HubSpotSDK::Models::Crm::Extensions::CardDisplayProperty::DataType
Type of data represented by this property.
-
#label ⇒ String
The label for this property as you’d like it displayed to users.
-
#name ⇒ String
An internal identifier for this property.
-
#options ⇒ Array<HubSpotSDK::Models::Crm::Extensions::DisplayOption>
An array of available options that can be displayed.
Instance Method Summary collapse
-
#initialize(data_type:, label:, name:, options:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CardDisplayProperty for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data_type:, label:, name:, options:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Extensions::CardDisplayProperty for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/extensions/card_display_property.rb', line 35
|
Instance Attribute Details
#data_type ⇒ Symbol, HubSpotSDK::Models::Crm::Extensions::CardDisplayProperty::DataType
Type of data represented by this property.
12 13 14 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_display_property.rb', line 12 required :data_type, enum: -> { HubSpotSDK::Crm::Extensions::CardDisplayProperty::DataType }, api_name: :dataType |
#label ⇒ String
The label for this property as you’d like it displayed to users.
20 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_display_property.rb', line 20 required :label, String |
#name ⇒ String
An internal identifier for this property. This value must be unique TODO.
26 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_display_property.rb', line 26 required :name, String |
#options ⇒ Array<HubSpotSDK::Models::Crm::Extensions::DisplayOption>
An array of available options that can be displayed. Only used in when ‘dataType` is `STATUS`.
33 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_display_property.rb', line 33 required :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::Extensions::DisplayOption] } |