Class: HubSpotSDK::Models::Crm::Extensions::CardFetchBodyPatch
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Extensions::CardFetchBodyPatch
- Defined in:
- lib/hubspot_sdk/models/crm/extensions/card_fetch_body_patch.rb
Defined Under Namespace
Modules: CardType
Instance Attribute Summary collapse
-
#card_type ⇒ Symbol, ...
A deprecated field to determine the type of card returned.
-
#object_types ⇒ Array<HubSpotSDK::Models::Crm::Extensions::CardObjectTypeBody>
An array of CRM object types where this card should be displayed.
-
#serverless_function ⇒ String?
A deprecated field to specify serverless functionality with the card.
-
#target_url ⇒ String?
URL to a service endpoint that will respond with details for this card.
Instance Method Summary collapse
-
#initialize(object_types:, card_type: nil, serverless_function: nil, target_url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CardFetchBodyPatch for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(object_types:, card_type: nil, serverless_function: nil, target_url: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Extensions::CardFetchBodyPatch for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/extensions/card_fetch_body_patch.rb', line 42
|
Instance Attribute Details
#card_type ⇒ Symbol, ...
A deprecated field to determine the type of card returned.
24 25 26 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_fetch_body_patch.rb', line 24 optional :card_type, enum: -> { HubSpotSDK::Crm::Extensions::CardFetchBodyPatch::CardType }, api_name: :cardType |
#object_types ⇒ Array<HubSpotSDK::Models::Crm::Extensions::CardObjectTypeBody>
An array of CRM object types where this card should be displayed. HubSpot will call your target URL whenever a user visits a record page of the types defined here.
14 15 16 17 18 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_fetch_body_patch.rb', line 14 required :object_types, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::Extensions::CardObjectTypeBody] }, api_name: :objectTypes |
#serverless_function ⇒ String?
A deprecated field to specify serverless functionality with the card
32 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_fetch_body_patch.rb', line 32 optional :serverless_function, String, api_name: :serverlessFunction |
#target_url ⇒ String?
URL to a service endpoint that will respond with details for this card. HubSpot will call this endpoint each time a user visits a CRM record page where this card should be displayed.
40 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_fetch_body_patch.rb', line 40 optional :target_url, String, api_name: :targetUrl |