Class: HubSpotSDK::Models::Crm::Extensions::CardObjectTypeBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Extensions::CardObjectTypeBody
- Defined in:
- lib/hubspot_sdk/models/crm/extensions/card_object_type_body.rb
Defined Under Namespace
Modules: Name
Instance Attribute Summary collapse
-
#name ⇒ Symbol, HubSpotSDK::Models::Crm::Extensions::CardObjectTypeBody::Name
A CRM object type where this card should be displayed.
-
#properties_to_send ⇒ Array<String>
An array of properties that should be sent to this card’s target URL when the data fetch request is made.
Instance Method Summary collapse
-
#initialize(name:, properties_to_send:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CardObjectTypeBody for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, properties_to_send:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Extensions::CardObjectTypeBody for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/extensions/card_object_type_body.rb', line 24
|
Instance Attribute Details
#name ⇒ Symbol, HubSpotSDK::Models::Crm::Extensions::CardObjectTypeBody::Name
A CRM object type where this card should be displayed.
12 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_object_type_body.rb', line 12 required :name, enum: -> { HubSpotSDK::Crm::Extensions::CardObjectTypeBody::Name } |
#properties_to_send ⇒ Array<String>
An array of properties that should be sent to this card’s target URL when the data fetch request is made. Must be valid properties for the corresponding CRM object type.
20 21 22 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_object_type_body.rb', line 20 required :properties_to_send, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :propertiesToSend |