Class: HubSpotSDK::Models::Crm::Extensions::ChannelConnectionSettingsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/extensions/channel_connection_settings_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(created_at:, is_ready:, updated_at:, url:) ⇒ Object

Parameters:

  • created_at (Time)

    The date and time when the channel connection settings were created.

  • is_ready (Boolean)

    Indicates whether the channel connection settings are ready for use.

  • updated_at (Time)

    The date and time when the channel connection settings were last updated.

  • url (String)

    The URL associated with the channel connection settings.



# File 'lib/hubspot_sdk/models/crm/extensions/channel_connection_settings_response.rb', line 33

Instance Attribute Details

#created_atTime

The date and time when the channel connection settings were created.

Returns:

  • (Time)


13
# File 'lib/hubspot_sdk/models/crm/extensions/channel_connection_settings_response.rb', line 13

required :created_at, Time, api_name: :createdAt

#is_readyBoolean

Indicates whether the channel connection settings are ready for use.

Returns:

  • (Boolean)


19
# File 'lib/hubspot_sdk/models/crm/extensions/channel_connection_settings_response.rb', line 19

required :is_ready, HubSpotSDK::Internal::Type::Boolean, api_name: :isReady

#updated_atTime

The date and time when the channel connection settings were last updated.

Returns:

  • (Time)


25
# File 'lib/hubspot_sdk/models/crm/extensions/channel_connection_settings_response.rb', line 25

required :updated_at, Time, api_name: :updatedAt

#urlString

The URL associated with the channel connection settings.

Returns:

  • (String)


31
# File 'lib/hubspot_sdk/models/crm/extensions/channel_connection_settings_response.rb', line 31

required :url, String