Class: HubSpotSDK::Models::Crm::Extensions::CompletedThirdPartyCallRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb

Defined Under Namespace

Modules: FinalCallStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(create_engagement:, engagement_properties:, external_call_id:, final_call_status:, from_number:, potential_recipient_user_ids:, to_number:, call_started_timestamp: nil, duration_seconds: nil, user_id: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Extensions::CompletedThirdPartyCallRequest for more details.

Parameters:



# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 77

Instance Attribute Details

#call_started_timestampTime?

The timestamp indicating when the call started, formatted as a date-time string.

Returns:

  • (Time, nil)


63
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 63

optional :call_started_timestamp, Time, api_name: :callStartedTimestamp

#create_engagementBoolean

Indicates whether an engagement should be created for the call.

Returns:

  • (Boolean)


12
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 12

required :create_engagement, HubSpotSDK::Internal::Type::Boolean, api_name: :createEngagement

#duration_secondsInteger?

The duration of the call in seconds.

Returns:

  • (Integer, nil)


69
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 69

optional :duration_seconds, Integer, api_name: :durationSeconds

#engagement_propertiesHash{Symbol=>String}

Contains additional properties related to the engagement.

Returns:

  • (Hash{Symbol=>String})


18
19
20
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 18

required :engagement_properties,
HubSpotSDK::Internal::Type::HashOf[String],
api_name: :engagementProperties

#external_call_idString

The unique identifier for the call from an external system.

Returns:

  • (String)


26
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 26

required :external_call_id, String, api_name: :externalCallId

#final_call_statusSymbol, HubSpotSDK::Models::Crm::Extensions::CompletedThirdPartyCallRequest::FinalCallStatus

The final status of the call, with accepted values including: BUSY, CALLING_CRM_USER, CANCELED, COMPLETED, CONNECTING, FAILED, HOLD, IN_PROGRESS, MISSED, NO_ANSWER, QUEUED, RINGING, UNKNOWN.



34
35
36
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 34

required :final_call_status,
enum: -> { HubSpotSDK::Crm::Extensions::CompletedThirdPartyCallRequest::FinalCallStatus },
api_name: :finalCallStatus

#from_numberHubSpotSDK::Models::Crm::Extensions::FormattedPhoneNumber



41
42
43
44
45
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 41

required :from_number,
-> {
  HubSpotSDK::Crm::Extensions::FormattedPhoneNumber
},
api_name: :fromNumber

#potential_recipient_user_idsArray<Integer>

Returns:

  • (Array<Integer>)


50
51
52
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 50

required :potential_recipient_user_ids,
HubSpotSDK::Internal::Type::ArrayOf[Integer],
api_name: :potentialRecipientUserIds

#to_numberHubSpotSDK::Models::Crm::Extensions::FormattedPhoneNumber



57
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 57

required :to_number, -> { HubSpotSDK::Crm::Extensions::FormattedPhoneNumber }, api_name: :toNumber

#user_idInteger?

The ID of the user associated with the call.

Returns:

  • (Integer, nil)


75
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 75

optional :user_id, Integer, api_name: :userId