Class: HubSpotSDK::Models::Crm::Extensions::IFrameActionBody

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/extensions/i_frame_action_body.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(height:, property_names_included:, type:, url:, width:, label: nil) ⇒ Object

Parameters:

  • height (Integer)

    The height of the iframe in pixels.

  • property_names_included (Array<String>)

    A list of property names that will be included on the url of the iframe.

  • type (Symbol, HubSpotSDK::Models::Crm::Extensions::IFrameActionBody::Type)

    The type of status.

  • url (String)

    The URL endpoint that will be loaded in the iframe when triggered.

  • width (Integer)

    The width of the iframe in pixels.

  • label (String) (defaults to: nil)

    The label for this property as you’d like it displayed to users.



# File 'lib/hubspot_sdk/models/crm/extensions/i_frame_action_body.rb', line 46

Instance Attribute Details

#heightInteger

The height of the iframe in pixels.

Returns:

  • (Integer)


12
# File 'lib/hubspot_sdk/models/crm/extensions/i_frame_action_body.rb', line 12

required :height, Integer

#labelString?

The label for this property as you’d like it displayed to users.

Returns:

  • (String, nil)


44
# File 'lib/hubspot_sdk/models/crm/extensions/i_frame_action_body.rb', line 44

optional :label, String

#property_names_includedArray<String>

A list of property names that will be included on the url of the iframe.

Returns:

  • (Array<String>)


18
19
20
# File 'lib/hubspot_sdk/models/crm/extensions/i_frame_action_body.rb', line 18

required :property_names_included,
HubSpotSDK::Internal::Type::ArrayOf[String],
api_name: :propertyNamesIncluded

#typeSymbol, HubSpotSDK::Models::Crm::Extensions::IFrameActionBody::Type

The type of status.



26
# File 'lib/hubspot_sdk/models/crm/extensions/i_frame_action_body.rb', line 26

required :type, enum: -> { HubSpotSDK::Crm::Extensions::IFrameActionBody::Type }

#urlString

The URL endpoint that will be loaded in the iframe when triggered.

Returns:

  • (String)


32
# File 'lib/hubspot_sdk/models/crm/extensions/i_frame_action_body.rb', line 32

required :url, String

#widthInteger

The width of the iframe in pixels.

Returns:

  • (Integer)


38
# File 'lib/hubspot_sdk/models/crm/extensions/i_frame_action_body.rb', line 38

required :width, Integer