Class: HubSpotSDK::Models::Crm::Extensions::IntegratorCardPayloadResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/extensions/integrator_card_payload_response.rb

Overview

Defined Under Namespace

Modules: ResponseVersion

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(response_version:, sections:, total_count:, all_items_link_url: nil, card_label: nil, top_level_actions: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Extensions::IntegratorCardPayloadResponse for more details.

Parameters:



# File 'lib/hubspot_sdk/models/crm/extensions/integrator_card_payload_response.rb', line 52

Instance Attribute Details

URL to a page the integrator has built that displays all details for this card. This URL will be displayed to users under a ‘See more [x]` link if there are more than five items in your response, where `[x]` is the value of `itemLabel`.

Returns:

  • (String, nil)


36
# File 'lib/hubspot_sdk/models/crm/extensions/integrator_card_payload_response.rb', line 36

optional :all_items_link_url, String, api_name: :allItemsLinkUrl

#card_labelString?

The label to be used for the ‘allItemsLinkUrl` link (e.g. ’See more tickets’). If not provided, this falls back to the card’s title.

Returns:

  • (String, nil)


43
# File 'lib/hubspot_sdk/models/crm/extensions/integrator_card_payload_response.rb', line 43

optional :card_label, String, api_name: :cardLabel

#response_versionSymbol, HubSpotSDK::Models::Crm::Extensions::IntegratorCardPayloadResponse::ResponseVersion

The number version of the response.



13
14
15
# File 'lib/hubspot_sdk/models/crm/extensions/integrator_card_payload_response.rb', line 13

required :response_version,
enum: -> { HubSpotSDK::Crm::Extensions::IntegratorCardPayloadResponse::ResponseVersion },
api_name: :responseVersion

#sectionsArray<HubSpotSDK::Models::Crm::Extensions::IntegratorObjectResult>

A list of up to five valid card sub categories.



21
22
# File 'lib/hubspot_sdk/models/crm/extensions/integrator_card_payload_response.rb', line 21

required :sections,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::Extensions::IntegratorObjectResult] }

#top_level_actionsHubSpotSDK::Models::Crm::Extensions::TopLevelActions?



48
49
50
# File 'lib/hubspot_sdk/models/crm/extensions/integrator_card_payload_response.rb', line 48

optional :top_level_actions,
-> { HubSpotSDK::Crm::Extensions::TopLevelActions },
api_name: :topLevelActions

#total_countInteger

The total number of card properties that will be sent in this response.

Returns:

  • (Integer)


28
# File 'lib/hubspot_sdk/models/crm/extensions/integrator_card_payload_response.rb', line 28

required :total_count, Integer, api_name: :totalCount