Class: HubSpotSDK::Models::Crm::Extensions::SettingsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/extensions/settings_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(created_at:, height:, is_ready:, name:, supports_custom_objects:, supports_inbound_calling:, updated_at:, url:, uses_calling_window:, uses_remote:, width:) ⇒ Object

Parameters:

  • created_at (Time)

    The date and time when the calling extension settings were created.

  • height (Integer)

    The height of the calling extension interface.

  • is_ready (Boolean)

    Specifies whether the calling extension settings are ready for use.

  • name (String)

    The name of the calling extension.

  • supports_custom_objects (Boolean)

    Indicates if the calling extension supports custom objects.

  • supports_inbound_calling (Boolean)

    Indicates if the calling extension supports inbound calling.

  • updated_at (Time)

    The date and time when the calling extension settings were last updated.

  • url (String)

    The URL associated with the calling extension.

  • uses_calling_window (Boolean)

    Specifies if the calling extension uses a dedicated calling window.

  • uses_remote (Boolean)

    Indicates if the calling extension uses a remote service.

  • width (Integer)

    The width of the calling extension interface.



# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 79

Instance Attribute Details

#created_atTime

The date and time when the calling extension settings were created.

Returns:

  • (Time)


13
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 13

required :created_at, Time, api_name: :createdAt

#heightInteger

The height of the calling extension interface.

Returns:

  • (Integer)


19
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 19

required :height, Integer

#is_readyBoolean

Specifies whether the calling extension settings are ready for use.

Returns:

  • (Boolean)


25
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 25

required :is_ready, HubSpotSDK::Internal::Type::Boolean, api_name: :isReady

#nameString

The name of the calling extension.

Returns:

  • (String)


31
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 31

required :name, String

#supports_custom_objectsBoolean

Indicates if the calling extension supports custom objects.

Returns:

  • (Boolean)


37
38
39
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 37

required :supports_custom_objects,
HubSpotSDK::Internal::Type::Boolean,
api_name: :supportsCustomObjects

#supports_inbound_callingBoolean

Indicates if the calling extension supports inbound calling.

Returns:

  • (Boolean)


45
46
47
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 45

required :supports_inbound_calling,
HubSpotSDK::Internal::Type::Boolean,
api_name: :supportsInboundCalling

#updated_atTime

The date and time when the calling extension settings were last updated.

Returns:

  • (Time)


53
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 53

required :updated_at, Time, api_name: :updatedAt

#urlString

The URL associated with the calling extension.

Returns:

  • (String)


59
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 59

required :url, String

#uses_calling_windowBoolean

Specifies if the calling extension uses a dedicated calling window.

Returns:

  • (Boolean)


65
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 65

required :uses_calling_window, HubSpotSDK::Internal::Type::Boolean, api_name: :usesCallingWindow

#uses_remoteBoolean

Indicates if the calling extension uses a remote service.

Returns:

  • (Boolean)


71
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 71

required :uses_remote, HubSpotSDK::Internal::Type::Boolean, api_name: :usesRemote

#widthInteger

The width of the calling extension interface.

Returns:

  • (Integer)


77
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 77

required :width, Integer