Class: HubSpotSDK::Models::Crm::Extensions::TopLevelActions

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/extensions/top_level_actions.rb

Defined Under Namespace

Modules: Primary, Secondary

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel

Instance Attribute Details

#primaryHubSpotSDK::Models::Crm::Extensions::ActionHookActionBody, ...

Defines the primary action for a card, which can be either an action hook or an iframe.



21
# File 'lib/hubspot_sdk/models/crm/extensions/top_level_actions.rb', line 21

optional :primary, union: -> { HubSpotSDK::Crm::Extensions::TopLevelActions::Primary }

#secondaryArray<HubSpotSDK::Models::Crm::Extensions::ActionHookActionBody, HubSpotSDK::Models::Crm::Extensions::IFrameActionBody>

Specifies a list of secondary actions for a card, each of which can be an action hook or an iframe.



13
14
# File 'lib/hubspot_sdk/models/crm/extensions/top_level_actions.rb', line 13

required :secondary,
-> { HubSpotSDK::Internal::Type::ArrayOf[union: HubSpotSDK::Crm::Extensions::TopLevelActions::Secondary] }

#settingsHubSpotSDK::Models::Crm::Extensions::IFrameActionBody?



26
# File 'lib/hubspot_sdk/models/crm/extensions/top_level_actions.rb', line 26

optional :settings, -> { HubSpotSDK::Crm::Extensions::IFrameActionBody }