Class: HubSpotSDK::Models::Crm::Filter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/filter.rb

Defined Under Namespace

Modules: Operator

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(operator:, property_name:, high_value: nil, value: nil, values: nil) ⇒ Object

Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against.

Parameters:

  • operator (Symbol, HubSpotSDK::Models::Crm::Filter::Operator)

    The comparison operator used in the filter, such as “EQ” or “GT”.

  • property_name (String)

    The name of the property to apply the filter to.

  • high_value (String) (defaults to: nil)

    The upper boundary value when using ranged-based filters.

  • value (String) (defaults to: nil)

    The value to match against the property.

  • values (Array<String>) (defaults to: nil)

    The values to match against the property.



# File 'lib/hubspot_sdk/models/crm/filter.rb', line 37

Instance Attribute Details

#high_valueString?

The upper boundary value when using ranged-based filters.

Returns:

  • (String, nil)


23
# File 'lib/hubspot_sdk/models/crm/filter.rb', line 23

optional :high_value, String, api_name: :highValue

#operatorSymbol, HubSpotSDK::Models::Crm::Filter::Operator

The comparison operator used in the filter, such as “EQ” or “GT”.



11
# File 'lib/hubspot_sdk/models/crm/filter.rb', line 11

required :operator, enum: -> { HubSpotSDK::Crm::Filter::Operator }

#property_nameString

The name of the property to apply the filter to.

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/crm/filter.rb', line 17

required :property_name, String, api_name: :propertyName

#valueString?

The value to match against the property.

Returns:

  • (String, nil)


29
# File 'lib/hubspot_sdk/models/crm/filter.rb', line 29

optional :value, String

#valuesArray<String>?

The values to match against the property.

Returns:

  • (Array<String>, nil)


35
# File 'lib/hubspot_sdk/models/crm/filter.rb', line 35

optional :values, HubSpotSDK::Internal::Type::ArrayOf[String]