Class: HubSpotSDK::Models::Crm::JoinTimeAndRecordID

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/join_time_and_record_id.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(membership_timestamp:, record_id:) ⇒ Object

Parameters:

  • membership_timestamp (Time)

    The date and time when the record was added to the list.

  • record_id (String)

    The unique identifier of the record.



# File 'lib/hubspot_sdk/models/crm/join_time_and_record_id.rb', line 20

Instance Attribute Details

#membership_timestampTime

The date and time when the record was added to the list.

Returns:

  • (Time)


12
# File 'lib/hubspot_sdk/models/crm/join_time_and_record_id.rb', line 12

required :membership_timestamp, Time, api_name: :membershipTimestamp

#record_idString

The unique identifier of the record.

Returns:

  • (String)


18
# File 'lib/hubspot_sdk/models/crm/join_time_and_record_id.rb', line 18

required :record_id, String, api_name: :recordId