Class: HubSpotSDK::Models::Crm::ListFolderCreateRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/list_folder_create_request.rb

Direct Known Subclasses

ListCreateFolderParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, parent_folder_id: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::ListFolderCreateRequest for more details.

Parameters:

  • name (String)

    The name of the folder to be created.

  • parent_folder_id (String) (defaults to: nil)

    The folder this should be created in, if not specified will be created in the ro



# File 'lib/hubspot_sdk/models/crm/list_folder_create_request.rb', line 20

Instance Attribute Details

#nameString

The name of the folder to be created.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/crm/list_folder_create_request.rb', line 11

required :name, String

#parent_folder_idString?

The folder this should be created in, if not specified will be created in the root folder 0.

Returns:

  • (String, nil)


18
# File 'lib/hubspot_sdk/models/crm/list_folder_create_request.rb', line 18

optional :parent_folder_id, String, api_name: :parentFolderId