Class: HubSpotSDK::Models::Crm::ListSearchRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/list_search_request.rb

Direct Known Subclasses

ListListBySearchParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(list_ids:, offset:, processing_types:, additional_filter_properties: nil, count: nil, object_type_id: nil, query: nil, sort: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::ListSearchRequest for more details.

Parameters:

  • list_ids (Array<String>)

    ILS list ids to be included in search results. If not specified, all lists match

  • offset (Integer)

    Value used to paginate through lists. The ‘offset` provided in the response can

  • processing_types (Array<String>)

    List processing types to be included in search results. If not specified, all li

  • additional_filter_properties (Array<String>) (defaults to: nil)

    The property names of any additional list properties to include in the response.

  • count (Integer) (defaults to: nil)

    The number of lists to include in the response. Defaults to ‘20` if no value is

  • object_type_id (String) (defaults to: nil)
  • query (String) (defaults to: nil)

    The ‘query` that will be used to search for lists by list name. If no `query` is

  • sort (String) (defaults to: nil)

    Sort field and order



# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 66

Instance Attribute Details

#additional_filter_propertiesArray<String>?

The property names of any additional list properties to include in the response. Properties that do not exist or that are empty for a particular list are not included in the response.

By default, all requests will fetch the following properties for each list: ‘hs_list_size`, `hs_last_record_added_at`, `hs_last_record_removed_at`, `hs_folder_name`, and `hs_list_reference_count`.

Returns:

  • (Array<String>, nil)


39
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 39

optional :additional_filter_properties, HubSpotSDK::Internal::Type::ArrayOf[String]

#countInteger?

The number of lists to include in the response. Defaults to ‘20` if no value is provided. The max `count` is `500`.

Returns:

  • (Integer, nil)


46
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 46

optional :count, Integer

#list_idsArray<String>

ILS list ids to be included in search results. If not specified, all lists matching other criteria will be included

Returns:

  • (Array<String>)


12
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 12

required :list_ids, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :listIds

#object_type_idString?

Returns:

  • (String, nil)


51
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 51

optional :object_type_id, String, api_name: :objectTypeId

#offsetInteger

Value used to paginate through lists. The ‘offset` provided in the response can be used in the next request to fetch the next page of results. Defaults to `0` if no offset is provided.

Returns:

  • (Integer)


20
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 20

required :offset, Integer

#processing_typesArray<String>

List processing types to be included in search results. If not specified, all lists with all processing types will be included.

Returns:

  • (Array<String>)


27
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 27

required :processing_types, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :processingTypes

#queryString?

The ‘query` that will be used to search for lists by list name. If no `query` is provided, then the results will include all lists.

Returns:

  • (String, nil)


58
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 58

optional :query, String

#sortString?

Sort field and order

Returns:

  • (String, nil)


64
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 64

optional :sort, String