Class: HubSpotSDK::Models::Crm::ListSearchResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/list_search_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(has_more:, lists:, offset:, total:) ⇒ Object

Parameters:

  • has_more (Boolean)

    Whether or not there are more results to page through.

  • lists (Array<HubSpotSDK::Models::Crm::PublicObjectListSearchResult>)

    The lists that matched the search criteria.

  • offset (Integer)

    Value to be passed in a future request to paginate through list search results.

  • total (Integer)

    The total number of lists that match the search criteria.



# File 'lib/hubspot_sdk/models/crm/list_search_response.rb', line 32

Instance Attribute Details

#has_moreBoolean

Whether or not there are more results to page through.

Returns:

  • (Boolean)


12
# File 'lib/hubspot_sdk/models/crm/list_search_response.rb', line 12

required :has_more, HubSpotSDK::Internal::Type::Boolean, api_name: :hasMore

#listsArray<HubSpotSDK::Models::Crm::PublicObjectListSearchResult>

The lists that matched the search criteria.



18
# File 'lib/hubspot_sdk/models/crm/list_search_response.rb', line 18

required :lists, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::PublicObjectListSearchResult] }

#offsetInteger

Value to be passed in a future request to paginate through list search results.

Returns:

  • (Integer)


24
# File 'lib/hubspot_sdk/models/crm/list_search_response.rb', line 24

required :offset, Integer

#totalInteger

The total number of lists that match the search criteria.

Returns:

  • (Integer)


30
# File 'lib/hubspot_sdk/models/crm/list_search_response.rb', line 30

required :total, Integer