Class: HubSpotSDK::Models::Crm::MultiAssociatedObjectWithLabel

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/multi_associated_object_with_label.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(association_types:, to_object_id:) ⇒ Object

Represents an object that is associated with multiple other objects, with optional context.

Parameters:



# File 'lib/hubspot_sdk/models/crm/multi_associated_object_with_label.rb', line 20

Instance Attribute Details

#association_typesArray<HubSpotSDK::Models::Crm::AssociationSpecWithLabel>



10
11
12
# File 'lib/hubspot_sdk/models/crm/multi_associated_object_with_label.rb', line 10

required :association_types,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::AssociationSpecWithLabel] },
api_name: :associationTypes

#to_object_idString

The unique identifier for the target object in the association.

Returns:

  • (String)


18
# File 'lib/hubspot_sdk/models/crm/multi_associated_object_with_label.rb', line 18

required :to_object_id, String, api_name: :toObjectId