Class: HubSpotSDK::Models::Crm::NearLimitRecordSample
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::NearLimitRecordSample
- Defined in:
- lib/hubspot_sdk/models/crm/near_limit_record_sample.rb
Instance Attribute Summary collapse
-
#label ⇒ String
The primary identifier of the record.
-
#object_id_ ⇒ Integer
The unique identifier for the object.
-
#percentage ⇒ Float
The percentage of the limit that has been used.
-
#usage ⇒ Integer
The number of records currently in use.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(label:, object_id_:, percentage:, usage:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/near_limit_record_sample.rb', line 31
|
Instance Attribute Details
#label ⇒ String
The primary identifier of the record.
11 |
# File 'lib/hubspot_sdk/models/crm/near_limit_record_sample.rb', line 11 required :label, String |
#object_id_ ⇒ Integer
The unique identifier for the object.
17 |
# File 'lib/hubspot_sdk/models/crm/near_limit_record_sample.rb', line 17 required :object_id_, Integer, api_name: :objectId |
#percentage ⇒ Float
The percentage of the limit that has been used.
23 |
# File 'lib/hubspot_sdk/models/crm/near_limit_record_sample.rb', line 23 required :percentage, Float |
#usage ⇒ Integer
The number of records currently in use.
29 |
# File 'lib/hubspot_sdk/models/crm/near_limit_record_sample.rb', line 29 required :usage, Integer |