Class: HubSpotSDK::Models::Crm::ObjectSchemaEgg

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/object_schema_egg.rb

Direct Known Subclasses

ObjectSchemaCreateParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allows_sensitive_properties:, associated_objects:, labels:, name:, properties:, required_properties:, searchable_properties:, secondary_display_properties:, description: nil, primary_display_property: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::ObjectSchemaEgg for more details.

Parameters:

  • allows_sensitive_properties (Boolean)

    Determines if the object type can include properties that are marked as sensitiv

  • associated_objects (Array<String>)

    Associations defined for this object type.

  • labels (HubSpotSDK::Models::ObjectTypeDefinitionLabels)
  • name (String)

    A unique name for this object. For internal use only.

  • properties (Array<HubSpotSDK::Models::Crm::ObjectTypePropertyCreate>)

    Properties defined for this object type.

  • required_properties (Array<String>)

    The names of properties that should be required when creating an object of t

  • searchable_properties (Array<String>)

    Names of properties that will be indexed for this object type in by HubSpot’s pr

  • secondary_display_properties (Array<String>)

    The names of secondary properties for this object. These will be displayed as se

  • description (String) (defaults to: nil)

    A brief explanation of the object type.

  • primary_display_property (String) (defaults to: nil)

    The name of the primary property for this object. This will be displayed as prim



# File 'lib/hubspot_sdk/models/crm/object_schema_egg.rb', line 82

Instance Attribute Details

#allows_sensitive_propertiesBoolean

Determines if the object type can include properties that are marked as sensitive.

Returns:

  • (Boolean)


12
13
14
# File 'lib/hubspot_sdk/models/crm/object_schema_egg.rb', line 12

required :allows_sensitive_properties,
HubSpotSDK::Internal::Type::Boolean,
api_name: :allowsSensitiveProperties

#associated_objectsArray<String>

Associations defined for this object type.

Returns:

  • (Array<String>)


20
21
22
# File 'lib/hubspot_sdk/models/crm/object_schema_egg.rb', line 20

required :associated_objects,
HubSpotSDK::Internal::Type::ArrayOf[String],
api_name: :associatedObjects

#descriptionString?

A brief explanation of the object type.

Returns:

  • (String, nil)


73
# File 'lib/hubspot_sdk/models/crm/object_schema_egg.rb', line 73

optional :description, String

#labelsHubSpotSDK::Models::ObjectTypeDefinitionLabels



27
# File 'lib/hubspot_sdk/models/crm/object_schema_egg.rb', line 27

required :labels, -> { HubSpotSDK::ObjectTypeDefinitionLabels }

#nameString

A unique name for this object. For internal use only.

Returns:

  • (String)


33
# File 'lib/hubspot_sdk/models/crm/object_schema_egg.rb', line 33

required :name, String

#primary_display_propertyString?

The name of the primary property for this object. This will be displayed as primary on the HubSpot record page for this object type.

Returns:

  • (String, nil)


80
# File 'lib/hubspot_sdk/models/crm/object_schema_egg.rb', line 80

optional :primary_display_property, String, api_name: :primaryDisplayProperty

#propertiesArray<HubSpotSDK::Models::Crm::ObjectTypePropertyCreate>

Properties defined for this object type.



39
40
# File 'lib/hubspot_sdk/models/crm/object_schema_egg.rb', line 39

required :properties,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::ObjectTypePropertyCreate] }

#required_propertiesArray<String>

The names of properties that should be required when creating an object of this type.

Returns:

  • (Array<String>)


47
48
49
# File 'lib/hubspot_sdk/models/crm/object_schema_egg.rb', line 47

required :required_properties,
HubSpotSDK::Internal::Type::ArrayOf[String],
api_name: :requiredProperties

#searchable_propertiesArray<String>

Names of properties that will be indexed for this object type in by HubSpot’s product search.

Returns:

  • (Array<String>)


56
57
58
# File 'lib/hubspot_sdk/models/crm/object_schema_egg.rb', line 56

required :searchable_properties,
HubSpotSDK::Internal::Type::ArrayOf[String],
api_name: :searchableProperties

#secondary_display_propertiesArray<String>

The names of secondary properties for this object. These will be displayed as secondary on the HubSpot record page for this object type.

Returns:

  • (Array<String>)


65
66
67
# File 'lib/hubspot_sdk/models/crm/object_schema_egg.rb', line 65

required :secondary_display_properties,
HubSpotSDK::Internal::Type::ArrayOf[String],
api_name: :secondaryDisplayProperties