Class: HubSpotSDK::Models::Crm::ObjectTypeNearOrAtAssociationLimit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/object_type_near_or_at_association_limit.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(has_records_at_limit:, has_records_near_limit:, object_type_id:, plural_label:, singular_label:) ⇒ Object

Parameters:

  • has_records_at_limit (Boolean)

    Indicates whether there are records that have reached the association limit.

  • has_records_near_limit (Boolean)

    Indicates whether there are records that are approaching the association limit.

  • object_type_id (String)

    The unique identifier for the object type.

  • plural_label (String)

    The plural form of the label for the object type.

  • singular_label (String)

    The singular form of the label for the object type.



# File 'lib/hubspot_sdk/models/crm/object_type_near_or_at_association_limit.rb', line 37

Instance Attribute Details

#has_records_at_limitBoolean

Indicates whether there are records that have reached the association limit.

Returns:

  • (Boolean)


11
# File 'lib/hubspot_sdk/models/crm/object_type_near_or_at_association_limit.rb', line 11

required :has_records_at_limit, HubSpotSDK::Internal::Type::Boolean, api_name: :hasRecordsAtLimit

#has_records_near_limitBoolean

Indicates whether there are records that are approaching the association limit.

Returns:

  • (Boolean)


17
# File 'lib/hubspot_sdk/models/crm/object_type_near_or_at_association_limit.rb', line 17

required :has_records_near_limit, HubSpotSDK::Internal::Type::Boolean, api_name: :hasRecordsNearLimit

#object_type_idString

The unique identifier for the object type.

Returns:

  • (String)


23
# File 'lib/hubspot_sdk/models/crm/object_type_near_or_at_association_limit.rb', line 23

required :object_type_id, String, api_name: :objectTypeId

#plural_labelString

The plural form of the label for the object type.

Returns:

  • (String)


29
# File 'lib/hubspot_sdk/models/crm/object_type_near_or_at_association_limit.rb', line 29

required :plural_label, String, api_name: :pluralLabel

#singular_labelString

The singular form of the label for the object type.

Returns:

  • (String)


35
# File 'lib/hubspot_sdk/models/crm/object_type_near_or_at_association_limit.rb', line 35

required :singular_label, String, api_name: :singularLabel