Class: HubSpotSDK::Models::Crm::ObjectTypePropertyCreate

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/object_type_property_create.rb

Defined Under Namespace

Modules: NumberDisplayHint, OptionSortStrategy, TextDisplayHint, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(field_type:, label:, name:, type:, description: nil, display_order: nil, external_options_reference_type: nil, form_field: nil, group_name: nil, has_unique_value: nil, hidden: nil, number_display_hint: nil, options: nil, option_sort_strategy: nil, referenced_object_type: nil, searchable_in_global_search: nil, show_currency_symbol: nil, text_display_hint: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::ObjectTypePropertyCreate for more details.

Parameters:

  • field_type (String)

    Controls how the property appears in HubSpot.

  • label (String)

    A human-readable property label that will be shown in HubSpot.

  • name (String)

    The internal property name, which must be used when referencing the property fro

  • type (Symbol, HubSpotSDK::Models::Crm::ObjectTypePropertyCreate::Type)

    The data type of the property.

  • description (String) (defaults to: nil)

    A description of the property that will be shown as help text in HubSpot.

  • display_order (Integer) (defaults to: nil)

    The order that this property should be displayed in the HubSpot UI relative to o

  • external_options_reference_type (String) (defaults to: nil)

    Specifies the reference type for external options associated with the property.

  • form_field (Boolean) (defaults to: nil)

    Whether the property can be used in a HubSpot form.

  • group_name (String) (defaults to: nil)

    The name of the group this property belongs to.

  • has_unique_value (Boolean) (defaults to: nil)

    Whether or not the property’s value must be unique. Once set, this can’t be chan

  • hidden (Boolean) (defaults to: nil)

    Hidden options won’t be shown in HubSpot.

  • number_display_hint (Symbol, HubSpotSDK::Models::Crm::ObjectTypePropertyCreate::NumberDisplayHint) (defaults to: nil)

    Controls how numeric properties are formatted in the HubSpot UI

  • options (Array<HubSpotSDK::Models::OptionInput>) (defaults to: nil)

    A list of available options for the property. This field is only required for en

  • option_sort_strategy (Symbol, HubSpotSDK::Models::Crm::ObjectTypePropertyCreate::OptionSortStrategy) (defaults to: nil)

    Controls how the property options will be sorted in the HubSpot UI.

  • referenced_object_type (String) (defaults to: nil)

    Defines the options this property will return, e.g. OWNER would return name of u

  • searchable_in_global_search (Boolean) (defaults to: nil)

    Allow users to search for information entered to this field (limited to 3 proper

  • show_currency_symbol (Boolean) (defaults to: nil)

    Whether the property will display the currency symbol in the HubSpot UI.

  • text_display_hint (Symbol, HubSpotSDK::Models::Crm::ObjectTypePropertyCreate::TextDisplayHint) (defaults to: nil)

    Controls how text properties are formatted in the HubSpot UI



# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 131

Instance Attribute Details

#descriptionString?

A description of the property that will be shown as help text in HubSpot.

Returns:

  • (String, nil)


36
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 36

optional :description, String

#display_orderInteger?

The order that this property should be displayed in the HubSpot UI relative to other properties for this object type. Properties are displayed in order starting with the lowest positive integer value. A value of -1 will cause the property to be displayed after any positive values.

Returns:

  • (Integer, nil)


45
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 45

optional :display_order, Integer, api_name: :displayOrder

#external_options_reference_typeString?

Specifies the reference type for external options associated with the property.

Returns:

  • (String, nil)


51
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 51

optional :external_options_reference_type, String, api_name: :externalOptionsReferenceType

#field_typeString

Controls how the property appears in HubSpot.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 11

required :field_type, String, api_name: :fieldType

#form_fieldBoolean?

Whether the property can be used in a HubSpot form.

Returns:

  • (Boolean, nil)


57
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 57

optional :form_field, HubSpotSDK::Internal::Type::Boolean, api_name: :formField

#group_nameString?

The name of the group this property belongs to.

Returns:

  • (String, nil)


63
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 63

optional :group_name, String, api_name: :groupName

#has_unique_valueBoolean?

Whether or not the property’s value must be unique. Once set, this can’t be changed.

Returns:

  • (Boolean, nil)


70
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 70

optional :has_unique_value, HubSpotSDK::Internal::Type::Boolean, api_name: :hasUniqueValue

#hiddenBoolean?

Hidden options won’t be shown in HubSpot.

Returns:

  • (Boolean, nil)


76
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 76

optional :hidden, HubSpotSDK::Internal::Type::Boolean

#labelString

A human-readable property label that will be shown in HubSpot.

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 17

required :label, String

#nameString

The internal property name, which must be used when referencing the property from the API.

Returns:

  • (String)


24
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 24

required :name, String

#number_display_hintSymbol, ...

Controls how numeric properties are formatted in the HubSpot UI



82
83
84
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 82

optional :number_display_hint,
enum: -> { HubSpotSDK::Crm::ObjectTypePropertyCreate::NumberDisplayHint },
api_name: :numberDisplayHint

#option_sort_strategySymbol, ...

Controls how the property options will be sorted in the HubSpot UI.



97
98
99
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 97

optional :option_sort_strategy,
enum: -> { HubSpotSDK::Crm::ObjectTypePropertyCreate::OptionSortStrategy },
api_name: :optionSortStrategy

#optionsArray<HubSpotSDK::Models::OptionInput>?

A list of available options for the property. This field is only required for enumerated properties.

Returns:



91
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 91

optional :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::OptionInput] }

#referenced_object_typeString?

Defines the options this property will return, e.g. OWNER would return name of users on the portal.

Returns:

  • (String, nil)


106
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 106

optional :referenced_object_type, String, api_name: :referencedObjectType

#searchable_in_global_searchBoolean?

Allow users to search for information entered to this field (limited to 3 properties)

Returns:

  • (Boolean, nil)


113
114
115
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 113

optional :searchable_in_global_search,
HubSpotSDK::Internal::Type::Boolean,
api_name: :searchableInGlobalSearch

#show_currency_symbolBoolean?

Whether the property will display the currency symbol in the HubSpot UI.

Returns:

  • (Boolean, nil)


121
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 121

optional :show_currency_symbol, HubSpotSDK::Internal::Type::Boolean, api_name: :showCurrencySymbol

#text_display_hintSymbol, ...

Controls how text properties are formatted in the HubSpot UI



127
128
129
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 127

optional :text_display_hint,
enum: -> { HubSpotSDK::Crm::ObjectTypePropertyCreate::TextDisplayHint },
api_name: :textDisplayHint

#typeSymbol, HubSpotSDK::Models::Crm::ObjectTypePropertyCreate::Type

The data type of the property.



30
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 30

required :type, enum: -> { HubSpotSDK::Crm::ObjectTypePropertyCreate::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 185