Class: HubSpotSDK::Models::Crm::Objects::CustomGetParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Objects::CustomGetParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/crm/objects/custom_get_params.rb
Overview
Instance Attribute Summary collapse
-
#archived ⇒ Boolean?
Whether to return only results that have been archived.
-
#associations ⇒ Array<String>?
A comma separated list of object types to retrieve associated IDs for.
-
#id_property ⇒ String?
The name of a property whose values are unique for this object type.
- #object_id_ ⇒ String
- #object_type ⇒ String
-
#properties ⇒ Array<String>?
A comma separated list of the properties to be returned in the response.
-
#properties_with_history ⇒ Array<String>?
A comma separated list of the properties to be returned along with their history of previous values.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(object_type:, object_id_:, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CustomGetParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(object_type:, object_id_:, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Objects::CustomGetParams for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/objects/custom_get_params.rb', line 57
|
Instance Attribute Details
#archived ⇒ Boolean?
Whether to return only results that have been archived.
26 |
# File 'lib/hubspot_sdk/models/crm/objects/custom_get_params.rb', line 26 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#associations ⇒ Array<String>?
A comma separated list of object types to retrieve associated IDs for. If any of the specified associations do not exist, they will be ignored.
33 |
# File 'lib/hubspot_sdk/models/crm/objects/custom_get_params.rb', line 33 optional :associations, HubSpotSDK::Internal::Type::ArrayOf[String] |
#id_property ⇒ String?
The name of a property whose values are unique for this object type
39 |
# File 'lib/hubspot_sdk/models/crm/objects/custom_get_params.rb', line 39 optional :id_property, String |
#object_id_ ⇒ String
20 |
# File 'lib/hubspot_sdk/models/crm/objects/custom_get_params.rb', line 20 required :object_id_, String |
#object_type ⇒ String
15 |
# File 'lib/hubspot_sdk/models/crm/objects/custom_get_params.rb', line 15 required :object_type, String |
#properties ⇒ Array<String>?
A comma separated list of the properties to be returned in the response. If any of the specified properties are not present on the requested object(s), they will be ignored.
47 |
# File 'lib/hubspot_sdk/models/crm/objects/custom_get_params.rb', line 47 optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String] |
#properties_with_history ⇒ Array<String>?
A comma separated list of the properties to be returned along with their history of previous values. If any of the specified properties are not present on the requested object(s), they will be ignored.
55 |
# File 'lib/hubspot_sdk/models/crm/objects/custom_get_params.rb', line 55 optional :properties_with_history, HubSpotSDK::Internal::Type::ArrayOf[String] |