Class: HubSpotSDK::Models::Crm::Objects::FeedbackSubmissionGetParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/crm/objects/feedback_submission_get_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(feedback_submission_id:, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Objects::FeedbackSubmissionGetParams for more details.

Parameters:

  • feedback_submission_id (String)
  • archived (Boolean) (defaults to: nil)

    Whether to return only results that have been archived.

  • associations (Array<String>) (defaults to: nil)

    A comma separated list of object types to retrieve associated IDs for. If any of

  • id_property (String) (defaults to: nil)

    The name of a property whose values are unique for this object type

  • properties (Array<String>) (defaults to: nil)

    A comma separated list of the properties to be returned in the response. If any

  • properties_with_history (Array<String>) (defaults to: nil)

    A comma separated list of the properties to be returned along with their history

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/crm/objects/feedback_submission_get_params.rb', line 52

Instance Attribute Details

#archivedBoolean?

Whether to return only results that have been archived.

Returns:

  • (Boolean, nil)


21
# File 'lib/hubspot_sdk/models/crm/objects/feedback_submission_get_params.rb', line 21

optional :archived, HubSpotSDK::Internal::Type::Boolean

#associationsArray<String>?

A comma separated list of object types to retrieve associated IDs for. If any of the specified associations do not exist, they will be ignored.

Returns:

  • (Array<String>, nil)


28
# File 'lib/hubspot_sdk/models/crm/objects/feedback_submission_get_params.rb', line 28

optional :associations, HubSpotSDK::Internal::Type::ArrayOf[String]

#feedback_submission_idString

Returns:

  • (String)


15
# File 'lib/hubspot_sdk/models/crm/objects/feedback_submission_get_params.rb', line 15

required :feedback_submission_id, String

#id_propertyString?

The name of a property whose values are unique for this object type

Returns:

  • (String, nil)


34
# File 'lib/hubspot_sdk/models/crm/objects/feedback_submission_get_params.rb', line 34

optional :id_property, String

#propertiesArray<String>?

A comma separated list of the properties to be returned in the response. If any of the specified properties are not present on the requested object(s), they will be ignored.

Returns:

  • (Array<String>, nil)


42
# File 'lib/hubspot_sdk/models/crm/objects/feedback_submission_get_params.rb', line 42

optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String]

#properties_with_historyArray<String>?

A comma separated list of the properties to be returned along with their history of previous values. If any of the specified properties are not present on the requested object(s), they will be ignored.

Returns:

  • (Array<String>, nil)


50
# File 'lib/hubspot_sdk/models/crm/objects/feedback_submission_get_params.rb', line 50

optional :properties_with_history, HubSpotSDK::Internal::Type::ArrayOf[String]