Class: HubSpotSDK::Models::Crm::Objects::PartnerServices::BatchGetParams
- Inherits:
-
BatchReadInputSimplePublicObjectID
- Object
- Internal::Type::BaseModel
- BatchReadInputSimplePublicObjectID
- HubSpotSDK::Models::Crm::Objects::PartnerServices::BatchGetParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/crm/objects/partner_services/batch_get_params.rb
Overview
Instance Attribute Summary collapse
-
#archived ⇒ Boolean?
Whether to return only results that have been archived.
Attributes included from Internal::Type::RequestParameters
Attributes inherited from BatchReadInputSimplePublicObjectID
#id_property, #inputs, #properties, #properties_with_history
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(archived: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/objects/partner_services/batch_get_params.rb', line 19
|
Instance Attribute Details
#archived ⇒ Boolean?
Whether to return only results that have been archived.
17 |
# File 'lib/hubspot_sdk/models/crm/objects/partner_services/batch_get_params.rb', line 17 optional :archived, HubSpotSDK::Internal::Type::Boolean |