Class: HubSpotSDK::Models::Crm::Objects::PublicGdprDeleteInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/objects/public_gdpr_delete_input.rb

Direct Known Subclasses

ContactGdprDeleteParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(object_id_:, id_property: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Objects::PublicGdprDeleteInput for more details.

An input that contains the information required to process a public GDPR data deletion request.

Parameters:

  • object_id_ (String)

    The ID of the contact to permanently delete.

  • id_property (String) (defaults to: nil)

    The name of a property whose values are unique for this object. An alternative t



# File 'lib/hubspot_sdk/models/crm/objects/public_gdpr_delete_input.rb', line 21

Instance Attribute Details

#id_propertyString?

The name of a property whose values are unique for this object. An alternative to identifying a contact by ID.

Returns:

  • (String, nil)


19
# File 'lib/hubspot_sdk/models/crm/objects/public_gdpr_delete_input.rb', line 19

optional :id_property, String, api_name: :idProperty

#object_id_String

The ID of the contact to permanently delete.

Returns:

  • (String)


12
# File 'lib/hubspot_sdk/models/crm/objects/public_gdpr_delete_input.rb', line 12

required :object_id_, String, api_name: :objectId