Class: HubSpotSDK::Models::Crm::Objects::TaskListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Objects::TaskListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/crm/objects/task_list_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
-
#archived ⇒ Boolean?
Whether to return only results that have been archived.
-
#associations ⇒ Array<String>?
A comma separated list of object types to retrieve associated IDs for.
-
#limit ⇒ Integer?
The maximum number of results to display per page.
-
#properties ⇒ Array<String>?
A comma separated list of the properties to be returned in the response.
-
#properties_with_history ⇒ Array<String>?
A comma separated list of the properties to be returned along with their history of previous values.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(after: nil, archived: nil, associations: nil, limit: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TaskListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, archived: nil, associations: nil, limit: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Objects::TaskListParams for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/objects/task_list_params.rb', line 56
|
Instance Attribute Details
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
18 |
# File 'lib/hubspot_sdk/models/crm/objects/task_list_params.rb', line 18 optional :after, String |
#archived ⇒ Boolean?
Whether to return only results that have been archived.
24 |
# File 'lib/hubspot_sdk/models/crm/objects/task_list_params.rb', line 24 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#associations ⇒ Array<String>?
A comma separated list of object types to retrieve associated IDs for. If any of the specified associations do not exist, they will be ignored.
31 |
# File 'lib/hubspot_sdk/models/crm/objects/task_list_params.rb', line 31 optional :associations, HubSpotSDK::Internal::Type::ArrayOf[String] |
#limit ⇒ Integer?
The maximum number of results to display per page.
37 |
# File 'lib/hubspot_sdk/models/crm/objects/task_list_params.rb', line 37 optional :limit, Integer |
#properties ⇒ Array<String>?
A comma separated list of the properties to be returned in the response. If any of the specified properties are not present on the requested object(s), they will be ignored.
45 |
# File 'lib/hubspot_sdk/models/crm/objects/task_list_params.rb', line 45 optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String] |
#properties_with_history ⇒ Array<String>?
A comma separated list of the properties to be returned along with their history of previous values. If any of the specified properties are not present on the requested object(s), they will be ignored. Usage of this parameter will reduce the maximum number of objects that can be read by a single request.
54 |
# File 'lib/hubspot_sdk/models/crm/objects/task_list_params.rb', line 54 optional :properties_with_history, HubSpotSDK::Internal::Type::ArrayOf[String] |