Class: HubSpotSDK::Models::Crm::Objects::UserGetParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Objects::UserGetParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/crm/objects/user_get_params.rb
Overview
Instance Attribute Summary collapse
-
#archived ⇒ Boolean?
Whether to return only results that have been archived.
-
#associations ⇒ Array<String>?
A comma separated list of object types to retrieve associated IDs for.
-
#id_property ⇒ String?
The name of a property whose values are unique for this object type.
-
#properties ⇒ Array<String>?
A comma separated list of the properties to be returned in the response.
-
#properties_with_history ⇒ Array<String>?
A comma separated list of the properties to be returned along with their history of previous values.
- #user_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(user_id:, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see UserGetParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(user_id:, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Objects::UserGetParams for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/objects/user_get_params.rb', line 52
|
Instance Attribute Details
#archived ⇒ Boolean?
Whether to return only results that have been archived.
21 |
# File 'lib/hubspot_sdk/models/crm/objects/user_get_params.rb', line 21 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#associations ⇒ Array<String>?
A comma separated list of object types to retrieve associated IDs for. If any of the specified associations do not exist, they will be ignored.
28 |
# File 'lib/hubspot_sdk/models/crm/objects/user_get_params.rb', line 28 optional :associations, HubSpotSDK::Internal::Type::ArrayOf[String] |
#id_property ⇒ String?
The name of a property whose values are unique for this object type
34 |
# File 'lib/hubspot_sdk/models/crm/objects/user_get_params.rb', line 34 optional :id_property, String |
#properties ⇒ Array<String>?
A comma separated list of the properties to be returned in the response. If any of the specified properties are not present on the requested object(s), they will be ignored.
42 |
# File 'lib/hubspot_sdk/models/crm/objects/user_get_params.rb', line 42 optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String] |
#properties_with_history ⇒ Array<String>?
A comma separated list of the properties to be returned along with their history of previous values. If any of the specified properties are not present on the requested object(s), they will be ignored.
50 |
# File 'lib/hubspot_sdk/models/crm/objects/user_get_params.rb', line 50 optional :properties_with_history, HubSpotSDK::Internal::Type::ArrayOf[String] |
#user_id ⇒ String
15 |
# File 'lib/hubspot_sdk/models/crm/objects/user_get_params.rb', line 15 required :user_id, String |