Class: HubSpotSDK::Models::Crm::OwnerGetParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::OwnerGetParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/crm/owner_get_params.rb
Overview
Defined Under Namespace
Modules: IDProperty
Instance Attribute Summary collapse
-
#archived ⇒ Boolean?
Whether to return only results that have been archived.
- #id_property ⇒ Symbol, ...
- #owner_id ⇒ Integer
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#archived ⇒ Boolean?
Whether to return only results that have been archived.
20 |
# File 'lib/hubspot_sdk/models/crm/owner_get_params.rb', line 20 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#id_property ⇒ Symbol, ...
25 |
# File 'lib/hubspot_sdk/models/crm/owner_get_params.rb', line 25 optional :id_property, enum: -> { HubSpotSDK::Crm::OwnerGetParams::IDProperty } |
#owner_id ⇒ Integer
14 |
# File 'lib/hubspot_sdk/models/crm/owner_get_params.rb', line 14 required :owner_id, Integer |