Class: HubSpotSDK::Models::Crm::PipelinePatchInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/pipeline_patch_input.rb

Direct Known Subclasses

PipelineUpdateParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(archived: nil, display_order: nil, label: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PipelinePatchInput for more details.

Parameters:

  • archived (Boolean) (defaults to: nil)

    Whether the pipeline is archived. This property should only be provided when res

  • display_order (Integer) (defaults to: nil)

    The order for displaying this pipeline. If two pipelines have a matching ‘displa

  • label (String) (defaults to: nil)

    A unique label used to organize pipelines in HubSpot’s UI



# File 'lib/hubspot_sdk/models/crm/pipeline_patch_input.rb', line 28

Instance Attribute Details

#archivedBoolean?

Whether the pipeline is archived. This property should only be provided when restoring an archived pipeline. If it’s provided in any other call, the request will fail and a ‘400 Bad Request` will be returned.

Returns:

  • (Boolean, nil)


13
# File 'lib/hubspot_sdk/models/crm/pipeline_patch_input.rb', line 13

optional :archived, HubSpotSDK::Internal::Type::Boolean

#display_orderInteger?

The order for displaying this pipeline. If two pipelines have a matching ‘displayOrder`, they will be sorted alphabetically by label.

Returns:

  • (Integer, nil)


20
# File 'lib/hubspot_sdk/models/crm/pipeline_patch_input.rb', line 20

optional :display_order, Integer, api_name: :displayOrder

#labelString?

A unique label used to organize pipelines in HubSpot’s UI

Returns:

  • (String, nil)


26
# File 'lib/hubspot_sdk/models/crm/pipeline_patch_input.rb', line 26

optional :label, String