Class: HubSpotSDK::Models::Crm::PipelineStage

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/pipeline_stage.rb

Overview

Defined Under Namespace

Modules: WritePermissions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, archived:, created_at:, display_order:, label:, metadata:, updated_at:, write_permissions:, archived_at: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PipelineStage for more details.

Parameters:

  • id (String)

    A unique identifier generated by HubSpot that can be used to retrieve and update

  • archived (Boolean)

    Whether the pipeline is archived.

  • created_at (Time)

    The date the pipeline stage was created. The stages on default pipelines will ha

  • display_order (Integer)

    The order for displaying this pipeline stage. If two pipeline stages have a matc

  • label (String)

    A label used to organize pipeline stages in HubSpot’s UI. Each pipeline stage’s

  • metadata (Hash{Symbol=>String})

    A JSON object containing properties that are not present on all object pipelines

  • updated_at (Time)

    The date the pipeline stage was last updated.

  • write_permissions (Symbol, HubSpotSDK::Models::Crm::PipelineStage::WritePermissions)

    Defines the level of write access for the pipeline stage, with possible values b

  • archived_at (Time) (defaults to: nil)

    The date the pipeline was archived. ‘archivedAt` will only be present if the pip



# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 80

Instance Attribute Details

#archivedBoolean

Whether the pipeline is archived.

Returns:

  • (Boolean)


19
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 19

required :archived, HubSpotSDK::Internal::Type::Boolean

#archived_atTime?

The date the pipeline was archived. ‘archivedAt` will only be present if the pipeline is archived.

Returns:

  • (Time, nil)


78
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 78

optional :archived_at, Time, api_name: :archivedAt

#created_atTime

The date the pipeline stage was created. The stages on default pipelines will have createdAt = 0.

Returns:

  • (Time)


26
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 26

required :created_at, Time, api_name: :createdAt

#display_orderInteger

The order for displaying this pipeline stage. If two pipeline stages have a matching ‘displayOrder`, they will be sorted alphabetically by label.

Returns:

  • (Integer)


33
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 33

required :display_order, Integer, api_name: :displayOrder

#idString

A unique identifier generated by HubSpot that can be used to retrieve and update the pipeline stage.

Returns:

  • (String)


13
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 13

required :id, String

#labelString

A label used to organize pipeline stages in HubSpot’s UI. Each pipeline stage’s label must be unique within that pipeline.

Returns:

  • (String)


40
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 40

required :label, String

#metadataHash{Symbol=>String}

A JSON object containing properties that are not present on all object pipelines.

For ‘deals` pipelines, the `probability` field is required (`{ “probability”: 0.5 }`), and represents the likelihood a deal will close. Possible values are between 0.0 and 1.0 in increments of 0.1.

For ‘tickets` pipelines, the `ticketState` field is optional (`{ “ticketState”: “OPEN” }`), and represents whether the ticket remains open or has been closed by a member of your Support team. Possible values are `OPEN` or `CLOSED`.

Returns:

  • (Hash{Symbol=>String})


56
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 56

required :metadata, HubSpotSDK::Internal::Type::HashOf[String]

#updated_atTime

The date the pipeline stage was last updated.

Returns:

  • (Time)


62
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 62

required :updated_at, Time, api_name: :updatedAt

#write_permissionsSymbol, HubSpotSDK::Models::Crm::PipelineStage::WritePermissions

Defines the level of write access for the pipeline stage, with possible values being CRM_PERMISSIONS_ENFORCEMENT, READ_ONLY, or INTERNAL_ONLY.



69
70
71
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 69

required :write_permissions,
enum: -> { HubSpotSDK::Crm::PipelineStage::WritePermissions },
api_name: :writePermissions