Class: HubSpotSDK::Models::Crm::PipelineStagePatchInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/pipeline_stage_patch_input.rb

Direct Known Subclasses

PipelineUpdateStageParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(metadata:, archived: nil, display_order: nil, label: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PipelineStagePatchInput for more details.

Parameters:

  • metadata (Hash{Symbol=>String})

    A JSON object containing properties that are not present on all object pipelines

  • archived (Boolean) (defaults to: nil)

    Whether the pipeline is archived.

  • display_order (Integer) (defaults to: nil)

    The order for displaying this pipeline stage. If two pipeline stages have a matc

  • label (String) (defaults to: nil)

    A label used to organize pipeline stages in HubSpot’s UI. Each pipeline stage’s



# File 'lib/hubspot_sdk/models/crm/pipeline_stage_patch_input.rb', line 43

Instance Attribute Details

#archivedBoolean?

Whether the pipeline is archived.

Returns:

  • (Boolean, nil)


27
# File 'lib/hubspot_sdk/models/crm/pipeline_stage_patch_input.rb', line 27

optional :archived, HubSpotSDK::Internal::Type::Boolean

#display_orderInteger?

The order for displaying this pipeline stage. If two pipeline stages have a matching ‘displayOrder`, they will be sorted alphabetically by label.

Returns:

  • (Integer, nil)


34
# File 'lib/hubspot_sdk/models/crm/pipeline_stage_patch_input.rb', line 34

optional :display_order, Integer, api_name: :displayOrder

#labelString?

A label used to organize pipeline stages in HubSpot’s UI. Each pipeline stage’s label must be unique within that pipeline.

Returns:

  • (String, nil)


41
# File 'lib/hubspot_sdk/models/crm/pipeline_stage_patch_input.rb', line 41

optional :label, String

#metadataHash{Symbol=>String}

A JSON object containing properties that are not present on all object pipelines.

For ‘deals` pipelines, the `probability` field is required (`{ “probability”: 0.5 }`), and represents the likelihood a deal will close. Possible values are between 0.0 and 1.0 in increments of 0.1.

For ‘tickets` pipelines, the `ticketState` field is optional (`{ “ticketState”: “OPEN” }`), and represents whether the ticket remains open or has been closed by a member of your Support team. Possible values are `OPEN` or `CLOSED`.

Returns:

  • (Hash{Symbol=>String})


21
# File 'lib/hubspot_sdk/models/crm/pipeline_stage_patch_input.rb', line 21

required :metadata, HubSpotSDK::Internal::Type::HashOf[String]