Class: HubSpotSDK::Models::Crm::Property

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/property.rb

Defined Under Namespace

Modules: DataSensitivity, DateDisplayHint

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(description:, field_type:, group_name:, label:, name:, options:, type:, archived: nil, archived_at: nil, calculated: nil, calculation_formula: nil, created_at: nil, created_user_id: nil, currency_property_name: nil, data_sensitivity: nil, date_display_hint: nil, display_order: nil, external_options: nil, form_field: nil, has_unique_value: nil, hidden: nil, hubspot_defined: nil, modification_metadata: nil, referenced_object_type: nil, sensitive_data_categories: nil, show_currency_symbol: nil, updated_at: nil, updated_user_id: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Property for more details.

A HubSpot property

Parameters:

  • description (String)

    A description of the property that will be shown as help text in HubSpot.

  • field_type (String)

    Controls how the property appears in HubSpot.

  • group_name (String)

    The name of the property group the property belongs to.

  • label (String)

    A human-readable property label that will be shown in HubSpot.

  • name (String)

    The internal property name, which must be used when referencing the property via

  • options (Array<HubSpotSDK::Models::Option>)

    A list of valid options for the property. This field is required for enumerated

  • type (String)

    The property data type.

  • archived (Boolean) (defaults to: nil)

    Whether or not the property is archived.

  • archived_at (Time) (defaults to: nil)

    When the property was archived.

  • calculated (Boolean) (defaults to: nil)

    For default properties, true indicates that the property is calculated by a HubS

  • calculation_formula (String) (defaults to: nil)

    The formula used for calculated properties.

  • created_at (Time) (defaults to: nil)

    When the property was created

  • created_user_id (String) (defaults to: nil)

    The internal ID of the user who created the property in HubSpot. This field may

  • currency_property_name (String) (defaults to: nil)

    The name of the related currency property.

  • data_sensitivity (Symbol, HubSpotSDK::Models::Crm::Property::DataSensitivity) (defaults to: nil)

    Indicates the sensitivity level of the property, such as “non_sensitive”, “sensi

  • date_display_hint (Symbol, HubSpotSDK::Models::Crm::Property::DateDisplayHint) (defaults to: nil)

    Controls how date properties are displayed in the HubSpot UI, with options such

  • display_order (Integer) (defaults to: nil)

    The order that this property should be displayed in the HubSpot UI relative to o

  • external_options (Boolean) (defaults to: nil)

    For default properties, true indicates that the options are stored externally to

  • form_field (Boolean) (defaults to: nil)

    Whether or not the property can be used in a HubSpot form.

  • has_unique_value (Boolean) (defaults to: nil)

    Whether or not the property’s value must be unique. Once set, this can’t be chan

  • hidden (Boolean) (defaults to: nil)

    Hidden options won’t be shown in HubSpot.

  • hubspot_defined (Boolean) (defaults to: nil)

    This will be true for default object properties built into HubSpot.

  • modification_metadata (HubSpotSDK::Models::PropertyModificationMetadata) (defaults to: nil)
  • referenced_object_type (String) (defaults to: nil)

    If this property is related to other object(s), they’ll be listed here.

  • sensitive_data_categories (Array<String>) (defaults to: nil)

    When sensitiveData is true, lists the type of sensitive data contained in the pr

  • show_currency_symbol (Boolean) (defaults to: nil)

    Whether the property will display the currency symbol set in the account setting

  • updated_at (Time) (defaults to: nil)

    When the object type was last updated.

  • updated_user_id (String) (defaults to: nil)

    The internal user ID of the user who updated the property in HubSpot. This field



# File 'lib/hubspot_sdk/models/crm/property.rb', line 196

Instance Attribute Details

#archivedBoolean?

Whether or not the property is archived.

Returns:

  • (Boolean, nil)


55
# File 'lib/hubspot_sdk/models/crm/property.rb', line 55

optional :archived, HubSpotSDK::Internal::Type::Boolean

#archived_atTime?

When the property was archived.

Returns:

  • (Time, nil)


61
# File 'lib/hubspot_sdk/models/crm/property.rb', line 61

optional :archived_at, Time, api_name: :archivedAt

#calculatedBoolean?

For default properties, true indicates that the property is calculated by a HubSpot process. It has no effect for custom properties.

Returns:

  • (Boolean, nil)


68
# File 'lib/hubspot_sdk/models/crm/property.rb', line 68

optional :calculated, HubSpotSDK::Internal::Type::Boolean

#calculation_formulaString?

The formula used for calculated properties.

Returns:

  • (String, nil)


74
# File 'lib/hubspot_sdk/models/crm/property.rb', line 74

optional :calculation_formula, String, api_name: :calculationFormula

#created_atTime?

When the property was created

Returns:

  • (Time, nil)


80
# File 'lib/hubspot_sdk/models/crm/property.rb', line 80

optional :created_at, Time, api_name: :createdAt

#created_user_idString?

The internal ID of the user who created the property in HubSpot. This field may not exist if the property was created outside of HubSpot.

Returns:

  • (String, nil)


87
# File 'lib/hubspot_sdk/models/crm/property.rb', line 87

optional :created_user_id, String, api_name: :createdUserId

#currency_property_nameString?

The name of the related currency property.

Returns:

  • (String, nil)


93
# File 'lib/hubspot_sdk/models/crm/property.rb', line 93

optional :currency_property_name, String, api_name: :currencyPropertyName

#data_sensitivitySymbol, ...

Indicates the sensitivity level of the property, such as “non_sensitive”, “sensitive”, or “highly_sensitive”.



100
101
102
# File 'lib/hubspot_sdk/models/crm/property.rb', line 100

optional :data_sensitivity,
enum: -> { HubSpotSDK::Crm::Property::DataSensitivity },
api_name: :dataSensitivity

#date_display_hintSymbol, ...

Controls how date properties are displayed in the HubSpot UI, with options such as ‘absolute’, ‘absolute_with_relative’, ‘time_since’, and ‘time_until’.



109
110
111
# File 'lib/hubspot_sdk/models/crm/property.rb', line 109

optional :date_display_hint,
enum: -> { HubSpotSDK::Crm::Property::DateDisplayHint },
api_name: :dateDisplayHint

#descriptionString

A description of the property that will be shown as help text in HubSpot.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/crm/property.rb', line 11

required :description, String

#display_orderInteger?

The order that this property should be displayed in the HubSpot UI relative to other properties for this object type. Properties are displayed in order starting with the lowest positive integer value. A value of -1 will cause the property to be displayed after any positive values.

Returns:

  • (Integer, nil)


120
# File 'lib/hubspot_sdk/models/crm/property.rb', line 120

optional :display_order, Integer, api_name: :displayOrder

#external_optionsBoolean?

For default properties, true indicates that the options are stored externally to the property settings.

Returns:

  • (Boolean, nil)


127
# File 'lib/hubspot_sdk/models/crm/property.rb', line 127

optional :external_options, HubSpotSDK::Internal::Type::Boolean, api_name: :externalOptions

#field_typeString

Controls how the property appears in HubSpot.

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/crm/property.rb', line 17

required :field_type, String, api_name: :fieldType

#form_fieldBoolean?

Whether or not the property can be used in a HubSpot form.

Returns:

  • (Boolean, nil)


133
# File 'lib/hubspot_sdk/models/crm/property.rb', line 133

optional :form_field, HubSpotSDK::Internal::Type::Boolean, api_name: :formField

#group_nameString

The name of the property group the property belongs to.

Returns:

  • (String)


23
# File 'lib/hubspot_sdk/models/crm/property.rb', line 23

required :group_name, String, api_name: :groupName

#has_unique_valueBoolean?

Whether or not the property’s value must be unique. Once set, this can’t be changed.

Returns:

  • (Boolean, nil)


140
# File 'lib/hubspot_sdk/models/crm/property.rb', line 140

optional :has_unique_value, HubSpotSDK::Internal::Type::Boolean, api_name: :hasUniqueValue

#hiddenBoolean?

Hidden options won’t be shown in HubSpot.

Returns:

  • (Boolean, nil)


146
# File 'lib/hubspot_sdk/models/crm/property.rb', line 146

optional :hidden, HubSpotSDK::Internal::Type::Boolean

#hubspot_definedBoolean?

This will be true for default object properties built into HubSpot.

Returns:

  • (Boolean, nil)


152
# File 'lib/hubspot_sdk/models/crm/property.rb', line 152

optional :hubspot_defined, HubSpotSDK::Internal::Type::Boolean, api_name: :hubspotDefined

#labelString

A human-readable property label that will be shown in HubSpot.

Returns:

  • (String)


29
# File 'lib/hubspot_sdk/models/crm/property.rb', line 29

required :label, String

#modification_metadataHubSpotSDK::Models::PropertyModificationMetadata?



157
158
159
# File 'lib/hubspot_sdk/models/crm/property.rb', line 157

optional :modification_metadata,
-> { HubSpotSDK::PropertyModificationMetadata },
api_name: :modificationMetadata

#nameString

The internal property name, which must be used when referencing the property via the API.

Returns:

  • (String)


36
# File 'lib/hubspot_sdk/models/crm/property.rb', line 36

required :name, String

#optionsArray<HubSpotSDK::Models::Option>

A list of valid options for the property. This field is required for enumerated properties, but will be empty for other property types.

Returns:



43
# File 'lib/hubspot_sdk/models/crm/property.rb', line 43

required :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Option] }

#referenced_object_typeString?

If this property is related to other object(s), they’ll be listed here.

Returns:

  • (String, nil)


165
# File 'lib/hubspot_sdk/models/crm/property.rb', line 165

optional :referenced_object_type, String, api_name: :referencedObjectType

#sensitive_data_categoriesArray<String>?

When sensitiveData is true, lists the type of sensitive data contained in the property (e.g., “HIPAA”).

Returns:

  • (Array<String>, nil)


172
173
174
# File 'lib/hubspot_sdk/models/crm/property.rb', line 172

optional :sensitive_data_categories,
HubSpotSDK::Internal::Type::ArrayOf[String],
api_name: :sensitiveDataCategories

#show_currency_symbolBoolean?

Whether the property will display the currency symbol set in the account settings.

Returns:

  • (Boolean, nil)


181
# File 'lib/hubspot_sdk/models/crm/property.rb', line 181

optional :show_currency_symbol, HubSpotSDK::Internal::Type::Boolean, api_name: :showCurrencySymbol

#typeString

The property data type.

Returns:

  • (String)


49
# File 'lib/hubspot_sdk/models/crm/property.rb', line 49

required :type, String

#updated_atTime?

When the object type was last updated.

Returns:

  • (Time, nil)


187
# File 'lib/hubspot_sdk/models/crm/property.rb', line 187

optional :updated_at, Time, api_name: :updatedAt

#updated_user_idString?

The internal user ID of the user who updated the property in HubSpot. This field may not exist if the property was updated outside of HubSpot.

Returns:

  • (String, nil)


194
# File 'lib/hubspot_sdk/models/crm/property.rb', line 194

optional :updated_user_id, String, api_name: :updatedUserId

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/crm/property.rb', line 269