Class: HubSpotSDK::Models::Crm::PropertyCreate

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/property_create.rb

Direct Known Subclasses

PropertyCreateParams

Defined Under Namespace

Modules: DataSensitivity, FieldType, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(field_type:, group_name:, label:, name:, type:, calculation_formula: nil, currency_property_name: nil, data_sensitivity: nil, description: nil, display_order: nil, external_options: nil, form_field: nil, has_unique_value: nil, hidden: nil, options: nil, referenced_object_type: nil, show_currency_symbol: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PropertyCreate for more details.

Parameters:

  • field_type (Symbol, HubSpotSDK::Models::Crm::PropertyCreate::FieldType)

    Controls how the property appears in HubSpot.

  • group_name (String)

    The name of the property group the property belongs to.

  • label (String)

    A human-readable property label that will be shown in HubSpot.

  • name (String)

    The internal property name, which must be used when referencing the property via

  • type (Symbol, HubSpotSDK::Models::Crm::PropertyCreate::Type)

    The data type of the property.

  • calculation_formula (String) (defaults to: nil)

    Represents a formula that is used to compute a calculated property.

  • currency_property_name (String) (defaults to: nil)
  • data_sensitivity (Symbol, HubSpotSDK::Models::Crm::PropertyCreate::DataSensitivity) (defaults to: nil)

    Indicates the sensitivity level of the property, with options: highly_sensitive,

  • description (String) (defaults to: nil)

    A description of the property that will be shown as help text in HubSpot.

  • display_order (Integer) (defaults to: nil)

    Properties are displayed in order starting with the lowest positive integer valu

  • external_options (Boolean) (defaults to: nil)

    Applicable only for ‘enumeration’ type properties. Should be set to true in con

  • form_field (Boolean) (defaults to: nil)

    Whether or not the property can be used in a HubSpot form.

  • has_unique_value (Boolean) (defaults to: nil)

    Whether or not the property’s value must be unique. Once set, this can’t be chan

  • hidden (Boolean) (defaults to: nil)

    If true, the property won’t be visible and can’t be used in HubSpot.

  • options (Array<HubSpotSDK::Models::OptionInput>) (defaults to: nil)

    A list of valid options for the property. This field is required for enumerated

  • referenced_object_type (String) (defaults to: nil)

    Should be set to ‘OWNER’ when ‘externalOptions’ is true, which causes the proper

  • show_currency_symbol (Boolean) (defaults to: nil)


# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 117

Instance Attribute Details

#calculation_formulaString?

Represents a formula that is used to compute a calculated property.

Returns:

  • (String, nil)


42
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 42

optional :calculation_formula, String, api_name: :calculationFormula

#currency_property_nameString?

Returns:

  • (String, nil)


47
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 47

optional :currency_property_name, String, api_name: :currencyPropertyName

#data_sensitivitySymbol, ...

Indicates the sensitivity level of the property, with options: highly_sensitive, non_sensitive, or sensitive.



54
55
56
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 54

optional :data_sensitivity,
enum: -> { HubSpotSDK::Crm::PropertyCreate::DataSensitivity },
api_name: :dataSensitivity

#descriptionString?

A description of the property that will be shown as help text in HubSpot.

Returns:

  • (String, nil)


62
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 62

optional :description, String

#display_orderInteger?

Properties are displayed in order starting with the lowest positive integer value. Values of -1 will cause the property to be displayed after any positive values.

Returns:

  • (Integer, nil)


70
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 70

optional :display_order, Integer, api_name: :displayOrder

#external_optionsBoolean?

Applicable only for ‘enumeration’ type properties. Should be set to true in conjunction with a ‘referencedObjectType’ of ‘OWNER’. Otherwise false.

Returns:

  • (Boolean, nil)


77
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 77

optional :external_options, HubSpotSDK::Internal::Type::Boolean, api_name: :externalOptions

#field_typeSymbol, HubSpotSDK::Models::Crm::PropertyCreate::FieldType

Controls how the property appears in HubSpot.



11
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 11

required :field_type, enum: -> { HubSpotSDK::Crm::PropertyCreate::FieldType }, api_name: :fieldType

#form_fieldBoolean?

Whether or not the property can be used in a HubSpot form.

Returns:

  • (Boolean, nil)


83
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 83

optional :form_field, HubSpotSDK::Internal::Type::Boolean, api_name: :formField

#group_nameString

The name of the property group the property belongs to.

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 17

required :group_name, String, api_name: :groupName

#has_unique_valueBoolean?

Whether or not the property’s value must be unique. Once set, this can’t be changed.

Returns:

  • (Boolean, nil)


90
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 90

optional :has_unique_value, HubSpotSDK::Internal::Type::Boolean, api_name: :hasUniqueValue

#hiddenBoolean?

If true, the property won’t be visible and can’t be used in HubSpot.

Returns:

  • (Boolean, nil)


96
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 96

optional :hidden, HubSpotSDK::Internal::Type::Boolean

#labelString

A human-readable property label that will be shown in HubSpot.

Returns:

  • (String)


23
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 23

required :label, String

#nameString

The internal property name, which must be used when referencing the property via the API.

Returns:

  • (String)


30
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 30

required :name, String

#optionsArray<HubSpotSDK::Models::OptionInput>?

A list of valid options for the property. This field is required for enumerated properties.

Returns:



103
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 103

optional :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::OptionInput] }

#referenced_object_typeString?

Should be set to ‘OWNER’ when ‘externalOptions’ is true, which causes the property to dynamically pull option values from the current HubSpot users.

Returns:

  • (String, nil)


110
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 110

optional :referenced_object_type, String, api_name: :referencedObjectType

#show_currency_symbolBoolean?

Returns:

  • (Boolean, nil)


115
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 115

optional :show_currency_symbol, HubSpotSDK::Internal::Type::Boolean, api_name: :showCurrencySymbol

#typeSymbol, HubSpotSDK::Models::Crm::PropertyCreate::Type

The data type of the property.



36
# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 36

required :type, enum: -> { HubSpotSDK::Crm::PropertyCreate::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/crm/property_create.rb', line 174