Class: HubSpotSDK::Models::Crm::PropertyGetParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PropertyGetParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/crm/property_get_params.rb
Overview
Defined Under Namespace
Modules: DataSensitivity
Instance Attribute Summary collapse
-
#archived ⇒ Boolean?
Whether to return only results that have been archived.
- #data_sensitivity ⇒ Symbol, ...
- #locale ⇒ String?
- #object_type ⇒ String
- #properties ⇒ String?
- #property_name ⇒ String
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#archived ⇒ Boolean?
Whether to return only results that have been archived.
25 |
# File 'lib/hubspot_sdk/models/crm/property_get_params.rb', line 25 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#data_sensitivity ⇒ Symbol, ...
30 |
# File 'lib/hubspot_sdk/models/crm/property_get_params.rb', line 30 optional :data_sensitivity, enum: -> { HubSpotSDK::Crm::PropertyGetParams::DataSensitivity } |
#locale ⇒ String?
35 |
# File 'lib/hubspot_sdk/models/crm/property_get_params.rb', line 35 optional :locale, String |
#object_type ⇒ String
14 |
# File 'lib/hubspot_sdk/models/crm/property_get_params.rb', line 14 required :object_type, String |
#properties ⇒ String?
40 |
# File 'lib/hubspot_sdk/models/crm/property_get_params.rb', line 40 optional :properties, String |
#property_name ⇒ String
19 |
# File 'lib/hubspot_sdk/models/crm/property_get_params.rb', line 19 required :property_name, String |