Class: HubSpotSDK::Models::Crm::PublicAssociationDefinitionConfigurationUpdateResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicAssociationDefinitionConfigurationUpdateResult
- Defined in:
- lib/hubspot_sdk/models/crm/public_association_definition_configuration_update_result.rb
Defined Under Namespace
Modules: Category
Instance Attribute Summary collapse
-
#category ⇒ Symbol, HubSpotSDK::Models::Crm::PublicAssociationDefinitionConfigurationUpdateResult::Category
The category of the association, which can be HUBSPOT_DEFINED, INTEGRATOR_DEFINED, or USER_DEFINED.
-
#type_id ⇒ Integer
An integer value used to uniquely identify a specific association type within its Association Category.
-
#user_enforced_max_to_object_ids ⇒ Integer?
The maximum number of object IDs that a user can enforce for associations.
Instance Method Summary collapse
-
#initialize(category:, type_id:, user_enforced_max_to_object_ids: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicAssociationDefinitionConfigurationUpdateResult for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(category:, type_id:, user_enforced_max_to_object_ids: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicAssociationDefinitionConfigurationUpdateResult for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_association_definition_configuration_update_result.rb', line 28
|
Instance Attribute Details
#category ⇒ Symbol, HubSpotSDK::Models::Crm::PublicAssociationDefinitionConfigurationUpdateResult::Category
The category of the association, which can be HUBSPOT_DEFINED, INTEGRATOR_DEFINED, or USER_DEFINED.
12 13 |
# File 'lib/hubspot_sdk/models/crm/public_association_definition_configuration_update_result.rb', line 12 required :category, enum: -> { HubSpotSDK::Crm::PublicAssociationDefinitionConfigurationUpdateResult::Category } |
#type_id ⇒ Integer
An integer value used to uniquely identify a specific association type within its Association Category.
20 |
# File 'lib/hubspot_sdk/models/crm/public_association_definition_configuration_update_result.rb', line 20 required :type_id, Integer, api_name: :typeId |
#user_enforced_max_to_object_ids ⇒ Integer?
The maximum number of object IDs that a user can enforce for associations.
26 |
# File 'lib/hubspot_sdk/models/crm/public_association_definition_configuration_update_result.rb', line 26 optional :user_enforced_max_to_object_ids, Integer, api_name: :userEnforcedMaxToObjectIds |