Class: HubSpotSDK::Models::Crm::PublicAssociationDefinitionCreateRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_association_definition_create_request.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(label:, name:, inverse_label: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicAssociationDefinitionCreateRequest for more details.

Parameters:

  • label (String)

    A descriptor that provides context about the relationship between two associated

  • name (String)

    The unique identifier for the association definition.

  • inverse_label (String) (defaults to: nil)

    An optional descriptor that clarifies the reverse relationship in the associatio



# File 'lib/hubspot_sdk/models/crm/public_association_definition_create_request.rb', line 27

Instance Attribute Details

#inverse_labelString?

An optional descriptor that clarifies the reverse relationship in the association.

Returns:

  • (String, nil)


25
# File 'lib/hubspot_sdk/models/crm/public_association_definition_create_request.rb', line 25

optional :inverse_label, String, api_name: :inverseLabel

#labelString

A descriptor that provides context about the relationship between two associated CRM objects.

Returns:

  • (String)


12
# File 'lib/hubspot_sdk/models/crm/public_association_definition_create_request.rb', line 12

required :label, String

#nameString

The unique identifier for the association definition.

Returns:

  • (String)


18
# File 'lib/hubspot_sdk/models/crm/public_association_definition_create_request.rb', line 18

required :name, String