Class: HubSpotSDK::Models::Crm::PublicAssociationDefinitionUpdateRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_association_definition_update_request.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(association_type_id:, label:, inverse_label: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicAssociationDefinitionUpdateRequest for more details.

Parameters:

  • association_type_id (Integer)

    The unique identifier for the association type.

  • label (String)

    A descriptor that provides context about the relationship between associated rec

  • inverse_label (String) (defaults to: nil)

    An optional descriptor for the inverse relationship between associated records.



# File 'lib/hubspot_sdk/models/crm/public_association_definition_update_request.rb', line 26

Instance Attribute Details

#association_type_idInteger

The unique identifier for the association type.

Returns:

  • (Integer)


11
# File 'lib/hubspot_sdk/models/crm/public_association_definition_update_request.rb', line 11

required :association_type_id, Integer, api_name: :associationTypeId

#inverse_labelString?

An optional descriptor for the inverse relationship between associated records.

Returns:

  • (String, nil)


24
# File 'lib/hubspot_sdk/models/crm/public_association_definition_update_request.rb', line 24

optional :inverse_label, String, api_name: :inverseLabel

#labelString

A descriptor that provides context about the relationship between associated records.

Returns:

  • (String)


18
# File 'lib/hubspot_sdk/models/crm/public_association_definition_update_request.rb', line 18

required :label, String