Class: HubSpotSDK::Models::Crm::PublicAssociationDefinitionUserConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicAssociationDefinitionUserConfiguration
- Defined in:
- lib/hubspot_sdk/models/crm/public_association_definition_user_configuration.rb
Defined Under Namespace
Modules: Category
Instance Attribute Summary collapse
-
#category ⇒ Symbol, HubSpotSDK::Models::Crm::PublicAssociationDefinitionUserConfiguration::Category
The category of the association, which can be HUBSPOT_DEFINED, INTEGRATOR_DEFINED, or USER_DEFINED.
-
#label ⇒ String?
A descriptor providing context about the relationship between associated records.
-
#type_id ⇒ Integer
A unique integer identifier for the association type within its category.
-
#user_enforced_max_to_object_ids ⇒ Integer?
The maximum number of target object IDs that a user can enforce in an association.
Instance Method Summary collapse
-
#initialize(category:, type_id:, label: nil, user_enforced_max_to_object_ids: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicAssociationDefinitionUserConfiguration for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(category:, type_id:, label: nil, user_enforced_max_to_object_ids: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicAssociationDefinitionUserConfiguration for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_association_definition_user_configuration.rb', line 34
|
Instance Attribute Details
#category ⇒ Symbol, HubSpotSDK::Models::Crm::PublicAssociationDefinitionUserConfiguration::Category
The category of the association, which can be HUBSPOT_DEFINED, INTEGRATOR_DEFINED, or USER_DEFINED.
12 |
# File 'lib/hubspot_sdk/models/crm/public_association_definition_user_configuration.rb', line 12 required :category, enum: -> { HubSpotSDK::Crm::PublicAssociationDefinitionUserConfiguration::Category } |
#label ⇒ String?
A descriptor providing context about the relationship between associated records.
25 |
# File 'lib/hubspot_sdk/models/crm/public_association_definition_user_configuration.rb', line 25 optional :label, String |
#type_id ⇒ Integer
A unique integer identifier for the association type within its category.
18 |
# File 'lib/hubspot_sdk/models/crm/public_association_definition_user_configuration.rb', line 18 required :type_id, Integer, api_name: :typeId |
#user_enforced_max_to_object_ids ⇒ Integer?
The maximum number of target object IDs that a user can enforce in an association.
32 |
# File 'lib/hubspot_sdk/models/crm/public_association_definition_user_configuration.rb', line 32 optional :user_enforced_max_to_object_ids, Integer, api_name: :userEnforcedMaxToObjectIds |