Class: HubSpotSDK::Models::Crm::PublicAssociationSpec

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_association_spec.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(category:, type_id:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicAssociationSpec for more details.

Parameters:

  • category (String)

    Specifies the category of the association, which can be HUBSPOT_DEFINED, INTEGRA

  • type_id (Integer)

    A unique integer identifier for the specific association type within its categor



# File 'lib/hubspot_sdk/models/crm/public_association_spec.rb', line 21

Instance Attribute Details

#categoryString

Specifies the category of the association, which can be HUBSPOT_DEFINED, INTEGRATOR_DEFINED, or USER_DEFINED.

Returns:

  • (String)


12
# File 'lib/hubspot_sdk/models/crm/public_association_spec.rb', line 12

required :category, String

#type_idInteger

A unique integer identifier for the specific association type within its category.

Returns:

  • (Integer)


19
# File 'lib/hubspot_sdk/models/crm/public_association_spec.rb', line 19

required :type_id, Integer, api_name: :typeId