Class: HubSpotSDK::Models::Crm::PublicBatchMigrationMapping
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicBatchMigrationMapping
- Defined in:
- lib/hubspot_sdk/models/crm/public_batch_migration_mapping.rb
Overview
Instance Attribute Summary collapse
- #legacy_list_ids_to_ids_mapping ⇒ Array<HubSpotSDK::Models::Crm::PublicMigrationMapping>
-
#missing_legacy_list_ids ⇒ Array<String>
A list of legacy list ids that were passed in but not found.
Instance Method Summary collapse
-
#initialize(legacy_list_ids_to_ids_mapping:, missing_legacy_list_ids:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicBatchMigrationMapping for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(legacy_list_ids_to_ids_mapping:, missing_legacy_list_ids:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicBatchMigrationMapping for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_batch_migration_mapping.rb', line 24
|
Instance Attribute Details
#legacy_list_ids_to_ids_mapping ⇒ Array<HubSpotSDK::Models::Crm::PublicMigrationMapping>
11 12 13 |
# File 'lib/hubspot_sdk/models/crm/public_batch_migration_mapping.rb', line 11 required :legacy_list_ids_to_ids_mapping, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::PublicMigrationMapping] }, api_name: :legacyListIdsToIdsMapping |
#missing_legacy_list_ids ⇒ Array<String>
A list of legacy list ids that were passed in but not found. It will be empty if no id’s are missing
20 21 22 |
# File 'lib/hubspot_sdk/models/crm/public_batch_migration_mapping.rb', line 20 required :missing_legacy_list_ids, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :missingLegacyListIds |