Class: HubSpotSDK::Models::Crm::PublicComparativeDatePropertyOperation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_comparative_date_property_operation.rb

Defined Under Namespace

Modules: OperationType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(comparison_property_name:, include_objects_with_no_value_set:, operation_type:, operator:, default_comparison_value: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicComparativeDatePropertyOperation for more details.

Parameters:

  • comparison_property_name (String)

    The name of the property to compare against in the operation.

  • include_objects_with_no_value_set (Boolean)

    Indicates whether objects with no value set for the property should be included

  • operation_type (Symbol, HubSpotSDK::Models::Crm::PublicComparativeDatePropertyOperation::OperationType)

    The type of operation (COMPARATIVE_DATE).

  • operator (String)

    Defines the operation to be applied in the comparative date property operation (

  • default_comparison_value (String) (defaults to: nil)

    The default value used for comparison if the actual comparison property value is



# File 'lib/hubspot_sdk/models/crm/public_comparative_date_property_operation.rb', line 44

Instance Attribute Details

#comparison_property_nameString

The name of the property to compare against in the operation.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/crm/public_comparative_date_property_operation.rb', line 11

required :comparison_property_name, String, api_name: :comparisonPropertyName

#default_comparison_valueString?

The default value used for comparison if the actual comparison property value is not set.

Returns:

  • (String, nil)


42
# File 'lib/hubspot_sdk/models/crm/public_comparative_date_property_operation.rb', line 42

optional :default_comparison_value, String, api_name: :defaultComparisonValue

#include_objects_with_no_value_setBoolean

Indicates whether objects with no value set for the property should be included in the operation.

Returns:

  • (Boolean)


18
19
20
# File 'lib/hubspot_sdk/models/crm/public_comparative_date_property_operation.rb', line 18

required :include_objects_with_no_value_set,
HubSpotSDK::Internal::Type::Boolean,
api_name: :includeObjectsWithNoValueSet

#operation_typeSymbol, HubSpotSDK::Models::Crm::PublicComparativeDatePropertyOperation::OperationType

The type of operation (COMPARATIVE_DATE).



26
27
28
# File 'lib/hubspot_sdk/models/crm/public_comparative_date_property_operation.rb', line 26

required :operation_type,
enum: -> { HubSpotSDK::Crm::PublicComparativeDatePropertyOperation::OperationType },
api_name: :operationType

#operatorString

Defines the operation to be applied in the comparative date property operation (IS_BEFORE, IS_AFTER).

Returns:

  • (String)


35
# File 'lib/hubspot_sdk/models/crm/public_comparative_date_property_operation.rb', line 35

required :operator, String