Class: HubSpotSDK::Models::Crm::PublicCtaAnalyticsFilter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_cta_analytics_filter.rb

Defined Under Namespace

Modules: CoalescingRefineBy, FilterType, PruningRefineBy

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cta_name:, filter_type:, operator:, coalescing_refine_by: nil, pruning_refine_by: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicCtaAnalyticsFilter for more details.

Parameters:



# File 'lib/hubspot_sdk/models/crm/public_cta_analytics_filter.rb', line 46

Instance Attribute Details

#cta_nameString

The name of the Call-to-Action (CTA) to be used in the filter.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/crm/public_cta_analytics_filter.rb', line 11

required :cta_name, String, api_name: :ctaName

#filter_typeSymbol, HubSpotSDK::Models::Crm::PublicCtaAnalyticsFilter::FilterType

Indicates the type of filter being applied, which is (CTA).



17
18
19
# File 'lib/hubspot_sdk/models/crm/public_cta_analytics_filter.rb', line 17

required :filter_type,
enum: -> { HubSpotSDK::Crm::PublicCtaAnalyticsFilter::FilterType },
api_name: :filterType

#operatorString

Defines the operation to be applied within the filter (HAS_CLICKED_CTA, HAS_NOT_CLICKED_CTA, HAS_OPENED_CTA, HAS_NOT_OPENED_CTA, HAS_CLICKED_CTA_PLACEMENT, HAS_NOT_CLICKED_CTA_PLACEMENT, HAS_OPENED_CTA_PLACEMENT, HAS_NOT_OPENED_CTA_PLACEMENT).

Returns:

  • (String)


28
# File 'lib/hubspot_sdk/models/crm/public_cta_analytics_filter.rb', line 28

required :operator, String