Class: HubSpotSDK::Models::Crm::PublicDateTimePropertyOperation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_date_time_property_operation.rb

Defined Under Namespace

Modules: OperationType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(include_objects_with_no_value_set:, operation_type:, operator:, requires_time_zone_conversion:, timestamp:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicDateTimePropertyOperation for more details.

Parameters:

  • include_objects_with_no_value_set (Boolean)

    Specifies whether objects without a set value should be included in the operatio

  • operation_type (Symbol, HubSpotSDK::Models::Crm::PublicDateTimePropertyOperation::OperationType)

    The type of operation (DATETIME).

  • operator (String)

    Defines the operation to be applied, such as comparison operators (IS_BEFORE, IS

  • requires_time_zone_conversion (Boolean)

    Indicates whether the timestamp requires conversion to a different time zone.

  • timestamp (Integer)

    The specific point in time used in the operation.



# File 'lib/hubspot_sdk/models/crm/public_date_time_property_operation.rb', line 45

Instance Attribute Details

#include_objects_with_no_value_setBoolean

Specifies whether objects without a set value should be included in the operation.

Returns:

  • (Boolean)


12
13
14
# File 'lib/hubspot_sdk/models/crm/public_date_time_property_operation.rb', line 12

required :include_objects_with_no_value_set,
HubSpotSDK::Internal::Type::Boolean,
api_name: :includeObjectsWithNoValueSet

#operation_typeSymbol, HubSpotSDK::Models::Crm::PublicDateTimePropertyOperation::OperationType

The type of operation (DATETIME).



20
21
22
# File 'lib/hubspot_sdk/models/crm/public_date_time_property_operation.rb', line 20

required :operation_type,
enum: -> { HubSpotSDK::Crm::PublicDateTimePropertyOperation::OperationType },
api_name: :operationType

#operatorString

Defines the operation to be applied, such as comparison operators (IS_BEFORE, IS_AFTER).

Returns:

  • (String)


29
# File 'lib/hubspot_sdk/models/crm/public_date_time_property_operation.rb', line 29

required :operator, String

#requires_time_zone_conversionBoolean

Indicates whether the timestamp requires conversion to a different time zone.

Returns:

  • (Boolean)


35
36
37
# File 'lib/hubspot_sdk/models/crm/public_date_time_property_operation.rb', line 35

required :requires_time_zone_conversion,
HubSpotSDK::Internal::Type::Boolean,
api_name: :requiresTimeZoneConversion

#timestampInteger

The specific point in time used in the operation.

Returns:

  • (Integer)


43
# File 'lib/hubspot_sdk/models/crm/public_date_time_property_operation.rb', line 43

required :timestamp, Integer