Class: HubSpotSDK::Models::Crm::PublicDealSplitInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_deal_split_input.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(owner_id:, percentage:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicDealSplitInput for more details.

Parameters:

  • owner_id (Integer)

    The unique identifier of the owner receiving the deal split.

  • percentage (Float)

    The portion of the deal assigned to the owner, expressed as a percentage. The to



# File 'lib/hubspot_sdk/models/crm/public_deal_split_input.rb', line 21

Instance Attribute Details

#owner_idInteger

The unique identifier of the owner receiving the deal split.

Returns:

  • (Integer)


11
# File 'lib/hubspot_sdk/models/crm/public_deal_split_input.rb', line 11

required :owner_id, Integer, api_name: :ownerId

#percentageFloat

The portion of the deal assigned to the owner, expressed as a percentage. The total percentage for all splits in a deal must sum up to 1.0 (100%) and can have up to 8 decimal places.

Returns:

  • (Float)


19
# File 'lib/hubspot_sdk/models/crm/public_deal_split_input.rb', line 19

required :percentage, Float