Class: HubSpotSDK::Models::Crm::PublicEmailSubscriptionFilter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicEmailSubscriptionFilter
- Defined in:
- lib/hubspot_sdk/models/crm/public_email_subscription_filter.rb
Defined Under Namespace
Modules: FilterType
Instance Attribute Summary collapse
- #accepted_statuses ⇒ Array<String>
-
#filter_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicEmailSubscriptionFilter::FilterType
Indicates the type of filter (EMAIL_SUBSCRIPTION).
- #subscription_ids ⇒ Array<String>
-
#subscription_type ⇒ String?
The type of subscription related to the filter (PORTAL, BRAND, SUBSCRIPTION, HARDBOUNCE, SPAMREPORT).
Instance Method Summary collapse
-
#initialize(accepted_statuses:, filter_type:, subscription_ids:, subscription_type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicEmailSubscriptionFilter for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(accepted_statuses:, filter_type:, subscription_ids:, subscription_type: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicEmailSubscriptionFilter for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_email_subscription_filter.rb', line 32
|
Instance Attribute Details
#accepted_statuses ⇒ Array<String>
10 |
# File 'lib/hubspot_sdk/models/crm/public_email_subscription_filter.rb', line 10 required :accepted_statuses, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :acceptedStatuses |
#filter_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicEmailSubscriptionFilter::FilterType
Indicates the type of filter (EMAIL_SUBSCRIPTION).
16 17 18 |
# File 'lib/hubspot_sdk/models/crm/public_email_subscription_filter.rb', line 16 required :filter_type, enum: -> { HubSpotSDK::Crm::PublicEmailSubscriptionFilter::FilterType }, api_name: :filterType |
#subscription_ids ⇒ Array<String>
23 |
# File 'lib/hubspot_sdk/models/crm/public_email_subscription_filter.rb', line 23 required :subscription_ids, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :subscriptionIds |
#subscription_type ⇒ String?
The type of subscription related to the filter (PORTAL, BRAND, SUBSCRIPTION, HARDBOUNCE, SPAMREPORT).
30 |
# File 'lib/hubspot_sdk/models/crm/public_email_subscription_filter.rb', line 30 optional :subscription_type, String, api_name: :subscriptionType |