Class: HubSpotSDK::Models::Crm::PublicEventAnalyticsFilter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_event_analytics_filter.rb

Defined Under Namespace

Modules: CoalescingRefineBy, FilterType, PruningRefineBy

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_id:, filter_type:, operator:, coalescing_refine_by: nil, pruning_refine_by: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicEventAnalyticsFilter for more details.

Parameters:



# File 'lib/hubspot_sdk/models/crm/public_event_analytics_filter.rb', line 44

Instance Attribute Details

#event_idString

The ID of the event to be used in the filter.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/crm/public_event_analytics_filter.rb', line 11

required :event_id, String, api_name: :eventId

#filter_typeSymbol, HubSpotSDK::Models::Crm::PublicEventAnalyticsFilter::FilterType

Indicates the type of filter being applied (EVENT).



17
18
19
# File 'lib/hubspot_sdk/models/crm/public_event_analytics_filter.rb', line 17

required :filter_type,
enum: -> { HubSpotSDK::Crm::PublicEventAnalyticsFilter::FilterType },
api_name: :filterType

#operatorString

Defines the operation to be applied within the event filter (HAS_EVENT, NOT_HAS_EVENT).

Returns:

  • (String)


26
# File 'lib/hubspot_sdk/models/crm/public_event_analytics_filter.rb', line 26

required :operator, String