Class: HubSpotSDK::Models::Crm::PublicEventFilterMetadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicEventFilterMetadata
- Defined in:
- lib/hubspot_sdk/models/crm/public_event_filter_metadata.rb
Defined Under Namespace
Modules: Operation
Instance Attribute Summary collapse
-
#operation ⇒ HubSpotSDK::Models::Crm::PublicBoolPropertyOperation, ...
Defines the operation to be performed on the property.
-
#property ⇒ String
Specifies the property on which the operation is to be applied.
Instance Method Summary collapse
- #initialize(operation:, property:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(operation:, property:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/public_event_filter_metadata.rb', line 19
|
Instance Attribute Details
#operation ⇒ HubSpotSDK::Models::Crm::PublicBoolPropertyOperation, ...
Defines the operation to be performed on the property
11 |
# File 'lib/hubspot_sdk/models/crm/public_event_filter_metadata.rb', line 11 required :operation, union: -> { HubSpotSDK::Crm::PublicEventFilterMetadata::Operation } |
#property ⇒ String
Specifies the property on which the operation is to be applied.
17 |
# File 'lib/hubspot_sdk/models/crm/public_event_filter_metadata.rb', line 17 required :property, String |