Class: HubSpotSDK::Models::Crm::PublicFetchAssociationsBatchRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_fetch_associations_batch_request.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, after: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicFetchAssociationsBatchRequest for more details.

Parameters:

  • id (String)

    The unique identifier for the object whose associations are being fetched.

  • after (String) (defaults to: nil)

    A paging cursor token used to retrieve the next set of results in a paginated re



# File 'lib/hubspot_sdk/models/crm/public_fetch_associations_batch_request.rb', line 20

Instance Attribute Details

#afterString?

A paging cursor token used to retrieve the next set of results in a paginated response.

Returns:

  • (String, nil)


18
# File 'lib/hubspot_sdk/models/crm/public_fetch_associations_batch_request.rb', line 18

optional :after, String

#idString

The unique identifier for the object whose associations are being fetched.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/crm/public_fetch_associations_batch_request.rb', line 11

required :id, String