Class: HubSpotSDK::Models::Crm::PublicImportMetadata

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_import_metadata.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(counters:, file_ids:, object_lists:) ⇒ Object

Parameters:

  • counters (Hash{Symbol=>Integer})

    Summarized outcomes of each row a developer attempted to import into HubSpot.

  • file_ids (Array<String>)

    The IDs of files uploaded in the File Manager API.

  • object_lists (Array<HubSpotSDK::Models::Crm::PublicObjectListRecord>)

    The lists containing the imported objects.



# File 'lib/hubspot_sdk/models/crm/public_import_metadata.rb', line 27

Instance Attribute Details

#countersHash{Symbol=>Integer}

Summarized outcomes of each row a developer attempted to import into HubSpot.

Returns:

  • (Hash{Symbol=>Integer})


11
# File 'lib/hubspot_sdk/models/crm/public_import_metadata.rb', line 11

required :counters, HubSpotSDK::Internal::Type::HashOf[Integer]

#file_idsArray<String>

The IDs of files uploaded in the File Manager API.

Returns:

  • (Array<String>)


17
# File 'lib/hubspot_sdk/models/crm/public_import_metadata.rb', line 17

required :file_ids, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :fileIds

#object_listsArray<HubSpotSDK::Models::Crm::PublicObjectListRecord>

The lists containing the imported objects.



23
24
25
# File 'lib/hubspot_sdk/models/crm/public_import_metadata.rb', line 23

required :object_lists,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::PublicObjectListRecord] },
api_name: :objectLists