Class: HubSpotSDK::Models::Crm::PublicIndexedTimePoint

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_indexed_time_point.rb

Defined Under Namespace

Modules: IndexReference, TimeType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(index_reference:, time_type:, zone_id:, offset: nil, timezone_source: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicIndexedTimePoint for more details.

Parameters:



# File 'lib/hubspot_sdk/models/crm/public_indexed_time_point.rb', line 44

Instance Attribute Details

#index_referenceHubSpotSDK::Models::Crm::PublicNowReference, ...

Specifies the reference point in time for the indexed time point.



11
12
13
# File 'lib/hubspot_sdk/models/crm/public_indexed_time_point.rb', line 11

required :index_reference,
union: -> { HubSpotSDK::Crm::PublicIndexedTimePoint::IndexReference },
api_name: :indexReference

#offsetHubSpotSDK::Models::Crm::PublicIndexOffset?



35
# File 'lib/hubspot_sdk/models/crm/public_indexed_time_point.rb', line 35

optional :offset, -> { HubSpotSDK::Crm::PublicIndexOffset }

#time_typeSymbol, HubSpotSDK::Models::Crm::PublicIndexedTimePoint::TimeType

Defines the type of time (INDEXED).



19
20
21
22
23
# File 'lib/hubspot_sdk/models/crm/public_indexed_time_point.rb', line 19

required :time_type,
enum: -> {
  HubSpotSDK::Crm::PublicIndexedTimePoint::TimeType
},
api_name: :timeType

#timezone_sourceString?

Specifies the source of the time zone information for the indexed time point (CUSTOM, USER, PORTAL).

Returns:

  • (String, nil)


42
# File 'lib/hubspot_sdk/models/crm/public_indexed_time_point.rb', line 42

optional :timezone_source, String, api_name: :timezoneSource

#zone_idString

Indicates the identifier for the time zone associated with the indexed time point.

Returns:

  • (String)


30
# File 'lib/hubspot_sdk/models/crm/public_indexed_time_point.rb', line 30

required :zone_id, String, api_name: :zoneId