Class: HubSpotSDK::Models::Crm::PublicIntegrationEventFilter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicIntegrationEventFilter
- Defined in:
- lib/hubspot_sdk/models/crm/public_integration_event_filter.rb
Defined Under Namespace
Modules: FilterType
Instance Attribute Summary collapse
-
#event_type_id ⇒ Integer
The ID representing the type of event for the integration event filter.
- #filter_lines ⇒ Array<HubSpotSDK::Models::Crm::PublicEventFilterMetadata>
-
#filter_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicIntegrationEventFilter::FilterType
Indicates the type of filter (INTEGRATION_EVENT).
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(event_type_id:, filter_lines:, filter_type:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/public_integration_event_filter.rb', line 28
|
Instance Attribute Details
#event_type_id ⇒ Integer
The ID representing the type of event for the integration event filter.
11 |
# File 'lib/hubspot_sdk/models/crm/public_integration_event_filter.rb', line 11 required :event_type_id, Integer, api_name: :eventTypeId |
#filter_lines ⇒ Array<HubSpotSDK::Models::Crm::PublicEventFilterMetadata>
16 17 18 |
# File 'lib/hubspot_sdk/models/crm/public_integration_event_filter.rb', line 16 required :filter_lines, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::PublicEventFilterMetadata] }, api_name: :filterLines |
#filter_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicIntegrationEventFilter::FilterType
Indicates the type of filter (INTEGRATION_EVENT).
24 25 26 |
# File 'lib/hubspot_sdk/models/crm/public_integration_event_filter.rb', line 24 required :filter_type, enum: -> { HubSpotSDK::Crm::PublicIntegrationEventFilter::FilterType }, api_name: :filterType |