Class: HubSpotSDK::Models::Crm::PublicListConversionInactivity
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicListConversionInactivity
- Defined in:
- lib/hubspot_sdk/models/crm/public_list_conversion_inactivity.rb
Defined Under Namespace
Modules: ConversionType, TimeUnit
Instance Attribute Summary collapse
-
#conversion_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicListConversionInactivity::ConversionType
Specifies the type of conversion (INACTIVITY).
-
#offset ⇒ Integer
Value used to paginate through lists.
-
#time_unit ⇒ Symbol, HubSpotSDK::Models::Crm::PublicListConversionInactivity::TimeUnit
The unit of time for the inactivity period, such as (DAY, MONTH, WEEK).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(conversion_type:, offset:, time_unit:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicListConversionInactivity for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(conversion_type:, offset:, time_unit:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicListConversionInactivity for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_list_conversion_inactivity.rb', line 31
|
Instance Attribute Details
#conversion_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicListConversionInactivity::ConversionType
Specifies the type of conversion (INACTIVITY).
11 12 13 |
# File 'lib/hubspot_sdk/models/crm/public_list_conversion_inactivity.rb', line 11 required :conversion_type, enum: -> { HubSpotSDK::Crm::PublicListConversionInactivity::ConversionType }, api_name: :conversionType |
#offset ⇒ Integer
Value used to paginate through lists. The ‘offset` provided in the response can be used in the next request to fetch the next page of results. Defaults to `0` if no offset is provided.
21 |
# File 'lib/hubspot_sdk/models/crm/public_list_conversion_inactivity.rb', line 21 required :offset, Integer |
#time_unit ⇒ Symbol, HubSpotSDK::Models::Crm::PublicListConversionInactivity::TimeUnit
The unit of time for the inactivity period, such as (DAY, MONTH, WEEK).
27 28 29 |
# File 'lib/hubspot_sdk/models/crm/public_list_conversion_inactivity.rb', line 27 required :time_unit, enum: -> { HubSpotSDK::Crm::PublicListConversionInactivity::TimeUnit }, api_name: :timeUnit |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/crm/public_list_conversion_inactivity.rb', line 49
|