Class: HubSpotSDK::Models::Crm::PublicMergeInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicMergeInput
- Defined in:
- lib/hubspot_sdk/models/crm/public_merge_input.rb
Direct Known Subclasses
Objects::CompanyMergeParams, Objects::ContactMergeParams, Objects::CustomMergeParams, Objects::DealMergeParams, Objects::ProjectMergeParams, Objects::TicketMergeParams
Instance Attribute Summary collapse
-
#object_id_to_merge ⇒ String
The ID of the company to merge into the primary.
-
#primary_object_id ⇒ String
The ID of the primary company, which the other will merge into.
Instance Method Summary collapse
-
#initialize(object_id_to_merge:, primary_object_id:) ⇒ Object
constructor
Input data for merging two records.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(object_id_to_merge:, primary_object_id:) ⇒ Object
Input data for merging two records.
|
|
# File 'lib/hubspot_sdk/models/crm/public_merge_input.rb', line 19
|
Instance Attribute Details
#object_id_to_merge ⇒ String
The ID of the company to merge into the primary.
11 |
# File 'lib/hubspot_sdk/models/crm/public_merge_input.rb', line 11 required :object_id_to_merge, String, api_name: :objectIdToMerge |
#primary_object_id ⇒ String
The ID of the primary company, which the other will merge into.
17 |
# File 'lib/hubspot_sdk/models/crm/public_merge_input.rb', line 17 required :primary_object_id, String, api_name: :primaryObjectId |