Class: HubSpotSDK::Models::Crm::PublicObjectList
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicObjectList
- Defined in:
- lib/hubspot_sdk/models/crm/public_object_list.rb
Defined Under Namespace
Modules: FilterBranch
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
The time when the list was created.
-
#created_by_id ⇒ String?
The ID of the user that created the list.
-
#deleted_at ⇒ Time?
The time when the list was deleted.
-
#filter_branch ⇒ HubSpotSDK::Models::Crm::PublicOrFilterBranch, ...
Defines the filter criteria for the list, allowing for complex logical operations and nested filter branches to determine list membership.
-
#filters_updated_at ⇒ Time?
The time when the filters for this list were last updated.
-
#list_id ⇒ String
The **ILS ID** of the list.
- #list_permissions ⇒ HubSpotSDK::Models::Crm::PublicListPermissions?
-
#list_version ⇒ Integer
The version of the list.
- #membership_settings ⇒ HubSpotSDK::Models::Crm::PublicMembershipSettings?
-
#name ⇒ String
The name of the list.
-
#object_type_id ⇒ String
The object type of the list.
-
#processing_status ⇒ String
The processing status of the list.
-
#processing_type ⇒ String
The processing type of the list.
-
#size ⇒ Integer?
Size of the list.
-
#updated_at ⇒ Time?
The time the list was last updated.
-
#updated_by_id ⇒ String?
The ID of the user that last updated the list.
Instance Method Summary collapse
-
#initialize(list_id:, list_version:, name:, object_type_id:, processing_status:, processing_type:, created_at: nil, created_by_id: nil, deleted_at: nil, filter_branch: nil, filters_updated_at: nil, list_permissions: nil, membership_settings: nil, size: nil, updated_at: nil, updated_by_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicObjectList for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(list_id:, list_version:, name:, object_type_id:, processing_status:, processing_type:, created_at: nil, created_by_id: nil, deleted_at: nil, filter_branch: nil, filters_updated_at: nil, list_permissions: nil, membership_settings: nil, size: nil, updated_at: nil, updated_by_id: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicObjectList for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 106
|
Instance Attribute Details
#created_at ⇒ Time?
The time when the list was created.
47 |
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 47 optional :created_at, Time, api_name: :createdAt |
#created_by_id ⇒ String?
The ID of the user that created the list.
53 |
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 53 optional :created_by_id, String, api_name: :createdById |
#deleted_at ⇒ Time?
The time when the list was deleted.
59 |
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 59 optional :deleted_at, Time, api_name: :deletedAt |
#filter_branch ⇒ HubSpotSDK::Models::Crm::PublicOrFilterBranch, ...
Defines the filter criteria for the list, allowing for complex logical operations and nested filter branches to determine list membership.
66 67 68 |
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 66 optional :filter_branch, union: -> { HubSpotSDK::Crm::PublicObjectList::FilterBranch }, api_name: :filterBranch |
#filters_updated_at ⇒ Time?
The time when the filters for this list were last updated.
74 |
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 74 optional :filters_updated_at, Time, api_name: :filtersUpdatedAt |
#list_id ⇒ String
The **ILS ID** of the list.
11 |
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 11 required :list_id, String, api_name: :listId |
#list_permissions ⇒ HubSpotSDK::Models::Crm::PublicListPermissions?
79 |
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 79 optional :list_permissions, -> { HubSpotSDK::Crm::PublicListPermissions }, api_name: :listPermissions |
#list_version ⇒ Integer
The version of the list.
17 |
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 17 required :list_version, Integer, api_name: :listVersion |
#membership_settings ⇒ HubSpotSDK::Models::Crm::PublicMembershipSettings?
84 85 86 |
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 84 optional :membership_settings, -> { HubSpotSDK::Crm::PublicMembershipSettings }, api_name: :membershipSettings |
#name ⇒ String
The name of the list.
23 |
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 23 required :name, String |
#object_type_id ⇒ String
The object type of the list.
29 |
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 29 required :object_type_id, String, api_name: :objectTypeId |
#processing_status ⇒ String
The processing status of the list.
35 |
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 35 required :processing_status, String, api_name: :processingStatus |
#processing_type ⇒ String
The processing type of the list.
41 |
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 41 required :processing_type, String, api_name: :processingType |
#size ⇒ Integer?
Size of the list
92 |
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 92 optional :size, Integer |
#updated_at ⇒ Time?
The time the list was last updated.
98 |
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 98 optional :updated_at, Time, api_name: :updatedAt |
#updated_by_id ⇒ String?
The ID of the user that last updated the list.
104 |
# File 'lib/hubspot_sdk/models/crm/public_object_list.rb', line 104 optional :updated_by_id, String, api_name: :updatedById |