Class: HubSpotSDK::Models::Crm::PublicPrivacyAnalyticsFilter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_privacy_analytics_filter.rb

Defined Under Namespace

Modules: FilterType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(filter_type:, operator:, privacy_name:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicPrivacyAnalyticsFilter for more details.

Parameters:



# File 'lib/hubspot_sdk/models/crm/public_privacy_analytics_filter.rb', line 28

Instance Attribute Details

#filter_typeSymbol, HubSpotSDK::Models::Crm::PublicPrivacyAnalyticsFilter::FilterType

Specifies the type of filter (PRIVACY).



11
12
13
# File 'lib/hubspot_sdk/models/crm/public_privacy_analytics_filter.rb', line 11

required :filter_type,
enum: -> { HubSpotSDK::Crm::PublicPrivacyAnalyticsFilter::FilterType },
api_name: :filterType

#operatorString

Defines the operation to be applied within the filter (PRIVACY_CONSENT_GRANTED, PRIVACY_CONSENT_NOT_GRANTED).

Returns:

  • (String)


20
# File 'lib/hubspot_sdk/models/crm/public_privacy_analytics_filter.rb', line 20

required :operator, String

#privacy_nameString

The name of the privacy setting used in the filter.

Returns:

  • (String)


26
# File 'lib/hubspot_sdk/models/crm/public_privacy_analytics_filter.rb', line 26

required :privacy_name, String, api_name: :privacyName