Class: HubSpotSDK::Models::Crm::PublicPropertyFilter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicPropertyFilter
- Defined in:
- lib/hubspot_sdk/models/crm/public_property_filter.rb
Defined Under Namespace
Modules: FilterType, Operation
Instance Attribute Summary collapse
-
#filter_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicPropertyFilter::FilterType
Indicates that the filter (PROPERTY).
-
#operation ⇒ HubSpotSDK::Models::Crm::PublicBoolPropertyOperation, ...
Defines the operation to be performed on the property, such as comparison or value matching.
-
#property ⇒ String
Specifies the name of the property that the filter is applied to.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(filter_type:, operation:, property:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicPropertyFilter for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(filter_type:, operation:, property:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicPropertyFilter for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_property_filter.rb', line 28
|
Instance Attribute Details
#filter_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicPropertyFilter::FilterType
Indicates that the filter (PROPERTY).
11 12 13 |
# File 'lib/hubspot_sdk/models/crm/public_property_filter.rb', line 11 required :filter_type, enum: -> { HubSpotSDK::Crm::PublicPropertyFilter::FilterType }, api_name: :filterType |
#operation ⇒ HubSpotSDK::Models::Crm::PublicBoolPropertyOperation, ...
Defines the operation to be performed on the property, such as comparison or value matching.
20 |
# File 'lib/hubspot_sdk/models/crm/public_property_filter.rb', line 20 required :operation, union: -> { HubSpotSDK::Crm::PublicPropertyFilter::Operation } |
#property ⇒ String
Specifies the name of the property that the filter is applied to.
26 |
# File 'lib/hubspot_sdk/models/crm/public_property_filter.rb', line 26 required :property, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/crm/public_property_filter.rb', line 46
|