Class: HubSpotSDK::Models::Crm::PublicPropertyValidationRule

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_property_validation_rule.rb

Overview

Defined Under Namespace

Modules: RuleType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(rule_arguments:, rule_type:, should_apply_normalization: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicPropertyValidationRule for more details.

Parameters:

  • rule_arguments (Array<String>)

    A list of arguments that define the specific conditions or parameters for the va

  • rule_type (Symbol, HubSpotSDK::Models::Crm::PublicPropertyValidationRule::RuleType)

    The category of validation applied to the property, such as FORMAT, ALPHANUMERIC

  • should_apply_normalization (Boolean) (defaults to: nil)


# File 'lib/hubspot_sdk/models/crm/public_property_validation_rule.rb', line 31

Instance Attribute Details

#rule_argumentsArray<String>

A list of arguments that define the specific conditions or parameters for the validation rule.

Returns:

  • (Array<String>)


13
# File 'lib/hubspot_sdk/models/crm/public_property_validation_rule.rb', line 13

required :rule_arguments, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :ruleArguments

#rule_typeSymbol, HubSpotSDK::Models::Crm::PublicPropertyValidationRule::RuleType

The category of validation applied to the property, such as FORMAT, ALPHANUMERIC, or MAX_LENGTH.



20
21
22
# File 'lib/hubspot_sdk/models/crm/public_property_validation_rule.rb', line 20

required :rule_type,
enum: -> { HubSpotSDK::Crm::PublicPropertyValidationRule::RuleType },
api_name: :ruleType

#should_apply_normalizationBoolean?

Returns:

  • (Boolean, nil)


27
28
29
# File 'lib/hubspot_sdk/models/crm/public_property_validation_rule.rb', line 27

optional :should_apply_normalization,
HubSpotSDK::Internal::Type::Boolean,
api_name: :shouldApplyNormalization