Class: HubSpotSDK::Models::Crm::PublicPropertyValidationRuleUpdate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicPropertyValidationRuleUpdate
- Defined in:
- lib/hubspot_sdk/models/crm/public_property_validation_rule_update.rb
Direct Known Subclasses
PropertiesValidationUpdateByObjectTypeIDPropertyNameAndRuleTypeParams
Instance Attribute Summary collapse
-
#rule_arguments ⇒ Array<String>
A list of arguments that define the constraints for the validation rule.
- #should_apply_normalization ⇒ Boolean?
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(rule_arguments:, should_apply_normalization: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/public_property_validation_rule_update.rb', line 20
|
Instance Attribute Details
#rule_arguments ⇒ Array<String>
A list of arguments that define the constraints for the validation rule.
11 |
# File 'lib/hubspot_sdk/models/crm/public_property_validation_rule_update.rb', line 11 required :rule_arguments, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :ruleArguments |
#should_apply_normalization ⇒ Boolean?
16 17 18 |
# File 'lib/hubspot_sdk/models/crm/public_property_validation_rule_update.rb', line 16 optional :should_apply_normalization, HubSpotSDK::Internal::Type::Boolean, api_name: :shouldApplyNormalization |