Class: HubSpotSDK::Models::Crm::PublicRelativeComparativeTimestampRefineBy
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicRelativeComparativeTimestampRefineBy
- Defined in:
- lib/hubspot_sdk/models/crm/public_relative_comparative_timestamp_refine_by.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#comparison ⇒ String
Defines the comparison operation to be used in the refinement (BEFORE, AFTER).
- #time_offset ⇒ HubSpotSDK::Models::Crm::PublicTimeOffset
-
#type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicRelativeComparativeTimestampRefineBy::Type
Specifies the type of refinement, (RELATIVE_COMPARATIVE).
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(comparison:, time_offset:, type:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/public_relative_comparative_timestamp_refine_by.rb', line 24
|
Instance Attribute Details
#comparison ⇒ String
Defines the comparison operation to be used in the refinement (BEFORE, AFTER).
11 |
# File 'lib/hubspot_sdk/models/crm/public_relative_comparative_timestamp_refine_by.rb', line 11 required :comparison, String |
#time_offset ⇒ HubSpotSDK::Models::Crm::PublicTimeOffset
16 |
# File 'lib/hubspot_sdk/models/crm/public_relative_comparative_timestamp_refine_by.rb', line 16 required :time_offset, -> { HubSpotSDK::Crm::PublicTimeOffset }, api_name: :timeOffset |
#type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicRelativeComparativeTimestampRefineBy::Type
Specifies the type of refinement, (RELATIVE_COMPARATIVE).
22 |
# File 'lib/hubspot_sdk/models/crm/public_relative_comparative_timestamp_refine_by.rb', line 22 required :type, enum: -> { HubSpotSDK::Crm::PublicRelativeComparativeTimestampRefineBy::Type } |