Class: HubSpotSDK::Models::Crm::PublicRelativeRangedTimestampRefineBy
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicRelativeRangedTimestampRefineBy
- Defined in:
- lib/hubspot_sdk/models/crm/public_relative_ranged_timestamp_refine_by.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
- #lower_bound_offset ⇒ HubSpotSDK::Models::Crm::PublicTimeOffset
-
#range_type ⇒ String
Specifies the type of range for the refinement criteria (BETWEEN, NOT_BETWEEN).
-
#type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicRelativeRangedTimestampRefineBy::Type
Indicates the type of refinement (RELATIVE_RANGED).
- #upper_bound_offset ⇒ HubSpotSDK::Models::Crm::PublicTimeOffset
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(lower_bound_offset:, range_type:, type:, upper_bound_offset:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/public_relative_ranged_timestamp_refine_by.rb', line 29
|
Instance Attribute Details
#lower_bound_offset ⇒ HubSpotSDK::Models::Crm::PublicTimeOffset
10 |
# File 'lib/hubspot_sdk/models/crm/public_relative_ranged_timestamp_refine_by.rb', line 10 required :lower_bound_offset, -> { HubSpotSDK::Crm::PublicTimeOffset }, api_name: :lowerBoundOffset |
#range_type ⇒ String
Specifies the type of range for the refinement criteria (BETWEEN, NOT_BETWEEN).
16 |
# File 'lib/hubspot_sdk/models/crm/public_relative_ranged_timestamp_refine_by.rb', line 16 required :range_type, String, api_name: :rangeType |
#type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicRelativeRangedTimestampRefineBy::Type
Indicates the type of refinement (RELATIVE_RANGED).
22 |
# File 'lib/hubspot_sdk/models/crm/public_relative_ranged_timestamp_refine_by.rb', line 22 required :type, enum: -> { HubSpotSDK::Crm::PublicRelativeRangedTimestampRefineBy::Type } |
#upper_bound_offset ⇒ HubSpotSDK::Models::Crm::PublicTimeOffset
27 |
# File 'lib/hubspot_sdk/models/crm/public_relative_ranged_timestamp_refine_by.rb', line 27 required :upper_bound_offset, -> { HubSpotSDK::Crm::PublicTimeOffset }, api_name: :upperBoundOffset |