Class: HubSpotSDK::Models::Crm::PublicRollingPropertyUpdatedOperation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_rolling_property_updated_operation.rb

Defined Under Namespace

Modules: OperationType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(include_objects_with_no_value_set:, number_of_days:, operation_type:, operator:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicRollingPropertyUpdatedOperation for more details.

Parameters:

  • include_objects_with_no_value_set (Boolean)

    Indicates whether objects with no value set for the property should be included

  • number_of_days (Integer)

    The number of days to be considered in the rolling property updated operation.

  • operation_type (Symbol, HubSpotSDK::Models::Crm::PublicRollingPropertyUpdatedOperation::OperationType)

    Specifies the type of operation (ROLLING_PROPERTY_UPDATED).

  • operator (String)

    Defines the operation to be applied within the rolling property updated operatio



# File 'lib/hubspot_sdk/models/crm/public_rolling_property_updated_operation.rb', line 37

Instance Attribute Details

#include_objects_with_no_value_setBoolean

Indicates whether objects with no value set for the property should be included in the operation.

Returns:

  • (Boolean)


12
13
14
# File 'lib/hubspot_sdk/models/crm/public_rolling_property_updated_operation.rb', line 12

required :include_objects_with_no_value_set,
HubSpotSDK::Internal::Type::Boolean,
api_name: :includeObjectsWithNoValueSet

#number_of_daysInteger

The number of days to be considered in the rolling property updated operation.

Returns:

  • (Integer)


20
# File 'lib/hubspot_sdk/models/crm/public_rolling_property_updated_operation.rb', line 20

required :number_of_days, Integer, api_name: :numberOfDays

#operation_typeSymbol, HubSpotSDK::Models::Crm::PublicRollingPropertyUpdatedOperation::OperationType

Specifies the type of operation (ROLLING_PROPERTY_UPDATED).



26
27
28
# File 'lib/hubspot_sdk/models/crm/public_rolling_property_updated_operation.rb', line 26

required :operation_type,
enum: -> { HubSpotSDK::Crm::PublicRollingPropertyUpdatedOperation::OperationType },
api_name: :operationType

#operatorString

Defines the operation to be applied within the rolling property updated operation (UPDATED_IN_LAST_X_DAYS, NOT_UPDATED_IN_LAST_X_DAYS).

Returns:

  • (String)


35
# File 'lib/hubspot_sdk/models/crm/public_rolling_property_updated_operation.rb', line 35

required :operator, String