Class: HubSpotSDK::Models::Crm::PublicSetOccurrencesRefineBy
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicSetOccurrencesRefineBy
- Defined in:
- lib/hubspot_sdk/models/crm/public_set_occurrences_refine_by.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#set_type ⇒ String
Indicates the specific set type used in the refinement (ALL, ALL_INCLUDE_EMPTY, ANY, NONE, NONE_EXCLUDE_EMPTY, ANY_INCLUDE_EMPTY).
-
#type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicSetOccurrencesRefineBy::Type
Specifies the type of refinement (SET_OCCURRENCES).
Instance Method Summary collapse
-
#initialize(set_type:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicSetOccurrencesRefineBy for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(set_type:, type:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicSetOccurrencesRefineBy for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_set_occurrences_refine_by.rb', line 20
|
Instance Attribute Details
#set_type ⇒ String
Indicates the specific set type used in the refinement (ALL, ALL_INCLUDE_EMPTY, ANY, NONE, NONE_EXCLUDE_EMPTY, ANY_INCLUDE_EMPTY).
12 |
# File 'lib/hubspot_sdk/models/crm/public_set_occurrences_refine_by.rb', line 12 required :set_type, String, api_name: :setType |
#type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicSetOccurrencesRefineBy::Type
Specifies the type of refinement (SET_OCCURRENCES).
18 |
# File 'lib/hubspot_sdk/models/crm/public_set_occurrences_refine_by.rb', line 18 required :type, enum: -> { HubSpotSDK::Crm::PublicSetOccurrencesRefineBy::Type } |