Class: HubSpotSDK::Models::Crm::PublicStringPropertyOperation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_string_property_operation.rb

Defined Under Namespace

Modules: OperationType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(include_objects_with_no_value_set:, operation_type:, operator:, value:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicStringPropertyOperation for more details.

Parameters:

  • include_objects_with_no_value_set (Boolean)

    Indicates whether objects with no value set for the property should be included

  • operation_type (Symbol, HubSpotSDK::Models::Crm::PublicStringPropertyOperation::OperationType)

    Specifies the type of operation (STRING).

  • operator (String)

    Defines the operation to be applied in the string property operation ()IS*EQUAL*

  • value (String)

    The string value to be used in the operation.



# File 'lib/hubspot_sdk/models/crm/public_string_property_operation.rb', line 39

Instance Attribute Details

#include_objects_with_no_value_setBoolean

Indicates whether objects with no value set for the property should be included in the operation.

Returns:

  • (Boolean)


12
13
14
# File 'lib/hubspot_sdk/models/crm/public_string_property_operation.rb', line 12

required :include_objects_with_no_value_set,
HubSpotSDK::Internal::Type::Boolean,
api_name: :includeObjectsWithNoValueSet

#operation_typeSymbol, HubSpotSDK::Models::Crm::PublicStringPropertyOperation::OperationType

Specifies the type of operation (STRING).



20
21
22
# File 'lib/hubspot_sdk/models/crm/public_string_property_operation.rb', line 20

required :operation_type,
enum: -> { HubSpotSDK::Crm::PublicStringPropertyOperation::OperationType },
api_name: :operationType

#operatorString

Defines the operation to be applied in the string property operation ()IS_EQUAL_TO, IS_NOT_EQUAL_TO, CONTAINS, DOES_NOT_CONTAIN, STARTS_WITH, ENDS_WITH, HAS_EVER_BEEN_EQUAL_TO, HAS_NEVER_BEEN_EQUAL_TO, HAS_EVER_CONTAINED, HAS_NEVER_CONTAINED).

Returns:

  • (String)


31
# File 'lib/hubspot_sdk/models/crm/public_string_property_operation.rb', line 31

required :operator, String

#valueString

The string value to be used in the operation.

Returns:

  • (String)


37
# File 'lib/hubspot_sdk/models/crm/public_string_property_operation.rb', line 37

required :value, String