Class: HubSpotSDK::Models::Crm::PublicSurveyMonkeyValueFilter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_survey_monkey_value_filter.rb

Defined Under Namespace

Modules: FilterType, ValueComparison

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(filter_type:, operator:, survey_id:, survey_question:, value_comparison:, survey_answer_col_id: nil, survey_answer_row_id: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicSurveyMonkeyValueFilter for more details.

Parameters:



# File 'lib/hubspot_sdk/models/crm/public_survey_monkey_value_filter.rb', line 54

Instance Attribute Details

#filter_typeSymbol, HubSpotSDK::Models::Crm::PublicSurveyMonkeyValueFilter::FilterType

Defines the type of filter (SURVEY_MONKEY_VALUE).



11
12
13
# File 'lib/hubspot_sdk/models/crm/public_survey_monkey_value_filter.rb', line 11

required :filter_type,
enum: -> { HubSpotSDK::Crm::PublicSurveyMonkeyValueFilter::FilterType },
api_name: :filterType

#operatorString

Defines the operation to be applied within the filter (HAS_ANSWERED_SURVEY_QUESTION_WITH_VALUE).

Returns:

  • (String)


20
# File 'lib/hubspot_sdk/models/crm/public_survey_monkey_value_filter.rb', line 20

required :operator, String

#survey_answer_col_idString?

The column ID of the survey answer used in the filter.

Returns:

  • (String, nil)


46
# File 'lib/hubspot_sdk/models/crm/public_survey_monkey_value_filter.rb', line 46

optional :survey_answer_col_id, String, api_name: :surveyAnswerColId

#survey_answer_row_idString?

The row ID of the survey answer used in the filter.

Returns:

  • (String, nil)


52
# File 'lib/hubspot_sdk/models/crm/public_survey_monkey_value_filter.rb', line 52

optional :survey_answer_row_id, String, api_name: :surveyAnswerRowId

#survey_idString

The ID of the survey used in the filter.

Returns:

  • (String)


26
# File 'lib/hubspot_sdk/models/crm/public_survey_monkey_value_filter.rb', line 26

required :survey_id, String, api_name: :surveyId

#survey_questionString

The question from the survey used in the filter.

Returns:

  • (String)


32
# File 'lib/hubspot_sdk/models/crm/public_survey_monkey_value_filter.rb', line 32

required :survey_question, String, api_name: :surveyQuestion

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/crm/public_survey_monkey_value_filter.rb', line 80