Class: HubSpotSDK::Models::Crm::PublicTimePointOperation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/public_time_point_operation.rb

Defined Under Namespace

Modules: OperationType, TimePoint

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(include_objects_with_no_value_set:, operation_type:, operator:, time_point:, type:, endpoint_behavior: nil, property_parser: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicTimePointOperation for more details.

Parameters:



# File 'lib/hubspot_sdk/models/crm/public_time_point_operation.rb', line 58

Instance Attribute Details

#endpoint_behaviorString?

Describes the behavior at the endpoint of the time point operation.

Returns:

  • (String, nil)


50
# File 'lib/hubspot_sdk/models/crm/public_time_point_operation.rb', line 50

optional :endpoint_behavior, String, api_name: :endpointBehavior

#include_objects_with_no_value_setBoolean

Indicates whether objects with no value set for the property should be included in the operation.

Returns:

  • (Boolean)


12
13
14
# File 'lib/hubspot_sdk/models/crm/public_time_point_operation.rb', line 12

required :include_objects_with_no_value_set,
HubSpotSDK::Internal::Type::Boolean,
api_name: :includeObjectsWithNoValueSet

#operation_typeSymbol, HubSpotSDK::Models::Crm::PublicTimePointOperation::OperationType

Specifies the type of operation (TIME_POINT).



20
21
22
# File 'lib/hubspot_sdk/models/crm/public_time_point_operation.rb', line 20

required :operation_type,
enum: -> { HubSpotSDK::Crm::PublicTimePointOperation::OperationType },
api_name: :operationType

#operatorString

Specifies the operation to be applied within the time point operation (IS_BEFORE, IS_AFTER).

Returns:

  • (String)


29
# File 'lib/hubspot_sdk/models/crm/public_time_point_operation.rb', line 29

required :operator, String

#property_parserString?

Specifies the parser used for interpreting the property in the operation.

Returns:

  • (String, nil)


56
# File 'lib/hubspot_sdk/models/crm/public_time_point_operation.rb', line 56

optional :property_parser, String, api_name: :propertyParser

#time_pointHubSpotSDK::Models::Crm::PublicDatePoint, ...

Defines the specific point in time for the operation, which can be a date, indexed time, or property-referenced time.



36
37
38
# File 'lib/hubspot_sdk/models/crm/public_time_point_operation.rb', line 36

required :time_point,
union: -> { HubSpotSDK::Crm::PublicTimePointOperation::TimePoint },
api_name: :timePoint

#typeString

Defines the type of operation being performed.

Returns:

  • (String)


44
# File 'lib/hubspot_sdk/models/crm/public_time_point_operation.rb', line 44

required :type, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/crm/public_time_point_operation.rb', line 84