Class: HubSpotSDK::Models::Crm::RecordListMembership
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::RecordListMembership
- Defined in:
- lib/hubspot_sdk/models/crm/record_list_membership.rb
Instance Attribute Summary collapse
-
#first_added_timestamp ⇒ Time
The timestamp when the record was first added to the list.
-
#is_public_list ⇒ Boolean?
Indicates whether the list is public.
-
#last_added_timestamp ⇒ Time
The timestamp when the record was last added to the list.
-
#list_id ⇒ String
The unique identifier of the list.
-
#list_version ⇒ Integer
The version number of the list.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(first_added_timestamp:, last_added_timestamp:, list_id:, list_version:, is_public_list: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/record_list_membership.rb', line 37
|
Instance Attribute Details
#first_added_timestamp ⇒ Time
The timestamp when the record was first added to the list.
11 |
# File 'lib/hubspot_sdk/models/crm/record_list_membership.rb', line 11 required :first_added_timestamp, Time, api_name: :firstAddedTimestamp |
#is_public_list ⇒ Boolean?
Indicates whether the list is public.
35 |
# File 'lib/hubspot_sdk/models/crm/record_list_membership.rb', line 35 optional :is_public_list, HubSpotSDK::Internal::Type::Boolean, api_name: :isPublicList |
#last_added_timestamp ⇒ Time
The timestamp when the record was last added to the list.
17 |
# File 'lib/hubspot_sdk/models/crm/record_list_membership.rb', line 17 required :last_added_timestamp, Time, api_name: :lastAddedTimestamp |
#list_id ⇒ String
The unique identifier of the list.
23 |
# File 'lib/hubspot_sdk/models/crm/record_list_membership.rb', line 23 required :list_id, String, api_name: :listId |
#list_version ⇒ Integer
The version number of the list.
29 |
# File 'lib/hubspot_sdk/models/crm/record_list_membership.rb', line 29 required :list_version, Integer, api_name: :listVersion |