Class: HubSpotSDK::Models::Crm::SimplePublicObject

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/simple_public_object.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, archived:, created_at:, properties:, updated_at:, archived_at: nil, object_write_trace_id: nil, properties_with_history: nil, url: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::SimplePublicObject for more details.

A simple public object.

Parameters:

  • id (String)

    The unique ID of the object.

  • archived (Boolean)

    Whether the object is archived.

  • created_at (Time)

    The timestamp when the object was created, in ISO 8601 format.

  • properties (Hash{Symbol=>String, nil})

    Key-value pairs representing the properties of the object.

  • updated_at (Time)

    The timestamp when the object was last updated, in ISO 8601 format.

  • archived_at (Time) (defaults to: nil)

    The timestamp when the object was archived, in ISO 8601 format.

  • object_write_trace_id (String) (defaults to: nil)

    A unique identifier for tracing the creation request.

  • properties_with_history (Hash{Symbol=>Array<HubSpotSDK::Models::Crm::ValueWithTimestamp>}) (defaults to: nil)

    Key-value pairs representing the properties of the object along with their histo

  • url (String) (defaults to: nil)

    The URL associated with the object.



# File 'lib/hubspot_sdk/models/crm/simple_public_object.rb', line 66

Instance Attribute Details

#archivedBoolean

Whether the object is archived.

Returns:

  • (Boolean)


17
# File 'lib/hubspot_sdk/models/crm/simple_public_object.rb', line 17

required :archived, HubSpotSDK::Internal::Type::Boolean

#archived_atTime?

The timestamp when the object was archived, in ISO 8601 format.

Returns:

  • (Time, nil)


41
# File 'lib/hubspot_sdk/models/crm/simple_public_object.rb', line 41

optional :archived_at, Time, api_name: :archivedAt

#created_atTime

The timestamp when the object was created, in ISO 8601 format.

Returns:

  • (Time)


23
# File 'lib/hubspot_sdk/models/crm/simple_public_object.rb', line 23

required :created_at, Time, api_name: :createdAt

#idString

The unique ID of the object.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/crm/simple_public_object.rb', line 11

required :id, String

#object_write_trace_idString?

A unique identifier for tracing the creation request.

Returns:

  • (String, nil)


47
# File 'lib/hubspot_sdk/models/crm/simple_public_object.rb', line 47

optional :object_write_trace_id, String, api_name: :objectWriteTraceId

#propertiesHash{Symbol=>String, nil}

Key-value pairs representing the properties of the object.

Returns:

  • (Hash{Symbol=>String, nil})


29
# File 'lib/hubspot_sdk/models/crm/simple_public_object.rb', line 29

required :properties, HubSpotSDK::Internal::Type::HashOf[String, nil?: true]

#properties_with_historyHash{Symbol=>Array<HubSpotSDK::Models::Crm::ValueWithTimestamp>}?

Key-value pairs representing the properties of the object along with their history.

Returns:



54
55
56
57
58
# File 'lib/hubspot_sdk/models/crm/simple_public_object.rb', line 54

optional :properties_with_history,
-> {
  HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::ValueWithTimestamp]]
},
api_name: :propertiesWithHistory

#updated_atTime

The timestamp when the object was last updated, in ISO 8601 format.

Returns:

  • (Time)


35
# File 'lib/hubspot_sdk/models/crm/simple_public_object.rb', line 35

required :updated_at, Time, api_name: :updatedAt

#urlString?

The URL associated with the object.

Returns:

  • (String, nil)


64
# File 'lib/hubspot_sdk/models/crm/simple_public_object.rb', line 64

optional :url, String