Class: HubSpotSDK::Models::Crm::SimplePublicObjectBatchInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/simple_public_object_batch_input.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, properties:, id_property: nil, object_write_trace_id: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::SimplePublicObjectBatchInput for more details.

Contains an array of CRM object records to be processed in a batch operation, each defined by their ID and properties.

Parameters:

  • id (String)

    The id to be updated. This can be the object id, or the unique property value of

  • properties (Hash{Symbol=>String})

    Key-value pairs representing the properties of the object.

  • id_property (String) (defaults to: nil)

    The name of a property whose values are unique for this object

  • object_write_trace_id (String) (defaults to: nil)

    A unique identifier for tracing the request.



# File 'lib/hubspot_sdk/models/crm/simple_public_object_batch_input.rb', line 32

Instance Attribute Details

#idString

The id to be updated. This can be the object id, or the unique property value of the idProperty property

Returns:

  • (String)


12
# File 'lib/hubspot_sdk/models/crm/simple_public_object_batch_input.rb', line 12

required :id, String

#id_propertyString?

The name of a property whose values are unique for this object

Returns:

  • (String, nil)


24
# File 'lib/hubspot_sdk/models/crm/simple_public_object_batch_input.rb', line 24

optional :id_property, String, api_name: :idProperty

#object_write_trace_idString?

A unique identifier for tracing the request.

Returns:

  • (String, nil)


30
# File 'lib/hubspot_sdk/models/crm/simple_public_object_batch_input.rb', line 30

optional :object_write_trace_id, String, api_name: :objectWriteTraceId

#propertiesHash{Symbol=>String}

Key-value pairs representing the properties of the object.

Returns:

  • (Hash{Symbol=>String})


18
# File 'lib/hubspot_sdk/models/crm/simple_public_object_batch_input.rb', line 18

required :properties, HubSpotSDK::Internal::Type::HashOf[String]