Class: HubSpotSDK::Models::Crm::SimplePublicObjectBatchInputUpsert

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/simple_public_object_batch_input_upsert.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, properties:, id_property: nil, object_write_trace_id: nil) ⇒ Object

Represents an object used in batch upsert operations, containing an object’s unique identifier, its properties, and optionally the unique property name and a write trace ID.

Parameters:

  • id (String)

    The unique ID of the object.

  • properties (Hash{Symbol=>String})

    Key value pairs representing the properties of the object.

  • id_property (String) (defaults to: nil)

    The name of a property whose values are unique for this object

  • object_write_trace_id (String) (defaults to: nil)

    An identifier for tracing the creation request.



# File 'lib/hubspot_sdk/models/crm/simple_public_object_batch_input_upsert.rb', line 31

Instance Attribute Details

#idString

The unique ID of the object.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/crm/simple_public_object_batch_input_upsert.rb', line 11

required :id, String

#id_propertyString?

The name of a property whose values are unique for this object

Returns:

  • (String, nil)


23
# File 'lib/hubspot_sdk/models/crm/simple_public_object_batch_input_upsert.rb', line 23

optional :id_property, String, api_name: :idProperty

#object_write_trace_idString?

An identifier for tracing the creation request.

Returns:

  • (String, nil)


29
# File 'lib/hubspot_sdk/models/crm/simple_public_object_batch_input_upsert.rb', line 29

optional :object_write_trace_id, String, api_name: :objectWriteTraceId

#propertiesHash{Symbol=>String}

Key value pairs representing the properties of the object.

Returns:

  • (Hash{Symbol=>String})


17
# File 'lib/hubspot_sdk/models/crm/simple_public_object_batch_input_upsert.rb', line 17

required :properties, HubSpotSDK::Internal::Type::HashOf[String]