Class: HubSpotSDK::Models::Crm::SimplePublicObjectInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::SimplePublicObjectInput
- Defined in:
- lib/hubspot_sdk/models/crm/simple_public_object_input.rb
Direct Known Subclasses
Objects::CallUpdateParams, Objects::CartUpdateParams, Objects::CommercePaymentUpdateParams, Objects::CommunicationUpdateParams, Objects::CompanyUpdateParams, Objects::ContactUpdateParams, Objects::ContractUpdateParams, Objects::CourseUpdateParams, Objects::CustomUpdateParams, Objects::DealUpdateParams, Objects::DiscountUpdateParams, Objects::EmailUpdateParams, Objects::FeeUpdateParams, Objects::GenericObjectUpdateParams, Objects::GoalTargetUpdateParams, Objects::InvoiceUpdateParams, Objects::LeadUpdateParams, Objects::LineItemUpdateParams, Objects::ListingUpdateParams, Objects::MeetingUpdateParams, Objects::NoteUpdateParams, Objects::OrderUpdateParams, Objects::PartnerClientUpdateParams, Objects::PartnerServiceUpdateParams, Objects::PostalMailUpdateParams, Objects::ProductUpdateParams, Objects::ProjectUpdateParams, Objects::QuoteUpdateParams, Objects::ServiceUpdateParams, Objects::SubscriptionUpdateParams, Objects::TaskUpdateParams, Objects::TaxUpdateParams, Objects::TicketUpdateParams, Objects::UserUpdateParams
Instance Attribute Summary collapse
-
#properties ⇒ Hash{Symbol=>String}
Key value pairs representing the properties of the object.
Instance Method Summary collapse
-
#initialize(properties:) ⇒ Object
constructor
Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(properties:) ⇒ Object
Represents the input required to create or update a CRM object, containing an object with property names and their corresponding values.
|
|
# File 'lib/hubspot_sdk/models/crm/simple_public_object_input.rb', line 13
|
Instance Attribute Details
#properties ⇒ Hash{Symbol=>String}
Key value pairs representing the properties of the object.
11 |
# File 'lib/hubspot_sdk/models/crm/simple_public_object_input.rb', line 11 required :properties, HubSpotSDK::Internal::Type::HashOf[String] |