Class: HubSpotSDK::Models::Crm::SimplePublicObjectInputForCreate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::SimplePublicObjectInputForCreate
- Defined in:
- lib/hubspot_sdk/models/crm/simple_public_object_input_for_create.rb
Direct Known Subclasses
Objects::CallCreateParams, Objects::CartCreateParams, Objects::CommercePaymentCreateParams, Objects::CommunicationCreateParams, Objects::CompanyCreateParams, Objects::ContactCreateParams, Objects::ContractCreateParams, Objects::CourseCreateParams, Objects::CustomCreateParams, Objects::DealCreateParams, Objects::DiscountCreateParams, Objects::EmailCreateParams, Objects::FeeCreateParams, Objects::GenericObjectCreateParams, Objects::GoalTargetCreateParams, Objects::InvoiceCreateParams, Objects::LeadCreateParams, Objects::LineItemCreateParams, Objects::ListingCreateParams, Objects::MeetingCreateParams, Objects::NoteCreateParams, Objects::OrderCreateParams, Objects::PostalMailCreateParams, Objects::ProductCreateParams, Objects::ProjectCreateParams, Objects::QuoteCreateParams, Objects::ServiceCreateParams, Objects::SubscriptionCreateParams, Objects::TaskCreateParams, Objects::TaxCreateParams, Objects::TicketCreateParams, Objects::UserCreateParams
Instance Attribute Summary collapse
- #associations ⇒ Array<HubSpotSDK::Models::Crm::PublicAssociationsForObject>
-
#properties ⇒ Hash{Symbol=>String}
Key-value pairs for setting properties for the new object.
Instance Method Summary collapse
-
#initialize(associations:, properties:) ⇒ Object
constructor
Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(associations:, properties:) ⇒ Object
Is the input object used to create a new CRM object, containing the properties to be set and optional associations to link the new record with other CRM objects.
|
|
# File 'lib/hubspot_sdk/models/crm/simple_public_object_input_for_create.rb', line 19
|
Instance Attribute Details
#associations ⇒ Array<HubSpotSDK::Models::Crm::PublicAssociationsForObject>
10 11 |
# File 'lib/hubspot_sdk/models/crm/simple_public_object_input_for_create.rb', line 10 required :associations, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::PublicAssociationsForObject] } |
#properties ⇒ Hash{Symbol=>String}
Key-value pairs for setting properties for the new object.
17 |
# File 'lib/hubspot_sdk/models/crm/simple_public_object_input_for_create.rb', line 17 required :properties, HubSpotSDK::Internal::Type::HashOf[String] |