Class: HubSpotSDK::Models::Crm::SimplePublicUpsertObject

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, archived:, created_at:, new:, properties:, updated_at:, archived_at: nil, object_write_trace_id: nil, properties_with_history: nil, url: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::SimplePublicUpsertObject for more details.

Represents a CRM object that has either been created or updated (upserted)

Parameters:

  • id (String)

    The unique ID of the object.

  • archived (Boolean)

    Whether the object is archived.

  • created_at (Time)

    The timestamp when the object was created, in ISO 8601 format.

  • new (Boolean)

    Whether the property is new.

  • properties (Hash{Symbol=>String})

    Key value pairs representing the properties of the object.

  • updated_at (Time)

    The timestamp when the object was last updated, in ISO 8601 format.

  • archived_at (Time) (defaults to: nil)

    The timestamp when the object was archived, in ISO 8601 format.

  • object_write_trace_id (String) (defaults to: nil)

    An identifier used for tracing the write request for the object.

  • properties_with_history (Hash{Symbol=>Array<HubSpotSDK::Models::Crm::ValueWithTimestamp>}) (defaults to: nil)

    Key-value pairs representing the properties of the object along with their histo

  • url (String) (defaults to: nil)

    The URL associated with the object.



# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 72

Instance Attribute Details

#archivedBoolean

Whether the object is archived.

Returns:

  • (Boolean)


17
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 17

required :archived, HubSpotSDK::Internal::Type::Boolean

#archived_atTime?

The timestamp when the object was archived, in ISO 8601 format.

Returns:

  • (Time, nil)


47
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 47

optional :archived_at, Time, api_name: :archivedAt

#created_atTime

The timestamp when the object was created, in ISO 8601 format.

Returns:

  • (Time)


23
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 23

required :created_at, Time, api_name: :createdAt

#idString

The unique ID of the object.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 11

required :id, String

#newBoolean

Whether the property is new.

Returns:

  • (Boolean)


29
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 29

required :new, HubSpotSDK::Internal::Type::Boolean

#object_write_trace_idString?

An identifier used for tracing the write request for the object.

Returns:

  • (String, nil)


53
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 53

optional :object_write_trace_id, String, api_name: :objectWriteTraceId

#propertiesHash{Symbol=>String}

Key value pairs representing the properties of the object.

Returns:

  • (Hash{Symbol=>String})


35
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 35

required :properties, HubSpotSDK::Internal::Type::HashOf[String]

#properties_with_historyHash{Symbol=>Array<HubSpotSDK::Models::Crm::ValueWithTimestamp>}?

Key-value pairs representing the properties of the object along with their history.

Returns:



60
61
62
63
64
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 60

optional :properties_with_history,
-> {
  HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::ValueWithTimestamp]]
},
api_name: :propertiesWithHistory

#updated_atTime

The timestamp when the object was last updated, in ISO 8601 format.

Returns:

  • (Time)


41
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 41

required :updated_at, Time, api_name: :updatedAt

#urlString?

The URL associated with the object.

Returns:

  • (String, nil)


70
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 70

optional :url, String