Class: HubSpotSDK::Models::Crm::TimelineEventIFrame

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/timeline_event_i_frame.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(header_label:, height:, link_label:, url:, width:) ⇒ Object

Parameters:

  • header_label (String)

    The label of the modal window that displays the iframe contents.

  • height (Integer)

    The height of the modal window in pixels.

  • link_label (String)

    The text displaying the link that will display the iframe.

  • url (String)

    The URI of the iframe contents.

  • width (Integer)

    The width of the modal window in pixels.



# File 'lib/hubspot_sdk/models/crm/timeline_event_i_frame.rb', line 37

Instance Attribute Details

#header_labelString

The label of the modal window that displays the iframe contents.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/crm/timeline_event_i_frame.rb', line 11

required :header_label, String, api_name: :headerLabel

#heightInteger

The height of the modal window in pixels.

Returns:

  • (Integer)


17
# File 'lib/hubspot_sdk/models/crm/timeline_event_i_frame.rb', line 17

required :height, Integer

The text displaying the link that will display the iframe.

Returns:

  • (String)


23
# File 'lib/hubspot_sdk/models/crm/timeline_event_i_frame.rb', line 23

required :link_label, String, api_name: :linkLabel

#urlString

The URI of the iframe contents.

Returns:

  • (String)


29
# File 'lib/hubspot_sdk/models/crm/timeline_event_i_frame.rb', line 29

required :url, String

#widthInteger

The width of the modal window in pixels.

Returns:

  • (Integer)


35
# File 'lib/hubspot_sdk/models/crm/timeline_event_i_frame.rb', line 35

required :width, Integer