Class: HubSpotSDK::Models::Crm::UsageForObjectType

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/usage_for_object_type.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(object_type_id:, plural_label:, singular_label:, usage:) ⇒ Object

Parameters:

  • object_type_id (String)

    The unique identifier for the object type.

  • plural_label (String)

    The plural form of the label for the object type.

  • singular_label (String)

    The singular form of the label for the object type.

  • usage (Integer)

    The number of records used for the object type.



# File 'lib/hubspot_sdk/models/crm/usage_for_object_type.rb', line 31

Instance Attribute Details

#object_type_idString

The unique identifier for the object type.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/crm/usage_for_object_type.rb', line 11

required :object_type_id, String, api_name: :objectTypeId

#plural_labelString

The plural form of the label for the object type.

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/crm/usage_for_object_type.rb', line 17

required :plural_label, String, api_name: :pluralLabel

#singular_labelString

The singular form of the label for the object type.

Returns:

  • (String)


23
# File 'lib/hubspot_sdk/models/crm/usage_for_object_type.rb', line 23

required :singular_label, String, api_name: :singularLabel

#usageInteger

The number of records used for the object type.

Returns:

  • (Integer)


29
# File 'lib/hubspot_sdk/models/crm/usage_for_object_type.rb', line 29

required :usage, Integer