Class: HubSpotSDK::Models::Crm::ValueWithTimestamp

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/crm/value_with_timestamp.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(source_type:, timestamp:, value:, source_id: nil, source_label: nil, updated_by_user_id: nil) ⇒ Object

Property model that includes timestamp.

Parameters:

  • source_type (String)

    The property type.

  • timestamp (Time)

    The timestamp when the property was updated, in ISO 8601 format.

  • value (String)

    The property value.

  • source_id (String) (defaults to: nil)

    The unique ID of the property.

  • source_label (String) (defaults to: nil)

    A human-readable label.

  • updated_by_user_id (Integer) (defaults to: nil)

    The ID of the user who last updated the property.



# File 'lib/hubspot_sdk/models/crm/value_with_timestamp.rb', line 43

Instance Attribute Details

#source_idString?

The unique ID of the property.

Returns:

  • (String, nil)


29
# File 'lib/hubspot_sdk/models/crm/value_with_timestamp.rb', line 29

optional :source_id, String, api_name: :sourceId

#source_labelString?

A human-readable label.

Returns:

  • (String, nil)


35
# File 'lib/hubspot_sdk/models/crm/value_with_timestamp.rb', line 35

optional :source_label, String, api_name: :sourceLabel

#source_typeString

The property type.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/crm/value_with_timestamp.rb', line 11

required :source_type, String, api_name: :sourceType

#timestampTime

The timestamp when the property was updated, in ISO 8601 format.

Returns:

  • (Time)


17
# File 'lib/hubspot_sdk/models/crm/value_with_timestamp.rb', line 17

required :timestamp, Time

#updated_by_user_idInteger?

The ID of the user who last updated the property.

Returns:

  • (Integer, nil)


41
# File 'lib/hubspot_sdk/models/crm/value_with_timestamp.rb', line 41

optional :updated_by_user_id, Integer, api_name: :updatedByUserId

#valueString

The property value.

Returns:

  • (String)


23
# File 'lib/hubspot_sdk/models/crm/value_with_timestamp.rb', line 23

required :value, String