Class: HubSpotSDK::Models::Error

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/error.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(category:, correlation_id:, message:, context: nil, errors: nil, links: nil, sub_category: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Error for more details.

Parameters:

  • category (String)

    The error category

  • correlation_id (String)

    A unique identifier for the request. Include this value with any error reports o

  • message (String)

    A human readable message describing the error along with remediation steps where

  • context (Hash{Symbol=>Array<String>}) (defaults to: nil)

    Context about the error condition

  • errors (Array<HubSpotSDK::Models::ErrorDetail>) (defaults to: nil)

    further information about the error

  • links (Hash{Symbol=>String}) (defaults to: nil)

    A map of link names to associated URIs containing documentation about the error

  • sub_category (String) (defaults to: nil)

    A specific category that contains more specific detail about the error



# File 'lib/hubspot_sdk/models/error.rb', line 51

Instance Attribute Details

#categoryString

The error category

Returns:

  • (String)


10
# File 'lib/hubspot_sdk/models/error.rb', line 10

required :category, String

#contextHash{Symbol=>Array<String>}?

Context about the error condition

Returns:

  • (Hash{Symbol=>Array<String>}, nil)


30
# File 'lib/hubspot_sdk/models/error.rb', line 30

optional :context, HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::ArrayOf[String]]

#correlation_idString

A unique identifier for the request. Include this value with any error reports or support tickets

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/error.rb', line 17

required :correlation_id, String, api_name: :correlationId

#errorsArray<HubSpotSDK::Models::ErrorDetail>?

further information about the error

Returns:



36
# File 'lib/hubspot_sdk/models/error.rb', line 36

optional :errors, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::ErrorDetail] }

A map of link names to associated URIs containing documentation about the error or recommended remediation steps

Returns:

  • (Hash{Symbol=>String}, nil)


43
# File 'lib/hubspot_sdk/models/error.rb', line 43

optional :links, HubSpotSDK::Internal::Type::HashOf[String]

#messageString

A human readable message describing the error along with remediation steps where appropriate

Returns:

  • (String)


24
# File 'lib/hubspot_sdk/models/error.rb', line 24

required :message, String

#sub_categoryString?

A specific category that contains more specific detail about the error

Returns:

  • (String, nil)


49
# File 'lib/hubspot_sdk/models/error.rb', line 49

optional :sub_category, String, api_name: :subCategory