Class: HubSpotSDK::Models::ErrorDetail
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::ErrorDetail
- Defined in:
- lib/hubspot_sdk/models/error_detail.rb
Instance Attribute Summary collapse
-
#code ⇒ String?
The status code associated with the error detail.
-
#context ⇒ Hash{Symbol=>Array<String>}?
Context about the error condition.
-
#in_ ⇒ String?
The name of the field or parameter in which the error was found.
-
#message ⇒ String
A human readable message describing the error along with remediation steps where appropriate.
-
#sub_category ⇒ String?
A specific category that contains more specific detail about the error.
Instance Method Summary collapse
-
#initialize(message:, code: nil, context: nil, in_: nil, sub_category: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ErrorDetail for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(message:, code: nil, context: nil, in_: nil, sub_category: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::ErrorDetail for more details.
|
|
# File 'lib/hubspot_sdk/models/error_detail.rb', line 37
|
Instance Attribute Details
#code ⇒ String?
The status code associated with the error detail
17 |
# File 'lib/hubspot_sdk/models/error_detail.rb', line 17 optional :code, String |
#context ⇒ Hash{Symbol=>Array<String>}?
Context about the error condition
23 |
# File 'lib/hubspot_sdk/models/error_detail.rb', line 23 optional :context, HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::ArrayOf[String]] |
#in_ ⇒ String?
The name of the field or parameter in which the error was found.
29 |
# File 'lib/hubspot_sdk/models/error_detail.rb', line 29 optional :in_, String, api_name: :in |
#message ⇒ String
A human readable message describing the error along with remediation steps where appropriate
11 |
# File 'lib/hubspot_sdk/models/error_detail.rb', line 11 required :message, String |
#sub_category ⇒ String?
A specific category that contains more specific detail about the error
35 |
# File 'lib/hubspot_sdk/models/error_detail.rb', line 35 optional :sub_category, String, api_name: :subCategory |