Class: HubSpotSDK::Models::Events::BehavioralEventHTTPCompletionRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb

Direct Known Subclasses

SendSendParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_name:, properties:, email: nil, object_id_: nil, occurred_at: nil, utk: nil, uuid: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Events::BehavioralEventHTTPCompletionRequest for more details.

Parameters:

  • event_name (String)

    Internal name of the event-type to trigger

  • properties (Hash{Symbol=>String})

    Map of properties for the event in the format property internal name - property

  • email (String) (defaults to: nil)

    Email of visitor

  • object_id_ (String) (defaults to: nil)

    The object id that this event occurred on. Could be a contact id or a visitor id

  • occurred_at (Time) (defaults to: nil)

    The time when this event occurred (if any). If this isn’t set, the current time

  • utk (String) (defaults to: nil)

    User token

  • uuid (String) (defaults to: nil)


# File 'lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb', line 51

Instance Attribute Details

#emailString?

Email of visitor

Returns:

  • (String, nil)


24
# File 'lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb', line 24

optional :email, String

#event_nameString

Internal name of the event-type to trigger

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb', line 11

required :event_name, String, api_name: :eventName

#object_id_String?

The object id that this event occurred on. Could be a contact id or a visitor id.

Returns:

  • (String, nil)


31
# File 'lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb', line 31

optional :object_id_, String, api_name: :objectId

#occurred_atTime?

The time when this event occurred (if any). If this isn’t set, the current time will be used

Returns:

  • (Time, nil)


38
# File 'lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb', line 38

optional :occurred_at, Time, api_name: :occurredAt

#propertiesHash{Symbol=>String}

Map of properties for the event in the format property internal name - property value

Returns:

  • (Hash{Symbol=>String})


18
# File 'lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb', line 18

required :properties, HubSpotSDK::Internal::Type::HashOf[String]

#utkString?

User token

Returns:

  • (String, nil)


44
# File 'lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb', line 44

optional :utk, String

#uuidString?

Returns:

  • (String, nil)


49
# File 'lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb', line 49

optional :uuid, String