Class: HubSpotSDK::Models::Events::CollectionResponseExternalUnifiedEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Events::CollectionResponseExternalUnifiedEvent
- Defined in:
- lib/hubspot_sdk/models/events/collection_response_external_unified_event.rb
Instance Attribute Summary collapse
- #paging ⇒ HubSpotSDK::Models::Paging?
-
#results ⇒ Array<HubSpotSDK::Models::Events::ExternalUnifiedEvent>
An array of ExternalUnifiedEvent objects, each representing an individual event with its associated details.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#paging ⇒ HubSpotSDK::Models::Paging?
17 |
# File 'lib/hubspot_sdk/models/events/collection_response_external_unified_event.rb', line 17 optional :paging, -> { HubSpotSDK::Paging } |
#results ⇒ Array<HubSpotSDK::Models::Events::ExternalUnifiedEvent>
An array of ExternalUnifiedEvent objects, each representing an individual event with its associated details.
12 |
# File 'lib/hubspot_sdk/models/events/collection_response_external_unified_event.rb', line 12 required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Events::ExternalUnifiedEvent] } |