Class: HubSpotSDK::Models::Events::DefinitionListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Events::DefinitionListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/events/definition_list_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
- #include_properties ⇒ Boolean?
-
#limit ⇒ Integer?
The maximum number of results to display per page.
- #search_string ⇒ String?
- #sort_order ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(after: nil, include_properties: nil, limit: nil, search_string: nil, sort_order: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see DefinitionListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, include_properties: nil, limit: nil, search_string: nil, sort_order: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Events::DefinitionListParams for more details.
|
|
# File 'lib/hubspot_sdk/models/events/definition_list_params.rb', line 40
|
Instance Attribute Details
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
17 |
# File 'lib/hubspot_sdk/models/events/definition_list_params.rb', line 17 optional :after, String |
#include_properties ⇒ Boolean?
22 |
# File 'lib/hubspot_sdk/models/events/definition_list_params.rb', line 22 optional :include_properties, HubSpotSDK::Internal::Type::Boolean |
#limit ⇒ Integer?
The maximum number of results to display per page.
28 |
# File 'lib/hubspot_sdk/models/events/definition_list_params.rb', line 28 optional :limit, Integer |
#search_string ⇒ String?
33 |
# File 'lib/hubspot_sdk/models/events/definition_list_params.rb', line 33 optional :search_string, String |
#sort_order ⇒ String?
38 |
# File 'lib/hubspot_sdk/models/events/definition_list_params.rb', line 38 optional :sort_order, String |