Class: HubSpotSDK::Models::Events::ExternalBehavioralEventPropertyCreate

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/events/external_behavioral_event_property_create.rb

Direct Known Subclasses

DefinitionCreatePropertyParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(label:, type:, description: nil, name: nil, options: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Events::ExternalBehavioralEventPropertyCreate for more details.

Parameters:

  • label (String)

    Human readable label for the property. Used in HubSpot UI

  • type (String)

    The data type of the property. Can be one of the following: [string, number, enu

  • description (String) (defaults to: nil)

    A description of the property that will be shown as help text in HubSpot.

  • name (String) (defaults to: nil)

    Internal property name, which must be used when referencing the property from th

  • options (Array<HubSpotSDK::Models::OptionInput>) (defaults to: nil)

    A list of available options for the property if it is an enumeration. NOTE: This



# File 'lib/hubspot_sdk/models/events/external_behavioral_event_property_create.rb', line 40

Instance Attribute Details

#descriptionString?

A description of the property that will be shown as help text in HubSpot.

Returns:

  • (String, nil)


24
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_property_create.rb', line 24

optional :description, String

#labelString

Human readable label for the property. Used in HubSpot UI

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_property_create.rb', line 11

required :label, String

#nameString?

Internal property name, which must be used when referencing the property from the API

Returns:

  • (String, nil)


31
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_property_create.rb', line 31

optional :name, String

#optionsArray<HubSpotSDK::Models::OptionInput>?

A list of available options for the property if it is an enumeration. NOTE: This field is only applicable for enumerated properties.

Returns:



38
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_property_create.rb', line 38

optional :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::OptionInput] }

#typeString

The data type of the property. Can be one of the following: [string, number, enumeration, datetime]

Returns:

  • (String)


18
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_property_create.rb', line 18

required :type, String