Class: HubSpotSDK::Models::Events::ExternalBehavioralEventPropertyDefinitionPatch
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Events::ExternalBehavioralEventPropertyDefinitionPatch
- Defined in:
- lib/hubspot_sdk/models/events/external_behavioral_event_property_definition_patch.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#description ⇒ String?
A description of the property that will be shown as help text in HubSpot.
-
#label ⇒ String?
Human readable label for the property.
-
#options ⇒ Array<HubSpotSDK::Models::OptionInput>?
A list of available options for the property if it is an enumeration.
Instance Method Summary collapse
-
#initialize(description: nil, label: nil, options: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalBehavioralEventPropertyDefinitionPatch for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(description: nil, label: nil, options: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Events::ExternalBehavioralEventPropertyDefinitionPatch for more details.
|
|
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_property_definition_patch.rb', line 26
|
Instance Attribute Details
#description ⇒ String?
A description of the property that will be shown as help text in HubSpot.
11 |
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_property_definition_patch.rb', line 11 optional :description, String |
#label ⇒ String?
Human readable label for the property. Used in HubSpot UI
17 |
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_property_definition_patch.rb', line 17 optional :label, String |
#options ⇒ Array<HubSpotSDK::Models::OptionInput>?
A list of available options for the property if it is an enumeration. NOTE: This field is only applicable for enumerated properties.
24 |
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_property_definition_patch.rb', line 24 optional :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::OptionInput] } |