Class: HubSpotSDK::Models::Events::ExternalBehavioralEventTypeDefinitionEgg

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_egg.rb

Direct Known Subclasses

DefinitionCreateParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(include_default_properties:, label:, property_definitions:, custom_matching_id: nil, description: nil, name: nil, primary_object: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Events::ExternalBehavioralEventTypeDefinitionEgg for more details.

Parameters:

  • include_default_properties (Boolean)
  • label (String)

    Human readable label for the event. Used in HubSpot UI

  • property_definitions (Array<HubSpotSDK::Models::Events::ExternalBehavioralEventPropertyCreate>)

    List of custom properties on event

  • custom_matching_id (HubSpotSDK::Models::Events::ExternalObjectResolutionMappingRequest) (defaults to: nil)
  • description (String) (defaults to: nil)

    A description of the event that will be shown as help text in HubSpot.

  • name (String) (defaults to: nil)

    Internal event name, which must be used when referencing the event from this eve

  • primary_object (String) (defaults to: nil)

    The object type to associate this event to. Can be one of CONTACT, COMPANY, DEAL



# File 'lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_egg.rb', line 61

Instance Attribute Details

#custom_matching_idHubSpotSDK::Models::Events::ExternalObjectResolutionMappingRequest?



33
34
35
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_egg.rb', line 33

optional :custom_matching_id,
-> { HubSpotSDK::Events::ExternalObjectResolutionMappingRequest },
api_name: :customMatchingId

#descriptionString?

A description of the event that will be shown as help text in HubSpot.

Returns:

  • (String, nil)


41
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_egg.rb', line 41

optional :description, String

#include_default_propertiesBoolean

Returns:

  • (Boolean)


10
11
12
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_egg.rb', line 10

required :include_default_properties,
HubSpotSDK::Internal::Type::Boolean,
api_name: :includeDefaultProperties

#labelString

Human readable label for the event. Used in HubSpot UI

Returns:

  • (String)


18
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_egg.rb', line 18

required :label, String

#nameString?

Internal event name, which must be used when referencing the event from this event definitions API. If a name is not supplied, one will be generated based on the label. The ‘name` value will also be used to automatically generate a `fullyQualifiedName` for the event definition, which you’ll use when sending event completions to this event.

Returns:

  • (String, nil)


51
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_egg.rb', line 51

optional :name, String

#primary_objectString?

The object type to associate this event to. Can be one of CONTACT, COMPANY, DEAL, TICKET. If no primaryObject is supplied, we will default to associating the event to CONTACT objects.

Returns:

  • (String, nil)


59
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_egg.rb', line 59

optional :primary_object, String, api_name: :primaryObject

#property_definitionsArray<HubSpotSDK::Models::Events::ExternalBehavioralEventPropertyCreate>

List of custom properties on event



24
25
26
27
28
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_egg.rb', line 24

required :property_definitions,
-> {
  HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Events::ExternalBehavioralEventPropertyCreate]
},
api_name: :propertyDefinitions