Class: HubSpotSDK::Models::Events::ExternalBehavioralEventTypeDefinitionPatch

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_patch.rb

Direct Known Subclasses

DefinitionUpdateParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(description: nil, label: nil) ⇒ Object

Parameters:

  • description (String) (defaults to: nil)

    A description of the event that will be shown as help text in HubSpot.

  • label (String) (defaults to: nil)

    Human readable label for the event. Used in HubSpot UI



# File 'lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_patch.rb', line 19

Instance Attribute Details

#descriptionString?

A description of the event that will be shown as help text in HubSpot.

Returns:

  • (String, nil)


11
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_patch.rb', line 11

optional :description, String

#labelString?

Human readable label for the event. Used in HubSpot UI

Returns:

  • (String, nil)


17
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_patch.rb', line 17

optional :label, String