Class: HubSpotSDK::Models::Events::OccurrenceListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/events/occurrence_list_params.rb

Overview

Defined Under Namespace

Classes: ObjectProperty, Property

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(propname: nil) ⇒ Object

Parameters:

  • propname (Object) (defaults to: nil)


# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 118

Instance Attribute Details

#afterString?

The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.

Returns:

  • (String, nil)


22
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 22

optional :after, String

#beforeString?

Returns:

  • (String, nil)


27
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 27

optional :before, String

#event_typeString?

Returns:

  • (String, nil)


32
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 32

optional :event_type, String

#idArray<String>?

Returns:

  • (Array<String>, nil)


14
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 14

optional :id, HubSpotSDK::Internal::Type::ArrayOf[String]

#limitInteger?

The maximum number of results to display per page.

Returns:

  • (Integer, nil)


38
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 38

optional :limit, Integer

#object_id_Integer?

Returns:

  • (Integer, nil)


43
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 43

optional :object_id_, Integer

#object_propertyHubSpotSDK::Models::Events::OccurrenceListParams::ObjectProperty?



48
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 48

optional :object_property, -> { HubSpotSDK::Events::OccurrenceListParams::ObjectProperty }

#object_typeString?

Returns:

  • (String, nil)


53
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 53

optional :object_type, String

#occurred_afterTime?

Returns:

  • (Time, nil)


58
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 58

optional :occurred_after, Time

#occurred_beforeTime?

Returns:

  • (Time, nil)


63
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 63

optional :occurred_before, Time

#propertiesArray<String>?

Returns:

  • (Array<String>, nil)


68
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 68

optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String]

#propertyHubSpotSDK::Models::Events::OccurrenceListParams::Property?



73
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 73

optional :property, -> { HubSpotSDK::Events::OccurrenceListParams::Property }

#sortArray<String>?

Returns:

  • (Array<String>, nil)


78
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 78

optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String]