Class: HubSpotSDK::Models::Events::OccurrenceListParams::ObjectProperty

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/events/occurrence_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, after: nil, before: nil, event_type: nil, limit: nil, object_id_: nil, object_property: nil, object_type: nil, occurred_after: nil, occurred_before: nil, properties: nil, property: nil, sort: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Events::OccurrenceListParams for more details.

Parameters:

  • id (Array<String>) (defaults to: nil)
  • after (String) (defaults to: nil)

    The paging cursor token of the last successfully read resource will be returned

  • before (String) (defaults to: nil)
  • event_type (String) (defaults to: nil)
  • limit (Integer) (defaults to: nil)

    The maximum number of results to display per page.

  • object_id_ (Integer) (defaults to: nil)
  • object_property (HubSpotSDK::Models::Events::OccurrenceListParams::ObjectProperty) (defaults to: nil)
  • object_type (String) (defaults to: nil)
  • occurred_after (Time) (defaults to: nil)
  • occurred_before (Time) (defaults to: nil)
  • properties (Array<String>) (defaults to: nil)
  • property (HubSpotSDK::Models::Events::OccurrenceListParams::Property) (defaults to: nil)
  • sort (Array<String>) (defaults to: nil)
  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


112
113
114
115
116
117
118
119
120
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 112

class ObjectProperty < HubSpotSDK::Internal::Type::BaseModel
  # @!attribute propname
  #
  #   @return [Object, nil]
  optional :propname, HubSpotSDK::Internal::Type::Unknown, api_name: :"{propname}"

  # @!method initialize(propname: nil)
  #   @param propname [Object]
end

Instance Attribute Details

#propnameObject?

Returns:

  • (Object, nil)


116
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 116

optional :propname, HubSpotSDK::Internal::Type::Unknown, api_name: :"{propname}"