Class: HubSpotSDK::Models::Events::Property

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/events/property.rb

Overview

Defined Under Namespace

Modules: DataSensitivity, DateDisplayHint

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(description:, field_type:, group_name:, label:, name:, options:, type:, archived: nil, archived_at: nil, calculated: nil, calculation_formula: nil, created_at: nil, created_user_id: nil, data_sensitivity: nil, date_display_hint: nil, display_order: nil, external_options: nil, form_field: nil, has_unique_value: nil, hidden: nil, hubspot_defined: nil, modification_metadata: nil, referenced_object_type: nil, sensitive_data_categories: nil, show_currency_symbol: nil, updated_at: nil, updated_user_id: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Events::Property for more details.

A HubSpot property

Parameters:

  • description (String)

    A summary of the property’s purpose.

  • field_type (String)

    Determines how the property will appear in HubSpot’s UI or on a form. Learn more

  • group_name (String)

    The name of the group to which the property is assigned.

  • label (String)

    The display label for the property.

  • name (String)

    The internal name for the property.

  • options (Array<HubSpotSDK::Models::Option>)

    A list of valid options for the property. This field is required for enumerated

  • type (String)

    The data type of the property, such as string or number.

  • archived (Boolean) (defaults to: nil)

    Whether the property is archived.

  • archived_at (Time) (defaults to: nil)

    The timestamp when the property was archived, in ISO 8601 format.

  • calculated (Boolean) (defaults to: nil)

    Whether the property is a calculated field.

  • calculation_formula (String) (defaults to: nil)

    The formula used for calculated properties.

  • created_at (Time) (defaults to: nil)

    The timestamp when the property was created, in ISO 8601 format.

  • created_user_id (String) (defaults to: nil)

    The ID of the user who created the property.

  • data_sensitivity (Symbol, HubSpotSDK::Models::Events::Property::DataSensitivity) (defaults to: nil)

    Indicates the sensitivity level of the property, such as “non_sensitive”, “sensi

  • date_display_hint (Symbol, HubSpotSDK::Models::Events::Property::DateDisplayHint) (defaults to: nil)
  • display_order (Integer) (defaults to: nil)

    The position of the item relative to others in the list.

  • external_options (Boolean) (defaults to: nil)

    Applicable only for enumeration type properties. Should be set to true with a ‘r

  • form_field (Boolean) (defaults to: nil)

    Whether the property can appear on forms.

  • has_unique_value (Boolean) (defaults to: nil)

    Whether the property is a unique identifier property.

  • hidden (Boolean) (defaults to: nil)

    Whether or not the property will be hidden from the HubSpot UI. It’s recommended

  • hubspot_defined (Boolean) (defaults to: nil)

    A boolean value set to true for HubSpot default properties.

  • modification_metadata (HubSpotSDK::Models::PropertyModificationMetadata) (defaults to: nil)
  • referenced_object_type (String) (defaults to: nil)

    Deprecated. Use externalOptionsReferenceType instead.

  • sensitive_data_categories (Array<String>) (defaults to: nil)

    When sensitiveData is true, lists the type of sensitive data contained in the pr

  • show_currency_symbol (Boolean) (defaults to: nil)

    Whether to show the currency symbol in HubSpot’s UI.

  • updated_at (Time) (defaults to: nil)

    The timestamp when the property was last updated, in ISO 8601 format.

  • updated_user_id (String) (defaults to: nil)


# File 'lib/hubspot_sdk/models/events/property.rb', line 181

Instance Attribute Details

#archivedBoolean?

Whether the property is archived.

Returns:

  • (Boolean, nil)


56
# File 'lib/hubspot_sdk/models/events/property.rb', line 56

optional :archived, HubSpotSDK::Internal::Type::Boolean

#archived_atTime?

The timestamp when the property was archived, in ISO 8601 format.

Returns:

  • (Time, nil)


62
# File 'lib/hubspot_sdk/models/events/property.rb', line 62

optional :archived_at, Time, api_name: :archivedAt

#calculatedBoolean?

Whether the property is a calculated field.

Returns:

  • (Boolean, nil)


68
# File 'lib/hubspot_sdk/models/events/property.rb', line 68

optional :calculated, HubSpotSDK::Internal::Type::Boolean

#calculation_formulaString?

The formula used for calculated properties.

Returns:

  • (String, nil)


74
# File 'lib/hubspot_sdk/models/events/property.rb', line 74

optional :calculation_formula, String, api_name: :calculationFormula

#created_atTime?

The timestamp when the property was created, in ISO 8601 format.

Returns:

  • (Time, nil)


80
# File 'lib/hubspot_sdk/models/events/property.rb', line 80

optional :created_at, Time, api_name: :createdAt

#created_user_idString?

The ID of the user who created the property.

Returns:

  • (String, nil)


86
# File 'lib/hubspot_sdk/models/events/property.rb', line 86

optional :created_user_id, String, api_name: :createdUserId

#data_sensitivitySymbol, ...

Indicates the sensitivity level of the property, such as “non_sensitive”, “sensitive”, or “highly_sensitive”.



93
94
95
# File 'lib/hubspot_sdk/models/events/property.rb', line 93

optional :data_sensitivity,
enum: -> { HubSpotSDK::Events::Property::DataSensitivity },
api_name: :dataSensitivity

#date_display_hintSymbol, ...



100
101
102
# File 'lib/hubspot_sdk/models/events/property.rb', line 100

optional :date_display_hint,
enum: -> { HubSpotSDK::Events::Property::DateDisplayHint },
api_name: :dateDisplayHint

#descriptionString

A summary of the property’s purpose.

Returns:

  • (String)


12
# File 'lib/hubspot_sdk/models/events/property.rb', line 12

required :description, String

#display_orderInteger?

The position of the item relative to others in the list.

Returns:

  • (Integer, nil)


108
# File 'lib/hubspot_sdk/models/events/property.rb', line 108

optional :display_order, Integer, api_name: :displayOrder

#external_optionsBoolean?

Applicable only for enumeration type properties. Should be set to true with a ‘referencedObjectType’ of ‘OWNER’. Otherwise false.

Returns:

  • (Boolean, nil)


115
# File 'lib/hubspot_sdk/models/events/property.rb', line 115

optional :external_options, HubSpotSDK::Internal::Type::Boolean, api_name: :externalOptions

#field_typeString

Determines how the property will appear in HubSpot’s UI or on a form. Learn more in the properties API guide.

Returns:

  • (String)


19
# File 'lib/hubspot_sdk/models/events/property.rb', line 19

required :field_type, String, api_name: :fieldType

#form_fieldBoolean?

Whether the property can appear on forms.

Returns:

  • (Boolean, nil)


121
# File 'lib/hubspot_sdk/models/events/property.rb', line 121

optional :form_field, HubSpotSDK::Internal::Type::Boolean, api_name: :formField

#group_nameString

The name of the group to which the property is assigned.

Returns:

  • (String)


25
# File 'lib/hubspot_sdk/models/events/property.rb', line 25

required :group_name, String, api_name: :groupName

#has_unique_valueBoolean?

Whether the property is a unique identifier property.

Returns:

  • (Boolean, nil)


127
# File 'lib/hubspot_sdk/models/events/property.rb', line 127

optional :has_unique_value, HubSpotSDK::Internal::Type::Boolean, api_name: :hasUniqueValue

#hiddenBoolean?

Whether or not the property will be hidden from the HubSpot UI. It’s recommended that this be set to false for custom properties.

Returns:

  • (Boolean, nil)


134
# File 'lib/hubspot_sdk/models/events/property.rb', line 134

optional :hidden, HubSpotSDK::Internal::Type::Boolean

#hubspot_definedBoolean?

A boolean value set to true for HubSpot default properties.

Returns:

  • (Boolean, nil)


140
# File 'lib/hubspot_sdk/models/events/property.rb', line 140

optional :hubspot_defined, HubSpotSDK::Internal::Type::Boolean, api_name: :hubspotDefined

#labelString

The display label for the property.

Returns:

  • (String)


31
# File 'lib/hubspot_sdk/models/events/property.rb', line 31

required :label, String

#modification_metadataHubSpotSDK::Models::PropertyModificationMetadata?



145
146
147
# File 'lib/hubspot_sdk/models/events/property.rb', line 145

optional :modification_metadata,
-> { HubSpotSDK::PropertyModificationMetadata },
api_name: :modificationMetadata

#nameString

The internal name for the property.

Returns:

  • (String)


37
# File 'lib/hubspot_sdk/models/events/property.rb', line 37

required :name, String

#optionsArray<HubSpotSDK::Models::Option>

A list of valid options for the property. This field is required for enumerated properties.

Returns:



44
# File 'lib/hubspot_sdk/models/events/property.rb', line 44

required :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Option] }

#referenced_object_typeString?

Deprecated. Use externalOptionsReferenceType instead.

Returns:

  • (String, nil)


153
# File 'lib/hubspot_sdk/models/events/property.rb', line 153

optional :referenced_object_type, String, api_name: :referencedObjectType

#sensitive_data_categoriesArray<String>?

When sensitiveData is true, lists the type of sensitive data contained in the property (e.g., “HIPAA”).

Returns:

  • (Array<String>, nil)


160
161
162
# File 'lib/hubspot_sdk/models/events/property.rb', line 160

optional :sensitive_data_categories,
HubSpotSDK::Internal::Type::ArrayOf[String],
api_name: :sensitiveDataCategories

#show_currency_symbolBoolean?

Whether to show the currency symbol in HubSpot’s UI.

Returns:

  • (Boolean, nil)


168
# File 'lib/hubspot_sdk/models/events/property.rb', line 168

optional :show_currency_symbol, HubSpotSDK::Internal::Type::Boolean, api_name: :showCurrencySymbol

#typeString

The data type of the property, such as string or number.

Returns:

  • (String)


50
# File 'lib/hubspot_sdk/models/events/property.rb', line 50

required :type, String

#updated_atTime?

The timestamp when the property was last updated, in ISO 8601 format.

Returns:

  • (Time, nil)


174
# File 'lib/hubspot_sdk/models/events/property.rb', line 174

optional :updated_at, Time, api_name: :updatedAt

#updated_user_idString?

Returns:

  • (String, nil)


179
# File 'lib/hubspot_sdk/models/events/property.rb', line 179

optional :updated_user_id, String, api_name: :updatedUserId

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/events/property.rb', line 252