Class: HubSpotSDK::Models::Files::File

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/files/file.rb

Defined Under Namespace

Modules: Access, SourceGroup

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, archived:, created_at:, updated_at:, access: nil, archived_at: nil, default_hosting_url: nil, encoding: nil, expires_at: nil, extension: nil, file_md5: nil, height: nil, is_usable_in_content: nil, name: nil, parent_folder_id: nil, path: nil, size: nil, source_group: nil, type: nil, url: nil, width: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Files::File for more details.

Parameters:

  • id (String)

    File ID.

  • archived (Boolean)

    If the file is deleted.

  • created_at (Time)

    Creation time of the file object.

  • updated_at (Time)

    Timestamp of the latest update to the file.

  • access (Symbol, HubSpotSDK::Models::Files::File::Access) (defaults to: nil)

    File access. Can be PUBLIC_INDEXABLE, PUBLIC_NOT_INDEXABLE, PRIVATE.

  • archived_at (Time) (defaults to: nil)

    Deletion time of the file object.

  • default_hosting_url (String) (defaults to: nil)

    Default hosting URL of the file. This will use one of HubSpot’s provided URLs to

  • encoding (String) (defaults to: nil)

    Encoding of the file.

  • expires_at (Integer) (defaults to: nil)
  • extension (String) (defaults to: nil)

    Extension of the file. ex: .jpg, .png, .gif, .pdf, etc.

  • file_md5 (String) (defaults to: nil)

    The MD5 hash of the file.

  • height (Integer) (defaults to: nil)

    For image and video files, the height of the content.

  • is_usable_in_content (Boolean) (defaults to: nil)

    Previously “archied”. Indicates if the file should be used when creating new con

  • name (String) (defaults to: nil)

    Name of the file.

  • parent_folder_id (String) (defaults to: nil)

    ID of the folder the file is in.

  • path (String) (defaults to: nil)

    Path of the file in the file manager.

  • size (Integer) (defaults to: nil)

    Size of the file in bytes.

  • source_group (Symbol, HubSpotSDK::Models::Files::File::SourceGroup) (defaults to: nil)
  • type (String) (defaults to: nil)

    Type of the file. Can be IMG, DOCUMENT, AUDIO, MOVIE, or OTHER.

  • url (String) (defaults to: nil)

    URL of the given file. This URL can change depending on the domain settings of t

  • width (Integer) (defaults to: nil)

    For image and video files, the width of the content.



# File 'lib/hubspot_sdk/models/files/file.rb', line 134

Instance Attribute Details

#accessSymbol, ...

File access. Can be PUBLIC_INDEXABLE, PUBLIC_NOT_INDEXABLE, PRIVATE.

Returns:



35
# File 'lib/hubspot_sdk/models/files/file.rb', line 35

optional :access, enum: -> { HubSpotSDK::Files::File::Access }

#archivedBoolean

If the file is deleted.

Returns:

  • (Boolean)


17
# File 'lib/hubspot_sdk/models/files/file.rb', line 17

required :archived, HubSpotSDK::Internal::Type::Boolean

#archived_atTime?

Deletion time of the file object.

Returns:

  • (Time, nil)


41
# File 'lib/hubspot_sdk/models/files/file.rb', line 41

optional :archived_at, Time, api_name: :archivedAt

#created_atTime

Creation time of the file object.

Returns:

  • (Time)


23
# File 'lib/hubspot_sdk/models/files/file.rb', line 23

required :created_at, Time, api_name: :createdAt

#default_hosting_urlString?

Default hosting URL of the file. This will use one of HubSpot’s provided URLs to serve the file.

Returns:

  • (String, nil)


48
# File 'lib/hubspot_sdk/models/files/file.rb', line 48

optional :default_hosting_url, String, api_name: :defaultHostingUrl

#encodingString?

Encoding of the file.

Returns:

  • (String, nil)


54
# File 'lib/hubspot_sdk/models/files/file.rb', line 54

optional :encoding, String

#expires_atInteger?

Returns:

  • (Integer, nil)


59
# File 'lib/hubspot_sdk/models/files/file.rb', line 59

optional :expires_at, Integer, api_name: :expiresAt

#extensionString?

Extension of the file. ex: .jpg, .png, .gif, .pdf, etc.

Returns:

  • (String, nil)


65
# File 'lib/hubspot_sdk/models/files/file.rb', line 65

optional :extension, String

#file_md5String?

The MD5 hash of the file.

Returns:

  • (String, nil)


71
# File 'lib/hubspot_sdk/models/files/file.rb', line 71

optional :file_md5, String, api_name: :fileMd5

#heightInteger?

For image and video files, the height of the content.

Returns:

  • (Integer, nil)


77
# File 'lib/hubspot_sdk/models/files/file.rb', line 77

optional :height, Integer

#idString

File ID.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/files/file.rb', line 11

required :id, String

#is_usable_in_contentBoolean?

Previously “archied”. Indicates if the file should be used when creating new content like web pages.

Returns:

  • (Boolean, nil)


84
# File 'lib/hubspot_sdk/models/files/file.rb', line 84

optional :is_usable_in_content, HubSpotSDK::Internal::Type::Boolean, api_name: :isUsableInContent

#nameString?

Name of the file.

Returns:

  • (String, nil)


90
# File 'lib/hubspot_sdk/models/files/file.rb', line 90

optional :name, String

#parent_folder_idString?

ID of the folder the file is in.

Returns:

  • (String, nil)


96
# File 'lib/hubspot_sdk/models/files/file.rb', line 96

optional :parent_folder_id, String, api_name: :parentFolderId

#pathString?

Path of the file in the file manager.

Returns:

  • (String, nil)


102
# File 'lib/hubspot_sdk/models/files/file.rb', line 102

optional :path, String

#sizeInteger?

Size of the file in bytes.

Returns:

  • (Integer, nil)


108
# File 'lib/hubspot_sdk/models/files/file.rb', line 108

optional :size, Integer

#source_groupSymbol, ...



113
# File 'lib/hubspot_sdk/models/files/file.rb', line 113

optional :source_group, enum: -> { HubSpotSDK::Files::File::SourceGroup }, api_name: :sourceGroup

#typeString?

Type of the file. Can be IMG, DOCUMENT, AUDIO, MOVIE, or OTHER.

Returns:

  • (String, nil)


119
# File 'lib/hubspot_sdk/models/files/file.rb', line 119

optional :type, String

#updated_atTime

Timestamp of the latest update to the file.

Returns:

  • (Time)


29
# File 'lib/hubspot_sdk/models/files/file.rb', line 29

required :updated_at, Time, api_name: :updatedAt

#urlString?

URL of the given file. This URL can change depending on the domain settings of the account. Will use the select file hosting domain.

Returns:

  • (String, nil)


126
# File 'lib/hubspot_sdk/models/files/file.rb', line 126

optional :url, String

#widthInteger?

For image and video files, the width of the content.

Returns:

  • (Integer, nil)


132
# File 'lib/hubspot_sdk/models/files/file.rb', line 132

optional :width, Integer

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/files/file.rb', line 195