Class: HubSpotSDK::Models::Files::FileAssetSearchParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/files/file_asset_search_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after: nil, allows_anonymous_access: nil, before: nil, created_at: nil, created_at_gte: nil, created_at_lte: nil, encoding: nil, expires_at: nil, expires_at_gte: nil, expires_at_lte: nil, extension: nil, file_md5: nil, height: nil, height_gte: nil, height_lte: nil, id_gte: nil, id_lte: nil, ids: nil, is_usable_in_content: nil, limit: nil, name: nil, parent_folder_ids: nil, path: nil, properties: nil, size: nil, size_gte: nil, size_lte: nil, sort: nil, type: nil, updated_at: nil, updated_at_gte: nil, updated_at_lte: nil, url: nil, width: nil, width_gte: nil, width_lte: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Files::FileAssetSearchParams for more details.

Parameters:

  • after (String) (defaults to: nil)

    The paging cursor token of the last successfully read resource will be returned

  • allows_anonymous_access (Boolean) (defaults to: nil)
  • before (String) (defaults to: nil)
  • created_at (Time) (defaults to: nil)
  • created_at_gte (Time) (defaults to: nil)
  • created_at_lte (Time) (defaults to: nil)
  • encoding (String) (defaults to: nil)
  • expires_at (Time) (defaults to: nil)
  • expires_at_gte (Time) (defaults to: nil)
  • expires_at_lte (Time) (defaults to: nil)
  • extension (String) (defaults to: nil)
  • file_md5 (String) (defaults to: nil)
  • height (Integer) (defaults to: nil)
  • height_gte (Integer) (defaults to: nil)
  • height_lte (Integer) (defaults to: nil)
  • id_gte (Integer) (defaults to: nil)
  • id_lte (Integer) (defaults to: nil)
  • ids (Array<Integer>) (defaults to: nil)
  • is_usable_in_content (Boolean) (defaults to: nil)
  • limit (Integer) (defaults to: nil)

    The maximum number of results to display per page.

  • name (String) (defaults to: nil)
  • parent_folder_ids (Array<Integer>) (defaults to: nil)
  • path (String) (defaults to: nil)
  • properties (Array<String>) (defaults to: nil)
  • size (Integer) (defaults to: nil)
  • size_gte (Integer) (defaults to: nil)
  • size_lte (Integer) (defaults to: nil)
  • sort (Array<String>) (defaults to: nil)
  • type (String) (defaults to: nil)
  • updated_at (Time) (defaults to: nil)
  • updated_at_gte (Time) (defaults to: nil)
  • updated_at_lte (Time) (defaults to: nil)
  • url (String) (defaults to: nil)
  • width (Integer) (defaults to: nil)
  • width_gte (Integer) (defaults to: nil)
  • width_lte (Integer) (defaults to: nil)
  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 195

Instance Attribute Details

#afterString?

The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.

Returns:

  • (String, nil)


17
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 17

optional :after, String

#allows_anonymous_accessBoolean?

Returns:

  • (Boolean, nil)


22
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 22

optional :allows_anonymous_access, HubSpotSDK::Internal::Type::Boolean

#beforeString?

Returns:

  • (String, nil)


27
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 27

optional :before, String

#created_atTime?

Returns:

  • (Time, nil)


32
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 32

optional :created_at, Time

#created_at_gteTime?

Returns:

  • (Time, nil)


37
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 37

optional :created_at_gte, Time

#created_at_lteTime?

Returns:

  • (Time, nil)


42
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 42

optional :created_at_lte, Time

#encodingString?

Returns:

  • (String, nil)


47
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 47

optional :encoding, String

#expires_atTime?

Returns:

  • (Time, nil)


52
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 52

optional :expires_at, Time

#expires_at_gteTime?

Returns:

  • (Time, nil)


57
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 57

optional :expires_at_gte, Time

#expires_at_lteTime?

Returns:

  • (Time, nil)


62
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 62

optional :expires_at_lte, Time

#extensionString?

Returns:

  • (String, nil)


67
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 67

optional :extension, String

#file_md5String?

Returns:

  • (String, nil)


72
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 72

optional :file_md5, String

#heightInteger?

Returns:

  • (Integer, nil)


77
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 77

optional :height, Integer

#height_gteInteger?

Returns:

  • (Integer, nil)


82
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 82

optional :height_gte, Integer

#height_lteInteger?

Returns:

  • (Integer, nil)


87
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 87

optional :height_lte, Integer

#id_gteInteger?

Returns:

  • (Integer, nil)


92
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 92

optional :id_gte, Integer

#id_lteInteger?

Returns:

  • (Integer, nil)


97
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 97

optional :id_lte, Integer

#idsArray<Integer>?

Returns:

  • (Array<Integer>, nil)


102
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 102

optional :ids, HubSpotSDK::Internal::Type::ArrayOf[Integer]

#is_usable_in_contentBoolean?

Returns:

  • (Boolean, nil)


107
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 107

optional :is_usable_in_content, HubSpotSDK::Internal::Type::Boolean

#limitInteger?

The maximum number of results to display per page.

Returns:

  • (Integer, nil)


113
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 113

optional :limit, Integer

#nameString?

Returns:

  • (String, nil)


118
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 118

optional :name, String

#parent_folder_idsArray<Integer>?

Returns:

  • (Array<Integer>, nil)


123
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 123

optional :parent_folder_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer]

#pathString?

Returns:

  • (String, nil)


128
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 128

optional :path, String

#propertiesArray<String>?

Returns:

  • (Array<String>, nil)


133
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 133

optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String]

#sizeInteger?

Returns:

  • (Integer, nil)


138
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 138

optional :size, Integer

#size_gteInteger?

Returns:

  • (Integer, nil)


143
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 143

optional :size_gte, Integer

#size_lteInteger?

Returns:

  • (Integer, nil)


148
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 148

optional :size_lte, Integer

#sortArray<String>?

Returns:

  • (Array<String>, nil)


153
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 153

optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String]

#typeString?

Returns:

  • (String, nil)


158
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 158

optional :type, String

#updated_atTime?

Returns:

  • (Time, nil)


163
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 163

optional :updated_at, Time

#updated_at_gteTime?

Returns:

  • (Time, nil)


168
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 168

optional :updated_at_gte, Time

#updated_at_lteTime?

Returns:

  • (Time, nil)


173
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 173

optional :updated_at_lte, Time

#urlString?

Returns:

  • (String, nil)


178
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 178

optional :url, String

#widthInteger?

Returns:

  • (Integer, nil)


183
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 183

optional :width, Integer

#width_gteInteger?

Returns:

  • (Integer, nil)


188
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 188

optional :width_gte, Integer

#width_lteInteger?

Returns:

  • (Integer, nil)


193
# File 'lib/hubspot_sdk/models/files/file_asset_search_params.rb', line 193

optional :width_lte, Integer