Class: HubSpotSDK::Models::Files::FileUpdateInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/files/file_update_input.rb

Direct Known Subclasses

FileAssetUpdateParams

Defined Under Namespace

Modules: Access

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(clear_expires:, access: nil, expires_at: nil, is_usable_in_content: nil, name: nil, parent_folder_id: nil, parent_folder_path: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Files::FileUpdateInput for more details.

Parameters:

  • clear_expires (Boolean)
  • access (Symbol, HubSpotSDK::Models::Files::FileUpdateInput::Access) (defaults to: nil)

    NONE: Do not run any duplicate validation. REJECT: Reject the upload if a duplic

  • expires_at (Time) (defaults to: nil)
  • is_usable_in_content (Boolean) (defaults to: nil)

    Mark whether the file should be used in new content or not.

  • name (String) (defaults to: nil)

    New name for the file.

  • parent_folder_id (String) (defaults to: nil)

    FolderId where the file should be moved to. folderId and folderPath parameters c

  • parent_folder_path (String) (defaults to: nil)

    Folder path where the file should be moved to. folderId and folderPath parameter



# File 'lib/hubspot_sdk/models/files/file_update_input.rb', line 51

Instance Attribute Details

#accessSymbol, ...

NONE: Do not run any duplicate validation. REJECT: Reject the upload if a duplicate is found. RETURN_EXISTING: If a duplicate file is found, do not upload a new file and return the found duplicate instead.



18
# File 'lib/hubspot_sdk/models/files/file_update_input.rb', line 18

optional :access, enum: -> { HubSpotSDK::Files::FileUpdateInput::Access }

#clear_expiresBoolean

Returns:

  • (Boolean)


10
# File 'lib/hubspot_sdk/models/files/file_update_input.rb', line 10

required :clear_expires, HubSpotSDK::Internal::Type::Boolean, api_name: :clearExpires

#expires_atTime?

Returns:

  • (Time, nil)


23
# File 'lib/hubspot_sdk/models/files/file_update_input.rb', line 23

optional :expires_at, Time, api_name: :expiresAt

#is_usable_in_contentBoolean?

Mark whether the file should be used in new content or not.

Returns:

  • (Boolean, nil)


29
# File 'lib/hubspot_sdk/models/files/file_update_input.rb', line 29

optional :is_usable_in_content, HubSpotSDK::Internal::Type::Boolean, api_name: :isUsableInContent

#nameString?

New name for the file.

Returns:

  • (String, nil)


35
# File 'lib/hubspot_sdk/models/files/file_update_input.rb', line 35

optional :name, String

#parent_folder_idString?

FolderId where the file should be moved to. folderId and folderPath parameters cannot be set at the same time.

Returns:

  • (String, nil)


42
# File 'lib/hubspot_sdk/models/files/file_update_input.rb', line 42

optional :parent_folder_id, String, api_name: :parentFolderId

#parent_folder_pathString?

Folder path where the file should be moved to. folderId and folderPath parameters cannot be set at the same time.

Returns:

  • (String, nil)


49
# File 'lib/hubspot_sdk/models/files/file_update_input.rb', line 49

optional :parent_folder_path, String, api_name: :parentFolderPath