Class: HubSpotSDK::Models::Files::FolderInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/files/folder_input.rb

Direct Known Subclasses

FileAssetCreateParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, parent_folder_id: nil, parent_path: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Files::FolderInput for more details.

Parameters:

  • name (String)

    Desired name for the folder.

  • parent_folder_id (String) (defaults to: nil)

    FolderId of the parent of the created folder. If not specified, the folder will

  • parent_path (String) (defaults to: nil)

    Path of the parent of the created folder. If not specified the folder will be cr



# File 'lib/hubspot_sdk/models/files/folder_input.rb', line 29

Instance Attribute Details

#nameString

Desired name for the folder.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/files/folder_input.rb', line 11

required :name, String

#parent_folder_idString?

FolderId of the parent of the created folder. If not specified, the folder will be created at the root level. parentFolderId and parentFolderPath cannot be set at the same time.

Returns:

  • (String, nil)


19
# File 'lib/hubspot_sdk/models/files/folder_input.rb', line 19

optional :parent_folder_id, String, api_name: :parentFolderId

#parent_pathString?

Path of the parent of the created folder. If not specified the folder will be created at the root level. parentFolderPath and parentFolderId cannot be set at the same time.

Returns:

  • (String, nil)


27
# File 'lib/hubspot_sdk/models/files/folder_input.rb', line 27

optional :parent_path, String, api_name: :parentPath