Class: HubSpotSDK::Models::Files::FolderSearchParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/files/folder_search_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after: nil, before: nil, created_at: nil, created_at_gte: nil, created_at_lte: nil, id_gte: nil, id_lte: nil, ids: nil, limit: nil, name: nil, parent_folder_ids: nil, path: nil, properties: nil, sort: nil, updated_at: nil, updated_at_gte: nil, updated_at_lte: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Files::FolderSearchParams for more details.

Parameters:

  • after (String) (defaults to: nil)

    The paging cursor token of the last successfully read resource will be returned

  • before (String) (defaults to: nil)
  • created_at (Time) (defaults to: nil)
  • created_at_gte (Time) (defaults to: nil)
  • created_at_lte (Time) (defaults to: nil)
  • id_gte (Integer) (defaults to: nil)
  • id_lte (Integer) (defaults to: nil)
  • ids (Array<Integer>) (defaults to: nil)
  • limit (Integer) (defaults to: nil)

    The maximum number of results to display per page.

  • name (String) (defaults to: nil)
  • parent_folder_ids (Array<Integer>) (defaults to: nil)
  • path (String) (defaults to: nil)
  • properties (Array<String>) (defaults to: nil)
  • sort (Array<String>) (defaults to: nil)
  • updated_at (Time) (defaults to: nil)
  • updated_at_gte (Time) (defaults to: nil)
  • updated_at_lte (Time) (defaults to: nil)
  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 100

Instance Attribute Details

#afterString?

The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.

Returns:

  • (String, nil)


17
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 17

optional :after, String

#beforeString?

Returns:

  • (String, nil)


22
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 22

optional :before, String

#created_atTime?

Returns:

  • (Time, nil)


27
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 27

optional :created_at, Time

#created_at_gteTime?

Returns:

  • (Time, nil)


32
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 32

optional :created_at_gte, Time

#created_at_lteTime?

Returns:

  • (Time, nil)


37
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 37

optional :created_at_lte, Time

#id_gteInteger?

Returns:

  • (Integer, nil)


42
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 42

optional :id_gte, Integer

#id_lteInteger?

Returns:

  • (Integer, nil)


47
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 47

optional :id_lte, Integer

#idsArray<Integer>?

Returns:

  • (Array<Integer>, nil)


52
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 52

optional :ids, HubSpotSDK::Internal::Type::ArrayOf[Integer]

#limitInteger?

The maximum number of results to display per page.

Returns:

  • (Integer, nil)


58
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 58

optional :limit, Integer

#nameString?

Returns:

  • (String, nil)


63
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 63

optional :name, String

#parent_folder_idsArray<Integer>?

Returns:

  • (Array<Integer>, nil)


68
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 68

optional :parent_folder_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer]

#pathString?

Returns:

  • (String, nil)


73
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 73

optional :path, String

#propertiesArray<String>?

Returns:

  • (Array<String>, nil)


78
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 78

optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String]

#sortArray<String>?

Returns:

  • (Array<String>, nil)


83
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 83

optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String]

#updated_atTime?

Returns:

  • (Time, nil)


88
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 88

optional :updated_at, Time

#updated_at_gteTime?

Returns:

  • (Time, nil)


93
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 93

optional :updated_at_gte, Time

#updated_at_lteTime?

Returns:

  • (Time, nil)


98
# File 'lib/hubspot_sdk/models/files/folder_search_params.rb', line 98

optional :updated_at_lte, Time