Class: HubSpotSDK::Models::Files::FolderUpdateInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/files/folder_update_input.rb

Direct Known Subclasses

FolderUpdateByIDParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: nil, parent_folder_id: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Files::FolderUpdateInput for more details.

Parameters:

  • name (String) (defaults to: nil)

    New name. If specified the folder’s name and fullPath will change. All children

  • parent_folder_id (Integer) (defaults to: nil)

    New parent folderId. If changed, the folder and all it’s children will be moved



# File 'lib/hubspot_sdk/models/files/folder_update_input.rb', line 22

Instance Attribute Details

#nameString?

New name. If specified the folder’s name and fullPath will change. All children of the folder will be updated accordingly.

Returns:

  • (String, nil)


12
# File 'lib/hubspot_sdk/models/files/folder_update_input.rb', line 12

optional :name, String

#parent_folder_idInteger?

New parent folderId. If changed, the folder and all it’s children will be moved into the specified folder. parentFolderId and parentFolderPath cannot be specified at the same time.

Returns:

  • (Integer, nil)


20
# File 'lib/hubspot_sdk/models/files/folder_update_input.rb', line 20

optional :parent_folder_id, Integer, api_name: :parentFolderId