Class: HubSpotSDK::Models::Files::FolderUpdateInputWithID
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Files::FolderUpdateInputWithID
- Defined in:
- lib/hubspot_sdk/models/files/folder_update_input_with_id.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier of the folder to be updated.
-
#name ⇒ String?
New name.
-
#parent_folder_id ⇒ Integer?
New parent folderId.
Instance Method Summary collapse
-
#initialize(id:, name: nil, parent_folder_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see FolderUpdateInputWithID for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, name: nil, parent_folder_id: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Files::FolderUpdateInputWithID for more details.
|
|
# File 'lib/hubspot_sdk/models/files/folder_update_input_with_id.rb', line 28
|
Instance Attribute Details
#id ⇒ String
The unique identifier of the folder to be updated.
11 |
# File 'lib/hubspot_sdk/models/files/folder_update_input_with_id.rb', line 11 required :id, String |
#name ⇒ String?
New name. If specified the folder’s name and fullPath will change. All children of the folder will be updated accordingly.
18 |
# File 'lib/hubspot_sdk/models/files/folder_update_input_with_id.rb', line 18 optional :name, String |
#parent_folder_id ⇒ Integer?
New parent folderId. If changed, the folder and all it’s children will be moved into the specified folder. parentFolderId and parentFolderPath cannot be specified at the same time.
26 |
# File 'lib/hubspot_sdk/models/files/folder_update_input_with_id.rb', line 26 optional :parent_folder_id, Integer, api_name: :parentFolderId |