Module: HubSpotSDK::Models::Files::ImportFromURLInput::Access

Extended by:
Internal::Type::Enum
Defined in:
lib/hubspot_sdk/models/files/import_from_url_input.rb

Overview

PUBLIC_INDEXABLE: File is publicly accessible by anyone who has the URL. Search engines can index the file. PUBLIC_NOT_INDEXABLE: File is publicly accessible by anyone who has the URL. Search engines _can’t_ index the file. PRIVATE: File is NOT publicly accessible. Requires a signed URL to see content. Search engines _can’t_ index the file.

See Also:

Constant Summary collapse

HIDDEN_INDEXABLE =
:HIDDEN_INDEXABLE
HIDDEN_NOT_INDEXABLE =
:HIDDEN_NOT_INDEXABLE
HIDDEN_PRIVATE =
:HIDDEN_PRIVATE
HIDDEN_SENSITIVE =
:HIDDEN_SENSITIVE
PRIVATE =
:PRIVATE
PUBLIC_INDEXABLE =
:PUBLIC_INDEXABLE
PUBLIC_NOT_INDEXABLE =
:PUBLIC_NOT_INDEXABLE
SENSITIVE =
:SENSITIVE

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info