Module: HubSpotSDK::Models::Files::ImportFromURLInput::DuplicateValidationScope

Extended by:
Internal::Type::Enum
Defined in:
lib/hubspot_sdk/models/files/import_from_url_input.rb

Overview

ENTIRE_PORTAL: Look for a duplicate file in the entire account. EXACT_FOLDER: Look for a duplicate file in the provided folder.

Constant Summary collapse

ENTIRE_PORTAL =
:ENTIRE_PORTAL
EXACT_FOLDER =
:EXACT_FOLDER

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info