Module: HubSpotSDK::Models::Files::ImportFromURLInput::DuplicateValidationStrategy

Extended by:
Internal::Type::Enum
Defined in:
lib/hubspot_sdk/models/files/import_from_url_input.rb

Overview

NONE: Do not run any duplicate validation. REJECT: Reject the upload if a duplicate is found. RETURN_EXISTING: If a duplicate file is found, do not upload a new file and return the found duplicate instead.

Constant Summary collapse

NONE =
:NONE
REJECT =
:REJECT
RETURN_EXISTING =
:RETURN_EXISTING

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/files/import_from_url_input.rb', line 159