Class: HubSpotSDK::Models::Files::ImportFromURLTaskLocator

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/files/import_from_url_task_locator.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, links: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Files::ImportFromURLTaskLocator for more details.

Parameters:

  • id (String)

    ID of the task

  • links (Hash{Symbol=>String}) (defaults to: nil)

    Links for where to check information related to the task. The ‘status` link give



# File 'lib/hubspot_sdk/models/files/import_from_url_task_locator.rb', line 20

Instance Attribute Details

#idString

ID of the task

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/files/import_from_url_task_locator.rb', line 11

required :id, String

Links for where to check information related to the task. The ‘status` link gives the URL for where to check the status of the task.

Returns:

  • (Hash{Symbol=>String}, nil)


18
# File 'lib/hubspot_sdk/models/files/import_from_url_task_locator.rb', line 18

optional :links, HubSpotSDK::Internal::Type::HashOf[String]