Class: HubSpotSDK::Models::Files::SignedURL

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/files/signed_url.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(expires_at:, url:, extension: nil, height: nil, name: nil, size: nil, type: nil, width: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Files::SignedURL for more details.

Parameters:

  • expires_at (Time)

    Timestamp of when the URL will no longer grant access to the file.

  • url (String)

    Signed URL with access to the specified file. Anyone with this URL will be able

  • extension (String) (defaults to: nil)

    Extension of the requested file.

  • height (Integer) (defaults to: nil)

    For image and video files. The height of the file.

  • name (String) (defaults to: nil)

    Name of the requested file.

  • size (Integer) (defaults to: nil)

    Size in bytes of the requested file.

  • type (String) (defaults to: nil)

    Type of the file. Can be IMG, DOCUMENT, AUDIO, MOVIE, or OTHER.

  • width (Integer) (defaults to: nil)

    For image and video files. The width of the file.



# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 56

Instance Attribute Details

#expires_atTime

Timestamp of when the URL will no longer grant access to the file.

Returns:

  • (Time)


11
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 11

required :expires_at, Time, api_name: :expiresAt

#extensionString?

Extension of the requested file.

Returns:

  • (String, nil)


24
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 24

optional :extension, String

#heightInteger?

For image and video files. The height of the file.

Returns:

  • (Integer, nil)


30
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 30

optional :height, Integer

#nameString?

Name of the requested file.

Returns:

  • (String, nil)


36
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 36

optional :name, String

#sizeInteger?

Size in bytes of the requested file.

Returns:

  • (Integer, nil)


42
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 42

optional :size, Integer

#typeString?

Type of the file. Can be IMG, DOCUMENT, AUDIO, MOVIE, or OTHER.

Returns:

  • (String, nil)


48
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 48

optional :type, String

#urlString

Signed URL with access to the specified file. Anyone with this URL will be able to access the file until it expires.

Returns:

  • (String)


18
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 18

required :url, String

#widthInteger?

For image and video files. The width of the file.

Returns:

  • (Integer, nil)


54
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 54

optional :width, Integer