Class: HubSpotSDK::Models::ForwardPaging

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/forward_paging.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(next_: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::ForwardPaging for more details.

Parameters:

  • next_ (HubSpotSDK::Models::NextPage) (defaults to: nil)

    Specifies the paging information needed to retrieve the next set of results in a



# File 'lib/hubspot_sdk/models/forward_paging.rb', line 13

Instance Attribute Details

#next_HubSpotSDK::Models::NextPage?

Specifies the paging information needed to retrieve the next set of results in a paginated API response



11
# File 'lib/hubspot_sdk/models/forward_paging.rb', line 11

optional :next_, -> { HubSpotSDK::NextPage }, api_name: :next