Class: HubSpotSDK::Models::Marketing::AttendanceCounters
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::AttendanceCounters
- Defined in:
- lib/hubspot_sdk/models/marketing/attendance_counters.rb
Instance Attribute Summary collapse
-
#attended ⇒ Integer
Number of attended contact records of a marketing event.
-
#cancelled ⇒ Integer
Number of cancelled contact records of a marketing event.
-
#no_shows ⇒ Integer
Number of no-show contact records of a marketing event.
-
#registered ⇒ Integer
Number of registered contact records of a marketing event.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(attended:, cancelled:, no_shows:, registered:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/marketing/attendance_counters.rb', line 31
|
Instance Attribute Details
#attended ⇒ Integer
Number of attended contact records of a marketing event
11 |
# File 'lib/hubspot_sdk/models/marketing/attendance_counters.rb', line 11 required :attended, Integer |
#cancelled ⇒ Integer
Number of cancelled contact records of a marketing event
17 |
# File 'lib/hubspot_sdk/models/marketing/attendance_counters.rb', line 17 required :cancelled, Integer |
#no_shows ⇒ Integer
Number of no-show contact records of a marketing event
23 |
# File 'lib/hubspot_sdk/models/marketing/attendance_counters.rb', line 23 required :no_shows, Integer, api_name: :noShows |
#registered ⇒ Integer
Number of registered contact records of a marketing event
29 |
# File 'lib/hubspot_sdk/models/marketing/attendance_counters.rb', line 29 required :registered, Integer |