Class: HubSpotSDK::Models::Marketing::BatchInputPublicCampaignInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::BatchInputPublicCampaignInput
- Defined in:
- lib/hubspot_sdk/models/marketing/batch_input_public_campaign_input.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#inputs ⇒ Array<HubSpotSDK::Models::Marketing::PublicCampaignInput>
An array of PublicCampaignInput objects, each representing the properties of a campaign to be created in the batch.
Instance Method Summary collapse
-
#initialize(inputs:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BatchInputPublicCampaignInput for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(inputs:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::BatchInputPublicCampaignInput for more details.
|
|
# File 'lib/hubspot_sdk/models/marketing/batch_input_public_campaign_input.rb', line 14
|
Instance Attribute Details
#inputs ⇒ Array<HubSpotSDK::Models::Marketing::PublicCampaignInput>
An array of PublicCampaignInput objects, each representing the properties of a campaign to be created in the batch. This property is required.
12 |
# File 'lib/hubspot_sdk/models/marketing/batch_input_public_campaign_input.rb', line 12 required :inputs, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Marketing::PublicCampaignInput] } |