Class: HubSpotSDK::Models::Marketing::BatchResponseMarketingEventPublicDefaultResponseV2WithErrors
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::BatchResponseMarketingEventPublicDefaultResponseV2WithErrors
- Defined in:
- lib/hubspot_sdk/models/marketing/batch_response_marketing_event_public_default_response_v2_with_errors.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
Timestamp that represents when the request finished processing.
- #errors ⇒ Array<HubSpotSDK::Models::StandardError>?
-
#links ⇒ Hash{Symbol=>String}?
Result of the request.
-
#num_errors ⇒ Integer?
The number of errors that occurred during the processing.
-
#requested_at ⇒ Time?
Timestamp that represents when the request was made.
- #results ⇒ Array<HubSpotSDK::Models::Marketing::MarketingEventPublicDefaultResponseV2>
-
#started_at ⇒ Time
Timestamp that represents when the request started processing.
-
#status ⇒ Symbol, HubSpotSDK::Models::Marketing::BatchResponseMarketingEventPublicDefaultResponseV2WithErrors::Status
The status of the request processing.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(completed_at:, results:, started_at:, status:, errors: nil, links: nil, num_errors: nil, requested_at: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/marketing/batch_response_marketing_event_public_default_response_v2_with_errors.rb', line 55
|
Instance Attribute Details
#completed_at ⇒ Time
Timestamp that represents when the request finished processing
11 |
# File 'lib/hubspot_sdk/models/marketing/batch_response_marketing_event_public_default_response_v2_with_errors.rb', line 11 required :completed_at, Time, api_name: :completedAt |
#errors ⇒ Array<HubSpotSDK::Models::StandardError>?
35 |
# File 'lib/hubspot_sdk/models/marketing/batch_response_marketing_event_public_default_response_v2_with_errors.rb', line 35 optional :errors, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::StandardError] } |
#links ⇒ Hash{Symbol=>String}?
Result of the request
41 |
# File 'lib/hubspot_sdk/models/marketing/batch_response_marketing_event_public_default_response_v2_with_errors.rb', line 41 optional :links, HubSpotSDK::Internal::Type::HashOf[String] |
#num_errors ⇒ Integer?
The number of errors that occurred during the processing
47 |
# File 'lib/hubspot_sdk/models/marketing/batch_response_marketing_event_public_default_response_v2_with_errors.rb', line 47 optional :num_errors, Integer, api_name: :numErrors |
#requested_at ⇒ Time?
Timestamp that represents when the request was made
53 |
# File 'lib/hubspot_sdk/models/marketing/batch_response_marketing_event_public_default_response_v2_with_errors.rb', line 53 optional :requested_at, Time, api_name: :requestedAt |
#results ⇒ Array<HubSpotSDK::Models::Marketing::MarketingEventPublicDefaultResponseV2>
16 17 |
# File 'lib/hubspot_sdk/models/marketing/batch_response_marketing_event_public_default_response_v2_with_errors.rb', line 16 required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Marketing::MarketingEventPublicDefaultResponseV2] } |
#started_at ⇒ Time
Timestamp that represents when the request started processing
23 |
# File 'lib/hubspot_sdk/models/marketing/batch_response_marketing_event_public_default_response_v2_with_errors.rb', line 23 required :started_at, Time, api_name: :startedAt |
#status ⇒ Symbol, HubSpotSDK::Models::Marketing::BatchResponseMarketingEventPublicDefaultResponseV2WithErrors::Status
The status of the request processing
29 30 |
# File 'lib/hubspot_sdk/models/marketing/batch_response_marketing_event_public_default_response_v2_with_errors.rb', line 29 required :status, enum: -> { HubSpotSDK::Marketing::BatchResponseMarketingEventPublicDefaultResponseV2WithErrors::Status } |