Class: HubSpotSDK::Models::Marketing::BatchResponsePublicCampaign

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/batch_response_public_campaign.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(completed_at:, results:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::BatchResponsePublicCampaign for more details.

Parameters:

  • completed_at (Time)

    The date and time when the batch operation was completed, formatted as a date-ti

  • results (Array<HubSpotSDK::Models::Marketing::PublicCampaign>)

    An array of results from the batch operation, each item representing a public ca

  • started_at (Time)

    The date and time when the batch operation started, formatted as a date-time str

  • status (Symbol, HubSpotSDK::Models::Marketing::BatchResponsePublicCampaign::Status)

    The current status of the batch operation, with possible values: CANCELED, COMPL

  • links (Hash{Symbol=>String}) (defaults to: nil)

    A map of related links associated with the batch operation.

  • requested_at (Time) (defaults to: nil)

    The date and time when the batch operation was requested, formatted as a date-ti



# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign.rb', line 48

Instance Attribute Details

#completed_atTime

The date and time when the batch operation was completed, formatted as a date-time string.

Returns:

  • (Time)


12
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign.rb', line 12

required :completed_at, Time, api_name: :completedAt

A map of related links associated with the batch operation.

Returns:

  • (Hash{Symbol=>String}, nil)


39
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign.rb', line 39

optional :links, HubSpotSDK::Internal::Type::HashOf[String]

#requested_atTime?

The date and time when the batch operation was requested, formatted as a date-time string.

Returns:

  • (Time, nil)


46
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign.rb', line 46

optional :requested_at, Time, api_name: :requestedAt

#resultsArray<HubSpotSDK::Models::Marketing::PublicCampaign>

An array of results from the batch operation, each item representing a public campaign.



19
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign.rb', line 19

required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Marketing::PublicCampaign] }

#started_atTime

The date and time when the batch operation started, formatted as a date-time string.

Returns:

  • (Time)


26
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign.rb', line 26

required :started_at, Time, api_name: :startedAt

#statusSymbol, HubSpotSDK::Models::Marketing::BatchResponsePublicCampaign::Status

The current status of the batch operation, with possible values: CANCELED, COMPLETE, PENDING, PROCESSING.



33
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign.rb', line 33

required :status, enum: -> { HubSpotSDK::Marketing::BatchResponsePublicCampaign::Status }