Class: HubSpotSDK::Models::Marketing::BatchResponsePublicCampaignWithAssets

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(completed_at:, results:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::BatchResponsePublicCampaignWithAssets for more details.

Parameters:

  • completed_at (Time)

    The timestamp when the batch request processing was completed.

  • results (Array<HubSpotSDK::Models::Marketing::PublicCampaignWithAssets>)

    An array of results from the batch operation, each representing a public campaig

  • started_at (Time)

    The timestamp when the processing of the batch request began.

  • status (Symbol, HubSpotSDK::Models::Marketing::BatchResponsePublicCampaignWithAssets::Status)

    The current processing status of the batch operation, with possible values: CANC

  • links (Hash{Symbol=>String}) (defaults to: nil)

    A collection of URLs linking to related resources or documentation.

  • requested_at (Time) (defaults to: nil)

    The timestamp when the batch request was initially made.



# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets.rb', line 46

Instance Attribute Details

#completed_atTime

The timestamp when the batch request processing was completed.

Returns:

  • (Time)


11
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets.rb', line 11

required :completed_at, Time, api_name: :completedAt

A collection of URLs linking to related resources or documentation.

Returns:

  • (Hash{Symbol=>String}, nil)


38
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets.rb', line 38

optional :links, HubSpotSDK::Internal::Type::HashOf[String]

#requested_atTime?

The timestamp when the batch request was initially made.

Returns:

  • (Time, nil)


44
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets.rb', line 44

optional :requested_at, Time, api_name: :requestedAt

#resultsArray<HubSpotSDK::Models::Marketing::PublicCampaignWithAssets>

An array of results from the batch operation, each representing a public campaign with assets.



18
19
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets.rb', line 18

required :results,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Marketing::PublicCampaignWithAssets] }

#started_atTime

The timestamp when the processing of the batch request began.

Returns:

  • (Time)


25
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets.rb', line 25

required :started_at, Time, api_name: :startedAt

#statusSymbol, HubSpotSDK::Models::Marketing::BatchResponsePublicCampaignWithAssets::Status

The current processing status of the batch operation, with possible values: CANCELED, COMPLETE, PENDING, PROCESSING.



32
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets.rb', line 32

required :status, enum: -> { HubSpotSDK::Marketing::BatchResponsePublicCampaignWithAssets::Status }