Class: HubSpotSDK::Models::Marketing::BatchResponsePublicCampaignWithAssetsWithErrors

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets_with_errors.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(completed_at:, results:, started_at:, status:, errors: nil, links: nil, num_errors: nil, requested_at: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::BatchResponsePublicCampaignWithAssetsWithErrors for more details.

Parameters:

  • completed_at (Time)

    The date and time when the batch operation was completed.

  • results (Array<HubSpotSDK::Models::Marketing::PublicCampaignWithAssets>)

    The list of successfully retrieved campaigns with their associated assets.

  • started_at (Time)

    The date and time when the batch operation started.

  • status (Symbol, HubSpotSDK::Models::Marketing::BatchResponsePublicCampaignWithAssetsWithErrors::Status)

    The current status of the batch operation, which can be CANCELED, COMPLETE, PEND

  • errors (Array<HubSpotSDK::Models::StandardError>) (defaults to: nil)

    The list of errors for individual campaign reads that failed within the batch (e

  • links (Hash{Symbol=>String}) (defaults to: nil)

    A collection of links related to the batch operation.

  • num_errors (Integer) (defaults to: nil)

    The number of errors that occurred during the batch operation.

  • requested_at (Time) (defaults to: nil)

    The date and time when the batch operation was requested.



# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets_with_errors.rb', line 59

Instance Attribute Details

#completed_atTime

The date and time when the batch operation was completed.

Returns:

  • (Time)


11
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets_with_errors.rb', line 11

required :completed_at, Time, api_name: :completedAt

#errorsArray<HubSpotSDK::Models::StandardError>?

The list of errors for individual campaign reads that failed within the batch (e.g., campaign not found, permission denied). Only included when non-empty.

Returns:



39
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets_with_errors.rb', line 39

optional :errors, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::StandardError] }

A collection of links related to the batch operation.

Returns:

  • (Hash{Symbol=>String}, nil)


45
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets_with_errors.rb', line 45

optional :links, HubSpotSDK::Internal::Type::HashOf[String]

#num_errorsInteger?

The number of errors that occurred during the batch operation.

Returns:

  • (Integer, nil)


51
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets_with_errors.rb', line 51

optional :num_errors, Integer, api_name: :numErrors

#requested_atTime?

The date and time when the batch operation was requested.

Returns:

  • (Time, nil)


57
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets_with_errors.rb', line 57

optional :requested_at, Time, api_name: :requestedAt

#resultsArray<HubSpotSDK::Models::Marketing::PublicCampaignWithAssets>

The list of successfully retrieved campaigns with their associated assets.



17
18
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets_with_errors.rb', line 17

required :results,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Marketing::PublicCampaignWithAssets] }

#started_atTime

The date and time when the batch operation started.

Returns:

  • (Time)


24
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets_with_errors.rb', line 24

required :started_at, Time, api_name: :startedAt

#statusSymbol, HubSpotSDK::Models::Marketing::BatchResponsePublicCampaignWithAssetsWithErrors::Status

The current status of the batch operation, which can be CANCELED, COMPLETE, PENDING, or PROCESSING.



31
32
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_assets_with_errors.rb', line 31

required :status,
enum: -> { HubSpotSDK::Marketing::BatchResponsePublicCampaignWithAssetsWithErrors::Status }