Class: HubSpotSDK::Models::Marketing::BatchResponsePublicCampaignWithErrors
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::BatchResponsePublicCampaignWithErrors
- Defined in:
- lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_errors.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The date and time when the batch operation was completed.
-
#errors ⇒ Array<HubSpotSDK::Models::StandardError>?
The list of errors for individual campaign operations that failed within the batch.
-
#links ⇒ Hash{Symbol=>String}?
URLs linking to resources or documentation related to the batch operation.
-
#num_errors ⇒ Integer?
The total number of errors encountered during the batch operation.
-
#requested_at ⇒ Time?
The date and time when the batch request was made.
-
#results ⇒ Array<HubSpotSDK::Models::Marketing::PublicCampaign>
The list of successfully created or updated campaigns.
-
#started_at ⇒ Time
The date and time when the batch operation began.
-
#status ⇒ Symbol, HubSpotSDK::Models::Marketing::BatchResponsePublicCampaignWithErrors::Status
The current status of the batch operation.
Instance Method Summary collapse
-
#initialize(completed_at:, results:, started_at:, status:, errors: nil, links: nil, num_errors: nil, requested_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BatchResponsePublicCampaignWithErrors for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(completed_at:, results:, started_at:, status:, errors: nil, links: nil, num_errors: nil, requested_at: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::BatchResponsePublicCampaignWithErrors for more details.
|
|
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_errors.rb', line 57
|
Instance Attribute Details
#completed_at ⇒ Time
The date and time when the batch operation was completed.
11 |
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_errors.rb', line 11 required :completed_at, Time, api_name: :completedAt |
#errors ⇒ Array<HubSpotSDK::Models::StandardError>?
The list of errors for individual campaign operations that failed within the batch. Only included when non-empty.
37 |
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_errors.rb', line 37 optional :errors, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::StandardError] } |
#links ⇒ Hash{Symbol=>String}?
URLs linking to resources or documentation related to the batch operation.
43 |
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_errors.rb', line 43 optional :links, HubSpotSDK::Internal::Type::HashOf[String] |
#num_errors ⇒ Integer?
The total number of errors encountered during the batch operation.
49 |
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_errors.rb', line 49 optional :num_errors, Integer, api_name: :numErrors |
#requested_at ⇒ Time?
The date and time when the batch request was made.
55 |
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_errors.rb', line 55 optional :requested_at, Time, api_name: :requestedAt |
#results ⇒ Array<HubSpotSDK::Models::Marketing::PublicCampaign>
The list of successfully created or updated campaigns.
17 |
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_errors.rb', line 17 required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Marketing::PublicCampaign] } |
#started_at ⇒ Time
The date and time when the batch operation began.
23 |
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_errors.rb', line 23 required :started_at, Time, api_name: :startedAt |
#status ⇒ Symbol, HubSpotSDK::Models::Marketing::BatchResponsePublicCampaignWithErrors::Status
The current status of the batch operation. Accepted values are: CANCELED, COMPLETE, PENDING, PROCESSING.
30 |
# File 'lib/hubspot_sdk/models/marketing/batch_response_public_campaign_with_errors.rb', line 30 required :status, enum: -> { HubSpotSDK::Marketing::BatchResponsePublicCampaignWithErrors::Status } |