Class: HubSpotSDK::Models::Marketing::CampaignGetParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::CampaignGetParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/marketing/campaign_get_params.rb
Overview
Instance Attribute Summary collapse
- #campaign_guid ⇒ String
-
#end_date ⇒ String?
The end date for fetching asset metrics, in YYYY-MM-DD format.
-
#properties ⇒ Array<String>?
A comma-separated list of properties to include in the response.
-
#start_date ⇒ String?
The start date for fetching asset metrics, in YYYY-MM-DD format.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(campaign_guid:, end_date: nil, properties: nil, start_date: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CampaignGetParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(campaign_guid:, end_date: nil, properties: nil, start_date: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::CampaignGetParams for more details.
|
|
# File 'lib/hubspot_sdk/models/marketing/campaign_get_params.rb', line 37
|
Instance Attribute Details
#campaign_guid ⇒ String
14 |
# File 'lib/hubspot_sdk/models/marketing/campaign_get_params.rb', line 14 required :campaign_guid, String |
#end_date ⇒ String?
The end date for fetching asset metrics, in YYYY-MM-DD format. Optional. Example: 2000-01-27
21 |
# File 'lib/hubspot_sdk/models/marketing/campaign_get_params.rb', line 21 optional :end_date, String |
#properties ⇒ Array<String>?
A comma-separated list of properties to include in the response.
Unrecognized properties are ignored. Optional. Example: hs_name,hs_budget, hs_notes
28 |
# File 'lib/hubspot_sdk/models/marketing/campaign_get_params.rb', line 28 optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String] |
#start_date ⇒ String?
The start date for fetching asset metrics, in YYYY-MM-DD format. Optional. Example: 2000-01-20
35 |
# File 'lib/hubspot_sdk/models/marketing/campaign_get_params.rb', line 35 optional :start_date, String |