Class: HubSpotSDK::Models::Marketing::Campaigns::AssetListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/marketing/campaigns/asset_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(campaign_guid:, asset_type:, after: nil, end_date: nil, limit: nil, start_date: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::Campaigns::AssetListParams for more details.

Parameters:

  • campaign_guid (String)
  • asset_type (String)
  • after (String) (defaults to: nil)

    The paging cursor token of the last successfully read resource will be returned

  • end_date (String) (defaults to: nil)

    End date to fetch asset metrics, formatted as YYYY-MM-DD. This date is used to f

  • limit (String) (defaults to: nil)

    The maximum number of results to display per page.

  • start_date (String) (defaults to: nil)

    Start date to fetch asset metrics, formatted as YYYY-MM-DD. This date is used to

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/marketing/campaigns/asset_list_params.rb', line 52

Instance Attribute Details

#afterString?

The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.

Returns:

  • (String, nil)


28
# File 'lib/hubspot_sdk/models/marketing/campaigns/asset_list_params.rb', line 28

optional :after, String

#asset_typeString

Returns:

  • (String)


20
# File 'lib/hubspot_sdk/models/marketing/campaigns/asset_list_params.rb', line 20

required :asset_type, String

#campaign_guidString

Returns:

  • (String)


15
# File 'lib/hubspot_sdk/models/marketing/campaigns/asset_list_params.rb', line 15

required :campaign_guid, String

#end_dateString?

End date to fetch asset metrics, formatted as YYYY-MM-DD. This date is used to fetch the metrics associated with the assets for a specified period. If not provided, no asset metrics will be fetched. Example: 2024-01-27

Returns:

  • (String, nil)


36
# File 'lib/hubspot_sdk/models/marketing/campaigns/asset_list_params.rb', line 36

optional :end_date, String

#limitString?

The maximum number of results to display per page.

Returns:

  • (String, nil)


42
# File 'lib/hubspot_sdk/models/marketing/campaigns/asset_list_params.rb', line 42

optional :limit, String

#start_dateString?

Start date to fetch asset metrics, formatted as YYYY-MM-DD. This date is used to fetch the metrics associated with the assets for a specified period. If not provided, no asset metrics will be fetched. Example: 2023-01-20

Returns:

  • (String, nil)


50
# File 'lib/hubspot_sdk/models/marketing/campaigns/asset_list_params.rb', line 50

optional :start_date, String