Class: HubSpotSDK::Models::Marketing::Campaigns::BatchGetParams

Inherits:
BatchInputPublicCampaignReadInput show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/marketing/campaigns/batch_get_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from BatchInputPublicCampaignReadInput

#inputs

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(end_date: nil, properties: nil, start_date: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::Campaigns::BatchGetParams for more details.

Parameters:

  • end_date (String) (defaults to: nil)

    End date to fetch asset metrics, formatted as YYYY-MM-DD. This date is used to f

  • properties (Array<String>) (defaults to: nil)

    A comma-separated list of the properties to be returned in the response. If any

  • start_date (String) (defaults to: nil)

    Start date to fetch asset metrics, formatted as YYYY-MM-DD. This date is used to

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/marketing/campaigns/batch_get_params.rb', line 38

Instance Attribute Details

#end_dateString?

End date to fetch asset metrics, formatted as YYYY-MM-DD. This date is used to fetch the metrics associated with the assets for a specified period. If not provided, no asset metrics will be fetched. Example: 2024-01-27

Returns:

  • (String, nil)


18
# File 'lib/hubspot_sdk/models/marketing/campaigns/batch_get_params.rb', line 18

optional :end_date, String

#propertiesArray<String>?

A comma-separated list of the properties to be returned in the response. If any of the specified properties has empty value on the requested object(s), they will be ignored and not returned in response. If this parameter is empty, the response will include an empty properties map. Example: hs_name, hs_campaign_status, hs_notes

Returns:

  • (Array<String>, nil)


28
# File 'lib/hubspot_sdk/models/marketing/campaigns/batch_get_params.rb', line 28

optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String]

#start_dateString?

Start date to fetch asset metrics, formatted as YYYY-MM-DD. This date is used to fetch the metrics associated with the assets for a specified period. If not provided, no asset metrics will be fetched. Example: 2023-01-20

Returns:

  • (String, nil)


36
# File 'lib/hubspot_sdk/models/marketing/campaigns/batch_get_params.rb', line 36

optional :start_date, String