Class: HubSpotSDK::Models::Marketing::Campaigns::MetricGetRevenueAttributionParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::Campaigns::MetricGetRevenueAttributionParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/marketing/campaigns/metric_get_revenue_attribution_params.rb
Overview
Instance Attribute Summary collapse
-
#attribution_model ⇒ String?
The revenue attribution model used to calculate deal revenue credit.
- #campaign_guid ⇒ String
-
#end_date ⇒ String?
End date to fetch attribution data, YYYY-MM-DD.
-
#start_date ⇒ String?
Start date to fetch attribution data, YYYY-MM-DD.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(campaign_guid:, attribution_model: nil, end_date: nil, start_date: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see MetricGetRevenueAttributionParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(campaign_guid:, attribution_model: nil, end_date: nil, start_date: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::Campaigns::MetricGetRevenueAttributionParams for more details.
|
|
# File 'lib/hubspot_sdk/models/marketing/campaigns/metric_get_revenue_attribution_params.rb', line 38
|
Instance Attribute Details
#attribution_model ⇒ String?
The revenue attribution model used to calculate deal revenue credit. Defaults to LINEAR if not specified. Enum values: LINEAR, FIRST_INTERACTION, LAST_INTERACTION, FULL_PATH, U_SHAPED, W_SHAPED, TIME_DECAY, J_SHAPED, INVERSE_J_SHAPED
24 |
# File 'lib/hubspot_sdk/models/marketing/campaigns/metric_get_revenue_attribution_params.rb', line 24 optional :attribution_model, String |
#campaign_guid ⇒ String
15 |
# File 'lib/hubspot_sdk/models/marketing/campaigns/metric_get_revenue_attribution_params.rb', line 15 required :campaign_guid, String |
#end_date ⇒ String?
End date to fetch attribution data, YYYY-MM-DD
30 |
# File 'lib/hubspot_sdk/models/marketing/campaigns/metric_get_revenue_attribution_params.rb', line 30 optional :end_date, String |
#start_date ⇒ String?
Start date to fetch attribution data, YYYY-MM-DD
36 |
# File 'lib/hubspot_sdk/models/marketing/campaigns/metric_get_revenue_attribution_params.rb', line 36 optional :start_date, String |