Class: HubSpotSDK::Models::Marketing::CollectionResponseWithTotalPublicCampaign

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/collection_response_with_total_public_campaign.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(results:, total:, paging: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::CollectionResponseWithTotalPublicCampaign for more details.

Parameters:



# File 'lib/hubspot_sdk/models/marketing/collection_response_with_total_public_campaign.rb', line 25

Instance Attribute Details

#pagingHubSpotSDK::Models::Paging?

Returns:



23
# File 'lib/hubspot_sdk/models/marketing/collection_response_with_total_public_campaign.rb', line 23

optional :paging, -> { HubSpotSDK::Paging }

#resultsArray<HubSpotSDK::Models::Marketing::PublicCampaign>

An array of PublicCampaign objects, each representing a campaign with its associated properties.



12
# File 'lib/hubspot_sdk/models/marketing/collection_response_with_total_public_campaign.rb', line 12

required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Marketing::PublicCampaign] }

#totalInteger

An integer representing the total number of public campaigns available.

Returns:

  • (Integer)


18
# File 'lib/hubspot_sdk/models/marketing/collection_response_with_total_public_campaign.rb', line 18

required :total, Integer