Class: HubSpotSDK::Models::Marketing::EmailCloneRequestVNext

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/email_clone_request_v_next.rb

Direct Known Subclasses

EmailCloneParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, clone_name: nil, language: nil) ⇒ Object

Parameters:

  • id (String)

    The email ID.

  • clone_name (String) (defaults to: nil)

    The name to assign to the cloned email.

  • language (String) (defaults to: nil)

    The language code for the cloned email, such as ‘en’ for English.



# File 'lib/hubspot_sdk/models/marketing/email_clone_request_v_next.rb', line 25

Instance Attribute Details

#clone_nameString?

The name to assign to the cloned email.

Returns:

  • (String, nil)


17
# File 'lib/hubspot_sdk/models/marketing/email_clone_request_v_next.rb', line 17

optional :clone_name, String, api_name: :cloneName

#idString

The email ID.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/marketing/email_clone_request_v_next.rb', line 11

required :id, String

#languageString?

The language code for the cloned email, such as ‘en’ for English.

Returns:

  • (String, nil)


23
# File 'lib/hubspot_sdk/models/marketing/email_clone_request_v_next.rb', line 23

optional :language, String