Class: HubSpotSDK::Models::Marketing::EmailCreateRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::EmailCreateRequest
- Defined in:
- lib/hubspot_sdk/models/marketing/email_create_request.rb
Direct Known Subclasses
Defined Under Namespace
Modules: Language, State, Subcategory
Instance Attribute Summary collapse
-
#active_domain ⇒ String?
The active domain of the email.
-
#archived ⇒ Boolean?
Determines if the email is archived or not.
-
#business_unit_id ⇒ Integer?
The ID of the business unit associated with the email.
-
#campaign ⇒ String?
The ID of the campaign this email is associated to.
- #content ⇒ HubSpotSDK::Models::Marketing::PublicEmailContent?
-
#feedback_survey_id ⇒ String?
The ID of the feedback survey linked to the email.
-
#folder_id_v2 ⇒ Integer?
The ID of the folder where the email will be stored.
- #from ⇒ HubSpotSDK::Models::Marketing::PublicEmailFromDetails?
-
#jitter_send_time ⇒ Boolean?
Determines whether the email send time should be randomized to avoid sending all emails at the exact same time.
-
#language ⇒ Symbol, ...
The language code for the email, such as ‘en’ for English.
-
#name ⇒ String?
The name of the email, as displayed on the email dashboard.
-
#publish_date ⇒ Time?
The date and time the email is scheduled for, in ISO8601 representation.
- #rss_data ⇒ HubSpotSDK::Models::Marketing::PublicRssEmailDetails?
-
#send_on_publish ⇒ Boolean?
Determines whether the email will be sent immediately on publish.
-
#state ⇒ Symbol, ...
The email state.
-
#subcategory ⇒ Symbol, ...
The email subcategory.
-
#subject ⇒ String?
The subject of the email.
- #subscription_details ⇒ HubSpotSDK::Models::Marketing::PublicEmailSubscriptionDetails?
- #testing ⇒ HubSpotSDK::Models::Marketing::PublicEmailTestingDetails?
- #to ⇒ HubSpotSDK::Models::Marketing::PublicEmailToDetails?
- #webversion ⇒ HubSpotSDK::Models::Marketing::PublicWebversionDetails?
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(active_domain: nil, archived: nil, business_unit_id: nil, campaign: nil, content: nil, feedback_survey_id: nil, folder_id_v2: nil, from: nil, jitter_send_time: nil, language: nil, name: nil, publish_date: nil, rss_data: nil, send_on_publish: nil, state: nil, subcategory: nil, subject: nil, subscription_details: nil, testing: nil, to: nil, webversion: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see EmailCreateRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(active_domain: nil, archived: nil, business_unit_id: nil, campaign: nil, content: nil, feedback_survey_id: nil, folder_id_v2: nil, from: nil, jitter_send_time: nil, language: nil, name: nil, publish_date: nil, rss_data: nil, send_on_publish: nil, state: nil, subcategory: nil, subject: nil, subscription_details: nil, testing: nil, to: nil, webversion: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::EmailCreateRequest for more details.
|
|
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 130
|
Instance Attribute Details
#active_domain ⇒ String?
The active domain of the email.
11 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 11 optional :active_domain, String, api_name: :activeDomain |
#archived ⇒ Boolean?
Determines if the email is archived or not.
17 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 17 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#business_unit_id ⇒ Integer?
The ID of the business unit associated with the email.
23 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 23 optional :business_unit_id, Integer, api_name: :businessUnitId |
#campaign ⇒ String?
The ID of the campaign this email is associated to.
29 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 29 optional :campaign, String |
#content ⇒ HubSpotSDK::Models::Marketing::PublicEmailContent?
34 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 34 optional :content, -> { HubSpotSDK::Marketing::PublicEmailContent } |
#feedback_survey_id ⇒ String?
The ID of the feedback survey linked to the email.
40 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 40 optional :feedback_survey_id, String, api_name: :feedbackSurveyId |
#folder_id_v2 ⇒ Integer?
The ID of the folder where the email will be stored.
46 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 46 optional :folder_id_v2, Integer, api_name: :folderIdV2 |
#from ⇒ HubSpotSDK::Models::Marketing::PublicEmailFromDetails?
51 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 51 optional :from, -> { HubSpotSDK::Marketing::PublicEmailFromDetails } |
#jitter_send_time ⇒ Boolean?
Determines whether the email send time should be randomized to avoid sending all emails at the exact same time.
58 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 58 optional :jitter_send_time, HubSpotSDK::Internal::Type::Boolean, api_name: :jitterSendTime |
#language ⇒ Symbol, ...
The language code for the email, such as ‘en’ for English.
64 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 64 optional :language, enum: -> { HubSpotSDK::Marketing::EmailCreateRequest::Language } |
#name ⇒ String?
The name of the email, as displayed on the email dashboard.
70 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 70 optional :name, String |
#publish_date ⇒ Time?
The date and time the email is scheduled for, in ISO8601 representation. This is only used in local time or scheduled emails.
77 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 77 optional :publish_date, Time, api_name: :publishDate |
#rss_data ⇒ HubSpotSDK::Models::Marketing::PublicRssEmailDetails?
82 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 82 optional :rss_data, -> { HubSpotSDK::Marketing::PublicRssEmailDetails }, api_name: :rssData |
#send_on_publish ⇒ Boolean?
Determines whether the email will be sent immediately on publish.
88 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 88 optional :send_on_publish, HubSpotSDK::Internal::Type::Boolean, api_name: :sendOnPublish |
#state ⇒ Symbol, ...
The email state.
94 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 94 optional :state, enum: -> { HubSpotSDK::Marketing::EmailCreateRequest::State } |
#subcategory ⇒ Symbol, ...
The email subcategory.
100 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 100 optional :subcategory, enum: -> { HubSpotSDK::Marketing::EmailCreateRequest::Subcategory } |
#subject ⇒ String?
The subject of the email.
106 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 106 optional :subject, String |
#subscription_details ⇒ HubSpotSDK::Models::Marketing::PublicEmailSubscriptionDetails?
111 112 113 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 111 optional :subscription_details, -> { HubSpotSDK::Marketing::PublicEmailSubscriptionDetails }, api_name: :subscriptionDetails |
#testing ⇒ HubSpotSDK::Models::Marketing::PublicEmailTestingDetails?
118 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 118 optional :testing, -> { HubSpotSDK::Marketing::PublicEmailTestingDetails } |
#to ⇒ HubSpotSDK::Models::Marketing::PublicEmailToDetails?
123 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 123 optional :to, -> { HubSpotSDK::Marketing::PublicEmailToDetails } |
#webversion ⇒ HubSpotSDK::Models::Marketing::PublicWebversionDetails?
128 |
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 128 optional :webversion, -> { HubSpotSDK::Marketing::PublicWebversionDetails } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/marketing/email_create_request.rb', line 1026
|