Class: HubSpotSDK::Models::Marketing::EmailListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/marketing/email_list_params.rb

Overview

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel

Instance Attribute Details

#afterString?

The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.

Returns:

  • (String, nil)


17
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 17

optional :after, String

#archivedBoolean?

Whether to return only results that have been archived.

Returns:

  • (Boolean, nil)


23
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 23

optional :archived, HubSpotSDK::Internal::Type::Boolean

#campaignString?

Returns:

  • (String, nil)


28
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 28

optional :campaign, String

#created_afterTime?

Returns:

  • (Time, nil)


33
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 33

optional :created_after, Time

#created_atTime?

Returns:

  • (Time, nil)


38
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 38

optional :created_at, Time

#created_beforeTime?

Returns:

  • (Time, nil)


43
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 43

optional :created_before, Time

#include_statsBoolean?

Returns:

  • (Boolean, nil)


53
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 53

optional :include_stats, HubSpotSDK::Internal::Type::Boolean

#included_propertiesArray<String>?

Returns:

  • (Array<String>, nil)


48
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 48

optional :included_properties, HubSpotSDK::Internal::Type::ArrayOf[String]

#is_publishedBoolean?

Returns:

  • (Boolean, nil)


58
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 58

optional :is_published, HubSpotSDK::Internal::Type::Boolean

#limitInteger?

The maximum number of results to display per page.

Returns:

  • (Integer, nil)


64
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 64

optional :limit, Integer

#marketing_campaign_namesBoolean?

Returns:

  • (Boolean, nil)


69
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 69

optional :marketing_campaign_names, HubSpotSDK::Internal::Type::Boolean

#published_afterTime?

Returns:

  • (Time, nil)


74
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 74

optional :published_after, Time

#published_atTime?

Returns:

  • (Time, nil)


79
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 79

optional :published_at, Time

#published_beforeTime?

Returns:

  • (Time, nil)


84
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 84

optional :published_before, Time

#sortArray<String>?

Returns:

  • (Array<String>, nil)


89
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 89

optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String]

#typeSymbol, ...



94
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 94

optional :type, enum: -> { HubSpotSDK::Marketing::EmailListParams::Type }

#updated_afterTime?

Returns:

  • (Time, nil)


99
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 99

optional :updated_after, Time

#updated_atTime?

Returns:

  • (Time, nil)


104
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 104

optional :updated_at, Time

#updated_beforeTime?

Returns:

  • (Time, nil)


109
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 109

optional :updated_before, Time

#variant_statsBoolean?

Returns:

  • (Boolean, nil)


114
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 114

optional :variant_stats, HubSpotSDK::Internal::Type::Boolean

#workflow_namesBoolean?

Returns:

  • (Boolean, nil)


119
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 119

optional :workflow_names, HubSpotSDK::Internal::Type::Boolean