Class: HubSpotSDK::Models::Marketing::EmailUpdateParams
- Inherits:
-
EmailUpdateRequest
- Object
- Internal::Type::BaseModel
- EmailUpdateRequest
- HubSpotSDK::Models::Marketing::EmailUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/marketing/email_update_params.rb
Overview
Instance Attribute Summary collapse
- #email_id ⇒ String
-
#query_archived ⇒ Boolean?
Whether to return only results that have been archived.
Attributes included from Internal::Type::RequestParameters
Attributes inherited from EmailUpdateRequest
#active_domain, #archived, #business_unit_id, #campaign, #content, #folder_id_v2, #from, #jitter_send_time, #language, #name, #publish_date, #rss_data, #send_on_publish, #state, #subcategory, #subject, #subscription_details, #testing, #to, #webversion
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from EmailUpdateRequest
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(email_id:, query_archived: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/marketing/email_update_params.rb', line 22
|
Instance Attribute Details
#email_id ⇒ String
14 |
# File 'lib/hubspot_sdk/models/marketing/email_update_params.rb', line 14 required :email_id, String |
#query_archived ⇒ Boolean?
Whether to return only results that have been archived.
20 |
# File 'lib/hubspot_sdk/models/marketing/email_update_params.rb', line 20 optional :query_archived, HubSpotSDK::Internal::Type::Boolean |