Class: HubSpotSDK::Models::Marketing::EventDetailSettingsURL

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/event_detail_settings_url.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_details_url:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::EventDetailSettingsURL for more details.

Parameters:

  • event_details_url (String)

    The url that will be used to fetch marketing event details by id. Must contain a



# File 'lib/hubspot_sdk/models/marketing/event_detail_settings_url.rb', line 15

Instance Attribute Details

#event_details_urlString

The url that will be used to fetch marketing event details by id. Must contain a ‘%s` character sequence that will be substituted with the event id. For example: `my.event.app/events/%s`

Returns:

  • (String)


13
# File 'lib/hubspot_sdk/models/marketing/event_detail_settings_url.rb', line 13

required :event_details_url, String, api_name: :eventDetailsUrl