Class: HubSpotSDK::Models::Marketing::MarketingEventAssociation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/marketing_event_association.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel

Instance Attribute Details

#external_account_idString?

The account ID that is associated with this marketing event in the external event application

Returns:

  • (String, nil)


24
# File 'lib/hubspot_sdk/models/marketing/marketing_event_association.rb', line 24

optional :external_account_id, String, api_name: :externalAccountId

#external_event_idString?

The event ID that is associated with this marketing event in the external event application

Returns:

  • (String, nil)


31
# File 'lib/hubspot_sdk/models/marketing/marketing_event_association.rb', line 31

optional :external_event_id, String, api_name: :externalEventId

#marketing_event_idString

The internal ID of the marketing event in HubSpot

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/marketing/marketing_event_association.rb', line 11

required :marketing_event_id, String, api_name: :marketingEventId

#nameString

The name of the marketing event in HubSpot

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/marketing/marketing_event_association.rb', line 17

required :name, String