Class: HubSpotSDK::Models::Marketing::MarketingEventEmailSubscriber
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::MarketingEventEmailSubscriber
- Defined in:
- lib/hubspot_sdk/models/marketing/marketing_event_email_subscriber.rb
Instance Attribute Summary collapse
-
#contact_properties ⇒ Hash{Symbol=>String}
The key-value set that contains properties of the contact.
-
#email ⇒ String
The email address of the contact in HubSpot to associate with the event.
-
#interaction_date_time ⇒ Integer
Timestamp in milliseconds at which the contact subscribed to the event.
-
#properties ⇒ Hash{Symbol=>String}
The key-value set that contains properties of the marketing event.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#contact_properties ⇒ Hash{Symbol=>String}
The key-value set that contains properties of the contact.
11 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_email_subscriber.rb', line 11 required :contact_properties, HubSpotSDK::Internal::Type::HashOf[String], api_name: :contactProperties |
#email ⇒ String
The email address of the contact in HubSpot to associate with the event.
17 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_email_subscriber.rb', line 17 required :email, String |
#interaction_date_time ⇒ Integer
Timestamp in milliseconds at which the contact subscribed to the event.
23 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_email_subscriber.rb', line 23 required :interaction_date_time, Integer, api_name: :interactionDateTime |
#properties ⇒ Hash{Symbol=>String}
The key-value set that contains properties of the marketing event.
29 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_email_subscriber.rb', line 29 required :properties, HubSpotSDK::Internal::Type::HashOf[String] |