Class: HubSpotSDK::Models::Marketing::MarketingEventExternalUniqueIdentifier
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::MarketingEventExternalUniqueIdentifier
- Defined in:
- lib/hubspot_sdk/models/marketing/marketing_event_external_unique_identifier.rb
Instance Attribute Summary collapse
-
#app_id ⇒ Integer
The id of the application that created the marketing event in HubSpot.
-
#external_account_id ⇒ String
The accountId that is associated with this marketing event in the external event application.
-
#external_event_id ⇒ String
The id of the marketing event in the external event application.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#app_id ⇒ Integer
The id of the application that created the marketing event in HubSpot.
11 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_external_unique_identifier.rb', line 11 required :app_id, Integer, api_name: :appId |
#external_account_id ⇒ String
The accountId that is associated with this marketing event in the external event application.
18 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_external_unique_identifier.rb', line 18 required :external_account_id, String, api_name: :externalAccountId |
#external_event_id ⇒ String
The id of the marketing event in the external event application.
24 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_external_unique_identifier.rb', line 24 required :external_event_id, String, api_name: :externalEventId |