Class: HubSpotSDK::Models::Marketing::MarketingEventIdentifiersResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::MarketingEventIdentifiersResponse
- Defined in:
- lib/hubspot_sdk/models/marketing/marketing_event_identifiers_response.rb
Instance Attribute Summary collapse
- #app_info ⇒ HubSpotSDK::Models::Marketing::AppInfo?
-
#external_account_id ⇒ String?
The accountId that is associated with this marketing event in the external event application.
-
#external_event_id ⇒ String
The ID that is associated with this marketing event in the external event application.
-
#marketing_event_name ⇒ String
The name of the marketing event.
-
#object_id_ ⇒ String
The internal ID of the marketing event in HubSpot CRM.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#app_info ⇒ HubSpotSDK::Models::Marketing::AppInfo?
29 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_identifiers_response.rb', line 29 optional :app_info, -> { HubSpotSDK::Marketing::AppInfo }, api_name: :appInfo |
#external_account_id ⇒ String?
The accountId that is associated with this marketing event in the external event application
36 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_identifiers_response.rb', line 36 optional :external_account_id, String, api_name: :externalAccountId |
#external_event_id ⇒ String
The ID that is associated with this marketing event in the external event application
12 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_identifiers_response.rb', line 12 required :external_event_id, String, api_name: :externalEventId |
#marketing_event_name ⇒ String
The name of the marketing event
18 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_identifiers_response.rb', line 18 required :marketing_event_name, String, api_name: :marketingEventName |
#object_id_ ⇒ String
The internal ID of the marketing event in HubSpot CRM
24 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_identifiers_response.rb', line 24 required :object_id_, String, api_name: :objectId |