Class: HubSpotSDK::Models::Marketing::MarketingEventPublicReadResponseV2

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb

Overview

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel

Instance Attribute Details

#app_infoHubSpotSDK::Models::Marketing::AppInfo?



42
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 42

optional :app_info, -> { HubSpotSDK::Marketing::AppInfo }, api_name: :appInfo

#attendeesInteger?

Number of attended contact records of a marketing event

Returns:

  • (Integer, nil)


48
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 48

optional :attendees, Integer

#cancellationsInteger?

Number of cancelled contact records of a marketing event

Returns:

  • (Integer, nil)


54
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 54

optional :cancellations, Integer

#created_atTime

The creation date and time of the marketing event

Returns:

  • (Time)


12
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 12

required :created_at, Time, api_name: :createdAt

#custom_propertiesArray<HubSpotSDK::Models::Marketing::CrmPropertyWrapper>



17
18
19
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 17

required :custom_properties,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Marketing::CrmPropertyWrapper] },
api_name: :customProperties

#end_date_timeTime?

The end date and time of the marketing event

Returns:

  • (Time, nil)


60
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 60

optional :end_date_time, Time, api_name: :endDateTime

#event_cancelledBoolean?

Indicates if the marketing event has been cancelled

Returns:

  • (Boolean, nil)


66
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 66

optional :event_cancelled, HubSpotSDK::Internal::Type::Boolean, api_name: :eventCancelled

#event_completedBoolean?

Indicates if the marketing event has been completed

Returns:

  • (Boolean, nil)


72
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 72

optional :event_completed, HubSpotSDK::Internal::Type::Boolean, api_name: :eventCompleted

#event_descriptionString?

The description of the marketing event

Returns:

  • (String, nil)


78
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 78

optional :event_description, String, api_name: :eventDescription

#event_nameString

The name of the marketing event

Returns:

  • (String)


25
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 25

required :event_name, String, api_name: :eventName

#event_organizerString?

The name of the organizer of the marketing event

Returns:

  • (String, nil)


84
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 84

optional :event_organizer, String, api_name: :eventOrganizer

#event_statusString?

The status of the marketing event

Returns:

  • (String, nil)


90
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 90

optional :event_status, String, api_name: :eventStatus

#event_status_v2String?

Returns:

  • (String, nil)


95
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 95

optional :event_status_v2, String, api_name: :eventStatusV2

#event_typeString?

The type of the marketing event

Returns:

  • (String, nil)


101
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 101

optional :event_type, String, api_name: :eventType

#event_urlString?

A URL in the external event application where the marketing event can be managed

Returns:

  • (String, nil)


107
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 107

optional :event_url, String, api_name: :eventUrl

#external_event_idString?

The ID that is associated with this marketing event in the external event application

Returns:

  • (String, nil)


114
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 114

optional :external_event_id, String, api_name: :externalEventId

#no_showsInteger?

Number of no-show contact records of a marketing event

Returns:

  • (Integer, nil)


120
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 120

optional :no_shows, Integer, api_name: :noShows

#object_id_String

The internal ID of the marketing event in HubSpot

Returns:

  • (String)


31
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 31

required :object_id_, String, api_name: :objectId

#registrantsInteger?

Number of registered contact records of a marketing event

Returns:

  • (Integer, nil)


126
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 126

optional :registrants, Integer

#start_date_timeTime?

The start date and time of the marketing event

Returns:

  • (Time, nil)


132
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 132

optional :start_date_time, Time, api_name: :startDateTime

#updated_atTime

The update date and time of the marketing event

Returns:

  • (Time)


37
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response_v2.rb', line 37

required :updated_at, Time, api_name: :updatedAt