Class: HubSpotSDK::Models::Marketing::MarketingEventPublicUpdateRequestFullV2

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel

Instance Attribute Details

#custom_propertiesArray<HubSpotSDK::Models::PropertyValue>



10
11
12
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 10

required :custom_properties,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::PropertyValue] },
api_name: :customProperties

#end_date_timeTime?

The end date and time of the marketing event

Returns:

  • (Time, nil)


24
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 24

optional :end_date_time, Time, api_name: :endDateTime

#event_cancelledBoolean?

Indicates if the marketing event has been cancelled

Returns:

  • (Boolean, nil)


30
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 30

optional :event_cancelled, HubSpotSDK::Internal::Type::Boolean, api_name: :eventCancelled

#event_descriptionString?

The description of the marketing event

Returns:

  • (String, nil)


36
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 36

optional :event_description, String, api_name: :eventDescription

#event_nameString?

The name of the marketing event

Returns:

  • (String, nil)


42
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 42

optional :event_name, String, api_name: :eventName

#event_organizerString?

The name of the organizer of the marketing event

Returns:

  • (String, nil)


48
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 48

optional :event_organizer, String, api_name: :eventOrganizer

#event_typeString?

The type of the marketing event

Returns:

  • (String, nil)


54
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 54

optional :event_type, String, api_name: :eventType

#event_urlString?

A URL in the external event application where the marketing event can be managed

Returns:

  • (String, nil)


60
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 60

optional :event_url, String, api_name: :eventUrl

#object_id_String

The internal ID of the marketing event in HubSpot

Returns:

  • (String)


18
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 18

required :object_id_, String, api_name: :objectId

#start_date_timeTime?

The start date and time of the marketing event

Returns:

  • (Time, nil)


66
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 66

optional :start_date_time, Time, api_name: :startDateTime