Class: HubSpotSDK::Models::Marketing::MarketingEventUpdateRequestParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/marketing_event_update_request_params.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel

Instance Attribute Details

#custom_propertiesArray<HubSpotSDK::Models::PropertyValue>

A list of PropertyValues. These can be whatever kind of property names and values you want. However, they must already exist on the HubSpot account’s definition of the MarketingEvent Object. If they don’t they will be filtered out and not set. In order to do this you’ll need to create a new PropertyGroup on the HubSpot account’s MarketingEvent object for your specific app and create the Custom Property you want to track on that HubSpot account. Do not create any new default properties on the MarketingEvent object as that will apply to all HubSpot accounts.



18
19
20
# File 'lib/hubspot_sdk/models/marketing/marketing_event_update_request_params.rb', line 18

required :custom_properties,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::PropertyValue] },
api_name: :customProperties

#end_date_timeTime?

The end date and time of the marketing event.

Returns:

  • (Time, nil)


26
# File 'lib/hubspot_sdk/models/marketing/marketing_event_update_request_params.rb', line 26

optional :end_date_time, Time, api_name: :endDateTime

#event_cancelledBoolean?

Indicates if the marketing event has been cancelled. Defaults to ‘false`

Returns:

  • (Boolean, nil)


32
# File 'lib/hubspot_sdk/models/marketing/marketing_event_update_request_params.rb', line 32

optional :event_cancelled, HubSpotSDK::Internal::Type::Boolean, api_name: :eventCancelled

#event_completedBoolean?

Indicates if the marketing event has been completed. Defaults to ‘false`

Returns:

  • (Boolean, nil)


38
# File 'lib/hubspot_sdk/models/marketing/marketing_event_update_request_params.rb', line 38

optional :event_completed, HubSpotSDK::Internal::Type::Boolean, api_name: :eventCompleted

#event_descriptionString?

The description of the marketing event.

Returns:

  • (String, nil)


44
# File 'lib/hubspot_sdk/models/marketing/marketing_event_update_request_params.rb', line 44

optional :event_description, String, api_name: :eventDescription

#event_nameString?

The name of the marketing event.

Returns:

  • (String, nil)


50
# File 'lib/hubspot_sdk/models/marketing/marketing_event_update_request_params.rb', line 50

optional :event_name, String, api_name: :eventName

#event_organizerString?

The name of the organizer of the marketing event.

Returns:

  • (String, nil)


56
# File 'lib/hubspot_sdk/models/marketing/marketing_event_update_request_params.rb', line 56

optional :event_organizer, String, api_name: :eventOrganizer

#event_typeString?

Describes what type of event this is. For example: ‘WEBINAR`, `CONFERENCE`, `WORKSHOP`

Returns:

  • (String, nil)


63
# File 'lib/hubspot_sdk/models/marketing/marketing_event_update_request_params.rb', line 63

optional :event_type, String, api_name: :eventType

#event_urlString?

A URL in the external event application where the marketing event can be managed.

Returns:

  • (String, nil)


70
# File 'lib/hubspot_sdk/models/marketing/marketing_event_update_request_params.rb', line 70

optional :event_url, String, api_name: :eventUrl

#start_date_timeTime?

The start date and time of the marketing event.

Returns:

  • (Time, nil)


76
# File 'lib/hubspot_sdk/models/marketing/marketing_event_update_request_params.rb', line 76

optional :start_date_time, Time, api_name: :startDateTime