Class: HubSpotSDK::Models::Marketing::MarketingEvents::ParticipationListBreakdownByContactParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_contact_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(contact_identifier:, after: nil, limit: nil, state: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::MarketingEvents::ParticipationListBreakdownByContactParams for more details.

Parameters:

  • contact_identifier (String)
  • after (String) (defaults to: nil)

    The cursor indicating the position of the last retrieved item.

  • limit (Integer) (defaults to: nil)

    The limit for response size. The default value is 10, the max number is 100

  • state (String) (defaults to: nil)

    The participation state value. It may be REGISTERED, CANCELLED, ATTENDED, NO_SHO

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_contact_params.rb', line 36

Instance Attribute Details

#afterString?

The cursor indicating the position of the last retrieved item.

Returns:

  • (String, nil)


21
# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_contact_params.rb', line 21

optional :after, String

#contact_identifierString

Returns:

  • (String)


15
# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_contact_params.rb', line 15

required :contact_identifier, String

#limitInteger?

The limit for response size. The default value is 10, the max number is 100

Returns:

  • (Integer, nil)


27
# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_contact_params.rb', line 27

optional :limit, Integer

#stateString?

The participation state value. It may be REGISTERED, CANCELLED, ATTENDED, NO_SHOW

Returns:

  • (String, nil)


34
# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_contact_params.rb', line 34

optional :state, String