Class: HubSpotSDK::Models::Marketing::MarketingEvents::ParticipationListBreakdownByExternalAccountAndEventIDParams

Inherits:
Internal::Type::BaseModel
  • Object
show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_external_account_and_event_id_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(external_account_id:, external_event_id:, after: nil, contact_identifier: nil, limit: nil, state: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::MarketingEvents::ParticipationListBreakdownByExternalAccountAndEventIDParams for more details.

Parameters:

  • external_account_id (String)
  • external_event_id (String)
  • after (String) (defaults to: nil)

    The cursor indicating the position of the last retrieved item.

  • contact_identifier (String) (defaults to: nil)

    The identifier of the Contact. It may be email or internal id.

  • limit (Integer) (defaults to: nil)

    The limit for response size. The default value is 10, the max number is 100

  • state (String) (defaults to: nil)

    The participation state value. It may be REGISTERED, CANCELLED, ATTENDED, NO_SHO

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_external_account_and_event_id_params.rb', line 47

Instance Attribute Details

#afterString?

The cursor indicating the position of the last retrieved item.

Returns:

  • (String, nil)


26
# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_external_account_and_event_id_params.rb', line 26

optional :after, String

#contact_identifierString?

The identifier of the Contact. It may be email or internal id.

Returns:

  • (String, nil)


32
# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_external_account_and_event_id_params.rb', line 32

optional :contact_identifier, String

#external_account_idString

Returns:

  • (String)


15
# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_external_account_and_event_id_params.rb', line 15

required :external_account_id, String

#external_event_idString

Returns:

  • (String)


20
# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_external_account_and_event_id_params.rb', line 20

required :external_event_id, String

#limitInteger?

The limit for response size. The default value is 10, the max number is 100

Returns:

  • (Integer, nil)


38
# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_external_account_and_event_id_params.rb', line 38

optional :limit, Integer

#stateString?

The participation state value. It may be REGISTERED, CANCELLED, ATTENDED, NO_SHOW

Returns:

  • (String, nil)


45
# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_external_account_and_event_id_params.rb', line 45

optional :state, String