Class: HubSpotSDK::Models::Marketing::MarketingEvents::ParticipationListBreakdownByIDParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::MarketingEvents::ParticipationListBreakdownByIDParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_id_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
The cursor indicating the position of the last retrieved item.
-
#contact_identifier ⇒ String?
The identifier of the Contact.
-
#limit ⇒ Integer?
The limit for response size.
- #marketing_event_id ⇒ Integer
-
#state ⇒ String?
The participation state value.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(marketing_event_id:, after: nil, contact_identifier: nil, limit: nil, state: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ParticipationListBreakdownByIDParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(marketing_event_id:, after: nil, contact_identifier: nil, limit: nil, state: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::MarketingEvents::ParticipationListBreakdownByIDParams for more details.
|
|
# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_id_params.rb', line 42
|
Instance Attribute Details
#after ⇒ String?
The cursor indicating the position of the last retrieved item.
21 |
# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_id_params.rb', line 21 optional :after, String |
#contact_identifier ⇒ String?
The identifier of the Contact. It may be email or internal id.
27 |
# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_id_params.rb', line 27 optional :contact_identifier, String |
#limit ⇒ Integer?
The limit for response size. The default value is 10, the max number is 100
33 |
# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_id_params.rb', line 33 optional :limit, Integer |
#marketing_event_id ⇒ Integer
15 |
# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_id_params.rb', line 15 required :marketing_event_id, Integer |
#state ⇒ String?
The participation state value. It may be REGISTERED, CANCELLED, ATTENDED, NO_SHOW
40 |
# File 'lib/hubspot_sdk/models/marketing/marketing_events/participation_list_breakdown_by_id_params.rb', line 40 optional :state, String |