Class: HubSpotSDK::Models::Marketing::MetricsCounters
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::MetricsCounters
- Defined in:
- lib/hubspot_sdk/models/marketing/metrics_counters.rb
Instance Attribute Summary collapse
-
#influenced_contacts ⇒ Integer
The number of contacts influenced by the campaign.
-
#new_contacts_first_touch ⇒ Integer
The number of new contacts attributed to the campaign as the first touchpoint.
-
#new_contacts_last_touch ⇒ Integer
The number of new contacts attributed to the campaign as the last touchpoint.
-
#sessions ⇒ Integer
The total number of sessions generated by the campaign.
Instance Method Summary collapse
- #initialize(influenced_contacts:, new_contacts_first_touch:, new_contacts_last_touch:, sessions:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(influenced_contacts:, new_contacts_first_touch:, new_contacts_last_touch:, sessions:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/marketing/metrics_counters.rb', line 31
|
Instance Attribute Details
#influenced_contacts ⇒ Integer
The number of contacts influenced by the campaign.
11 |
# File 'lib/hubspot_sdk/models/marketing/metrics_counters.rb', line 11 required :influenced_contacts, Integer, api_name: :influencedContacts |
#new_contacts_first_touch ⇒ Integer
The number of new contacts attributed to the campaign as the first touchpoint.
17 |
# File 'lib/hubspot_sdk/models/marketing/metrics_counters.rb', line 17 required :new_contacts_first_touch, Integer, api_name: :newContactsFirstTouch |
#new_contacts_last_touch ⇒ Integer
The number of new contacts attributed to the campaign as the last touchpoint.
23 |
# File 'lib/hubspot_sdk/models/marketing/metrics_counters.rb', line 23 required :new_contacts_last_touch, Integer, api_name: :newContactsLastTouch |
#sessions ⇒ Integer
The total number of sessions generated by the campaign.
29 |
# File 'lib/hubspot_sdk/models/marketing/metrics_counters.rb', line 29 required :sessions, Integer |