Class: HubSpotSDK::Models::Marketing::ParticipationBreakdown
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::ParticipationBreakdown
- Defined in:
- lib/hubspot_sdk/models/marketing/participation_breakdown.rb
Instance Attribute Summary collapse
- #associations ⇒ HubSpotSDK::Models::Marketing::ParticipationAssociations
-
#created_at ⇒ Time
The creation time and date of the target marketing event.
-
#id ⇒ String
The internal ID of the target marketing event.
- #properties ⇒ HubSpotSDK::Models::Marketing::ParticipationProperties
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, associations:, created_at:, properties:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/marketing/participation_breakdown.rb', line 29
|
Instance Attribute Details
#associations ⇒ HubSpotSDK::Models::Marketing::ParticipationAssociations
16 |
# File 'lib/hubspot_sdk/models/marketing/participation_breakdown.rb', line 16 required :associations, -> { HubSpotSDK::Marketing::ParticipationAssociations } |
#created_at ⇒ Time
The creation time and date of the target marketing event
22 |
# File 'lib/hubspot_sdk/models/marketing/participation_breakdown.rb', line 22 required :created_at, Time, api_name: :createdAt |
#id ⇒ String
The internal ID of the target marketing event
11 |
# File 'lib/hubspot_sdk/models/marketing/participation_breakdown.rb', line 11 required :id, String |
#properties ⇒ HubSpotSDK::Models::Marketing::ParticipationProperties
27 |
# File 'lib/hubspot_sdk/models/marketing/participation_breakdown.rb', line 27 required :properties, -> { HubSpotSDK::Marketing::ParticipationProperties } |