Class: HubSpotSDK::Models::Marketing::PublicBudgetItemInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::PublicBudgetItemInput
- Defined in:
- lib/hubspot_sdk/models/marketing/public_budget_item_input.rb
Direct Known Subclasses
Campaigns::BudgetCreateParams, Campaigns::BudgetUpdateParams
Instance Attribute Summary collapse
-
#amount ⇒ Float
The monetary value assigned to the budget item.
-
#description ⇒ String?
A detailed explanation or notes about the budget item.
-
#name ⇒ String
The name of the budget item.
-
#order ⇒ Integer
The sequence number indicating the order of the budget item.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, name:, order:, description: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/marketing/public_budget_item_input.rb', line 31
|
Instance Attribute Details
#amount ⇒ Float
The monetary value assigned to the budget item.
11 |
# File 'lib/hubspot_sdk/models/marketing/public_budget_item_input.rb', line 11 required :amount, Float |
#description ⇒ String?
A detailed explanation or notes about the budget item.
29 |
# File 'lib/hubspot_sdk/models/marketing/public_budget_item_input.rb', line 29 optional :description, String |
#name ⇒ String
The name of the budget item.
17 |
# File 'lib/hubspot_sdk/models/marketing/public_budget_item_input.rb', line 17 required :name, String |
#order ⇒ Integer
The sequence number indicating the order of the budget item.
23 |
# File 'lib/hubspot_sdk/models/marketing/public_budget_item_input.rb', line 23 required :order, Integer |