Class: HubSpotSDK::Models::Marketing::PublicBudgetTotals

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/public_budget_totals.rb

Defined Under Namespace

Modules: CurrencyCode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(budget_items:, currency_code:, spend_items:, budget_total: nil, remaining_budget: nil, spend_total: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::PublicBudgetTotals for more details.

Parameters:

  • budget_items (Array<HubSpotSDK::Models::Marketing::PublicBudgetItem>)

    An array of budget items associated with the campaign. Each item is represented

  • currency_code (Symbol, HubSpotSDK::Models::Marketing::PublicBudgetTotals::CurrencyCode)

    The currency code used for the budget and spend amounts, following ISO 4217 stan

  • spend_items (Array<HubSpotSDK::Models::Marketing::PublicSpendItem>)

    An array of spend items associated with the campaign. Each item is represented b

  • budget_total (Float) (defaults to: nil)

    The total budget allocated for the campaign.

  • remaining_budget (Float) (defaults to: nil)

    The remaining budget available for the campaign after accounting for all spend i

  • spend_total (Float) (defaults to: nil)

    The total amount spent across all spend items in the campaign.



# File 'lib/hubspot_sdk/models/marketing/public_budget_totals.rb', line 53

Instance Attribute Details

#budget_itemsArray<HubSpotSDK::Models::Marketing::PublicBudgetItem>

An array of budget items associated with the campaign. Each item is represented by a PublicBudgetItem object.



12
13
14
# File 'lib/hubspot_sdk/models/marketing/public_budget_totals.rb', line 12

required :budget_items,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Marketing::PublicBudgetItem] },
api_name: :budgetItems

#budget_totalFloat?

The total budget allocated for the campaign.

Returns:

  • (Float, nil)


38
# File 'lib/hubspot_sdk/models/marketing/public_budget_totals.rb', line 38

optional :budget_total, Float, api_name: :budgetTotal

#currency_codeSymbol, HubSpotSDK::Models::Marketing::PublicBudgetTotals::CurrencyCode

The currency code used for the budget and spend amounts, following ISO 4217 standards.



21
22
23
# File 'lib/hubspot_sdk/models/marketing/public_budget_totals.rb', line 21

required :currency_code,
enum: -> { HubSpotSDK::Marketing::PublicBudgetTotals::CurrencyCode },
api_name: :currencyCode

#remaining_budgetFloat?

The remaining budget available for the campaign after accounting for all spend items.

Returns:

  • (Float, nil)


45
# File 'lib/hubspot_sdk/models/marketing/public_budget_totals.rb', line 45

optional :remaining_budget, Float, api_name: :remainingBudget

#spend_itemsArray<HubSpotSDK::Models::Marketing::PublicSpendItem>

An array of spend items associated with the campaign. Each item is represented by a PublicSpendItem object.



30
31
32
# File 'lib/hubspot_sdk/models/marketing/public_budget_totals.rb', line 30

required :spend_items,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Marketing::PublicSpendItem] },
api_name: :spendItems

#spend_totalFloat?

The total amount spent across all spend items in the campaign.

Returns:

  • (Float, nil)


51
# File 'lib/hubspot_sdk/models/marketing/public_budget_totals.rb', line 51

optional :spend_total, Float, api_name: :spendTotal