Class: HubSpotSDK::Models::Marketing::PublicCampaign

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/public_campaign.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, business_units:, created_at:, properties:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::PublicCampaign for more details.

Parameters:

  • id (String)

    The unique identifier for the campaign.

  • business_units (Array<HubSpotSDK::Models::Marketing::PublicBusinessUnit>)

    An array of business units associated with the campaign, each represented by a P

  • created_at (Time)

    The date and time when the campaign was created, formatted as a date-time string

  • properties (Hash{Symbol=>String})

    A collection of key-value pairs representing additional properties of the campai

  • updated_at (Time)

    The date and time when the campaign was last updated, formatted as a date-time s



# File 'lib/hubspot_sdk/models/marketing/public_campaign.rb', line 44

Instance Attribute Details

#business_unitsArray<HubSpotSDK::Models::Marketing::PublicBusinessUnit>

An array of business units associated with the campaign, each represented by a PublicBusinessUnit object.



19
20
21
# File 'lib/hubspot_sdk/models/marketing/public_campaign.rb', line 19

required :business_units,
-> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Marketing::PublicBusinessUnit] },
api_name: :businessUnits

#created_atTime

The date and time when the campaign was created, formatted as a date-time string.

Returns:

  • (Time)


28
# File 'lib/hubspot_sdk/models/marketing/public_campaign.rb', line 28

required :created_at, Time, api_name: :createdAt

#idString

The unique identifier for the campaign.

Returns:

  • (String)


12
# File 'lib/hubspot_sdk/models/marketing/public_campaign.rb', line 12

required :id, String

#propertiesHash{Symbol=>String}

A collection of key-value pairs representing additional properties of the campaign.

Returns:

  • (Hash{Symbol=>String})


35
# File 'lib/hubspot_sdk/models/marketing/public_campaign.rb', line 35

required :properties, HubSpotSDK::Internal::Type::HashOf[String]

#updated_atTime

The date and time when the campaign was last updated, formatted as a date-time string.

Returns:

  • (Time)


42
# File 'lib/hubspot_sdk/models/marketing/public_campaign.rb', line 42

required :updated_at, Time, api_name: :updatedAt