Class: HubSpotSDK::Models::Marketing::PublicCampaignAsset

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/public_campaign_asset.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, metrics: nil, name: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::PublicCampaignAsset for more details.

Parameters:

  • id (String)

    The unique identifier for the campaign asset.

  • metrics (Hash{Symbol=>Float}) (defaults to: nil)

    A collection of metrics associated with the campaign asset, represented as key-v

  • name (String) (defaults to: nil)

    The name of the campaign asset.



# File 'lib/hubspot_sdk/models/marketing/public_campaign_asset.rb', line 26

Instance Attribute Details

#idString

The unique identifier for the campaign asset.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/marketing/public_campaign_asset.rb', line 11

required :id, String

#metricsHash{Symbol=>Float}?

A collection of metrics associated with the campaign asset, represented as key-value pairs.

Returns:

  • (Hash{Symbol=>Float}, nil)


18
# File 'lib/hubspot_sdk/models/marketing/public_campaign_asset.rb', line 18

optional :metrics, HubSpotSDK::Internal::Type::HashOf[Float]

#nameString?

The name of the campaign asset.

Returns:

  • (String, nil)


24
# File 'lib/hubspot_sdk/models/marketing/public_campaign_asset.rb', line 24

optional :name, String