Class: HubSpotSDK::Models::Marketing::PublicCampaignBatchUpdateItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::PublicCampaignBatchUpdateItem
- Defined in:
- lib/hubspot_sdk/models/marketing/public_campaign_batch_update_item.rb
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the campaign to be updated.
-
#properties ⇒ Hash{Symbol=>String}
A set of key-value pairs representing the properties to be updated for the campaign.
Instance Method Summary collapse
-
#initialize(id:, properties:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicCampaignBatchUpdateItem for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, properties:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::PublicCampaignBatchUpdateItem for more details.
|
|
# File 'lib/hubspot_sdk/models/marketing/public_campaign_batch_update_item.rb', line 20
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the campaign to be updated.
11 |
# File 'lib/hubspot_sdk/models/marketing/public_campaign_batch_update_item.rb', line 11 required :id, String |
#properties ⇒ Hash{Symbol=>String}
A set of key-value pairs representing the properties to be updated for the campaign.
18 |
# File 'lib/hubspot_sdk/models/marketing/public_campaign_batch_update_item.rb', line 18 required :properties, HubSpotSDK::Internal::Type::HashOf[String] |