Class: HubSpotSDK::Models::Marketing::PublicCampaignWithAssets
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::PublicCampaignWithAssets
- Defined in:
- lib/hubspot_sdk/models/marketing/public_campaign_with_assets.rb
Overview
Instance Attribute Summary collapse
-
#assets ⇒ Hash{Symbol=>HubSpotSDK::Models::Marketing::CollectionResponsePublicCampaignAsset}
Contains the assets associated with the campaign, each represented as a collection of campaign assets.
-
#business_units ⇒ Array<HubSpotSDK::Models::Marketing::PublicBusinessUnit>
An array of business units associated with the campaign, each represented by a PublicBusinessUnit object.
-
#created_at ⇒ Time
The date and time when the campaign was created, formatted as a date-time string.
-
#id ⇒ String
The unique identifier for the campaign.
-
#properties ⇒ Hash{Symbol=>String}
A map of key-value pairs representing the properties of the campaign.
-
#updated_at ⇒ Time
The date and time when the campaign was last updated, formatted as a date-time string.
Instance Method Summary collapse
-
#initialize(id:, assets:, business_units:, created_at:, properties:, updated_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicCampaignWithAssets for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, assets:, business_units:, created_at:, properties:, updated_at:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::PublicCampaignWithAssets for more details.
|
|
# File 'lib/hubspot_sdk/models/marketing/public_campaign_with_assets.rb', line 51
|
Instance Attribute Details
#assets ⇒ Hash{Symbol=>HubSpotSDK::Models::Marketing::CollectionResponsePublicCampaignAsset}
Contains the assets associated with the campaign, each represented as a collection of campaign assets.
19 20 |
# File 'lib/hubspot_sdk/models/marketing/public_campaign_with_assets.rb', line 19 required :assets, -> { HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Marketing::CollectionResponsePublicCampaignAsset] } |
#business_units ⇒ Array<HubSpotSDK::Models::Marketing::PublicBusinessUnit>
An array of business units associated with the campaign, each represented by a PublicBusinessUnit object.
27 28 29 |
# File 'lib/hubspot_sdk/models/marketing/public_campaign_with_assets.rb', line 27 required :business_units, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Marketing::PublicBusinessUnit] }, api_name: :businessUnits |
#created_at ⇒ Time
The date and time when the campaign was created, formatted as a date-time string.
36 |
# File 'lib/hubspot_sdk/models/marketing/public_campaign_with_assets.rb', line 36 required :created_at, Time, api_name: :createdAt |
#id ⇒ String
The unique identifier for the campaign.
12 |
# File 'lib/hubspot_sdk/models/marketing/public_campaign_with_assets.rb', line 12 required :id, String |
#properties ⇒ Hash{Symbol=>String}
A map of key-value pairs representing the properties of the campaign.
42 |
# File 'lib/hubspot_sdk/models/marketing/public_campaign_with_assets.rb', line 42 required :properties, HubSpotSDK::Internal::Type::HashOf[String] |
#updated_at ⇒ Time
The date and time when the campaign was last updated, formatted as a date-time string.
49 |
# File 'lib/hubspot_sdk/models/marketing/public_campaign_with_assets.rb', line 49 required :updated_at, Time, api_name: :updatedAt |