Class: HubSpotSDK::Models::Marketing::PublicEmail
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::PublicEmail
- Defined in:
- lib/hubspot_sdk/models/marketing/public_email.rb
Overview
Defined Under Namespace
Modules: EmailTemplateMode, Language, State, Type
Instance Attribute Summary collapse
-
#active_domain ⇒ String?
The active domain of the email.
-
#all_email_campaign_ids ⇒ Array<String>?
List of emailCampaignIds.
-
#archived ⇒ Boolean?
Determines if the email is archived or not.
- #business_unit_id ⇒ String?
-
#campaign ⇒ String?
The ID of the campaign this email is associated to.
-
#campaign_name ⇒ String?
The name of the campaign.
- #campaign_utm ⇒ String?
-
#cloned_from ⇒ String?
The ID of the email this email was cloned from.
- #content ⇒ HubSpotSDK::Models::Marketing::PublicEmailContent?
-
#created_at ⇒ Time?
The date and time of the email’s creation, in ISO8601 representation.
-
#created_by_id ⇒ String?
The id of the user who created the email.
-
#deleted_at ⇒ Time?
The date and time the email was deleted at, in ISO8601 representation.
- #email_campaign_group_id ⇒ String?
- #email_template_mode ⇒ Symbol, ...
-
#feedback_survey_id ⇒ String?
The ID of the feedback survey linked to the email.
- #folder_id ⇒ Integer?
- #folder_id_v2 ⇒ Integer?
- #from ⇒ HubSpotSDK::Models::Marketing::PublicEmailFromDetails?
-
#id ⇒ String?
The email ID.
- #is_ab ⇒ Boolean
-
#is_published ⇒ Boolean?
Returns the published status of the email.
-
#is_transactional ⇒ Boolean?
Returns whether the email is a transactional email or not.
- #jitter_send_time ⇒ Boolean?
- #language ⇒ Symbol, ...
-
#name ⇒ String?
The name of the email, as displayed on the email dashboard.
- #preview_key ⇒ String?
- #primary_email_campaign_id ⇒ String?
-
#publish_date ⇒ Time?
The date and time the email is scheduled for, in ISO8601 representation.
-
#published_at ⇒ Time?
The date and time the email was published at, in ISO8601 representation.
-
#published_by_email ⇒ String?
Email of the user who published/sent the email.
-
#published_by_id ⇒ String?
The ID of the user who published the email.
-
#published_by_name ⇒ String?
Name of the user who published the email.
- #rss_data ⇒ HubSpotSDK::Models::Marketing::PublicRssEmailDetails?
-
#send_on_publish ⇒ Boolean?
Determines whether the email will be sent immediately on publish.
-
#state ⇒ Symbol, ...
The email state.
- #stats ⇒ HubSpotSDK::Models::Marketing::EmailStatisticsData?
-
#subcategory ⇒ String?
The email subcategory.
-
#subject ⇒ String?
The subject of the email.
- #subscription_details ⇒ HubSpotSDK::Models::Marketing::PublicEmailSubscriptionDetails?
- #teams_with_access ⇒ Array<String>?
- #testing ⇒ HubSpotSDK::Models::Marketing::PublicEmailTestingDetails?
- #to ⇒ HubSpotSDK::Models::Marketing::PublicEmailToDetails?
-
#type ⇒ Symbol, ...
The email type, this is derived from other properties on the email such as subcategory.
- #unpublished_at ⇒ Time?
-
#updated_at ⇒ Time?
The date and time of the last update to the email, in ISO8601 representation.
-
#updated_by_id ⇒ String?
The id of the user who last updated the email.
- #users_with_access ⇒ Array<String>?
- #webversion ⇒ HubSpotSDK::Models::Marketing::PublicWebversionDetails?
-
#workflow_names ⇒ Array<String>?
Names of workflows in which the email is used within a “send email” action.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(is_ab:, id: nil, active_domain: nil, all_email_campaign_ids: nil, archived: nil, business_unit_id: nil, campaign: nil, campaign_name: nil, campaign_utm: nil, cloned_from: nil, content: nil, created_at: nil, created_by_id: nil, deleted_at: nil, email_campaign_group_id: nil, email_template_mode: nil, feedback_survey_id: nil, folder_id: nil, folder_id_v2: nil, from: nil, is_published: nil, is_transactional: nil, jitter_send_time: nil, language: nil, name: nil, preview_key: nil, primary_email_campaign_id: nil, publish_date: nil, published_at: nil, published_by_email: nil, published_by_id: nil, published_by_name: nil, rss_data: nil, send_on_publish: nil, state: nil, stats: nil, subcategory: nil, subject: nil, subscription_details: nil, teams_with_access: nil, testing: nil, to: nil, type: nil, unpublished_at: nil, updated_at: nil, updated_by_id: nil, users_with_access: nil, webversion: nil, workflow_names: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicEmail for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(is_ab:, id: nil, active_domain: nil, all_email_campaign_ids: nil, archived: nil, business_unit_id: nil, campaign: nil, campaign_name: nil, campaign_utm: nil, cloned_from: nil, content: nil, created_at: nil, created_by_id: nil, deleted_at: nil, email_campaign_group_id: nil, email_template_mode: nil, feedback_survey_id: nil, folder_id: nil, folder_id_v2: nil, from: nil, is_published: nil, is_transactional: nil, jitter_send_time: nil, language: nil, name: nil, preview_key: nil, primary_email_campaign_id: nil, publish_date: nil, published_at: nil, published_by_email: nil, published_by_id: nil, published_by_name: nil, rss_data: nil, send_on_publish: nil, state: nil, stats: nil, subcategory: nil, subject: nil, subscription_details: nil, teams_with_access: nil, testing: nil, to: nil, type: nil, unpublished_at: nil, updated_at: nil, updated_by_id: nil, users_with_access: nil, webversion: nil, workflow_names: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::PublicEmail for more details.
|
|
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 288
|
Instance Attribute Details
#active_domain ⇒ String?
The active domain of the email.
23 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 23 optional :active_domain, String, api_name: :activeDomain |
#all_email_campaign_ids ⇒ Array<String>?
List of emailCampaignIds.
29 30 31 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 29 optional :all_email_campaign_ids, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :allEmailCampaignIds |
#archived ⇒ Boolean?
Determines if the email is archived or not.
37 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 37 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#business_unit_id ⇒ String?
42 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 42 optional :business_unit_id, String, api_name: :businessUnitId |
#campaign ⇒ String?
The ID of the campaign this email is associated to.
48 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 48 optional :campaign, String |
#campaign_name ⇒ String?
The name of the campaign.
54 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 54 optional :campaign_name, String, api_name: :campaignName |
#campaign_utm ⇒ String?
59 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 59 optional :campaign_utm, String, api_name: :campaignUtm |
#cloned_from ⇒ String?
The ID of the email this email was cloned from.
65 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 65 optional :cloned_from, String, api_name: :clonedFrom |
#content ⇒ HubSpotSDK::Models::Marketing::PublicEmailContent?
70 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 70 optional :content, -> { HubSpotSDK::Marketing::PublicEmailContent } |
#created_at ⇒ Time?
The date and time of the email’s creation, in ISO8601 representation.
76 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 76 optional :created_at, Time, api_name: :createdAt |
#created_by_id ⇒ String?
The id of the user who created the email.
82 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 82 optional :created_by_id, String, api_name: :createdById |
#deleted_at ⇒ Time?
The date and time the email was deleted at, in ISO8601 representation.
88 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 88 optional :deleted_at, Time, api_name: :deletedAt |
#email_campaign_group_id ⇒ String?
93 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 93 optional :email_campaign_group_id, String, api_name: :emailCampaignGroupId |
#email_template_mode ⇒ Symbol, ...
98 99 100 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 98 optional :email_template_mode, enum: -> { HubSpotSDK::Marketing::PublicEmail::EmailTemplateMode }, api_name: :emailTemplateMode |
#feedback_survey_id ⇒ String?
The ID of the feedback survey linked to the email.
106 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 106 optional :feedback_survey_id, String, api_name: :feedbackSurveyId |
#folder_id ⇒ Integer?
111 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 111 optional :folder_id, Integer, api_name: :folderId |
#folder_id_v2 ⇒ Integer?
116 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 116 optional :folder_id_v2, Integer, api_name: :folderIdV2 |
#from ⇒ HubSpotSDK::Models::Marketing::PublicEmailFromDetails?
121 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 121 optional :from, -> { HubSpotSDK::Marketing::PublicEmailFromDetails } |
#id ⇒ String?
The email ID.
17 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 17 optional :id, String |
#is_ab ⇒ Boolean
11 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 11 required :is_ab, HubSpotSDK::Internal::Type::Boolean, api_name: :isAb |
#is_published ⇒ Boolean?
Returns the published status of the email. This is read only.
127 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 127 optional :is_published, HubSpotSDK::Internal::Type::Boolean, api_name: :isPublished |
#is_transactional ⇒ Boolean?
Returns whether the email is a transactional email or not. This is read only.
133 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 133 optional :is_transactional, HubSpotSDK::Internal::Type::Boolean, api_name: :isTransactional |
#jitter_send_time ⇒ Boolean?
138 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 138 optional :jitter_send_time, HubSpotSDK::Internal::Type::Boolean, api_name: :jitterSendTime |
#language ⇒ Symbol, ...
143 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 143 optional :language, enum: -> { HubSpotSDK::Marketing::PublicEmail::Language } |
#name ⇒ String?
The name of the email, as displayed on the email dashboard.
149 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 149 optional :name, String |
#preview_key ⇒ String?
154 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 154 optional :preview_key, String, api_name: :previewKey |
#primary_email_campaign_id ⇒ String?
159 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 159 optional :primary_email_campaign_id, String, api_name: :primaryEmailCampaignId |
#publish_date ⇒ Time?
The date and time the email is scheduled for, in ISO8601 representation. This is only used in local time or scheduled emails.
166 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 166 optional :publish_date, Time, api_name: :publishDate |
#published_at ⇒ Time?
The date and time the email was published at, in ISO8601 representation.
172 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 172 optional :published_at, Time, api_name: :publishedAt |
#published_by_email ⇒ String?
Email of the user who published/sent the email.
178 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 178 optional :published_by_email, String, api_name: :publishedByEmail |
#published_by_id ⇒ String?
The ID of the user who published the email.
184 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 184 optional :published_by_id, String, api_name: :publishedById |
#published_by_name ⇒ String?
Name of the user who published the email.
190 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 190 optional :published_by_name, String, api_name: :publishedByName |
#rss_data ⇒ HubSpotSDK::Models::Marketing::PublicRssEmailDetails?
195 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 195 optional :rss_data, -> { HubSpotSDK::Marketing::PublicRssEmailDetails }, api_name: :rssData |
#send_on_publish ⇒ Boolean?
Determines whether the email will be sent immediately on publish.
201 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 201 optional :send_on_publish, HubSpotSDK::Internal::Type::Boolean, api_name: :sendOnPublish |
#state ⇒ Symbol, ...
The email state.
207 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 207 optional :state, enum: -> { HubSpotSDK::Marketing::PublicEmail::State } |
#stats ⇒ HubSpotSDK::Models::Marketing::EmailStatisticsData?
212 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 212 optional :stats, -> { HubSpotSDK::Marketing::EmailStatisticsData } |
#subcategory ⇒ String?
The email subcategory.
218 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 218 optional :subcategory, String |
#subject ⇒ String?
The subject of the email.
224 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 224 optional :subject, String |
#subscription_details ⇒ HubSpotSDK::Models::Marketing::PublicEmailSubscriptionDetails?
229 230 231 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 229 optional :subscription_details, -> { HubSpotSDK::Marketing::PublicEmailSubscriptionDetails }, api_name: :subscriptionDetails |
#teams_with_access ⇒ Array<String>?
236 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 236 optional :teams_with_access, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :teamsWithAccess |
#testing ⇒ HubSpotSDK::Models::Marketing::PublicEmailTestingDetails?
241 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 241 optional :testing, -> { HubSpotSDK::Marketing::PublicEmailTestingDetails } |
#to ⇒ HubSpotSDK::Models::Marketing::PublicEmailToDetails?
246 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 246 optional :to, -> { HubSpotSDK::Marketing::PublicEmailToDetails } |
#type ⇒ Symbol, ...
The email type, this is derived from other properties on the email such as subcategory.
253 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 253 optional :type, enum: -> { HubSpotSDK::Marketing::PublicEmail::Type } |
#unpublished_at ⇒ Time?
258 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 258 optional :unpublished_at, Time, api_name: :unpublishedAt |
#updated_at ⇒ Time?
The date and time of the last update to the email, in ISO8601 representation.
264 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 264 optional :updated_at, Time, api_name: :updatedAt |
#updated_by_id ⇒ String?
The id of the user who last updated the email.
270 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 270 optional :updated_by_id, String, api_name: :updatedById |
#users_with_access ⇒ Array<String>?
275 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 275 optional :users_with_access, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :usersWithAccess |
#webversion ⇒ HubSpotSDK::Models::Marketing::PublicWebversionDetails?
280 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 280 optional :webversion, -> { HubSpotSDK::Marketing::PublicWebversionDetails } |
#workflow_names ⇒ Array<String>?
Names of workflows in which the email is used within a “send email” action.
286 |
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 286 optional :workflow_names, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :workflowNames |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/marketing/public_email.rb', line 397
|