Class: HubSpotSDK::Models::Marketing::PublicEmailTestingDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::PublicEmailTestingDetails
- Defined in:
- lib/hubspot_sdk/models/marketing/public_email_testing_details.rb
Defined Under Namespace
Modules: AbSampleSizeDefault, AbSamplingDefault, AbStatus, AbSuccessMetric
Instance Attribute Summary collapse
-
#ab_sample_size_default ⇒ Symbol, ...
Version of the email that should be sent if there are too few recipients to conduct an AB test.
-
#ab_sampling_default ⇒ Symbol, ...
Version of the email that should be sent if the results are inconclusive after the test period, master or variant.
-
#ab_status ⇒ Symbol, ...
Status of the AB test.
-
#ab_success_metric ⇒ Symbol, ...
Metric to determine the version that will be sent to the remaining contacts.
-
#ab_test_percentage ⇒ Integer?
The size of your test group.
-
#hours_to_wait ⇒ Integer?
Time limit on gathering test results.
- #is_ab_variation ⇒ Boolean
-
#test_id ⇒ String?
The ID of the AB test.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(is_ab_variation:, ab_sample_size_default: nil, ab_sampling_default: nil, ab_status: nil, ab_success_metric: nil, ab_test_percentage: nil, hours_to_wait: nil, test_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicEmailTestingDetails for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(is_ab_variation:, ab_sample_size_default: nil, ab_sampling_default: nil, ab_status: nil, ab_success_metric: nil, ab_test_percentage: nil, hours_to_wait: nil, test_id: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::PublicEmailTestingDetails for more details.
|
|
# File 'lib/hubspot_sdk/models/marketing/public_email_testing_details.rb', line 65
|
Instance Attribute Details
#ab_sample_size_default ⇒ Symbol, ...
Version of the email that should be sent if there are too few recipients to conduct an AB test.
17 18 19 |
# File 'lib/hubspot_sdk/models/marketing/public_email_testing_details.rb', line 17 optional :ab_sample_size_default, enum: -> { HubSpotSDK::Marketing::PublicEmailTestingDetails::AbSampleSizeDefault }, api_name: :abSampleSizeDefault |
#ab_sampling_default ⇒ Symbol, ...
Version of the email that should be sent if the results are inconclusive after the test period, master or variant.
26 27 28 |
# File 'lib/hubspot_sdk/models/marketing/public_email_testing_details.rb', line 26 optional :ab_sampling_default, enum: -> { HubSpotSDK::Marketing::PublicEmailTestingDetails::AbSamplingDefault }, api_name: :abSamplingDefault |
#ab_status ⇒ Symbol, ...
Status of the AB test.
34 35 36 |
# File 'lib/hubspot_sdk/models/marketing/public_email_testing_details.rb', line 34 optional :ab_status, enum: -> { HubSpotSDK::Marketing::PublicEmailTestingDetails::AbStatus }, api_name: :abStatus |
#ab_success_metric ⇒ Symbol, ...
Metric to determine the version that will be sent to the remaining contacts.
42 43 44 |
# File 'lib/hubspot_sdk/models/marketing/public_email_testing_details.rb', line 42 optional :ab_success_metric, enum: -> { HubSpotSDK::Marketing::PublicEmailTestingDetails::AbSuccessMetric }, api_name: :abSuccessMetric |
#ab_test_percentage ⇒ Integer?
The size of your test group.
50 |
# File 'lib/hubspot_sdk/models/marketing/public_email_testing_details.rb', line 50 optional :ab_test_percentage, Integer, api_name: :abTestPercentage |
#hours_to_wait ⇒ Integer?
Time limit on gathering test results. After this time is up, the winning version will be sent to the remaining contacts.
57 |
# File 'lib/hubspot_sdk/models/marketing/public_email_testing_details.rb', line 57 optional :hours_to_wait, Integer, api_name: :hoursToWait |
#is_ab_variation ⇒ Boolean
10 |
# File 'lib/hubspot_sdk/models/marketing/public_email_testing_details.rb', line 10 required :is_ab_variation, HubSpotSDK::Internal::Type::Boolean, api_name: :isAbVariation |
#test_id ⇒ String?
The ID of the AB test.
63 |
# File 'lib/hubspot_sdk/models/marketing/public_email_testing_details.rb', line 63 optional :test_id, String, api_name: :testId |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/marketing/public_email_testing_details.rb', line 101
|