Module: HubSpotSDK::Models::Marketing::PublicEmailTestingDetails::AbSamplingDefault
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/hubspot_sdk/models/marketing/public_email_testing_details.rb
Overview
Version of the email that should be sent if the results are inconclusive after the test period, master or variant.
Constant Summary collapse
- AUTOMATED_LOSER_VARIANT =
:automated_loser_variant- AUTOMATED_MASTER =
:automated_master- AUTOMATED_VARIANT =
:automated_variant- LOSER_VARIANT =
:loser_variant- MAB_MASTER =
:mab_master- MAB_VARIANT =
:mab_variant- MASTER =
:master- VARIANT =
:variant
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info