Class: HubSpotSDK::Models::Marketing::PublicSingleSendEmail

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/public_single_send_email.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(bcc:, cc:, reply_to:, from: nil, send_id: nil, to: nil) ⇒ Object

Parameters:

  • bcc (Array<String>)

    List of email addresses to send as Bcc.

  • cc (Array<String>)

    List of email addresses to send as Cc.

  • reply_to (Array<String>)

    List of Reply-To header values for the email.

  • from (String) (defaults to: nil)

    The From header for the email.

  • send_id (String) (defaults to: nil)

    ID for a particular send. No more than one email will be sent per sendId.

  • to (String) (defaults to: nil)

    The recipient of the email.



# File 'lib/hubspot_sdk/models/marketing/public_single_send_email.rb', line 43

Instance Attribute Details

#bccArray<String>

List of email addresses to send as Bcc.

Returns:

  • (Array<String>)


11
# File 'lib/hubspot_sdk/models/marketing/public_single_send_email.rb', line 11

required :bcc, HubSpotSDK::Internal::Type::ArrayOf[String]

#ccArray<String>

List of email addresses to send as Cc.

Returns:

  • (Array<String>)


17
# File 'lib/hubspot_sdk/models/marketing/public_single_send_email.rb', line 17

required :cc, HubSpotSDK::Internal::Type::ArrayOf[String]

#fromString?

The From header for the email.

Returns:

  • (String, nil)


29
# File 'lib/hubspot_sdk/models/marketing/public_single_send_email.rb', line 29

optional :from, String

#reply_toArray<String>

List of Reply-To header values for the email.

Returns:

  • (Array<String>)


23
# File 'lib/hubspot_sdk/models/marketing/public_single_send_email.rb', line 23

required :reply_to, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :replyTo

#send_idString?

ID for a particular send. No more than one email will be sent per sendId.

Returns:

  • (String, nil)


35
# File 'lib/hubspot_sdk/models/marketing/public_single_send_email.rb', line 35

optional :send_id, String, api_name: :sendId

#toString?

The recipient of the email.

Returns:

  • (String, nil)


41
# File 'lib/hubspot_sdk/models/marketing/public_single_send_email.rb', line 41

optional :to, String