Class: HubSpotSDK::Models::Marketing::PublicSpendItem

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/public_spend_item.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount:, created_at:, name:, order:, updated_at:, description: nil) ⇒ Object

Parameters:

  • id (String)

    Unique identifier for the spend item.

  • amount (Float)

    The monetary value associated with the spend item.

  • created_at (Integer)

    The timestamp indicating when the spend item was created.

  • name (String)

    The name assigned to the spend item.

  • order (Integer)

    The sequence order of the spend item, where 0 is the oldest.

  • updated_at (Integer)

    The timestamp indicating when the spend item was last updated.

  • description (String) (defaults to: nil)

    A detailed explanation or notes about the spend item.



# File 'lib/hubspot_sdk/models/marketing/public_spend_item.rb', line 49

Instance Attribute Details

#amountFloat

The monetary value associated with the spend item.

Returns:

  • (Float)


17
# File 'lib/hubspot_sdk/models/marketing/public_spend_item.rb', line 17

required :amount, Float

#created_atInteger

The timestamp indicating when the spend item was created.

Returns:

  • (Integer)


23
# File 'lib/hubspot_sdk/models/marketing/public_spend_item.rb', line 23

required :created_at, Integer, api_name: :createdAt

#descriptionString?

A detailed explanation or notes about the spend item.

Returns:

  • (String, nil)


47
# File 'lib/hubspot_sdk/models/marketing/public_spend_item.rb', line 47

optional :description, String

#idString

Unique identifier for the spend item.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/marketing/public_spend_item.rb', line 11

required :id, String

#nameString

The name assigned to the spend item.

Returns:

  • (String)


29
# File 'lib/hubspot_sdk/models/marketing/public_spend_item.rb', line 29

required :name, String

#orderInteger

The sequence order of the spend item, where 0 is the oldest.

Returns:

  • (Integer)


35
# File 'lib/hubspot_sdk/models/marketing/public_spend_item.rb', line 35

required :order, Integer

#updated_atInteger

The timestamp indicating when the spend item was last updated.

Returns:

  • (Integer)


41
# File 'lib/hubspot_sdk/models/marketing/public_spend_item.rb', line 41

required :updated_at, Integer, api_name: :updatedAt