Class: HubSpotSDK::Models::Marketing::SearchPublicResponseWrapper

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/search_public_response_wrapper.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(app_id:, external_account_id:, external_event_id:, object_id_:) ⇒ Object

Parameters:

  • app_id (Integer)

    The ID of the source application of the marketing event

  • external_account_id (String)

    The account ID associated with this marketing event in the external application

  • external_event_id (String)

    The ID of the marketing event in the external event application

  • object_id_ (String)

    The internal ID of the marketing event in HubSpot



# File 'lib/hubspot_sdk/models/marketing/search_public_response_wrapper.rb', line 31

Instance Attribute Details

#app_idInteger

The ID of the source application of the marketing event

Returns:

  • (Integer)


11
# File 'lib/hubspot_sdk/models/marketing/search_public_response_wrapper.rb', line 11

required :app_id, Integer, api_name: :appId

#external_account_idString

The account ID associated with this marketing event in the external application

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/marketing/search_public_response_wrapper.rb', line 17

required :external_account_id, String, api_name: :externalAccountId

#external_event_idString

The ID of the marketing event in the external event application

Returns:

  • (String)


23
# File 'lib/hubspot_sdk/models/marketing/search_public_response_wrapper.rb', line 23

required :external_event_id, String, api_name: :externalEventId

#object_id_String

The internal ID of the marketing event in HubSpot

Returns:

  • (String)


29
# File 'lib/hubspot_sdk/models/marketing/search_public_response_wrapper.rb', line 29

required :object_id_, String, api_name: :objectId