Class: HubSpotSDK::Models::Marketing::SmtpAPITokenRequestEgg

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/smtp_api_token_request_egg.rb

Direct Known Subclasses

Transactional::SmtpTokenCreateParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(campaign_name:, create_contact:) ⇒ Object

Parameters:

  • campaign_name (String)

    A name for the campaign tied to the SMTP API token.

  • create_contact (Boolean)

    Indicates whether a contact should be created for email recipients.



# File 'lib/hubspot_sdk/models/marketing/smtp_api_token_request_egg.rb', line 19

Instance Attribute Details

#campaign_nameString

A name for the campaign tied to the SMTP API token.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/marketing/smtp_api_token_request_egg.rb', line 11

required :campaign_name, String, api_name: :campaignName

#create_contactBoolean

Indicates whether a contact should be created for email recipients.

Returns:

  • (Boolean)


17
# File 'lib/hubspot_sdk/models/marketing/smtp_api_token_request_egg.rb', line 17

required :create_contact, HubSpotSDK::Internal::Type::Boolean, api_name: :createContact