Class: HubSpotSDK::Models::Marketing::SmtpAPITokenView

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/marketing/smtp_api_token_view.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, campaign_name:, create_contact:, created_at:, created_by:, email_campaign_id:, password: nil) ⇒ Object

Parameters:

  • id (String)

    User name to log into the HubSpot SMTP server.

  • campaign_name (String)

    A name for the campaign tied to the token.

  • create_contact (Boolean)

    Indicates whether a contact should be created for email recipients.

  • created_at (Time)

    Timestamp generated when a token is created.

  • created_by (String)

    Email address of the user that sent the token creation request.

  • email_campaign_id (String)

    Identifier assigned to the campaign provided in the token creation request.

  • password (String) (defaults to: nil)

    Password used to log into the HubSpot SMTP server.



# File 'lib/hubspot_sdk/models/marketing/smtp_api_token_view.rb', line 49

Instance Attribute Details

#campaign_nameString

A name for the campaign tied to the token.

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/marketing/smtp_api_token_view.rb', line 17

required :campaign_name, String, api_name: :campaignName

#create_contactBoolean

Indicates whether a contact should be created for email recipients.

Returns:

  • (Boolean)


23
# File 'lib/hubspot_sdk/models/marketing/smtp_api_token_view.rb', line 23

required :create_contact, HubSpotSDK::Internal::Type::Boolean, api_name: :createContact

#created_atTime

Timestamp generated when a token is created.

Returns:

  • (Time)


29
# File 'lib/hubspot_sdk/models/marketing/smtp_api_token_view.rb', line 29

required :created_at, Time, api_name: :createdAt

#created_byString

Email address of the user that sent the token creation request.

Returns:

  • (String)


35
# File 'lib/hubspot_sdk/models/marketing/smtp_api_token_view.rb', line 35

required :created_by, String, api_name: :createdBy

#email_campaign_idString

Identifier assigned to the campaign provided in the token creation request.

Returns:

  • (String)


41
# File 'lib/hubspot_sdk/models/marketing/smtp_api_token_view.rb', line 41

required :email_campaign_id, String, api_name: :emailCampaignId

#idString

User name to log into the HubSpot SMTP server.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/marketing/smtp_api_token_view.rb', line 11

required :id, String

#passwordString?

Password used to log into the HubSpot SMTP server.

Returns:

  • (String, nil)


47
# File 'lib/hubspot_sdk/models/marketing/smtp_api_token_view.rb', line 47

optional :password, String