Class: HubSpotSDK::Models::Marketing::Transactional::SmtpTokenListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::Transactional::SmtpTokenListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/marketing/transactional/smtp_token_list_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
- #campaign_name ⇒ String?
- #email_campaign_id ⇒ String?
-
#limit ⇒ Integer?
The maximum number of results to display per page.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(after: nil, campaign_name: nil, email_campaign_id: nil, limit: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SmtpTokenListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, campaign_name: nil, email_campaign_id: nil, limit: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::Transactional::SmtpTokenListParams for more details.
|
|
# File 'lib/hubspot_sdk/models/marketing/transactional/smtp_token_list_params.rb', line 36
|
Instance Attribute Details
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
18 |
# File 'lib/hubspot_sdk/models/marketing/transactional/smtp_token_list_params.rb', line 18 optional :after, String |
#campaign_name ⇒ String?
23 |
# File 'lib/hubspot_sdk/models/marketing/transactional/smtp_token_list_params.rb', line 23 optional :campaign_name, String |
#email_campaign_id ⇒ String?
28 |
# File 'lib/hubspot_sdk/models/marketing/transactional/smtp_token_list_params.rb', line 28 optional :email_campaign_id, String |
#limit ⇒ Integer?
The maximum number of results to display per page.
34 |
# File 'lib/hubspot_sdk/models/marketing/transactional/smtp_token_list_params.rb', line 34 optional :limit, Integer |