Class: HubSpotSDK::Models::Marketing::VersionPublicEmail
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::VersionPublicEmail
- Defined in:
- lib/hubspot_sdk/models/marketing/version_public_email.rb
Overview
Instance Attribute Summary collapse
-
#id ⇒ String
ID of this marketing email version.
- #object ⇒ HubSpotSDK::Models::Marketing::PublicEmail
-
#updated_at ⇒ Time
The date and time of the last update to the email, in ISO8601 representation.
- #user ⇒ HubSpotSDK::Models::VersionUser
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, object:, updated_at:, user:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/marketing/version_public_email.rb', line 30
|
Instance Attribute Details
#id ⇒ String
ID of this marketing email version.
12 |
# File 'lib/hubspot_sdk/models/marketing/version_public_email.rb', line 12 required :id, String |
#object ⇒ HubSpotSDK::Models::Marketing::PublicEmail
17 |
# File 'lib/hubspot_sdk/models/marketing/version_public_email.rb', line 17 required :object, -> { HubSpotSDK::Marketing::PublicEmail } |
#updated_at ⇒ Time
The date and time of the last update to the email, in ISO8601 representation.
23 |
# File 'lib/hubspot_sdk/models/marketing/version_public_email.rb', line 23 required :updated_at, Time, api_name: :updatedAt |
#user ⇒ HubSpotSDK::Models::VersionUser
28 |
# File 'lib/hubspot_sdk/models/marketing/version_public_email.rb', line 28 required :user, -> { HubSpotSDK::VersionUser } |