Class: HubSpotSDK::Models::NextPage

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/next_page.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after:, link: nil) ⇒ Object

Specifies the paging information needed to retrieve the next set of results in a paginated API response

Parameters:

  • after (String)

    A paging cursor token for retrieving subsequent pages.

  • link (String) (defaults to: nil)

    A URL that can be used to retrieve the next page results.



# File 'lib/hubspot_sdk/models/next_page.rb', line 18

Instance Attribute Details

#afterString

A paging cursor token for retrieving subsequent pages.

Returns:

  • (String)


10
# File 'lib/hubspot_sdk/models/next_page.rb', line 10

required :after, String

A URL that can be used to retrieve the next page results.

Returns:

  • (String, nil)


16
# File 'lib/hubspot_sdk/models/next_page.rb', line 16

optional :link, String