Class: HubSpotSDK::Models::Option
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Option
- Defined in:
- lib/hubspot_sdk/models/option.rb
Instance Attribute Summary collapse
-
#description ⇒ String?
A description of the option.
-
#display_order ⇒ Integer?
Options are displayed in order starting with the lowest positive integer value.
-
#hidden ⇒ Boolean
Hidden options will not be displayed in HubSpot.
-
#label ⇒ String
A human-readable option label that will be shown in HubSpot.
-
#value ⇒ String
The internal value of the option, which must be used when setting the property value through the API.
Instance Method Summary collapse
-
#initialize(hidden:, label:, value:, description: nil, display_order: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Option for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(hidden:, label:, value:, description: nil, display_order: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Option for more details.
A HubSpot property option
|
|
# File 'lib/hubspot_sdk/models/option.rb', line 38
|
Instance Attribute Details
#description ⇒ String?
A description of the option.
29 |
# File 'lib/hubspot_sdk/models/option.rb', line 29 optional :description, String |
#display_order ⇒ Integer?
Options are displayed in order starting with the lowest positive integer value. Values of -1 will cause the option to be displayed after any positive values.
36 |
# File 'lib/hubspot_sdk/models/option.rb', line 36 optional :display_order, Integer, api_name: :displayOrder |
#hidden ⇒ Boolean
Hidden options will not be displayed in HubSpot.
10 |
# File 'lib/hubspot_sdk/models/option.rb', line 10 required :hidden, HubSpotSDK::Internal::Type::Boolean |
#label ⇒ String
A human-readable option label that will be shown in HubSpot.
16 |
# File 'lib/hubspot_sdk/models/option.rb', line 16 required :label, String |
#value ⇒ String
The internal value of the option, which must be used when setting the property value through the API.
23 |
# File 'lib/hubspot_sdk/models/option.rb', line 23 required :value, String |