Class: HubSpotSDK::Models::Paging
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Paging
- Defined in:
- lib/hubspot_sdk/models/paging.rb
Instance Attribute Summary collapse
-
#next_ ⇒ HubSpotSDK::Models::NextPage?
Specifies the paging information needed to retrieve the next set of results in a paginated API response.
-
#prev ⇒ HubSpotSDK::Models::PreviousPage?
specifies the paging information needed to retrieve the previous set of results in a paginated API response.
Instance Method Summary collapse
-
#initialize(next_: nil, prev: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Paging for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(next_: nil, prev: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Paging for more details.
|
|
# File 'lib/hubspot_sdk/models/paging.rb', line 20
|
Instance Attribute Details
#next_ ⇒ HubSpotSDK::Models::NextPage?
Specifies the paging information needed to retrieve the next set of results in a paginated API response
11 |
# File 'lib/hubspot_sdk/models/paging.rb', line 11 optional :next_, -> { HubSpotSDK::NextPage }, api_name: :next |
#prev ⇒ HubSpotSDK::Models::PreviousPage?
specifies the paging information needed to retrieve the previous set of results in a paginated API response
18 |
# File 'lib/hubspot_sdk/models/paging.rb', line 18 optional :prev, -> { HubSpotSDK::PreviousPage } |