Class: HubSpotSDK::Models::PreviousPage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::PreviousPage
- Defined in:
- lib/hubspot_sdk/models/previous_page.rb
Instance Attribute Summary collapse
-
#before ⇒ String
A string token used to identify the position before the current page in the pagination sequence.
-
#link ⇒ String?
A URL string that provides a direct link to the previous page of results.
Instance Method Summary collapse
-
#initialize(before:, link: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PreviousPage for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(before:, link: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::PreviousPage for more details.
specifies the paging information needed to retrieve the previous set of results in a paginated API response
|
|
# File 'lib/hubspot_sdk/models/previous_page.rb', line 19
|
Instance Attribute Details
#before ⇒ String
A string token used to identify the position before the current page in the pagination sequence.
11 |
# File 'lib/hubspot_sdk/models/previous_page.rb', line 11 required :before, String |
#link ⇒ String?
A URL string that provides a direct link to the previous page of results.
17 |
# File 'lib/hubspot_sdk/models/previous_page.rb', line 17 optional :link, String |