Class: HubSpotSDK::Models::Property

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/property.rb

Defined Under Namespace

Modules: DataSensitivity, DateDisplayHint, NumberDisplayHint

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(description:, field_type:, group_name:, label:, name:, options:, type:, archived: nil, archived_at: nil, calculated: nil, calculation_formula: nil, created_at: nil, created_user_id: nil, currency_property_name: nil, data_sensitivity: nil, date_display_hint: nil, display_order: nil, external_options: nil, form_field: nil, has_unique_value: nil, hidden: nil, hubspot_defined: nil, modification_metadata: nil, number_display_hint: nil, referenced_object_type: nil, sensitive_data_categories: nil, show_currency_symbol: nil, updated_at: nil, updated_user_id: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Property for more details.

A HubSpot property

Parameters:

  • description (String)

    A description of the property that will be shown as help text in HubSpot.

  • field_type (String)

    Controls how the property appears in HubSpot.

  • group_name (String)

    The name of the property group the property belongs to.

  • label (String)

    A human-readable property label that will be shown in HubSpot.

  • name (String)

    The internal property name, which must be used when referencing the property via

  • options (Array<HubSpotSDK::Models::Option>)

    A list of valid options for the property. This field is required for enumerated

  • type (String)

    The property data type.

  • archived (Boolean) (defaults to: nil)

    Whether or not the property is archived.

  • archived_at (Time) (defaults to: nil)

    When the property was archived.

  • calculated (Boolean) (defaults to: nil)

    For default properties, true indicates that the property is calculated by a HubS

  • calculation_formula (String) (defaults to: nil)

    The formula used for calculated properties.

  • created_at (Time) (defaults to: nil)

    When the property was created

  • created_user_id (String) (defaults to: nil)

    The internal ID of the user who created the property in HubSpot. This field may

  • currency_property_name (String) (defaults to: nil)

    The name of the related currency property.

  • data_sensitivity (Symbol, HubSpotSDK::Models::Property::DataSensitivity) (defaults to: nil)

    Indicates the sensitivity level of the property, such as “non_sensitive”, “sensi

  • date_display_hint (Symbol, HubSpotSDK::Models::Property::DateDisplayHint) (defaults to: nil)

    Controls how date properties are displayed in the HubSpot UI, with options such

  • display_order (Integer) (defaults to: nil)

    The order that this property should be displayed in the HubSpot UI relative to o

  • external_options (Boolean) (defaults to: nil)

    For default properties, true indicates that the options are stored externally to

  • form_field (Boolean) (defaults to: nil)

    Whether or not the property can be used in a HubSpot form.

  • has_unique_value (Boolean) (defaults to: nil)

    Whether or not the property’s value must be unique. Once set, this can’t be chan

  • hidden (Boolean) (defaults to: nil)

    Hidden options won’t be shown in HubSpot.

  • hubspot_defined (Boolean) (defaults to: nil)

    This will be true for default object properties built into HubSpot.

  • modification_metadata (HubSpotSDK::Models::PropertyModificationMetadata) (defaults to: nil)
  • number_display_hint (Symbol, HubSpotSDK::Models::Property::NumberDisplayHint) (defaults to: nil)

    Hint for how a number property is displayed and validated in HubSpot’s UI. Can b

  • referenced_object_type (String) (defaults to: nil)

    If this property is related to other object(s), they’ll be listed here.

  • sensitive_data_categories (Array<String>) (defaults to: nil)

    When sensitiveData is true, lists the type of sensitive data contained in the pr

  • show_currency_symbol (Boolean) (defaults to: nil)

    Whether the property will display the currency symbol set in the account setting

  • updated_at (Time) (defaults to: nil)

    When the object type was last updated.

  • updated_user_id (String) (defaults to: nil)

    The internal user ID of the user who updated the property in HubSpot. This field



# File 'lib/hubspot_sdk/models/property.rb', line 207

Instance Attribute Details

#archivedBoolean?

Whether or not the property is archived.

Returns:

  • (Boolean, nil)


54
# File 'lib/hubspot_sdk/models/property.rb', line 54

optional :archived, HubSpotSDK::Internal::Type::Boolean

#archived_atTime?

When the property was archived.

Returns:

  • (Time, nil)


60
# File 'lib/hubspot_sdk/models/property.rb', line 60

optional :archived_at, Time, api_name: :archivedAt

#calculatedBoolean?

For default properties, true indicates that the property is calculated by a HubSpot process. It has no effect for custom properties.

Returns:

  • (Boolean, nil)


67
# File 'lib/hubspot_sdk/models/property.rb', line 67

optional :calculated, HubSpotSDK::Internal::Type::Boolean

#calculation_formulaString?

The formula used for calculated properties.

Returns:

  • (String, nil)


73
# File 'lib/hubspot_sdk/models/property.rb', line 73

optional :calculation_formula, String, api_name: :calculationFormula

#created_atTime?

When the property was created

Returns:

  • (Time, nil)


79
# File 'lib/hubspot_sdk/models/property.rb', line 79

optional :created_at, Time, api_name: :createdAt

#created_user_idString?

The internal ID of the user who created the property in HubSpot. This field may not exist if the property was created outside of HubSpot.

Returns:

  • (String, nil)


86
# File 'lib/hubspot_sdk/models/property.rb', line 86

optional :created_user_id, String, api_name: :createdUserId

#currency_property_nameString?

The name of the related currency property.

Returns:

  • (String, nil)


92
# File 'lib/hubspot_sdk/models/property.rb', line 92

optional :currency_property_name, String, api_name: :currencyPropertyName

#data_sensitivitySymbol, ...

Indicates the sensitivity level of the property, such as “non_sensitive”, “sensitive”, or “highly_sensitive”.



99
100
101
102
103
# File 'lib/hubspot_sdk/models/property.rb', line 99

optional :data_sensitivity,
enum: -> {
  HubSpotSDK::Property::DataSensitivity
},
api_name: :dataSensitivity

#date_display_hintSymbol, ...

Controls how date properties are displayed in the HubSpot UI, with options such as ‘absolute’, ‘absolute_with_relative’, ‘time_since’, and ‘time_until’.



110
111
112
# File 'lib/hubspot_sdk/models/property.rb', line 110

optional :date_display_hint,
enum: -> { HubSpotSDK::Property::DateDisplayHint },
api_name: :dateDisplayHint

#descriptionString

A description of the property that will be shown as help text in HubSpot.

Returns:

  • (String)


10
# File 'lib/hubspot_sdk/models/property.rb', line 10

required :description, String

#display_orderInteger?

The order that this property should be displayed in the HubSpot UI relative to other properties for this object type. Properties are displayed in order starting with the lowest positive integer value. A value of -1 will cause the property to be displayed after any positive values.

Returns:

  • (Integer, nil)


121
# File 'lib/hubspot_sdk/models/property.rb', line 121

optional :display_order, Integer, api_name: :displayOrder

#external_optionsBoolean?

For default properties, true indicates that the options are stored externally to the property settings.

Returns:

  • (Boolean, nil)


128
# File 'lib/hubspot_sdk/models/property.rb', line 128

optional :external_options, HubSpotSDK::Internal::Type::Boolean, api_name: :externalOptions

#field_typeString

Controls how the property appears in HubSpot.

Returns:

  • (String)


16
# File 'lib/hubspot_sdk/models/property.rb', line 16

required :field_type, String, api_name: :fieldType

#form_fieldBoolean?

Whether or not the property can be used in a HubSpot form.

Returns:

  • (Boolean, nil)


134
# File 'lib/hubspot_sdk/models/property.rb', line 134

optional :form_field, HubSpotSDK::Internal::Type::Boolean, api_name: :formField

#group_nameString

The name of the property group the property belongs to.

Returns:

  • (String)


22
# File 'lib/hubspot_sdk/models/property.rb', line 22

required :group_name, String, api_name: :groupName

#has_unique_valueBoolean?

Whether or not the property’s value must be unique. Once set, this can’t be changed.

Returns:

  • (Boolean, nil)


141
# File 'lib/hubspot_sdk/models/property.rb', line 141

optional :has_unique_value, HubSpotSDK::Internal::Type::Boolean, api_name: :hasUniqueValue

#hiddenBoolean?

Hidden options won’t be shown in HubSpot.

Returns:

  • (Boolean, nil)


147
# File 'lib/hubspot_sdk/models/property.rb', line 147

optional :hidden, HubSpotSDK::Internal::Type::Boolean

#hubspot_definedBoolean?

This will be true for default object properties built into HubSpot.

Returns:

  • (Boolean, nil)


153
# File 'lib/hubspot_sdk/models/property.rb', line 153

optional :hubspot_defined, HubSpotSDK::Internal::Type::Boolean, api_name: :hubspotDefined

#labelString

A human-readable property label that will be shown in HubSpot.

Returns:

  • (String)


28
# File 'lib/hubspot_sdk/models/property.rb', line 28

required :label, String

#modification_metadataHubSpotSDK::Models::PropertyModificationMetadata?



158
159
160
# File 'lib/hubspot_sdk/models/property.rb', line 158

optional :modification_metadata,
-> { HubSpotSDK::PropertyModificationMetadata },
api_name: :modificationMetadata

#nameString

The internal property name, which must be used when referencing the property via the API.

Returns:

  • (String)


35
# File 'lib/hubspot_sdk/models/property.rb', line 35

required :name, String

#number_display_hintSymbol, ...

Hint for how a number property is displayed and validated in HubSpot’s UI. Can be: “unformatted”, “formatted”, “currency”, “percentage”, “duration”, or “probability”.



168
169
170
# File 'lib/hubspot_sdk/models/property.rb', line 168

optional :number_display_hint,
enum: -> { HubSpotSDK::Property::NumberDisplayHint },
api_name: :numberDisplayHint

#optionsArray<HubSpotSDK::Models::Option>

A list of valid options for the property. This field is required for enumerated properties, but will be empty for other property types.

Returns:



42
# File 'lib/hubspot_sdk/models/property.rb', line 42

required :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Option] }

#referenced_object_typeString?

If this property is related to other object(s), they’ll be listed here.

Returns:

  • (String, nil)


176
# File 'lib/hubspot_sdk/models/property.rb', line 176

optional :referenced_object_type, String, api_name: :referencedObjectType

#sensitive_data_categoriesArray<String>?

When sensitiveData is true, lists the type of sensitive data contained in the property (e.g., “HIPAA”).

Returns:

  • (Array<String>, nil)


183
184
185
# File 'lib/hubspot_sdk/models/property.rb', line 183

optional :sensitive_data_categories,
HubSpotSDK::Internal::Type::ArrayOf[String],
api_name: :sensitiveDataCategories

#show_currency_symbolBoolean?

Whether the property will display the currency symbol set in the account settings.

Returns:

  • (Boolean, nil)


192
# File 'lib/hubspot_sdk/models/property.rb', line 192

optional :show_currency_symbol, HubSpotSDK::Internal::Type::Boolean, api_name: :showCurrencySymbol

#typeString

The property data type.

Returns:

  • (String)


48
# File 'lib/hubspot_sdk/models/property.rb', line 48

required :type, String

#updated_atTime?

When the object type was last updated.

Returns:

  • (Time, nil)


198
# File 'lib/hubspot_sdk/models/property.rb', line 198

optional :updated_at, Time, api_name: :updatedAt

#updated_user_idString?

The internal user ID of the user who updated the property in HubSpot. This field may not exist if the property was updated outside of HubSpot.

Returns:

  • (String, nil)


205
# File 'lib/hubspot_sdk/models/property.rb', line 205

optional :updated_user_id, String, api_name: :updatedUserId

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/property.rb', line 282