Class: HubSpotSDK::Models::Scheduler::ExternalBookingInfo
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Scheduler::ExternalBookingInfo
- Defined in:
- lib/hubspot_sdk/models/scheduler/external_booking_info.rb
Defined Under Namespace
Modules: LinkType
Instance Attribute Summary collapse
- #all_users_busy_times ⇒ Array<HubSpotSDK::Models::Scheduler::ExternalUserBusyTimes>
- #branding_metadata ⇒ HubSpotSDK::Models::Scheduler::ExternalBrandingMetadata?
- #custom_params ⇒ HubSpotSDK::Models::Scheduler::ExternalMeetingsLinkSettings
-
#is_offline ⇒ Boolean
Whether the meeting was booked offline, meaning no associated calendar event was created.
- #link_availability ⇒ HubSpotSDK::Models::Scheduler::ExternalLinkAvailability?
-
#link_id ⇒ String
The unique identifier for the meeting link.
-
#link_type ⇒ Symbol, HubSpotSDK::Models::Scheduler::ExternalBookingInfo::LinkType
The type of the meeting link.
Instance Method Summary collapse
-
#initialize(all_users_busy_times:, custom_params:, is_offline:, link_id:, link_type:, branding_metadata: nil, link_availability: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalBookingInfo for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(all_users_busy_times:, custom_params:, is_offline:, link_id:, link_type:, branding_metadata: nil, link_availability: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Scheduler::ExternalBookingInfo for more details.
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_booking_info.rb', line 57
|
Instance Attribute Details
#all_users_busy_times ⇒ Array<HubSpotSDK::Models::Scheduler::ExternalUserBusyTimes>
10 11 12 |
# File 'lib/hubspot_sdk/models/scheduler/external_booking_info.rb', line 10 required :all_users_busy_times, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Scheduler::ExternalUserBusyTimes] }, api_name: :allUsersBusyTimes |
#branding_metadata ⇒ HubSpotSDK::Models::Scheduler::ExternalBrandingMetadata?
46 47 48 |
# File 'lib/hubspot_sdk/models/scheduler/external_booking_info.rb', line 46 optional :branding_metadata, -> { HubSpotSDK::Scheduler::ExternalBrandingMetadata }, api_name: :brandingMetadata |
#custom_params ⇒ HubSpotSDK::Models::Scheduler::ExternalMeetingsLinkSettings
17 18 19 |
# File 'lib/hubspot_sdk/models/scheduler/external_booking_info.rb', line 17 required :custom_params, -> { HubSpotSDK::Scheduler::ExternalMeetingsLinkSettings }, api_name: :customParams |
#is_offline ⇒ Boolean
Whether the meeting was booked offline, meaning no associated calendar event was created.
26 |
# File 'lib/hubspot_sdk/models/scheduler/external_booking_info.rb', line 26 required :is_offline, HubSpotSDK::Internal::Type::Boolean, api_name: :isOffline |
#link_availability ⇒ HubSpotSDK::Models::Scheduler::ExternalLinkAvailability?
53 54 55 |
# File 'lib/hubspot_sdk/models/scheduler/external_booking_info.rb', line 53 optional :link_availability, -> { HubSpotSDK::Scheduler::ExternalLinkAvailability }, api_name: :linkAvailability |
#link_id ⇒ String
The unique identifier for the meeting link.
32 |
# File 'lib/hubspot_sdk/models/scheduler/external_booking_info.rb', line 32 required :link_id, String, api_name: :linkId |
#link_type ⇒ Symbol, HubSpotSDK::Models::Scheduler::ExternalBookingInfo::LinkType
The type of the meeting link. Accepted values are: GROUP_CALENDAR, PERSONAL_LINK, ROUND_ROBIN_CALENDAR.
39 40 41 |
# File 'lib/hubspot_sdk/models/scheduler/external_booking_info.rb', line 39 required :link_type, enum: -> { HubSpotSDK::Scheduler::ExternalBookingInfo::LinkType }, api_name: :linkType |