Class: HubSpotSDK::Models::Scheduler::ExternalCalendarMeetingEventResponseProperties

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb

Defined Under Namespace

Modules: HsEngagementSource, HsMeetingLocationType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(hs_engagement_source:, hs_engagement_source_id:, hs_meeting_end_time:, hs_meeting_outcome:, hs_meeting_start_time:, hs_meeting_title:, hs_timestamp:, hs_activity_type: nil, hs_attachment_ids: nil, hs_attendee_owner_ids: nil, hs_include_description_in_reminder: nil, hs_internal_meeting_notes: nil, hs_meeting_body: nil, hs_meeting_external_url: nil, hs_meeting_location: nil, hs_meeting_location_type: nil, hs_unique_id: nil, hubspot_owner_id: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Scheduler::ExternalCalendarMeetingEventResponseProperties for more details.

Parameters:

  • hs_engagement_source (Symbol, HubSpotSDK::Models::Scheduler::ExternalCalendarMeetingEventResponseProperties::HsEngagementSource)

    The source of the engagement, will always be ‘MEETINGS`.

  • hs_engagement_source_id (String)

    The ID associated with the process created the engagement. Should always be empt

  • hs_meeting_end_time (Time)

    The end time of the meeting in ISO 8601 format.

  • hs_meeting_outcome (String)

    The outcome of the meeting. Acceptable default values are: SCHEDULED, COMPLETED,

  • hs_meeting_start_time (Time)

    The start time of the meeting in ISO 8601 format.

  • hs_meeting_title (String)

    The title of the meeting and calendar event.

  • hs_timestamp (Time)

    The time that the meeting should start in ISO 8601 format. This value should be

  • hs_activity_type (String) (defaults to: nil)

    The activity type of the meeting. Acceptable values are based on portal defined

  • hs_attachment_ids (Array<String>) (defaults to: nil)
  • hs_attendee_owner_ids (Array<String>) (defaults to: nil)
  • hs_include_description_in_reminder (String) (defaults to: nil)

    Whether to include the meeting description in the reminder.

  • hs_internal_meeting_notes (String) (defaults to: nil)

    Internal notes related to the meeting.

  • hs_meeting_body (String) (defaults to: nil)

    The description of the meeting and calendar event.

  • hs_meeting_external_url (String) (defaults to: nil)

    The calendar event URL for the meeting.

  • hs_meeting_location (String) (defaults to: nil)

    The physical address, virtual location, or phone number where the meeting will t

  • hs_meeting_location_type (Symbol, HubSpotSDK::Models::Scheduler::ExternalCalendarMeetingEventResponseProperties::HsMeetingLocationType) (defaults to: nil)

    The type of location for the meeting. Acceptable values are: ADDRESS, CUSTOM, PH

  • hs_unique_id (String) (defaults to: nil)

    The unique ID of the created calendar event.

  • hubspot_owner_id (String) (defaults to: nil)

    The owner ID of the HubSpot user hosting the meeting.



# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 122

Instance Attribute Details

#hs_activity_typeString?

The activity type of the meeting. Acceptable values are based on portal defined call and meeting types.

Returns:

  • (String, nil)


59
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 59

optional :hs_activity_type, String

#hs_attachment_idsArray<String>?

Returns:

  • (Array<String>, nil)


64
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 64

optional :hs_attachment_ids, HubSpotSDK::Internal::Type::ArrayOf[String]

#hs_attendee_owner_idsArray<String>?

Returns:

  • (Array<String>, nil)


69
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 69

optional :hs_attendee_owner_ids, HubSpotSDK::Internal::Type::ArrayOf[String]

#hs_engagement_sourceSymbol, HubSpotSDK::Models::Scheduler::ExternalCalendarMeetingEventResponseProperties::HsEngagementSource

The source of the engagement, will always be ‘MEETINGS`.



11
12
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 11

required :hs_engagement_source,
enum: -> { HubSpotSDK::Scheduler::ExternalCalendarMeetingEventResponseProperties::HsEngagementSource }

#hs_engagement_source_idString

The ID associated with the process created the engagement. Should always be empty when creating meeting events through this API.

Returns:

  • (String)


19
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 19

required :hs_engagement_source_id, String

#hs_include_description_in_reminderString?

Whether to include the meeting description in the reminder.

Returns:

  • (String, nil)


75
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 75

optional :hs_include_description_in_reminder, String

#hs_internal_meeting_notesString?

Internal notes related to the meeting.

Returns:

  • (String, nil)


81
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 81

optional :hs_internal_meeting_notes, String

#hs_meeting_bodyString?

The description of the meeting and calendar event.

Returns:

  • (String, nil)


87
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 87

optional :hs_meeting_body, String

#hs_meeting_end_timeTime

The end time of the meeting in ISO 8601 format.

Returns:

  • (Time)


25
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 25

required :hs_meeting_end_time, Time

#hs_meeting_external_urlString?

The calendar event URL for the meeting.

Returns:

  • (String, nil)


93
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 93

optional :hs_meeting_external_url, String

#hs_meeting_locationString?

The physical address, virtual location, or phone number where the meeting will take place.

Returns:

  • (String, nil)


100
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 100

optional :hs_meeting_location, String

#hs_meeting_location_typeSymbol, ...

The type of location for the meeting. Acceptable values are: ADDRESS, CUSTOM, PHONE.



107
108
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 107

optional :hs_meeting_location_type,
enum: -> { HubSpotSDK::Scheduler::ExternalCalendarMeetingEventResponseProperties::HsMeetingLocationType }

#hs_meeting_outcomeString

The outcome of the meeting. Acceptable default values are: SCHEDULED, COMPLETED, RESCHEDULED, NO_SHOW, CANCELED. This property can be changed to include additional custom values.

Returns:

  • (String)


33
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 33

required :hs_meeting_outcome, String

#hs_meeting_start_timeTime

The start time of the meeting in ISO 8601 format.

Returns:

  • (Time)


39
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 39

required :hs_meeting_start_time, Time

#hs_meeting_titleString

The title of the meeting and calendar event.

Returns:

  • (String)


45
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 45

required :hs_meeting_title, String

#hs_timestampTime

The time that the meeting should start in ISO 8601 format. This value should be the same as ‘hs_meeting_start_time`.

Returns:

  • (Time)


52
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 52

required :hs_timestamp, Time

#hs_unique_idString?

The unique ID of the created calendar event.

Returns:

  • (String, nil)


114
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 114

optional :hs_unique_id, String

#hubspot_owner_idString?

The owner ID of the HubSpot user hosting the meeting.

Returns:

  • (String, nil)


120
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 120

optional :hubspot_owner_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 283