Class: HubSpotSDK::Models::Scheduler::ExternalEmailReminderSchedule
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Scheduler::ExternalEmailReminderSchedule
- Defined in:
- lib/hubspot_sdk/models/scheduler/external_email_reminder_schedule.rb
Instance Attribute Summary collapse
- #reminders ⇒ Array<HubSpotSDK::Models::Scheduler::ExternalReminder>
-
#should_include_invite_description ⇒ Boolean
Whether the invite description should be included in the reminder.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(reminders:, should_include_invite_description:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_email_reminder_schedule.rb', line 20
|
Instance Attribute Details
#reminders ⇒ Array<HubSpotSDK::Models::Scheduler::ExternalReminder>
10 |
# File 'lib/hubspot_sdk/models/scheduler/external_email_reminder_schedule.rb', line 10 required :reminders, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Scheduler::ExternalReminder] } |
#should_include_invite_description ⇒ Boolean
Whether the invite description should be included in the reminder.
16 17 18 |
# File 'lib/hubspot_sdk/models/scheduler/external_email_reminder_schedule.rb', line 16 required :should_include_invite_description, HubSpotSDK::Internal::Type::Boolean, api_name: :shouldIncludeInviteDescription |