Class: HubSpotSDK::Models::Scheduler::ExternalGuestSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/scheduler/external_guest_settings.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(can_add_guests:, max_guest_count:) ⇒ Object

Parameters:

  • can_add_guests (Boolean)

    Indicates whether guests can be added to the meeting.

  • max_guest_count (Integer)

    The maximum number of guests that can be added to the meeting.



# File 'lib/hubspot_sdk/models/scheduler/external_guest_settings.rb', line 19

Instance Attribute Details

#can_add_guestsBoolean

Indicates whether guests can be added to the meeting.

Returns:

  • (Boolean)


11
# File 'lib/hubspot_sdk/models/scheduler/external_guest_settings.rb', line 11

required :can_add_guests, HubSpotSDK::Internal::Type::Boolean, api_name: :canAddGuests

#max_guest_countInteger

The maximum number of guests that can be added to the meeting.

Returns:

  • (Integer)


17
# File 'lib/hubspot_sdk/models/scheduler/external_guest_settings.rb', line 17

required :max_guest_count, Integer, api_name: :maxGuestCount