Class: HubSpotSDK::Models::Scheduler::ExternalLegalConsentResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/scheduler/external_legal_consent_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(communication_type_id:, consented:) ⇒ Object

Parameters:

  • communication_type_id (String)

    The ID of communication consent form being recorded.

  • consented (Boolean)

    Whether the user has given consent for the specified communication type.



# File 'lib/hubspot_sdk/models/scheduler/external_legal_consent_response.rb', line 19

Instance Attribute Details

#communication_type_idString

The ID of communication consent form being recorded.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/scheduler/external_legal_consent_response.rb', line 11

required :communication_type_id, String, api_name: :communicationTypeId

#consentedBoolean

Whether the user has given consent for the specified communication type.

Returns:

  • (Boolean)


17
# File 'lib/hubspot_sdk/models/scheduler/external_legal_consent_response.rb', line 17

required :consented, HubSpotSDK::Internal::Type::Boolean