Class: HubSpotSDK::Models::Scheduler::ExternalLinkAvailability
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Scheduler::ExternalLinkAvailability
- Defined in:
- lib/hubspot_sdk/models/scheduler/external_link_availability.rb
Instance Attribute Summary collapse
-
#has_more ⇒ Boolean
Whether there are more available meeting times beyond the returned set.
-
#link_availability_by_duration ⇒ Hash{Symbol=>HubSpotSDK::Models::Scheduler::ExternalLinkAvailabilityForDuration}
Available booking slots for the meeting, grouped by the duration.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(has_more:, link_availability_by_duration:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_link_availability.rb', line 23
|
Instance Attribute Details
#has_more ⇒ Boolean
Whether there are more available meeting times beyond the returned set.
11 |
# File 'lib/hubspot_sdk/models/scheduler/external_link_availability.rb', line 11 required :has_more, HubSpotSDK::Internal::Type::Boolean, api_name: :hasMore |
#link_availability_by_duration ⇒ Hash{Symbol=>HubSpotSDK::Models::Scheduler::ExternalLinkAvailabilityForDuration}
Available booking slots for the meeting, grouped by the duration.
17 18 19 20 21 |
# File 'lib/hubspot_sdk/models/scheduler/external_link_availability.rb', line 17 required :link_availability_by_duration, -> { HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Scheduler::ExternalLinkAvailabilityForDuration] }, api_name: :linkAvailabilityByDuration |