Class: HubSpotSDK::Models::Scheduler::ExternalLinkDisplayInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/scheduler/external_link_display_info.rb

Defined Under Namespace

Modules: PublicDisplayAvatarOption

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(avatar: nil, company_avatar: nil, headline: nil, public_display_avatar_option: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Scheduler::ExternalLinkDisplayInfo for more details.

Parameters:

  • avatar (String) (defaults to: nil)

    The URL of the user’s custom uploaded avatar image.

  • company_avatar (String) (defaults to: nil)

    The URL of the company’s avatar image.

  • headline (String) (defaults to: nil)

    Deprecated field with no impact of link display info.

  • public_display_avatar_option (Symbol, HubSpotSDK::Models::Scheduler::ExternalLinkDisplayInfo::PublicDisplayAvatarOption) (defaults to: nil)

    Option for determining which avatar to display on scheduling page. Accepted valu



# File 'lib/hubspot_sdk/models/scheduler/external_link_display_info.rb', line 34

Instance Attribute Details

#avatarString?

The URL of the user’s custom uploaded avatar image.

Returns:

  • (String, nil)


11
# File 'lib/hubspot_sdk/models/scheduler/external_link_display_info.rb', line 11

optional :avatar, String

#company_avatarString?

The URL of the company’s avatar image.

Returns:

  • (String, nil)


17
# File 'lib/hubspot_sdk/models/scheduler/external_link_display_info.rb', line 17

optional :company_avatar, String, api_name: :companyAvatar

#headlineString?

Deprecated field with no impact of link display info.

Returns:

  • (String, nil)


23
# File 'lib/hubspot_sdk/models/scheduler/external_link_display_info.rb', line 23

optional :headline, String

#public_display_avatar_optionSymbol, ...

Option for determining which avatar to display on scheduling page. Accepted values are: PROFILE_IMAGE, COMPANY_LOGO, CUSTOM_AVATAR,



30
31
32
# File 'lib/hubspot_sdk/models/scheduler/external_link_display_info.rb', line 30

optional :public_display_avatar_option,
enum: -> { HubSpotSDK::Scheduler::ExternalLinkDisplayInfo::PublicDisplayAvatarOption },
api_name: :publicDisplayAvatarOption