Class: HubSpotSDK::Models::Scheduler::ExternalMeetingBookingResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(booking_timezone:, calendar_event_id:, contact_id:, duration:, end_:, form_fields:, guest_emails:, is_offline:, legal_consent_responses:, start:, subject:, locale: nil, location: nil, web_conference_meeting_id: nil, web_conference_url: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Scheduler::ExternalMeetingBookingResponse for more details.

Parameters:

  • booking_timezone (String)

    The timezone the meeting was booked from.

  • calendar_event_id (String)

    The unique identifier for the meeting’s calendar event.

  • contact_id (String)

    The ID of the contact associated to the meeting.

  • duration (Integer)

    The duration of the meeting in milliseconds.

  • end_ (Time)

    The date and time when the meeting is scheduled to end, in ISO 8601 format.

  • form_fields (Array<HubSpotSDK::Models::Scheduler::ExternalValidatedFormField>)
  • guest_emails (Array<String>)
  • is_offline (Boolean)

    Whether the meeting was booked offline and no associated calendar event was crea

  • legal_consent_responses (Array<HubSpotSDK::Models::Scheduler::ExternalLegalConsentResponse>)
  • start (Time)

    The date and time when the meeting is scheduled to start, in ISO 8601 format.

  • subject (String)

    The title of the meeting and calendar event.

  • locale (String) (defaults to: nil)

    The locale the meeting was booked with, used to determine date formatting in cal

  • location (String) (defaults to: nil)

    The physical or virtual location where the meeting will take place.

  • web_conference_meeting_id (String) (defaults to: nil)

    The unique identifier for the web conference meeting.

  • web_conference_url (String) (defaults to: nil)

    The URL for accessing the meeting’s web conference.



# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 104

Instance Attribute Details

#booking_timezoneString

The timezone the meeting was booked from.

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 11

required :booking_timezone, String, api_name: :bookingTimezone

#calendar_event_idString

The unique identifier for the meeting’s calendar event.

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 17

required :calendar_event_id, String, api_name: :calendarEventId

#contact_idString

The ID of the contact associated to the meeting.

Returns:

  • (String)


23
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 23

required :contact_id, String, api_name: :contactId

#durationInteger

The duration of the meeting in milliseconds.

Returns:

  • (Integer)


29
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 29

required :duration, Integer

#end_Time

The date and time when the meeting is scheduled to end, in ISO 8601 format.

Returns:

  • (Time)


35
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 35

required :end_, Time, api_name: :end

#form_fieldsArray<HubSpotSDK::Models::Scheduler::ExternalValidatedFormField>



40
41
42
43
44
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 40

required :form_fields,
-> {
  HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Scheduler::ExternalValidatedFormField]
},
api_name: :formFields

#guest_emailsArray<String>

Returns:

  • (Array<String>)


49
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 49

required :guest_emails, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :guestEmails

#is_offlineBoolean

Whether the meeting was booked offline and no associated calendar event was created.

Returns:

  • (Boolean)


56
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 56

required :is_offline, HubSpotSDK::Internal::Type::Boolean, api_name: :isOffline


61
62
63
64
65
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 61

required :legal_consent_responses,
-> {
  HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Scheduler::ExternalLegalConsentResponse]
},
api_name: :legalConsentResponses

#localeString?

The locale the meeting was booked with, used to determine date formatting in calendar event description.

Returns:

  • (String, nil)


84
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 84

optional :locale, String

#locationString?

The physical or virtual location where the meeting will take place.

Returns:

  • (String, nil)


90
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 90

optional :location, String

#startTime

The date and time when the meeting is scheduled to start, in ISO 8601 format.

Returns:

  • (Time)


71
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 71

required :start, Time

#subjectString

The title of the meeting and calendar event.

Returns:

  • (String)


77
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 77

required :subject, String

#web_conference_meeting_idString?

The unique identifier for the web conference meeting.

Returns:

  • (String, nil)


96
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 96

optional :web_conference_meeting_id, String, api_name: :webConferenceMeetingId

#web_conference_urlString?

The URL for accessing the meeting’s web conference.

Returns:

  • (String, nil)


102
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 102

optional :web_conference_url, String, api_name: :webConferenceUrl