Class: HubSpotSDK::Models::Scheduler::ExternalReminder
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Scheduler::ExternalReminder
- Defined in:
- lib/hubspot_sdk/models/scheduler/external_reminder.rb
Defined Under Namespace
Modules: TimeUnit
Instance Attribute Summary collapse
-
#number_of_time_units ⇒ Integer
The number of timeUnits prior to the meeting start when the reminder will be sent.
-
#time_unit ⇒ Symbol, HubSpotSDK::Models::Scheduler::ExternalReminder::TimeUnit
Accepted values are: WEEKS, DAYS, HOURS, MINUTES.
Instance Method Summary collapse
-
#initialize(number_of_time_units:, time_unit:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalReminder for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(number_of_time_units:, time_unit:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Scheduler::ExternalReminder for more details.
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_reminder.rb', line 24
|
Instance Attribute Details
#number_of_time_units ⇒ Integer
The number of timeUnits prior to the meeting start when the reminder will be sent.
12 |
# File 'lib/hubspot_sdk/models/scheduler/external_reminder.rb', line 12 required :number_of_time_units, Integer, api_name: :numberOfTimeUnits |
#time_unit ⇒ Symbol, HubSpotSDK::Models::Scheduler::ExternalReminder::TimeUnit
Accepted values are: WEEKS, DAYS, HOURS, MINUTES.
18 19 20 21 22 |
# File 'lib/hubspot_sdk/models/scheduler/external_reminder.rb', line 18 required :time_unit, enum: -> { HubSpotSDK::Scheduler::ExternalReminder::TimeUnit }, api_name: :timeUnit |