Class: HubSpotSDK::Models::Scheduler::ExternalValidatedFormField

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(is_custom:, label:, name:, value:, field_type: nil, translated_label: nil, value_label: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Scheduler::ExternalValidatedFormField for more details.

Parameters:

  • is_custom (Boolean)

    Whether the form field is a custom field.

  • label (String)

    The text label associated with the form field.

  • name (String)

    The name identifier for the form field, includes underscores in place of spaces

  • value (String)

    The value associated with the form field.

  • field_type (String) (defaults to: nil)

    The specific input type of the form field. Corresponds to property types (e.g.,

  • translated_label (String) (defaults to: nil)

    The translated text label for the form field.

  • value_label (String) (defaults to: nil)

    The text label associated to a form field selection or option.



# File 'lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb', line 51

Instance Attribute Details

#field_typeString?

The specific input type of the form field. Corresponds to property types (e.g., ‘select`, `radio`, `date`, etc).

Returns:

  • (String, nil)


37
# File 'lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb', line 37

optional :field_type, String, api_name: :fieldType

#is_customBoolean

Whether the form field is a custom field.

Returns:

  • (Boolean)


11
# File 'lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb', line 11

required :is_custom, HubSpotSDK::Internal::Type::Boolean, api_name: :isCustom

#labelString

The text label associated with the form field.

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb', line 17

required :label, String

#nameString

The name identifier for the form field, includes underscores in place of spaces (e.g., the label ‘my form` is converted to `my_form`).

Returns:

  • (String)


24
# File 'lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb', line 24

required :name, String

#translated_labelString?

The translated text label for the form field.

Returns:

  • (String, nil)


43
# File 'lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb', line 43

optional :translated_label, String, api_name: :translatedLabel

#valueString

The value associated with the form field.

Returns:

  • (String)


30
# File 'lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb', line 30

required :value, String

#value_labelString?

The text label associated to a form field selection or option.

Returns:

  • (String, nil)


49
# File 'lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb', line 49

optional :value_label, String, api_name: :valueLabel