Class: HubSpotSDK::Models::Scheduler::Meetings::BasicListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/hubspot_sdk/models/scheduler/meetings/basic_list_params.rb

Overview

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel

Instance Attribute Details

#afterString?

The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.

Returns:

  • (String, nil)


18
# File 'lib/hubspot_sdk/models/scheduler/meetings/basic_list_params.rb', line 18

optional :after, String

#limitInteger?

The maximum number of results to display per page.

Returns:

  • (Integer, nil)


24
# File 'lib/hubspot_sdk/models/scheduler/meetings/basic_list_params.rb', line 24

optional :limit, Integer

#nameString?

Returns:

  • (String, nil)


29
# File 'lib/hubspot_sdk/models/scheduler/meetings/basic_list_params.rb', line 29

optional :name, String

#organizer_user_idString?

Returns:

  • (String, nil)


34
# File 'lib/hubspot_sdk/models/scheduler/meetings/basic_list_params.rb', line 34

optional :organizer_user_id, String

#typeSymbol, ...



39
# File 'lib/hubspot_sdk/models/scheduler/meetings/basic_list_params.rb', line 39

optional :type, enum: -> { HubSpotSDK::Scheduler::Meetings::BasicListParams::Type }