Class: HubSpotSDK::Models::Settings::BatchResponseExchangeRate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Settings::BatchResponseExchangeRate
- Defined in:
- lib/hubspot_sdk/models/settings/batch_response_exchange_rate.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The datetime the response was completed.
-
#links ⇒ Hash{Symbol=>String}?
The link to the next page with exchange rates.
-
#requested_at ⇒ Time?
The datetime the of the request.
- #results ⇒ Array<HubSpotSDK::Models::Settings::ExchangeRate>
-
#started_at ⇒ Time
The datetime the of the request.
-
#status ⇒ Symbol, HubSpotSDK::Models::Settings::BatchResponseExchangeRate::Status
The current status of the response (e.g. COMPLETED).
Instance Method Summary collapse
- #initialize(completed_at:, results:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(completed_at:, results:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/settings/batch_response_exchange_rate.rb', line 42
|
Instance Attribute Details
#completed_at ⇒ Time
The datetime the response was completed
11 |
# File 'lib/hubspot_sdk/models/settings/batch_response_exchange_rate.rb', line 11 required :completed_at, Time, api_name: :completedAt |
#links ⇒ Hash{Symbol=>String}?
The link to the next page with exchange rates.
34 |
# File 'lib/hubspot_sdk/models/settings/batch_response_exchange_rate.rb', line 34 optional :links, HubSpotSDK::Internal::Type::HashOf[String] |
#requested_at ⇒ Time?
The datetime the of the request.
40 |
# File 'lib/hubspot_sdk/models/settings/batch_response_exchange_rate.rb', line 40 optional :requested_at, Time, api_name: :requestedAt |
#results ⇒ Array<HubSpotSDK::Models::Settings::ExchangeRate>
16 |
# File 'lib/hubspot_sdk/models/settings/batch_response_exchange_rate.rb', line 16 required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Settings::ExchangeRate] } |
#started_at ⇒ Time
The datetime the of the request.
22 |
# File 'lib/hubspot_sdk/models/settings/batch_response_exchange_rate.rb', line 22 required :started_at, Time, api_name: :startedAt |
#status ⇒ Symbol, HubSpotSDK::Models::Settings::BatchResponseExchangeRate::Status
The current status of the response (e.g. COMPLETED)
28 |
# File 'lib/hubspot_sdk/models/settings/batch_response_exchange_rate.rb', line 28 required :status, enum: -> { HubSpotSDK::Settings::BatchResponseExchangeRate::Status } |