Class: HubSpotSDK::Models::Settings::CentralExchangeRatesInformation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/settings/central_exchange_rates_information.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(central_exchange_rates_enabled:) ⇒ Object

Parameters:

  • central_exchange_rates_enabled (Boolean)

    Indicates if central exchange rates is enabled for the portal or not.



# File 'lib/hubspot_sdk/models/settings/central_exchange_rates_information.rb', line 15

Instance Attribute Details

#central_exchange_rates_enabledBoolean

Indicates if central exchange rates is enabled for the portal or not.

Returns:

  • (Boolean)


11
12
13
# File 'lib/hubspot_sdk/models/settings/central_exchange_rates_information.rb', line 11

required :central_exchange_rates_enabled,
HubSpotSDK::Internal::Type::Boolean,
api_name: :centralExchangeRatesEnabled