Class: HubSpotSDK::Models::Settings::CurrencyPairUpdate

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/settings/currency_pair_update.rb

Defined Under Namespace

Modules: FromCurrencyCode, ToCurrencyCode

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(from_currency_code:, to_currency_code:, visible_in_ui:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Settings::CurrencyPairUpdate for more details.

Parameters:



# File 'lib/hubspot_sdk/models/settings/currency_pair_update.rb', line 32

Instance Attribute Details

#from_currency_codeSymbol, HubSpotSDK::Models::Settings::CurrencyPairUpdate::FromCurrencyCode

This represents the three-letter currency code (such as USD for US Dollar) of the currency you want to convert from.



12
13
14
# File 'lib/hubspot_sdk/models/settings/currency_pair_update.rb', line 12

required :from_currency_code,
enum: -> { HubSpotSDK::Settings::CurrencyPairUpdate::FromCurrencyCode },
api_name: :fromCurrencyCode

#to_currency_codeSymbol, HubSpotSDK::Models::Settings::CurrencyPairUpdate::ToCurrencyCode

This represents the three-letter currency code (such as USD for US Dollar) of the currency you want to convert to.



21
22
23
# File 'lib/hubspot_sdk/models/settings/currency_pair_update.rb', line 21

required :to_currency_code,
enum: -> { HubSpotSDK::Settings::CurrencyPairUpdate::ToCurrencyCode },
api_name: :toCurrencyCode

#visible_in_uiBoolean

This indicates if the currency pair is shown in the MultiCurrency settings page. Setting this to false will remove the currency pair from the settings page.

Returns:

  • (Boolean)


30
# File 'lib/hubspot_sdk/models/settings/currency_pair_update.rb', line 30

required :visible_in_ui, HubSpotSDK::Internal::Type::Boolean, api_name: :visibleInUI

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/settings/currency_pair_update.rb', line 226