Class: HubSpotSDK::Models::Settings::ExchangeRate

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/settings/exchange_rate.rb

Defined Under Namespace

Modules: FromCurrencyCode, ToCurrencyCode

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, conversion_rate:, created_at:, effective_at:, from_currency_code:, to_currency_code:, updated_at:, visible_in_ui:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Settings::ExchangeRate for more details.

Parameters:

  • id (String)

    A unique identifier for the exchange rate

  • conversion_rate (Float)

    The conversion rate between the to and from currency code of this exchange rate.

  • created_at (Time)

    The date the exchange rate was created.

  • effective_at (Time)

    The date the exchange rate is in effect.

  • from_currency_code (Symbol, HubSpotSDK::Models::Settings::ExchangeRate::FromCurrencyCode)

    This represents the three-letter currency code (such as USD for US Dollar) of th

  • to_currency_code (Symbol, HubSpotSDK::Models::Settings::ExchangeRate::ToCurrencyCode)

    This represents the three-letter currency code (such as USD for US Dollar) of th

  • updated_at (Time)

    The date the exchange rate was last updated.

  • visible_in_ui (Boolean)

    This indicates if the exchange rate is shown in the MultiCurrency settings page.



# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 61

Instance Attribute Details

#conversion_rateFloat

The conversion rate between the to and from currency code of this exchange rate.

Returns:

  • (Float)


17
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 17

required :conversion_rate, Float, api_name: :conversionRate

#created_atTime

The date the exchange rate was created.

Returns:

  • (Time)


23
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 23

required :created_at, Time, api_name: :createdAt

#effective_atTime

The date the exchange rate is in effect.

Returns:

  • (Time)


29
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 29

required :effective_at, Time, api_name: :effectiveAt

#from_currency_codeSymbol, HubSpotSDK::Models::Settings::ExchangeRate::FromCurrencyCode

This represents the three-letter currency code (such as USD for US Dollar) of the currency you are converting from.



36
37
38
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 36

required :from_currency_code,
enum: -> { HubSpotSDK::Settings::ExchangeRate::FromCurrencyCode },
api_name: :fromCurrencyCode

#idString

A unique identifier for the exchange rate

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 11

required :id, String

#to_currency_codeSymbol, HubSpotSDK::Models::Settings::ExchangeRate::ToCurrencyCode

This represents the three-letter currency code (such as USD for US Dollar) of the currency you are converting to.



45
46
47
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 45

required :to_currency_code,
enum: -> { HubSpotSDK::Settings::ExchangeRate::ToCurrencyCode },
api_name: :toCurrencyCode

#updated_atTime

The date the exchange rate was last updated.

Returns:

  • (Time)


53
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 53

required :updated_at, Time, api_name: :updatedAt

#visible_in_uiBoolean

This indicates if the exchange rate is shown in the MultiCurrency settings page.

Returns:

  • (Boolean)


59
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 59

required :visible_in_ui, HubSpotSDK::Internal::Type::Boolean, api_name: :visibleInUI

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 265