Class: HubSpotSDK::Models::Settings::ExchangeRateCreateRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/settings/exchange_rate_create_request.rb

Defined Under Namespace

Modules: FromCurrencyCode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(conversion_rate:, from_currency_code:, effective_at: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Settings::ExchangeRateCreateRequest for more details.

Parameters:

  • conversion_rate (Float)

    The conversion rate between the to and from currency code of this exchange rate.

  • from_currency_code (Symbol, HubSpotSDK::Models::Settings::ExchangeRateCreateRequest::FromCurrencyCode)

    This represents the three-letter currency code (such as USD for US Dollar) of th

  • effective_at (Time) (defaults to: nil)

    The date the exchange rate is in effect.



# File 'lib/hubspot_sdk/models/settings/exchange_rate_create_request.rb', line 28

Instance Attribute Details

#conversion_rateFloat

The conversion rate between the to and from currency code of this exchange rate.

Returns:

  • (Float)


11
# File 'lib/hubspot_sdk/models/settings/exchange_rate_create_request.rb', line 11

required :conversion_rate, Float, api_name: :conversionRate

#effective_atTime?

The date the exchange rate is in effect.

Returns:

  • (Time, nil)


26
# File 'lib/hubspot_sdk/models/settings/exchange_rate_create_request.rb', line 26

optional :effective_at, Time, api_name: :effectiveAt

#from_currency_codeSymbol, HubSpotSDK::Models::Settings::ExchangeRateCreateRequest::FromCurrencyCode

This represents the three-letter currency code (such as USD for US Dollar) of the currency you want to convert from.



18
19
20
# File 'lib/hubspot_sdk/models/settings/exchange_rate_create_request.rb', line 18

required :from_currency_code,
enum: -> { HubSpotSDK::Settings::ExchangeRateCreateRequest::FromCurrencyCode },
api_name: :fromCurrencyCode