Class: HubSpotSDK::Models::Settings::ExchangeRateUpdateRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/settings/exchange_rate_update_request.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, conversion_rate:, effective_at: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Settings::ExchangeRateUpdateRequest for more details.

Parameters:

  • id (String)

    A unique identifier for the exchange rate being updated

  • conversion_rate (Float)

    The updated conversion rate between the to and from currency code of this exchan

  • effective_at (Time) (defaults to: nil)

    The date the exchange rate will be in effect.



# File 'lib/hubspot_sdk/models/settings/exchange_rate_update_request.rb', line 26

Instance Attribute Details

#conversion_rateFloat

The updated conversion rate between the to and from currency code of this exchange rate.

Returns:

  • (Float)


18
# File 'lib/hubspot_sdk/models/settings/exchange_rate_update_request.rb', line 18

required :conversion_rate, Float, api_name: :conversionRate

#effective_atTime?

The date the exchange rate will be in effect.

Returns:

  • (Time, nil)


24
# File 'lib/hubspot_sdk/models/settings/exchange_rate_update_request.rb', line 24

optional :effective_at, Time, api_name: :effectiveAt

#idString

A unique identifier for the exchange rate being updated

Returns:

  • (String)


11
# File 'lib/hubspot_sdk/models/settings/exchange_rate_update_request.rb', line 11

required :id, String