Class: HubSpotSDK::Models::Webhooks::ActionOverrideRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/webhooks/action_override_request.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(associated_object_type_ids: nil, list_ids: nil, object_ids: nil, properties: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::ActionOverrideRequest for more details.

Parameters:

  • associated_object_type_ids (Array<String>) (defaults to: nil)

    An array of strings, each representing an associated object type ID relevant to

  • list_ids (Array<Integer>) (defaults to: nil)

    An array of integers representing list IDs that are affected by the action overr

  • object_ids (Array<Integer>) (defaults to: nil)

    An array of integers, each representing an object ID for which the action overri

  • properties (Array<String>) (defaults to: nil)

    An array of strings representing specific properties to be overridden in the act



# File 'lib/hubspot_sdk/models/webhooks/action_override_request.rb', line 37

Instance Attribute Details

#associated_object_type_idsArray<String>?

An array of strings, each representing an associated object type ID relevant to the action override.

Returns:

  • (Array<String>, nil)


12
13
14
# File 'lib/hubspot_sdk/models/webhooks/action_override_request.rb', line 12

optional :associated_object_type_ids,
HubSpotSDK::Internal::Type::ArrayOf[String],
api_name: :associatedObjectTypeIds

#list_idsArray<Integer>?

An array of integers representing list IDs that are affected by the action override. These IDs are in int64 format.

Returns:

  • (Array<Integer>, nil)


21
# File 'lib/hubspot_sdk/models/webhooks/action_override_request.rb', line 21

optional :list_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :listIds

#object_idsArray<Integer>?

An array of integers, each representing an object ID for which the action override is applicable. These IDs are in int64 format.

Returns:

  • (Array<Integer>, nil)


28
# File 'lib/hubspot_sdk/models/webhooks/action_override_request.rb', line 28

optional :object_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :objectIds

#propertiesArray<String>?

An array of strings representing specific properties to be overridden in the action. Each entry in the array corresponds to a property name.

Returns:

  • (Array<String>, nil)


35
# File 'lib/hubspot_sdk/models/webhooks/action_override_request.rb', line 35

optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String]