Class: HubSpotSDK::Models::Webhooks::BatchResponseJournalFetchResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/webhooks/batch_response_journal_fetch_response.rb

Overview

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(completed_at:, results:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::BatchResponseJournalFetchResponse for more details.

Parameters:

  • completed_at (Time)

    The date and time when the batch operation was completed, in ISO 8601 format.

  • results (Array<HubSpotSDK::Models::Webhooks::JournalFetchResponse>)

    An array of journal fetch responses, each containing details about individual jo

  • started_at (Time)

    The date and time when the batch operation started, in ISO 8601 format.

  • status (Symbol, HubSpotSDK::Models::Webhooks::BatchResponseJournalFetchResponse::Status)

    The current status of the batch operation. Valid values include ‘PENDING’, ‘PROC

  • links (Hash{Symbol=>String}) (defaults to: nil)

    A map of link names to associated URIs, providing additional resources or docume

  • requested_at (Time) (defaults to: nil)

    The date and time when the batch operation was requested, in ISO 8601 format.



# File 'lib/hubspot_sdk/models/webhooks/batch_response_journal_fetch_response.rb', line 47

Instance Attribute Details

#completed_atTime

The date and time when the batch operation was completed, in ISO 8601 format.

Returns:

  • (Time)


12
# File 'lib/hubspot_sdk/models/webhooks/batch_response_journal_fetch_response.rb', line 12

required :completed_at, Time, api_name: :completedAt

A map of link names to associated URIs, providing additional resources or documentation related to the batch operation.

Returns:

  • (Hash{Symbol=>String}, nil)


39
# File 'lib/hubspot_sdk/models/webhooks/batch_response_journal_fetch_response.rb', line 39

optional :links, HubSpotSDK::Internal::Type::HashOf[String]

#requested_atTime?

The date and time when the batch operation was requested, in ISO 8601 format.

Returns:

  • (Time, nil)


45
# File 'lib/hubspot_sdk/models/webhooks/batch_response_journal_fetch_response.rb', line 45

optional :requested_at, Time, api_name: :requestedAt

#resultsArray<HubSpotSDK::Models::Webhooks::JournalFetchResponse>

An array of journal fetch responses, each containing details about individual journal entries.



19
# File 'lib/hubspot_sdk/models/webhooks/batch_response_journal_fetch_response.rb', line 19

required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Webhooks::JournalFetchResponse] }

#started_atTime

The date and time when the batch operation started, in ISO 8601 format.

Returns:

  • (Time)


25
# File 'lib/hubspot_sdk/models/webhooks/batch_response_journal_fetch_response.rb', line 25

required :started_at, Time, api_name: :startedAt

#statusSymbol, HubSpotSDK::Models::Webhooks::BatchResponseJournalFetchResponse::Status

The current status of the batch operation. Valid values include ‘PENDING’, ‘PROCESSING’, ‘CANCELED’, and ‘COMPLETE’.



32
# File 'lib/hubspot_sdk/models/webhooks/batch_response_journal_fetch_response.rb', line 32

required :status, enum: -> { HubSpotSDK::Webhooks::BatchResponseJournalFetchResponse::Status }