Class: HubSpotSDK::Models::Webhooks::Condition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Webhooks::Condition
- Defined in:
- lib/hubspot_sdk/models/webhooks/condition.rb
Defined Under Namespace
Modules: FilterType, Operator
Instance Attribute Summary collapse
-
#filter_type ⇒ Symbol, HubSpotSDK::Models::Webhooks::Condition::FilterType
A string indicating the type of filter being applied.
-
#operator ⇒ Symbol, HubSpotSDK::Models::Webhooks::Condition::Operator
A string specifying the operation to be performed in the condition.
-
#property ⇒ String
A string representing the specific property of the CRM object that the condition applies to.
-
#value ⇒ String?
A string representing the value to be compared against the specified property when using single-value operators.
-
#values ⇒ Array<String>?
An array of strings used to specify multiple values for comparison when using operators that support multiple values, such as ‘IN’ or ‘NOT_IN’.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(filter_type:, operator:, property:, value: nil, values: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Condition for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(filter_type:, operator:, property:, value: nil, values: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::Condition for more details.
|
|
# File 'lib/hubspot_sdk/models/webhooks/condition.rb', line 43
|
Instance Attribute Details
#filter_type ⇒ Symbol, HubSpotSDK::Models::Webhooks::Condition::FilterType
A string indicating the type of filter being applied. Valid value is ‘CRM_OBJECT_PROPERTY’.
12 |
# File 'lib/hubspot_sdk/models/webhooks/condition.rb', line 12 required :filter_type, enum: -> { HubSpotSDK::Webhooks::Condition::FilterType }, api_name: :filterType |
#operator ⇒ Symbol, HubSpotSDK::Models::Webhooks::Condition::Operator
A string specifying the operation to be performed in the condition. Valid values include ‘EQ’, ‘N_EQ’, ‘LT’, ‘GT’, ‘LTE’, ‘GTE’, ‘CONTAINS’, ‘STARTS_WITH’, ‘ENDS_WITH’, ‘IN’, ‘NOT_IN’, ‘IS_EMPTY’, and ‘IS_NOT_EMPTY’.
20 |
# File 'lib/hubspot_sdk/models/webhooks/condition.rb', line 20 required :operator, enum: -> { HubSpotSDK::Webhooks::Condition::Operator } |
#property ⇒ String
A string representing the specific property of the CRM object that the condition applies to.
27 |
# File 'lib/hubspot_sdk/models/webhooks/condition.rb', line 27 required :property, String |
#value ⇒ String?
A string representing the value to be compared against the specified property when using single-value operators.
34 |
# File 'lib/hubspot_sdk/models/webhooks/condition.rb', line 34 optional :value, String |
#values ⇒ Array<String>?
An array of strings used to specify multiple values for comparison when using operators that support multiple values, such as ‘IN’ or ‘NOT_IN’.
41 |
# File 'lib/hubspot_sdk/models/webhooks/condition.rb', line 41 optional :values, HubSpotSDK::Internal::Type::ArrayOf[String] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/webhooks/condition.rb', line 66
|