Class: HubSpotSDK::Models::Webhooks::CrmObjectSnapshotRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/webhooks/crm_object_snapshot_request.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(object_id_:, object_type_id:, portal_id:, properties:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::CrmObjectSnapshotRequest for more details.

Parameters:

  • object_id_ (Integer)

    An integer representing the unique identifier of the CRM object for which the sn

  • object_type_id (String)

    A string representing the type identifier of the CRM object.

  • portal_id (Integer)

    An integer representing the unique identifier of the HubSpot portal.

  • properties (Array<String>)

    An array of strings, each representing a property of the CRM object to be includ



# File 'lib/hubspot_sdk/models/webhooks/crm_object_snapshot_request.rb', line 33

Instance Attribute Details

#object_id_Integer

An integer representing the unique identifier of the CRM object for which the snapshot is being requested.

Returns:

  • (Integer)


12
# File 'lib/hubspot_sdk/models/webhooks/crm_object_snapshot_request.rb', line 12

required :object_id_, Integer, api_name: :objectId

#object_type_idString

A string representing the type identifier of the CRM object.

Returns:

  • (String)


18
# File 'lib/hubspot_sdk/models/webhooks/crm_object_snapshot_request.rb', line 18

required :object_type_id, String, api_name: :objectTypeId

#portal_idInteger

An integer representing the unique identifier of the HubSpot portal.

Returns:

  • (Integer)


24
# File 'lib/hubspot_sdk/models/webhooks/crm_object_snapshot_request.rb', line 24

required :portal_id, Integer, api_name: :portalId

#propertiesArray<String>

An array of strings, each representing a property of the CRM object to be included in the snapshot.

Returns:

  • (Array<String>)


31
# File 'lib/hubspot_sdk/models/webhooks/crm_object_snapshot_request.rb', line 31

required :properties, HubSpotSDK::Internal::Type::ArrayOf[String]