Class: HubSpotSDK::Models::Webhooks::CrmObjectSnapshotResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Webhooks::CrmObjectSnapshotResponse
- Defined in:
- lib/hubspot_sdk/models/webhooks/crm_object_snapshot_response.rb
Instance Attribute Summary collapse
-
#object_id_ ⇒ Integer
An integer representing the unique identifier of the CRM object for which the snapshot is taken.
-
#object_type_id ⇒ String
A string indicating the type of the CRM object, such as contact, company, or deal.
-
#portal_id ⇒ Integer
An integer representing the unique identifier of the HubSpot portal associated with the CRM object.
-
#snapshot_status_id ⇒ String
A UUID string representing the status identifier of the snapshot request, indicating the current state of the snapshot process.
Instance Method Summary collapse
-
#initialize(object_id_:, object_type_id:, portal_id:, snapshot_status_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CrmObjectSnapshotResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(object_id_:, object_type_id:, portal_id:, snapshot_status_id:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::CrmObjectSnapshotResponse for more details.
|
|
# File 'lib/hubspot_sdk/models/webhooks/crm_object_snapshot_response.rb', line 35
|
Instance Attribute Details
#object_id_ ⇒ Integer
An integer representing the unique identifier of the CRM object for which the snapshot is taken.
12 |
# File 'lib/hubspot_sdk/models/webhooks/crm_object_snapshot_response.rb', line 12 required :object_id_, Integer, api_name: :objectId |
#object_type_id ⇒ String
A string indicating the type of the CRM object, such as contact, company, or deal.
19 |
# File 'lib/hubspot_sdk/models/webhooks/crm_object_snapshot_response.rb', line 19 required :object_type_id, String, api_name: :objectTypeId |
#portal_id ⇒ Integer
An integer representing the unique identifier of the HubSpot portal associated with the CRM object.
26 |
# File 'lib/hubspot_sdk/models/webhooks/crm_object_snapshot_response.rb', line 26 required :portal_id, Integer, api_name: :portalId |
#snapshot_status_id ⇒ String
A UUID string representing the status identifier of the snapshot request, indicating the current state of the snapshot process.
33 |
# File 'lib/hubspot_sdk/models/webhooks/crm_object_snapshot_response.rb', line 33 required :snapshot_status_id, String, api_name: :snapshotStatusId |