Class: HubSpotSDK::Models::Webhooks::Filter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Webhooks::Filter
- Defined in:
- lib/hubspot_sdk/models/webhooks/filter.rb
Instance Attribute Summary collapse
-
#conditions ⇒ Array<HubSpotSDK::Models::Webhooks::Condition>
An array of conditions that define the filter criteria.
Instance Method Summary collapse
-
#initialize(conditions:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Filter for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(conditions:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::Filter for more details.
Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against.
|
|
# File 'lib/hubspot_sdk/models/webhooks/filter.rb', line 15
|
Instance Attribute Details
#conditions ⇒ Array<HubSpotSDK::Models::Webhooks::Condition>
An array of conditions that define the filter criteria. Each condition specifies a property, operator, and value to determine if a data item meets the filter requirements.
13 |
# File 'lib/hubspot_sdk/models/webhooks/filter.rb', line 13 required :conditions, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Webhooks::Condition] } |