Class: HubSpotSDK::Models::Webhooks::FilterResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/webhooks/filter_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, filter:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::FilterResponse for more details.

Parameters:

  • id (Integer)

    The unique identifier for the filter. It is an integer in int64 format.

  • created_at (Integer)

    A timestamp indicating when the filter was created, represented as an integer in

  • filter (HubSpotSDK::Models::Webhooks::Filter)

    Defines a single condition for searching CRM objects, specifying the property to



# File 'lib/hubspot_sdk/models/webhooks/filter_response.rb', line 29

Instance Attribute Details

#created_atInteger

A timestamp indicating when the filter was created, represented as an integer in int64 format.

Returns:

  • (Integer)


19
# File 'lib/hubspot_sdk/models/webhooks/filter_response.rb', line 19

required :created_at, Integer, api_name: :createdAt

#filterHubSpotSDK::Models::Webhooks::Filter

Defines a single condition for searching CRM objects, specifying the property to filter on, the operator to use (such as equals, greater than, or contains), and the value(s) to compare against.



27
# File 'lib/hubspot_sdk/models/webhooks/filter_response.rb', line 27

required :filter, -> { HubSpotSDK::Webhooks::Filter }

#idInteger

The unique identifier for the filter. It is an integer in int64 format.

Returns:

  • (Integer)


12
# File 'lib/hubspot_sdk/models/webhooks/filter_response.rb', line 12

required :id, Integer