Class: HubSpotSDK::Models::Webhooks::SettingsChangeRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/webhooks/settings_change_request.rb

Direct Known Subclasses

WebhookUpdateSettingsParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(target_url:, throttling:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::SettingsChangeRequest for more details.

Parameters:



# File 'lib/hubspot_sdk/models/webhooks/settings_change_request.rb', line 20

Instance Attribute Details

#target_urlString

A publicly available URL for Hubspot to call where event payloads will be delivered. See [link-so-some-doc](#) for details about the format of these event payloads.

Returns:

  • (String)


13
# File 'lib/hubspot_sdk/models/webhooks/settings_change_request.rb', line 13

required :target_url, String, api_name: :targetUrl

#throttlingHubSpotSDK::Models::Webhooks::ThrottlingSettings



18
# File 'lib/hubspot_sdk/models/webhooks/settings_change_request.rb', line 18

required :throttling, -> { HubSpotSDK::Webhooks::ThrottlingSettings }