Class: HubSpotSDK::Models::Webhooks::SettingsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/webhooks/settings_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(created_at:, target_url:, throttling:, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::SettingsResponse for more details.

Parameters:

  • created_at (Time)

    When this subscription was created. Formatted as milliseconds from the [Unix epo

  • target_url (String)

    A publicly available URL for Hubspot to call where event payloads will be delive

  • throttling (HubSpotSDK::Models::Webhooks::ThrottlingSettings)
  • updated_at (Time) (defaults to: nil)

    When this subscription was last updated. Formatted as milliseconds from the [Uni



# File 'lib/hubspot_sdk/models/webhooks/settings_response.rb', line 35

Instance Attribute Details

#created_atTime

When this subscription was created. Formatted as milliseconds from the [Unix epoch](#).

Returns:

  • (Time)


13
# File 'lib/hubspot_sdk/models/webhooks/settings_response.rb', line 13

required :created_at, Time, api_name: :createdAt

#target_urlString

A publicly available URL for Hubspot to call where event payloads will be delivered. See [link-so-some-doc](#) for details about the format of these event payloads.

Returns:

  • (String)


21
# File 'lib/hubspot_sdk/models/webhooks/settings_response.rb', line 21

required :target_url, String, api_name: :targetUrl

#throttlingHubSpotSDK::Models::Webhooks::ThrottlingSettings



26
# File 'lib/hubspot_sdk/models/webhooks/settings_response.rb', line 26

required :throttling, -> { HubSpotSDK::Webhooks::ThrottlingSettings }

#updated_atTime?

When this subscription was last updated. Formatted as milliseconds from the [Unix epoch](#).

Returns:

  • (Time, nil)


33
# File 'lib/hubspot_sdk/models/webhooks/settings_response.rb', line 33

optional :updated_at, Time, api_name: :updatedAt