Class: HubSpotSDK::Models::Webhooks::SnapshotStatusResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb

Overview

Defined Under Namespace

Modules: ErrorCode, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, initiated_at:, status:, completed_at: nil, error_code: nil, message: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::SnapshotStatusResponse for more details.

Parameters:

  • id (String)

    The unique identifier for the snapshot operation, represented as a UUID.

  • initiated_at (Integer)

    The timestamp indicating when the snapshot operation was initiated, represented

  • status (Symbol, HubSpotSDK::Models::Webhooks::SnapshotStatusResponse::Status)

    The current status of the snapshot. Valid values include ‘PENDING’, ‘IN_PROGRESS

  • completed_at (Integer) (defaults to: nil)

    The timestamp indicating when the snapshot operation was completed, represented

  • error_code (Symbol, HubSpotSDK::Models::Webhooks::SnapshotStatusResponse::ErrorCode) (defaults to: nil)

    A code representing the error that occurred, if any. Possible values are ‘TIMEOU

  • message (String) (defaults to: nil)

    A descriptive message providing additional information about the snapshot operat



# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 51

Instance Attribute Details

#completed_atInteger?

The timestamp indicating when the snapshot operation was completed, represented as a Unix timestamp in milliseconds.

Returns:

  • (Integer, nil)


33
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 33

optional :completed_at, Integer, api_name: :completedAt

#error_codeSymbol, ...

A code representing the error that occurred, if any. Possible values are ‘TIMEOUT’, ‘VALIDATION_ERROR’, ‘INTERNAL_ERROR’, and ‘PERMISSION_DENIED’.



40
41
42
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 40

optional :error_code,
enum: -> { HubSpotSDK::Webhooks::SnapshotStatusResponse::ErrorCode },
api_name: :errorCode

#idString

The unique identifier for the snapshot operation, represented as a UUID.

Returns:

  • (String)


12
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 12

required :id, String

#initiated_atInteger

The timestamp indicating when the snapshot operation was initiated, represented as a Unix timestamp in milliseconds.

Returns:

  • (Integer)


19
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 19

required :initiated_at, Integer, api_name: :initiatedAt

#messageString?

A descriptive message providing additional information about the snapshot operation or error.

Returns:

  • (String, nil)


49
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 49

optional :message, String

#statusSymbol, HubSpotSDK::Models::Webhooks::SnapshotStatusResponse::Status

The current status of the snapshot. Valid values include ‘PENDING’, ‘IN_PROGRESS’, ‘COMPLETED’, ‘FAILED’, and ‘EXPIRED’.



26
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 26

required :status, enum: -> { HubSpotSDK::Webhooks::SnapshotStatusResponse::Status }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 80