Class: HubSpotSDK::Models::Webhooks::SubscriptionBatchUpdateRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Webhooks::SubscriptionBatchUpdateRequest
- Defined in:
- lib/hubspot_sdk/models/webhooks/subscription_batch_update_request.rb
Instance Attribute Summary collapse
-
#active ⇒ Boolean
A boolean indicating whether the subscription is active.
-
#id ⇒ Integer
The unique identifier for the subscription to be updated.
Instance Method Summary collapse
- #initialize(id:, active:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, active:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_batch_update_request.rb', line 19
|
Instance Attribute Details
#active ⇒ Boolean
A boolean indicating whether the subscription is active.
17 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_batch_update_request.rb', line 17 required :active, HubSpotSDK::Internal::Type::Boolean |
#id ⇒ Integer
The unique identifier for the subscription to be updated. It is an integer.
11 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_batch_update_request.rb', line 11 required :id, Integer |