Class: HubSpotSDK::Models::Webhooks::SubscriptionCreateRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/webhooks/subscription_create_request.rb

Direct Known Subclasses

WebhookCreateEventSubscriptionParams

Defined Under Namespace

Modules: EventType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(active:, event_type:, event_type_name: nil, object_type_id: nil, property_name: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::SubscriptionCreateRequest for more details.

Parameters:

  • active (Boolean)

    A boolean indicating whether the subscription is active. This field is required.

  • event_type (Symbol, HubSpotSDK::Models::Webhooks::SubscriptionCreateRequest::EventType)

    A string representing the type of event to subscribe to. Valid values include va

  • event_type_name (String) (defaults to: nil)

    A string that provides a human-readable name for the event type. This is optiona

  • object_type_id (String) (defaults to: nil)

    A string representing the identifier of the object type for which the subscripti

  • property_name (String) (defaults to: nil)

    A string indicating the name of the property that triggers the event. This is op



# File 'lib/hubspot_sdk/models/webhooks/subscription_create_request.rb', line 44

Instance Attribute Details

#activeBoolean

A boolean indicating whether the subscription is active. This field is required.

Returns:

  • (Boolean)


11
# File 'lib/hubspot_sdk/models/webhooks/subscription_create_request.rb', line 11

required :active, HubSpotSDK::Internal::Type::Boolean

#event_typeSymbol, HubSpotSDK::Models::Webhooks::SubscriptionCreateRequest::EventType

A string representing the type of event to subscribe to. Valid values include various object changes such as ‘contact.propertyChange’, ‘deal.creation’, and ‘conversation.newMessage’.



19
20
21
# File 'lib/hubspot_sdk/models/webhooks/subscription_create_request.rb', line 19

required :event_type,
enum: -> { HubSpotSDK::Webhooks::SubscriptionCreateRequest::EventType },
api_name: :eventType

#event_type_nameString?

A string that provides a human-readable name for the event type. This is optional.

Returns:

  • (String, nil)


28
# File 'lib/hubspot_sdk/models/webhooks/subscription_create_request.rb', line 28

optional :event_type_name, String, api_name: :eventTypeName

#object_type_idString?

A string representing the identifier of the object type for which the subscription is being created. This is optional.

Returns:

  • (String, nil)


35
# File 'lib/hubspot_sdk/models/webhooks/subscription_create_request.rb', line 35

optional :object_type_id, String, api_name: :objectTypeId

#property_nameString?

A string indicating the name of the property that triggers the event. This is optional and used when subscribing to property change events.

Returns:

  • (String, nil)


42
# File 'lib/hubspot_sdk/models/webhooks/subscription_create_request.rb', line 42

optional :property_name, String, api_name: :propertyName