Class: HubSpotSDK::Models::Webhooks::SubscriptionListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Webhooks::SubscriptionListResponse
- Defined in:
- lib/hubspot_sdk/models/webhooks/subscription_list_response.rb
Overview
Instance Attribute Summary collapse
-
#results ⇒ Array<HubSpotSDK::Models::Webhooks::SubscriptionResponse>
An array containing all active and paused event subscriptions configured for the app.
Instance Method Summary collapse
-
#initialize(results:) ⇒ Object
constructor
Some parameter documentations has been truncated, see SubscriptionListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(results:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::SubscriptionListResponse for more details.
|
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_list_response.rb', line 15
|
Instance Attribute Details
#results ⇒ Array<HubSpotSDK::Models::Webhooks::SubscriptionResponse>
An array containing all active and paused event subscriptions configured for the app.
13 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_list_response.rb', line 13 required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Webhooks::SubscriptionResponse] } |