Class: HubSpotSDK::Models::Webhooks::SubscriptionResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/webhooks/subscription_response.rb

Overview

Defined Under Namespace

Modules: EventType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, active:, created_at:, event_type:, event_type_name: nil, object_type_id: nil, property_name: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::SubscriptionResponse for more details.

Parameters:

  • id (String)

    The unique identifier for the subscription, represented as an integer.

  • active (Boolean)

    A boolean indicating whether the subscription is currently active.

  • created_at (Time)

    The date and time when the subscription was created, in ISO 8601 format.

  • event_type (Symbol, HubSpotSDK::Models::Webhooks::SubscriptionResponse::EventType)

    The type of event that triggers the subscription. Valid values include various o

  • event_type_name (String) (defaults to: nil)

    A descriptive name for the event type.

  • object_type_id (String) (defaults to: nil)

    The identifier for the object type associated with the subscription, represented

  • property_name (String) (defaults to: nil)

    The name of the property associated with the event, if applicable.

  • updated_at (Time) (defaults to: nil)

    The date and time when the subscription was last updated, in ISO 8601 format.



# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 61

Instance Attribute Details

#activeBoolean

A boolean indicating whether the subscription is currently active.

Returns:

  • (Boolean)


18
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 18

required :active, HubSpotSDK::Internal::Type::Boolean

#created_atTime

The date and time when the subscription was created, in ISO 8601 format.

Returns:

  • (Time)


24
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 24

required :created_at, Time, api_name: :createdAt

#event_typeSymbol, HubSpotSDK::Models::Webhooks::SubscriptionResponse::EventType

The type of event that triggers the subscription. Valid values include various object changes such as ‘contact.propertyChange’, ‘deal.creation’, and ‘ticket.deletion’.



32
33
34
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 32

required :event_type,
enum: -> { HubSpotSDK::Webhooks::SubscriptionResponse::EventType },
api_name: :eventType

#event_type_nameString?

A descriptive name for the event type.

Returns:

  • (String, nil)


40
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 40

optional :event_type_name, String, api_name: :eventTypeName

#idString

The unique identifier for the subscription, represented as an integer.

Returns:

  • (String)


12
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 12

required :id, String

#object_type_idString?

The identifier for the object type associated with the subscription, represented as a string.

Returns:

  • (String, nil)


47
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 47

optional :object_type_id, String, api_name: :objectTypeId

#property_nameString?

The name of the property associated with the event, if applicable.

Returns:

  • (String, nil)


53
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 53

optional :property_name, String, api_name: :propertyName

#updated_atTime?

The date and time when the subscription was last updated, in ISO 8601 format.

Returns:

  • (Time, nil)


59
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 59

optional :updated_at, Time, api_name: :updatedAt