Class: HubSpotSDK::Models::Webhooks::SubscriptionResponse1
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Webhooks::SubscriptionResponse1
- Defined in:
- lib/hubspot_sdk/models/webhooks/subscription_response_1.rb
Overview
Defined Under Namespace
Modules: Action, SubscriptionType
Instance Attribute Summary collapse
-
#action_overrides ⇒ Hash{Symbol=>HubSpotSDK::Models::Webhooks::ActionOverrideRequest}?
An object containing action overrides, where each key is an action and the value is an ActionOverrideRequest object.
-
#actions ⇒ Array<Symbol, HubSpotSDK::Models::Webhooks::SubscriptionResponse1::Action>
A list of actions that trigger the subscription.
-
#app_id ⇒ Integer
The unique identifier for the app associated with the subscription.
-
#associated_object_type_ids ⇒ Array<String>?
A list of associated object type IDs.
-
#created_at ⇒ Time
The date and time when the subscription was created, in ISO 8601 format.
-
#created_by ⇒ Integer?
The ID of the user who created the subscription.
-
#deleted_at ⇒ Time?
The date and time when the subscription was deleted, in ISO 8601 format, if applicable.
-
#id ⇒ Integer
The unique identifier for the subscription.
-
#list_ids ⇒ Array<Integer>?
A list of list IDs associated with the subscription.
-
#object_ids ⇒ Array<Integer>?
A list of object IDs associated with the subscription.
-
#object_type_id ⇒ String
The identifier for the object type associated with the subscription.
-
#portal_id ⇒ Integer?
The unique identifier for the portal associated with the subscription.
-
#properties ⇒ Array<String>?
A list of property names associated with the subscription.
-
#subscription_type ⇒ Symbol, HubSpotSDK::Models::Webhooks::SubscriptionResponse1::SubscriptionType
The type of subscription, which can be one of the following: ‘OBJECT’, ‘ASSOCIATION’, ‘EVENT’, ‘APP_LIFECYCLE_EVENT’, ‘LIST_MEMBERSHIP’, or ‘GDPR_PRIVACY_DELETION’.
-
#updated_at ⇒ Time
The date and time when the subscription was last updated, in ISO 8601 format.
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#action_overrides ⇒ Hash{Symbol=>HubSpotSDK::Models::Webhooks::ActionOverrideRequest}?
An object containing action overrides, where each key is an action and the value is an ActionOverrideRequest object.
65 66 67 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 65 optional :action_overrides, -> { HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Webhooks::ActionOverrideRequest] }, api_name: :actionOverrides |
#actions ⇒ Array<Symbol, HubSpotSDK::Models::Webhooks::SubscriptionResponse1::Action>
A list of actions that trigger the subscription. Possible values include ‘CREATE’, ‘UPDATE’, ‘DELETE’, ‘MERGE’, ‘RESTORE’, ‘ASSOCIATION_ADDED’, ‘ASSOCIATION_REMOVED’, ‘SNAPSHOT’, ‘APP_INSTALL’, ‘APP_UNINSTALL’, ‘ADDED_TO_LIST’, ‘REMOVED_FROM_LIST’, and ‘GDPR_DELETE’.
21 22 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 21 required :actions, -> { HubSpotSDK::Internal::Type::ArrayOf[enum: HubSpotSDK::Webhooks::SubscriptionResponse1::Action] } |
#app_id ⇒ Integer
The unique identifier for the app associated with the subscription. It is an integer formatted as int64.
29 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 29 required :app_id, Integer, api_name: :appId |
#associated_object_type_ids ⇒ Array<String>?
A list of associated object type IDs. Each ID is a string.
73 74 75 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 73 optional :associated_object_type_ids, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :associatedObjectTypeIds |
#created_at ⇒ Time
The date and time when the subscription was created, in ISO 8601 format.
35 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 35 required :created_at, Time, api_name: :createdAt |
#created_by ⇒ Integer?
The ID of the user who created the subscription. It is an integer formatted as int64.
82 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 82 optional :created_by, Integer, api_name: :createdBy |
#deleted_at ⇒ Time?
The date and time when the subscription was deleted, in ISO 8601 format, if applicable.
89 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 89 optional :deleted_at, Time, api_name: :deletedAt |
#id ⇒ Integer
The unique identifier for the subscription. It is an integer formatted as int64.
12 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 12 required :id, Integer |
#list_ids ⇒ Array<Integer>?
A list of list IDs associated with the subscription. Each ID is an integer formatted as int64.
96 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 96 optional :list_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :listIds |
#object_ids ⇒ Array<Integer>?
A list of object IDs associated with the subscription. Each ID is an integer formatted as int64.
103 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 103 optional :object_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :objectIds |
#object_type_id ⇒ String
The identifier for the object type associated with the subscription. It is a string.
42 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 42 required :object_type_id, String, api_name: :objectTypeId |
#portal_id ⇒ Integer?
The unique identifier for the portal associated with the subscription. It is an integer formatted as int64.
110 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 110 optional :portal_id, Integer, api_name: :portalId |
#properties ⇒ Array<String>?
A list of property names associated with the subscription. Each property is a string.
117 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 117 optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String] |
#subscription_type ⇒ Symbol, HubSpotSDK::Models::Webhooks::SubscriptionResponse1::SubscriptionType
The type of subscription, which can be one of the following: ‘OBJECT’, ‘ASSOCIATION’, ‘EVENT’, ‘APP_LIFECYCLE_EVENT’, ‘LIST_MEMBERSHIP’, or ‘GDPR_PRIVACY_DELETION’.
50 51 52 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 50 required :subscription_type, enum: -> { HubSpotSDK::Webhooks::SubscriptionResponse1::SubscriptionType }, api_name: :subscriptionType |
#updated_at ⇒ Time
The date and time when the subscription was last updated, in ISO 8601 format.
58 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 58 required :updated_at, Time, api_name: :updatedAt |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 170
|