Module: HubSpotSDK::Models::Webhooks::SubscriptionResponse1::Action

Extended by:
Internal::Type::Enum
Defined in:
lib/hubspot_sdk/models/webhooks/subscription_response_1.rb

Constant Summary collapse

CREATE =
:CREATE
UPDATE =
:UPDATE
DELETE =
:DELETE
MERGE =
:MERGE
RESTORE =
:RESTORE
ASSOCIATION_ADDED =
:ASSOCIATION_ADDED
ASSOCIATION_REMOVED =
:ASSOCIATION_REMOVED
SNAPSHOT =
:SNAPSHOT
APP_INSTALL =
:APP_INSTALL
APP_UNINSTALL =
:APP_UNINSTALL
ADDED_TO_LIST =
:ADDED_TO_LIST
REMOVED_FROM_LIST =
:REMOVED_FROM_LIST
GDPR_DELETE =
:GDPR_DELETE

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(id:, actions:, app_id:, created_at:, object_type_id:, subscription_type:, updated_at:, action_overrides: nil, associated_object_type_ids: nil, created_by: nil, deleted_at: nil, list_ids: nil, object_ids: nil, portal_id: nil, properties: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::SubscriptionResponse1 for more details.

Parameters:

  • id (Integer)

    The unique identifier for the subscription, represented as an integer.

  • actions (Array<Symbol, HubSpotSDK::Models::Webhooks::SubscriptionResponse1::Action>)

    An array of actions that trigger the subscription, such as ‘CREATE’, ‘UPDATE’, ‘

  • app_id (Integer)

    The unique identifier for the app associated with the subscription, represented

  • created_at (Time)

    The date and time when the subscription was created, in ISO 8601 format.

  • object_type_id (String)

    The identifier for the object type associated with the subscription, represented

  • subscription_type (Symbol, HubSpotSDK::Models::Webhooks::SubscriptionResponse1::SubscriptionType)

    The type of subscription, which can be one of ‘OBJECT’, ‘ASSOCIATION’, ‘EVENT’,

  • updated_at (Time)

    The date and time when the subscription was last updated, in ISO 8601 format.

  • action_overrides (Hash{Symbol=>HubSpotSDK::Models::Webhooks::ActionOverrideRequest}) (defaults to: nil)

    An object containing action overrides, where each key is an action and the value

  • associated_object_type_ids (Array<String>) (defaults to: nil)

    An array of strings representing the associated object type IDs for the subscrip

  • created_by (Integer) (defaults to: nil)

    The unique identifier for the user who created the subscription, represented as

  • deleted_at (Time) (defaults to: nil)

    The date and time when the subscription was deleted, in ISO 8601 format.

  • list_ids (Array<Integer>) (defaults to: nil)

    An array of integers representing the list IDs associated with the subscription.

  • object_ids (Array<Integer>) (defaults to: nil)

    An array of integers representing the object IDs associated with the subscriptio

  • portal_id (Integer) (defaults to: nil)

    The unique identifier for the portal associated with the subscription, represent

  • properties (Array<String>) (defaults to: nil)

    An array of strings representing the properties associated with the subscription



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 151

module Action
  extend HubSpotSDK::Internal::Type::Enum

  CREATE = :CREATE
  UPDATE = :UPDATE
  DELETE = :DELETE
  MERGE = :MERGE
  RESTORE = :RESTORE
  ASSOCIATION_ADDED = :ASSOCIATION_ADDED
  ASSOCIATION_REMOVED = :ASSOCIATION_REMOVED
  SNAPSHOT = :SNAPSHOT
  APP_INSTALL = :APP_INSTALL
  APP_UNINSTALL = :APP_UNINSTALL
  ADDED_TO_LIST = :ADDED_TO_LIST
  REMOVED_FROM_LIST = :REMOVED_FROM_LIST
  GDPR_DELETE = :GDPR_DELETE

  # @!method self.values
  #   @return [Array<Symbol>]
end