Class: HubSpotSDK::Models::Webhooks::ThrottlingSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/webhooks/throttling_settings.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(max_concurrent_requests:) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::ThrottlingSettings for more details.

Parameters:

  • max_concurrent_requests (Integer)

    The maximum number of HTTP requests HubSpot will attempt to make to your app in



# File 'lib/hubspot_sdk/models/webhooks/throttling_settings.rb', line 14

Instance Attribute Details

#max_concurrent_requestsInteger

The maximum number of HTTP requests HubSpot will attempt to make to your app in a given time frame determined by ‘period`.

Returns:

  • (Integer)


12
# File 'lib/hubspot_sdk/models/webhooks/throttling_settings.rb', line 12

required :max_concurrent_requests, Integer, api_name: :maxConcurrentRequests