Class: HubSpotSDK::Models::WebhooksJournal::JournalSubscriptionResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb

Defined Under Namespace

Modules: Action, SubscriptionType

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel

Instance Attribute Details

#action_overridesHash{Symbol=>HubSpotSDK::Models::ActionOverrideRequest}?

An object containing overrides for actions, where each key is an action and the value is an ActionOverrideRequest object.

Returns:



64
65
66
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 64

optional :action_overrides,
-> { HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::ActionOverrideRequest] },
api_name: :actionOverrides

#actionsArray<Symbol, HubSpotSDK::Models::WebhooksJournal::JournalSubscriptionResponse::Action>

An array of actions associated with the subscription. Valid actions include ‘CREATE’, ‘UPDATE’, ‘DELETE’, ‘MERGE’, ‘RESTORE’, ‘ASSOCIATION_ADDED’, ‘ASSOCIATION_REMOVED’, ‘SNAPSHOT’, ‘APP_INSTALL’, ‘APP_UNINSTALL’, ‘ADDED_TO_LIST’, ‘REMOVED_FROM_LIST’, and ‘GDPR_DELETE’.



20
21
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 20

required :actions,
-> { HubSpotSDK::Internal::Type::ArrayOf[enum: HubSpotSDK::WebhooksJournal::JournalSubscriptionResponse::Action] }

#app_idInteger

The unique identifier for the app associated with the subscription, represented as an integer.

Returns:

  • (Integer)


28
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 28

required :app_id, Integer, api_name: :appId

#associated_object_type_idsArray<String>?

An array of strings representing the IDs of associated object types.

Returns:

  • (Array<String>, nil)


72
73
74
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 72

optional :associated_object_type_ids,
HubSpotSDK::Internal::Type::ArrayOf[String],
api_name: :associatedObjectTypeIds

#created_atTime

The date and time when the subscription was created, in ISO 8601 format.

Returns:

  • (Time)


34
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 34

required :created_at, Time, api_name: :createdAt

#created_byInteger?

The unique identifier of the user who created the subscription, represented as an integer.

Returns:

  • (Integer, nil)


81
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 81

optional :created_by, Integer, api_name: :createdBy

#deleted_atTime?

The date and time when the subscription was deleted, in ISO 8601 format, if applicable.

Returns:

  • (Time, nil)


88
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 88

optional :deleted_at, Time, api_name: :deletedAt

#idInteger

The unique identifier for the subscription, represented as an integer.

Returns:

  • (Integer)


11
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 11

required :id, Integer

#list_idsArray<Integer>?

An array of integers representing the IDs of lists associated with the subscription.

Returns:

  • (Array<Integer>, nil)


95
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 95

optional :list_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :listIds

#object_idsArray<Integer>?

An array of integers representing the IDs of objects associated with the subscription.

Returns:

  • (Array<Integer>, nil)


102
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 102

optional :object_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :objectIds

#object_type_idString

The identifier for the type of object associated with the subscription, represented as a string.

Returns:

  • (String)


41
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 41

required :object_type_id, String, api_name: :objectTypeId

#portal_idInteger?

The unique identifier for the portal associated with the subscription, represented as an integer.

Returns:

  • (Integer, nil)


109
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 109

optional :portal_id, Integer, api_name: :portalId

#propertiesArray<String>?

An array of strings representing the properties associated with the subscription.

Returns:

  • (Array<String>, nil)


116
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 116

optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String]

#subscription_typeSymbol, HubSpotSDK::Models::WebhooksJournal::JournalSubscriptionResponse::SubscriptionType

The type of subscription, indicating the nature of events it pertains to. Valid values include ‘OBJECT’, ‘ASSOCIATION’, ‘EVENT’, ‘APP_LIFECYCLE_EVENT’, ‘LIST_MEMBERSHIP’, and ‘GDPR_PRIVACY_DELETION’.



49
50
51
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 49

required :subscription_type,
enum: -> { HubSpotSDK::WebhooksJournal::JournalSubscriptionResponse::SubscriptionType },
api_name: :subscriptionType

#updated_atTime

The date and time when the subscription was last updated, in ISO 8601 format.

Returns:

  • (Time)


57
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 57

required :updated_at, Time, api_name: :updatedAt

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 170