Class: HubSpotSDK::Resources::Account

Inherits:
Object
  • Object
show all
Defined in:
lib/hubspot_sdk/resources/account.rb,
lib/hubspot_sdk/resources/account/activity.rb

Defined Under Namespace

Classes: Activity

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Account

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Account.

Parameters:



50
51
52
53
# File 'lib/hubspot_sdk/resources/account.rb', line 50

def initialize(client:)
  @client = client
  @activity = HubSpotSDK::Resources::Account::Activity.new(client: client)
end

Instance Attribute Details

#activityHubSpotSDK::Resources::Account::Activity (readonly)



7
8
9
# File 'lib/hubspot_sdk/resources/account.rb', line 7

def activity
  @activity
end

Instance Method Details

#get(request_options: {}) ⇒ HubSpotSDK::Models::Account::PortalInformationResponse

Retrieve account details such as the account type, time zone, currencies, and data hosting location.

Parameters:

Returns:

See Also:



19
20
21
22
23
24
25
26
# File 'lib/hubspot_sdk/resources/account.rb', line 19

def get(params = {})
  @client.request(
    method: :get,
    path: "account-info/2026-03/details",
    model: HubSpotSDK::Account::PortalInformationResponse,
    options: params[:request_options]
  )
end

#get_daily_private_apps_usage(request_options: {}) ⇒ HubSpotSDK::Models::Account::CollectionResponseAPIUsageNoPaging

Retrieve the daily API usage for private apps in the account, along with information about usage limits.



38
39
40
41
42
43
44
45
# File 'lib/hubspot_sdk/resources/account.rb', line 38

def get_daily_private_apps_usage(params = {})
  @client.request(
    method: :get,
    path: "account-info/2026-03/api-usage/daily/private-apps",
    model: HubSpotSDK::Account::CollectionResponseAPIUsageNoPaging,
    options: params[:request_options]
  )
end