Class: HubSpotSDK::Resources::Cms::MediaBridge
- Inherits:
-
Object
- Object
- HubSpotSDK::Resources::Cms::MediaBridge
- Defined in:
- lib/hubspot_sdk/resources/cms/media_bridge.rb,
lib/hubspot_sdk/resources/cms/media_bridge/batch.rb
Defined Under Namespace
Classes: Batch
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#create_association(object_type, app_id:, from_object_type_id:, to_object_type_id:, name: nil, request_options: {}) ⇒ HubSpotSDK::Models::AssociationDefinition
Create a new association definition for the specified object type.
-
#create_attention_span_event(media_type:, occurred_timestamp:, raw_data_map:, session_id:, _hsenc: nil, contact_id: nil, contact_utk: nil, derived_values: nil, external_id: nil, external_play_context: nil, media_bridge_id: nil, media_name: nil, media_url: nil, page_id: nil, page_name: nil, page_url: nil, raw_data_string: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::AttentionSpanEvent
Create an event containing the viewers attention span details for the media.
-
#create_media_played_event(media_type:, occurred_timestamp:, session_id:, state:, _hsenc: nil, contact_id: nil, contact_utk: nil, external_id: nil, external_play_context: nil, iframe_url: nil, media_bridge_id: nil, media_name: nil, media_url: nil, page_id: nil, page_name: nil, page_url: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::MediaPlayedEvent
Create an event for when a user begins playing a piece of media.
-
#create_media_played_percent_event(media_type:, occurred_timestamp:, played_percent:, session_id:, _hsenc: nil, contact_id: nil, contact_utk: nil, external_id: nil, external_play_context: nil, media_bridge_id: nil, media_name: nil, media_url: nil, page_id: nil, page_name: nil, page_url: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::MediaPlayedPercentageEvent
Create an event representing a user reaching quarterly milestones in a piece of media they’re viewing.
-
#create_object_type(app_id, media_types:, request_options: {}) ⇒ HubSpotSDK::Models::Cms::BulkIntegratorObjectCreationResponse
Create a new media object type.
-
#create_oembed_domain(app_id, endpoints:, portal_id: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::IntegratorOEmbedDomainModel
Set up a new oEmbed domain for your media bridge app.
-
#create_property(object_type, app_id:, field_type:, group_name:, label:, name:, type:, calculation_formula: nil, currency_property_name: nil, data_sensitivity: nil, description: nil, display_order: nil, external_options: nil, form_field: nil, has_unique_value: nil, hidden: nil, number_display_hint: nil, options: nil, referenced_object_type: nil, show_currency_symbol: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::Property
Create a new property for the specified media type.
-
#create_property_group(object_type, app_id:, label:, name:, display_order: nil, request_options: {}) ⇒ HubSpotSDK::Models::PropertyGroup
Create a new property group for the specified object type.
- #create_video_association_definition(app_id, request_options: {}) ⇒ HubSpotSDK::Models::AssociationDefinition
-
#delete_association(association_id, app_id:, object_type:, request_options: {}) ⇒ nil
Delete an existing association definition for an object type.
-
#delete_oembed_domain(app_id, id: nil, domain_portal_id: nil, request_options: {}) ⇒ nil
Delete an existing oEmbed domain.
-
#delete_property(property_name, app_id:, object_type:, request_options: {}) ⇒ nil
Delete an existing property for an object type.
-
#delete_property_group(group_name, app_id:, object_type:, request_options: {}) ⇒ nil
Delete an existing property group by name.
-
#get_event_visibility_settings(app_id, request_options: {}) ⇒ HubSpotSDK::Models::Cms::EventVisibilityResponse
Get the visibility settings for media bridge events for your apps.
-
#get_oembed_domain(o_embed_domain_id, app_id:, request_options: {}) ⇒ HubSpotSDK::Models::Cms::IntegratorOEmbedDomainModel
Get the details for an existing oEmbed domain.
-
#get_property(property_name, app_id:, object_type:, archived: nil, properties: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::Property
Get the details for an existing property by name.
-
#get_property_group(group_name, app_id:, object_type:, request_options: {}) ⇒ HubSpotSDK::Models::PropertyGroup
Get the details of an existing property group by name.
-
#get_schema(object_type, app_id:, request_options: {}) ⇒ HubSpotSDK::Models::Cms::ObjectSchema
Get the schema for a specified object type.
-
#initialize(client:) ⇒ MediaBridge
constructor
private
A new instance of MediaBridge.
-
#list_object_types_by_media_type(media_type, app_id:, include_full_definition: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::ObjectDefinitionResponse
Get the existing objects types that belong to the specified media type.
-
#list_oembed_domains(app_id, domain_portal_id: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::OEmbedDomainsCollectionResponse
Get the details for existing oEmbed domains for your app.
-
#list_properties(object_type, app_id:, archived: nil, properties: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::CollectionResponsePropertyNoPaging
Get the existing properties defined for a media object type.
-
#list_property_groups(object_type, app_id:, request_options: {}) ⇒ HubSpotSDK::Models::CollectionResponsePropertyGroupNoPaging
Get the property groups for a specified object type.
-
#list_schemas(app_id, archived: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::CollectionResponseObjectSchemaNoPaging
Get the schemas for all object types.
- #register_app_name(app_id, updated_at:, allow_import_on_disconnect: nil, module_name: nil, name: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::MediaBridgeProviderRegistrationResponse deprecated Deprecated.
-
#update_event_visibility_settings(app_id, event_type:, updated_at:, show_in_reporting: nil, show_in_timeline: nil, show_in_workflows: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::EventVisibilityChange
Set the visibility settings for media bridge events created by your app.
-
#update_oembed_domain(o_embed_domain_id, app_id:, endpoints:, portal_id: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::IntegratorOEmbedDomainModel
Update an existing oEmbed domain.
-
#update_property(property_name, app_id:, object_type:, calculation_formula: nil, currency_property_name: nil, description: nil, display_order: nil, field_type: nil, form_field: nil, group_name: nil, has_unique_value: nil, hidden: nil, label: nil, number_display_hint: nil, options: nil, show_currency_symbol: nil, type: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::Property
Update an existing property for an object type.
-
#update_property_group(group_name, app_id:, object_type:, display_order: nil, label: nil, request_options: {}) ⇒ HubSpotSDK::Models::PropertyGroup
Update an existing property group by name.
-
#update_schema(object_type, app_id:, clear_description:, allows_sensitive_properties: nil, description: nil, labels: nil, primary_display_property: nil, required_properties: nil, restorable: nil, searchable_properties: nil, secondary_display_properties: nil, request_options: {}) ⇒ HubSpotSDK::Models::ObjectTypeDefinition
Update the schema for an existing object type.
-
#update_settings(app_id, updated_at:, allow_import_on_disconnect: nil, module_name: nil, name: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::MediaBridgeProviderRegistrationResponse
Update the name that your app will display when a user is selecting media bridge items.
Constructor Details
#initialize(client:) ⇒ MediaBridge
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of MediaBridge.
968 969 970 971 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 968 def initialize(client:) @client = client @batch = HubSpotSDK::Resources::Cms::MediaBridge::Batch.new(client: client) end |
Instance Attribute Details
#batch ⇒ HubSpotSDK::Resources::Cms::MediaBridge::Batch (readonly)
8 9 10 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 8 def batch @batch end |
Instance Method Details
#create_association(object_type, app_id:, from_object_type_id:, to_object_type_id:, name: nil, request_options: {}) ⇒ HubSpotSDK::Models::AssociationDefinition
Create a new association definition for the specified object type.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 29 def create_association(object_type, params) parsed, = HubSpotSDK::Cms::MediaBridgeCreateAssociationParams.dump_request(params) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :post, path: ["media-bridge/2026-03/%1$s/schemas/%2$s/associations", app_id, object_type], body: parsed, model: HubSpotSDK::AssociationDefinition, options: ) end |
#create_attention_span_event(media_type:, occurred_timestamp:, raw_data_map:, session_id:, _hsenc: nil, contact_id: nil, contact_utk: nil, derived_values: nil, external_id: nil, external_play_context: nil, media_bridge_id: nil, media_name: nil, media_url: nil, page_id: nil, page_name: nil, page_url: nil, raw_data_string: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::AttentionSpanEvent
Create an event containing the viewers attention span details for the media.
70 71 72 73 74 75 76 77 78 79 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 70 def create_attention_span_event(params) parsed, = HubSpotSDK::Cms::MediaBridgeCreateAttentionSpanEventParams.dump_request(params) @client.request( method: :post, path: "media-bridge/2026-03/events/attention-span", body: parsed, model: HubSpotSDK::Cms::AttentionSpanEvent, options: ) end |
#create_media_played_event(media_type:, occurred_timestamp:, session_id:, state:, _hsenc: nil, contact_id: nil, contact_utk: nil, external_id: nil, external_play_context: nil, iframe_url: nil, media_bridge_id: nil, media_name: nil, media_url: nil, page_id: nil, page_name: nil, page_url: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::MediaPlayedEvent
Create an event for when a user begins playing a piece of media.
106 107 108 109 110 111 112 113 114 115 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 106 def create_media_played_event(params) parsed, = HubSpotSDK::Cms::MediaBridgeCreateMediaPlayedEventParams.dump_request(params) @client.request( method: :post, path: "media-bridge/2026-03/events/media-played", body: parsed, model: HubSpotSDK::Cms::MediaPlayedEvent, options: ) end |
#create_media_played_percent_event(media_type:, occurred_timestamp:, played_percent:, session_id:, _hsenc: nil, contact_id: nil, contact_utk: nil, external_id: nil, external_play_context: nil, media_bridge_id: nil, media_name: nil, media_url: nil, page_id: nil, page_name: nil, page_url: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::MediaPlayedPercentageEvent
Create an event representing a user reaching quarterly milestones in a piece of media they’re viewing.
142 143 144 145 146 147 148 149 150 151 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 142 def create_media_played_percent_event(params) parsed, = HubSpotSDK::Cms::MediaBridgeCreateMediaPlayedPercentEventParams.dump_request(params) @client.request( method: :post, path: "media-bridge/2026-03/events/media-played-percent", body: parsed, model: HubSpotSDK::Cms::MediaPlayedPercentageEvent, options: ) end |
#create_object_type(app_id, media_types:, request_options: {}) ⇒ HubSpotSDK::Models::Cms::BulkIntegratorObjectCreationResponse
Create a new media object type
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 164 def create_object_type(app_id, params) parsed, = HubSpotSDK::Cms::MediaBridgeCreateObjectTypeParams.dump_request(params) @client.request( method: :post, path: ["media-bridge/2026-03/%1$s/settings/object-definitions", app_id], body: parsed, model: HubSpotSDK::Cms::BulkIntegratorObjectCreationResponse, options: ) end |
#create_oembed_domain(app_id, endpoints:, portal_id: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::IntegratorOEmbedDomainModel
Set up a new oEmbed domain for your media bridge app.
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 187 def (app_id, params) parsed, = HubSpotSDK::Cms::MediaBridgeCreateOembedDomainParams.dump_request(params) @client.request( method: :post, path: ["media-bridge/2026-03/%1$s/settings/oembed-domains", app_id], body: parsed, model: HubSpotSDK::Cms::IntegratorOEmbedDomainModel, options: ) end |
#create_property(object_type, app_id:, field_type:, group_name:, label:, name:, type:, calculation_formula: nil, currency_property_name: nil, data_sensitivity: nil, description: nil, display_order: nil, external_options: nil, form_field: nil, has_unique_value: nil, hidden: nil, number_display_hint: nil, options: nil, referenced_object_type: nil, show_currency_symbol: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::Property
Create a new property for the specified media type
247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 247 def create_property(object_type, params) parsed, = HubSpotSDK::Cms::MediaBridgeCreatePropertyParams.dump_request(params) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :post, path: ["media-bridge/2026-03/%1$s/properties/%2$s", app_id, object_type], body: parsed, model: HubSpotSDK::Cms::Property, options: ) end |
#create_property_group(object_type, app_id:, label:, name:, display_order: nil, request_options: {}) ⇒ HubSpotSDK::Models::PropertyGroup
Create a new property group for the specified object type.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 281 def create_property_group(object_type, params) parsed, = HubSpotSDK::Cms::MediaBridgeCreatePropertyGroupParams.dump_request(params) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :post, path: ["media-bridge/2026-03/%1$s/properties/%2$s/groups", app_id, object_type], body: parsed, model: HubSpotSDK::PropertyGroup, options: ) end |
#create_video_association_definition(app_id, request_options: {}) ⇒ HubSpotSDK::Models::AssociationDefinition
304 305 306 307 308 309 310 311 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 304 def create_video_association_definition(app_id, params = {}) @client.request( method: :post, path: ["media-bridge/2026-03/%1$s/settings/video-association-definition", app_id], model: HubSpotSDK::AssociationDefinition, options: params[:request_options] ) end |
#delete_association(association_id, app_id:, object_type:, request_options: {}) ⇒ nil
Delete an existing association definition for an object type.
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 325 def delete_association(association_id, params) parsed, = HubSpotSDK::Cms::MediaBridgeDeleteAssociationParams.dump_request(params) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end object_type = parsed.delete(:object_type) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :delete, path: [ "media-bridge/2026-03/%1$s/schemas/%2$s/associations/%3$s", app_id, object_type, association_id ], model: NilClass, options: ) end |
#delete_oembed_domain(app_id, id: nil, domain_portal_id: nil, request_options: {}) ⇒ nil
Delete an existing oEmbed domain.
360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 360 def (app_id, params = {}) parsed, = HubSpotSDK::Cms::MediaBridgeDeleteOembedDomainParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :delete, path: ["media-bridge/2026-03/%1$s/settings/oembed-domains", app_id], query: query.transform_keys(domain_portal_id: "domainPortalId"), model: NilClass, options: ) end |
#delete_property(property_name, app_id:, object_type:, request_options: {}) ⇒ nil
Delete an existing property for an object type.
384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 384 def delete_property(property_name, params) parsed, = HubSpotSDK::Cms::MediaBridgeDeletePropertyParams.dump_request(params) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end object_type = parsed.delete(:object_type) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :delete, path: ["media-bridge/2026-03/%1$s/properties/%2$s/%3$s", app_id, object_type, property_name], model: NilClass, options: ) end |
#delete_property_group(group_name, app_id:, object_type:, request_options: {}) ⇒ nil
Delete an existing property group by name
414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 414 def delete_property_group(group_name, params) parsed, = HubSpotSDK::Cms::MediaBridgeDeletePropertyGroupParams.dump_request(params) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end object_type = parsed.delete(:object_type) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :delete, path: ["media-bridge/2026-03/%1$s/properties/%2$s/groups/%3$s", app_id, object_type, group_name], model: NilClass, options: ) end |
#get_event_visibility_settings(app_id, request_options: {}) ⇒ HubSpotSDK::Models::Cms::EventVisibilityResponse
Get the visibility settings for media bridge events for your apps.
442 443 444 445 446 447 448 449 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 442 def get_event_visibility_settings(app_id, params = {}) @client.request( method: :get, path: ["media-bridge/2026-03/%1$s/settings/event-visibility", app_id], model: HubSpotSDK::Cms::EventVisibilityResponse, options: params[:request_options] ) end |
#get_oembed_domain(o_embed_domain_id, app_id:, request_options: {}) ⇒ HubSpotSDK::Models::Cms::IntegratorOEmbedDomainModel
Get the details for an existing oEmbed domain.
462 463 464 465 466 467 468 469 470 471 472 473 474 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 462 def (, params) parsed, = HubSpotSDK::Cms::MediaBridgeGetOembedDomainParams.dump_request(params) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["media-bridge/2026-03/%1$s/settings/oembed-domains/%2$s", app_id, ], model: HubSpotSDK::Cms::IntegratorOEmbedDomainModel, options: ) end |
#get_property(property_name, app_id:, object_type:, archived: nil, properties: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::Property
Get the details for an existing property by name.
495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 495 def get_property(property_name, params) parsed, = HubSpotSDK::Cms::MediaBridgeGetPropertyParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end object_type = parsed.delete(:object_type) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["media-bridge/2026-03/%1$s/properties/%2$s/%3$s", app_id, object_type, property_name], query: query, model: HubSpotSDK::Cms::Property, options: ) end |
#get_property_group(group_name, app_id:, object_type:, request_options: {}) ⇒ HubSpotSDK::Models::PropertyGroup
Get the details of an existing property group by name.
527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 527 def get_property_group(group_name, params) parsed, = HubSpotSDK::Cms::MediaBridgeGetPropertyGroupParams.dump_request(params) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end object_type = parsed.delete(:object_type) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["media-bridge/2026-03/%1$s/properties/%2$s/groups/%3$s", app_id, object_type, group_name], model: HubSpotSDK::PropertyGroup, options: ) end |
#get_schema(object_type, app_id:, request_options: {}) ⇒ HubSpotSDK::Models::Cms::ObjectSchema
Get the schema for a specified object type.
556 557 558 559 560 561 562 563 564 565 566 567 568 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 556 def get_schema(object_type, params) parsed, = HubSpotSDK::Cms::MediaBridgeGetSchemaParams.dump_request(params) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["media-bridge/2026-03/%1$s/schemas/%2$s", app_id, object_type], model: HubSpotSDK::Cms::ObjectSchema, options: ) end |
#list_object_types_by_media_type(media_type, app_id:, include_full_definition: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::ObjectDefinitionResponse
Get the existing objects types that belong to the specified media type.
585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 585 def list_object_types_by_media_type(media_type, params) parsed, = HubSpotSDK::Cms::MediaBridgeListObjectTypesByMediaTypeParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["media-bridge/2026-03/%1$s/settings/object-definitions/%2$s", app_id, media_type], query: query.transform_keys(include_full_definition: "includeFullDefinition"), model: HubSpotSDK::Cms::ObjectDefinitionResponse, options: ) end |
#list_oembed_domains(app_id, domain_portal_id: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::OEmbedDomainsCollectionResponse
Get the details for existing oEmbed domains for your app
612 613 614 615 616 617 618 619 620 621 622 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 612 def (app_id, params = {}) parsed, = HubSpotSDK::Cms::MediaBridgeListOembedDomainsParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["media-bridge/2026-03/%1$s/settings/oembed-domains", app_id], query: query.transform_keys(domain_portal_id: "domainPortalId"), model: HubSpotSDK::Cms::OEmbedDomainsCollectionResponse, options: ) end |
#list_properties(object_type, app_id:, archived: nil, properties: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::CollectionResponsePropertyNoPaging
Get the existing properties defined for a media object type.
641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 641 def list_properties(object_type, params) parsed, = HubSpotSDK::Cms::MediaBridgeListPropertiesParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["media-bridge/2026-03/%1$s/properties/%2$s", app_id, object_type], query: query, model: HubSpotSDK::Cms::CollectionResponsePropertyNoPaging, options: ) end |
#list_property_groups(object_type, app_id:, request_options: {}) ⇒ HubSpotSDK::Models::CollectionResponsePropertyGroupNoPaging
Get the property groups for a specified object type.
668 669 670 671 672 673 674 675 676 677 678 679 680 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 668 def list_property_groups(object_type, params) parsed, = HubSpotSDK::Cms::MediaBridgeListPropertyGroupsParams.dump_request(params) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["media-bridge/2026-03/%1$s/properties/%2$s/groups", app_id, object_type], model: HubSpotSDK::CollectionResponsePropertyGroupNoPaging, options: ) end |
#list_schemas(app_id, archived: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::CollectionResponseObjectSchemaNoPaging
Get the schemas for all object types.
695 696 697 698 699 700 701 702 703 704 705 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 695 def list_schemas(app_id, params = {}) parsed, = HubSpotSDK::Cms::MediaBridgeListSchemasParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["media-bridge/2026-03/%1$s/schemas", app_id], query: query, model: HubSpotSDK::Cms::CollectionResponseObjectSchemaNoPaging, options: ) end |
#register_app_name(app_id, updated_at:, allow_import_on_disconnect: nil, module_name: nil, name: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::MediaBridgeProviderRegistrationResponse
Register the name that your app will display when a user is selecting media bridge items.
724 725 726 727 728 729 730 731 732 733 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 724 def register_app_name(app_id, params) parsed, = HubSpotSDK::Cms::MediaBridgeRegisterAppNameParams.dump_request(params) @client.request( method: :post, path: ["media-bridge/2026-03/%1$s/settings/register", app_id], body: parsed, model: HubSpotSDK::Cms::MediaBridgeProviderRegistrationResponse, options: ) end |
#update_event_visibility_settings(app_id, event_type:, updated_at:, show_in_reporting: nil, show_in_timeline: nil, show_in_workflows: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::EventVisibilityChange
Set the visibility settings for media bridge events created by your app.
750 751 752 753 754 755 756 757 758 759 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 750 def update_event_visibility_settings(app_id, params) parsed, = HubSpotSDK::Cms::MediaBridgeUpdateEventVisibilitySettingsParams.dump_request(params) @client.request( method: :patch, path: ["media-bridge/2026-03/%1$s/settings/event-visibility", app_id], body: parsed, model: HubSpotSDK::Cms::EventVisibilityChange, options: ) end |
#update_oembed_domain(o_embed_domain_id, app_id:, endpoints:, portal_id: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::IntegratorOEmbedDomainModel
Update an existing oEmbed domain.
778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 778 def (, params) parsed, = HubSpotSDK::Cms::MediaBridgeUpdateOembedDomainParams.dump_request(params) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :patch, path: ["media-bridge/2026-03/%1$s/settings/oembed-domains/%2$s", app_id, ], body: parsed, model: HubSpotSDK::Cms::IntegratorOEmbedDomainModel, options: ) end |
#update_property(property_name, app_id:, object_type:, calculation_formula: nil, currency_property_name: nil, description: nil, display_order: nil, field_type: nil, form_field: nil, group_name: nil, has_unique_value: nil, hidden: nil, label: nil, number_display_hint: nil, options: nil, show_currency_symbol: nil, type: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::Property
Update an existing property for an object type.
836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 836 def update_property(property_name, params) parsed, = HubSpotSDK::Cms::MediaBridgeUpdatePropertyParams.dump_request(params) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end object_type = parsed.delete(:object_type) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :patch, path: ["media-bridge/2026-03/%1$s/properties/%2$s/%3$s", app_id, object_type, property_name], body: parsed, model: HubSpotSDK::Cms::Property, options: ) end |
#update_property_group(group_name, app_id:, object_type:, display_order: nil, label: nil, request_options: {}) ⇒ HubSpotSDK::Models::PropertyGroup
Update an existing property group by name.
874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 874 def update_property_group(group_name, params) parsed, = HubSpotSDK::Cms::MediaBridgeUpdatePropertyGroupParams.dump_request(params) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end object_type = parsed.delete(:object_type) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :patch, path: ["media-bridge/2026-03/%1$s/properties/%2$s/groups/%3$s", app_id, object_type, group_name], body: parsed, model: HubSpotSDK::PropertyGroup, options: ) end |
#update_schema(object_type, app_id:, clear_description:, allows_sensitive_properties: nil, description: nil, labels: nil, primary_display_property: nil, required_properties: nil, restorable: nil, searchable_properties: nil, secondary_display_properties: nil, request_options: {}) ⇒ HubSpotSDK::Models::ObjectTypeDefinition
Update the schema for an existing object type
924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 924 def update_schema(object_type, params) parsed, = HubSpotSDK::Cms::MediaBridgeUpdateSchemaParams.dump_request(params) app_id = parsed.delete(:app_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :patch, path: ["media-bridge/2026-03/%1$s/schemas/%2$s", app_id, object_type], body: parsed, model: HubSpotSDK::ObjectTypeDefinition, options: ) end |
#update_settings(app_id, updated_at:, allow_import_on_disconnect: nil, module_name: nil, name: nil, request_options: {}) ⇒ HubSpotSDK::Models::Cms::MediaBridgeProviderRegistrationResponse
Update the name that your app will display when a user is selecting media bridge items.
954 955 956 957 958 959 960 961 962 963 |
# File 'lib/hubspot_sdk/resources/cms/media_bridge.rb', line 954 def update_settings(app_id, params) parsed, = HubSpotSDK::Cms::MediaBridgeUpdateSettingsParams.dump_request(params) @client.request( method: :put, path: ["media-bridge/2026-03/%1$s/settings", app_id], body: parsed, model: HubSpotSDK::Cms::MediaBridgeProviderRegistrationResponse, options: ) end |