Class: HubSpotSDK::Resources::Cms::MediaBridge::Batch

Inherits:
Object
  • Object
show all
Defined in:
lib/hubspot_sdk/resources/cms/media_bridge/batch.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Batch

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Batch.

Parameters:



105
106
107
# File 'lib/hubspot_sdk/resources/cms/media_bridge/batch.rb', line 105

def initialize(client:)
  @client = client
end

Instance Method Details

#create(object_type, app_id:, inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Cms::BatchResponseProperty

Create a batch of properties of the specified object type.

Parameters:

Returns:

See Also:



23
24
25
26
27
28
29
30
31
32
33
34
35
36
# File 'lib/hubspot_sdk/resources/cms/media_bridge/batch.rb', line 23

def create(object_type, params)
  parsed, options = HubSpotSDK::Cms::MediaBridge::BatchCreateParams.dump_request(params)
  app_id =
    parsed.delete(:app_id) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :post,
    path: ["media-bridge/2026-03/%1$s/properties/%2$s/batch/create", app_id, object_type],
    body: parsed,
    model: HubSpotSDK::Cms::BatchResponseProperty,
    options: options
  )
end

#delete(object_type, app_id:, inputs:, request_options: {}) ⇒ nil

Archive a batch of existing properties for the specified types.

Parameters:

Returns:

  • (nil)

See Also:



53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/hubspot_sdk/resources/cms/media_bridge/batch.rb', line 53

def delete(object_type, params)
  parsed, options = HubSpotSDK::Cms::MediaBridge::BatchDeleteParams.dump_request(params)
  app_id =
    parsed.delete(:app_id) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :post,
    path: ["media-bridge/2026-03/%1$s/properties/%2$s/batch/archive", app_id, object_type],
    body: parsed,
    model: NilClass,
    options: options
  )
end

#get(object_type, app_id:, archived:, data_sensitivity:, inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Cms::BatchResponseProperty

Get the details for a batch of properties for a specified object type.

Parameters:

Returns:

See Also:



87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/hubspot_sdk/resources/cms/media_bridge/batch.rb', line 87

def get(object_type, params)
  parsed, options = HubSpotSDK::Cms::MediaBridge::BatchGetParams.dump_request(params)
  app_id =
    parsed.delete(:app_id) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :post,
    path: ["media-bridge/2026-03/%1$s/properties/%2$s/batch/read", app_id, object_type],
    body: parsed,
    model: HubSpotSDK::Cms::BatchResponseProperty,
    options: options
  )
end