Class: HubSpotSDK::Resources::Crm::AppUninstalls

Inherits:
Object
  • Object
show all
Defined in:
lib/hubspot_sdk/resources/crm/app_uninstalls.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ AppUninstalls

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of AppUninstalls.

Parameters:



30
31
32
# File 'lib/hubspot_sdk/resources/crm/app_uninstalls.rb', line 30

def initialize(client:)
  @client = client
end

Instance Method Details

#uninstall(request_options: {}) ⇒ nil

Use this endpoint to uninstall your app from a customer’s HubSpot account. If successful, this endpoint will return a 204 and the customer will receive an email notification that the developer has uninstall the app from their account.

Parameters:

Returns:

  • (nil)

See Also:



18
19
20
21
22
23
24
25
# File 'lib/hubspot_sdk/resources/crm/app_uninstalls.rb', line 18

def uninstall(params = {})
  @client.request(
    method: :delete,
    path: "appinstalls/2026-03/external-install",
    model: NilClass,
    options: params[:request_options]
  )
end