Class: HubSpotSDK::Resources::Crm::Limits

Inherits:
Object
  • Object
show all
Defined in:
lib/hubspot_sdk/resources/crm/limits.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Limits

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Limits.

Parameters:



194
195
196
# File 'lib/hubspot_sdk/resources/crm/limits.rb', line 194

def initialize(client:)
  @client = client
end

Instance Method Details

#get_association_label_limits(from_object_type_id: nil, to_object_type_id: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseAssociationLabelLimitResponseNoPaging

Returns limits and usage for custom association labels

Parameters:

Returns:

See Also:



18
19
20
21
22
23
24
25
26
27
28
29
30
31
# File 'lib/hubspot_sdk/resources/crm/limits.rb', line 18

def get_association_label_limits(params = {})
  parsed, options = HubSpotSDK::Crm::LimitGetAssociationLabelLimitsParams.dump_request(params)
  query = HubSpotSDK::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "crm/limits/2026-03/associations/labels",
    query: query.transform_keys(
      from_object_type_id: "fromObjectTypeId",
      to_object_type_id: "toObjectTypeId"
    ),
    model: HubSpotSDK::Crm::CollectionResponseAssociationLabelLimitResponseNoPaging,
    options: options
  )
end

#get_association_records_limits_by_object_type(to_object_type_id, from_object_type_id:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::AssociationRecordLimitResponse

Returns records approaching or at association limits between two objects

Parameters:

Returns:

See Also:



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/hubspot_sdk/resources/crm/limits.rb', line 44

def get_association_records_limits_by_object_type(to_object_type_id, params)
  parsed, options =
    HubSpotSDK::Crm::LimitGetAssociationRecordsLimitsByObjectTypeParams.dump_request(params)
  from_object_type_id =
    parsed.delete(:from_object_type_id) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :get,
    path: [
      "crm/limits/2026-03/associations/records/%1$s/%2$s",
      from_object_type_id,
      to_object_type_id
    ],
    model: HubSpotSDK::Crm::AssociationRecordLimitResponse,
    options: options
  )
end

#get_association_records_limits_from_objects(request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseObjectTypeNearOrAtAssociationLimitNoPaging

Returns objects with records approaching or at association limits



72
73
74
75
76
77
78
79
# File 'lib/hubspot_sdk/resources/crm/limits.rb', line 72

def get_association_records_limits_from_objects(params = {})
  @client.request(
    method: :get,
    path: "crm/limits/2026-03/associations/records/from",
    model: HubSpotSDK::Crm::CollectionResponseObjectTypeNearOrAtAssociationLimitNoPaging,
    options: params[:request_options]
  )
end

#get_association_records_limits_to_objects(from_object_type_id, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseObjectTypeNearOrAtAssociationLimitNoPaging

Returns objects for which the from object has records approaching or at association limits



92
93
94
95
96
97
98
99
# File 'lib/hubspot_sdk/resources/crm/limits.rb', line 92

def get_association_records_limits_to_objects(from_object_type_id, params = {})
  @client.request(
    method: :get,
    path: ["crm/limits/2026-03/associations/records/%1$s/to", from_object_type_id],
    model: HubSpotSDK::Crm::CollectionResponseObjectTypeNearOrAtAssociationLimitNoPaging,
    options: params[:request_options]
  )
end

#get_calculated_property_limits(request_options: {}) ⇒ HubSpotSDK::Models::Crm::CalculatedPropertyLimitResponse

Returns overall limit and per object usage for calculated properties



110
111
112
113
114
115
116
117
# File 'lib/hubspot_sdk/resources/crm/limits.rb', line 110

def get_calculated_property_limits(params = {})
  @client.request(
    method: :get,
    path: "crm/limits/2026-03/calculated-properties",
    model: HubSpotSDK::Crm::CalculatedPropertyLimitResponse,
    options: params[:request_options]
  )
end

#get_custom_object_type_limits(request_options: {}) ⇒ HubSpotSDK::Models::Crm::CustomObjectLimitResponse

Returns limits and usage for custom object schemas



128
129
130
131
132
133
134
135
# File 'lib/hubspot_sdk/resources/crm/limits.rb', line 128

def get_custom_object_type_limits(params = {})
  @client.request(
    method: :get,
    path: "crm/limits/2026-03/custom-object-types",
    model: HubSpotSDK::Crm::CustomObjectLimitResponse,
    options: params[:request_options]
  )
end

#get_custom_property_limits(request_options: {}) ⇒ HubSpotSDK::Models::Crm::CustomPropertyLimitResponse

Returns limits and usage per object for custom properties



146
147
148
149
150
151
152
153
# File 'lib/hubspot_sdk/resources/crm/limits.rb', line 146

def get_custom_property_limits(params = {})
  @client.request(
    method: :get,
    path: "crm/limits/2026-03/custom-properties",
    model: HubSpotSDK::Crm::CustomPropertyLimitResponse,
    options: params[:request_options]
  )
end

#get_pipeline_limits(request_options: {}) ⇒ HubSpotSDK::Models::Crm::PipelineLimitResponse

Returns limits and usage per object for pipelines

Parameters:

Returns:

See Also:



164
165
166
167
168
169
170
171
# File 'lib/hubspot_sdk/resources/crm/limits.rb', line 164

def get_pipeline_limits(params = {})
  @client.request(
    method: :get,
    path: "crm/limits/2026-03/pipelines",
    model: HubSpotSDK::Crm::PipelineLimitResponse,
    options: params[:request_options]
  )
end

#get_record_limits(request_options: {}) ⇒ HubSpotSDK::Models::Crm::RecordLimitResponse

Returns limits and usage per object for records

Parameters:

Returns:

See Also:



182
183
184
185
186
187
188
189
# File 'lib/hubspot_sdk/resources/crm/limits.rb', line 182

def get_record_limits(params = {})
  @client.request(
    method: :get,
    path: "crm/limits/2026-03/records",
    model: HubSpotSDK::Crm::RecordLimitResponse,
    options: params[:request_options]
  )
end