Class: HubSpotSDK::Resources::Crm::Objects::CommercePayments

Inherits:
Object
  • Object
show all
Defined in:
lib/hubspot_sdk/resources/crm/objects/commerce_payments.rb,
lib/hubspot_sdk/resources/crm/objects/commerce_payments/batch.rb

Defined Under Namespace

Classes: Batch

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ CommercePayments

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of CommercePayments.

Parameters:



212
213
214
215
# File 'lib/hubspot_sdk/resources/crm/objects/commerce_payments.rb', line 212

def initialize(client:)
  @client = client
  @batch = HubSpotSDK::Resources::Crm::Objects::CommercePayments::Batch.new(client: client)
end

Instance Attribute Details

#batchHubSpotSDK::Resources::Crm::Objects::CommercePayments::Batch (readonly)



9
10
11
# File 'lib/hubspot_sdk/resources/crm/objects/commerce_payments.rb', line 9

def batch
  @batch
end

Instance Method Details

#create(associations:, properties:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject

Create a commerce payment with the given properties and return a copy of the object, including the ID. Documentation and examples for creating standard commerce payments is provided.

Parameters:

Returns:

See Also:



26
27
28
29
30
31
32
33
34
35
# File 'lib/hubspot_sdk/resources/crm/objects/commerce_payments.rb', line 26

def create(params)
  parsed, options = HubSpotSDK::Crm::Objects::CommercePaymentCreateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/commerce_payments",
    body: parsed,
    model: HubSpotSDK::Crm::SimplePublicObject,
    options: options
  )
end

#delete(commerce_payment_id, request_options: {}) ⇒ nil

Move an Object identified by ‘commercePaymentId` to the recycling bin.

Parameters:

Returns:

  • (nil)

See Also:



124
125
126
127
128
129
130
131
# File 'lib/hubspot_sdk/resources/crm/objects/commerce_payments.rb', line 124

def delete(commerce_payment_id, params = {})
  @client.request(
    method: :delete,
    path: ["crm/objects/2026-03/commerce_payments/%1$s", commerce_payment_id],
    model: NilClass,
    options: params[:request_options]
  )
end

#get(commerce_payment_id, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations

Some parameter documentations has been truncated, see Models::Crm::Objects::CommercePaymentGetParams for more details.

Read an Object identified by ‘commercePaymentId`. `commercePaymentId` refers to the internal object ID by default, or optionally any unique property value as specified by the `idProperty` query param. Control what is returned via the `properties` query param.

Parameters:

  • commerce_payment_id (String)
  • archived (Boolean)

    Whether to return only results that have been archived.

  • associations (Array<String>)

    A comma separated list of object types to retrieve associated IDs for. If any of

  • id_property (String)

    The name of a property whose values are unique for this object type

  • properties (Array<String>)

    A comma separated list of the properties to be returned in the response. If any

  • properties_with_history (Array<String>)

    A comma separated list of the properties to be returned along with their history

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/hubspot_sdk/resources/crm/objects/commerce_payments.rb', line 160

def get(commerce_payment_id, params = {})
  parsed, options = HubSpotSDK::Crm::Objects::CommercePaymentGetParams.dump_request(params)
  query = HubSpotSDK::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: ["crm/objects/2026-03/commerce_payments/%1$s", commerce_payment_id],
    query: query.transform_keys(
      id_property: "idProperty",
      properties_with_history: "propertiesWithHistory"
    ),
    model: HubSpotSDK::Crm::SimplePublicObjectWithAssociations,
    options: options
  )
end

#list(after: nil, archived: nil, associations: nil, limit: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Internal::Page<HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations>

Some parameter documentations has been truncated, see Models::Crm::Objects::CommercePaymentListParams for more details.

Read a page of commerce payments. Control what is returned via the ‘properties` query param.

Parameters:

  • after (String)

    The paging cursor token of the last successfully read resource will be returned

  • archived (Boolean)

    Whether to return only results that have been archived.

  • associations (Array<String>)

    A comma separated list of object types to retrieve associated IDs for. If any of

  • limit (Integer)

    The maximum number of results to display per page.

  • properties (Array<String>)

    A comma separated list of the properties to be returned in the response. If any

  • properties_with_history (Array<String>)

    A comma separated list of the properties to be returned along with their history

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/hubspot_sdk/resources/crm/objects/commerce_payments.rb', line 101

def list(params = {})
  parsed, options = HubSpotSDK::Crm::Objects::CommercePaymentListParams.dump_request(params)
  query = HubSpotSDK::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "crm/objects/2026-03/commerce_payments",
    query: query.transform_keys(properties_with_history: "propertiesWithHistory"),
    page: HubSpotSDK::Internal::Page,
    model: HubSpotSDK::Crm::SimplePublicObjectWithAssociations,
    options: options
  )
end

#search(after:, filter_groups:, limit:, properties:, sorts:, query: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseWithTotalSimplePublicObject

Execute a search for commerce payments based on the provided filter groups, properties, and sorting options. This endpoint allows for complex queries to retrieve specific payment records from the CRM.

Parameters:

  • after (String)

    A paging cursor token for retrieving subsequent pages.

  • filter_groups (Array<HubSpotSDK::Models::Crm::FilterGroup>)

    Up to 6 groups of filters defining additional query criteria.

  • limit (Integer)

    The maximum results to return, up to 200 objects.

  • properties (Array<String>)

    A list of property names to include in the response.

  • sorts (Array<String>)

    Specifies sorting order based on object properties.

  • query (String)

    The search query string, up to 3000 characters.

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



198
199
200
201
202
203
204
205
206
207
# File 'lib/hubspot_sdk/resources/crm/objects/commerce_payments.rb', line 198

def search(params)
  parsed, options = HubSpotSDK::Crm::Objects::CommercePaymentSearchParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/commerce_payments/search",
    body: parsed,
    model: HubSpotSDK::Crm::CollectionResponseWithTotalSimplePublicObject,
    options: options
  )
end

#update(commerce_payment_id, properties:, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject

Some parameter documentations has been truncated, see Models::Crm::Objects::CommercePaymentUpdateParams for more details.

Perform a partial update of an Object identified by ‘commercePaymentId`or optionally a unique property value as specified by the `idProperty` query param. `commercePaymentId` refers to the internal object ID by default, and the `idProperty` query param refers to a property whose values are unique for the object. Provided property values will be overwritten. Read-only and non-existent properties will result in an error. Properties values can be cleared by passing an empty string.

Parameters:

  • commerce_payment_id (String)

    Path param

  • properties (Hash{Symbol=>String})

    Body param: Key value pairs representing the properties of the object.

  • id_property (String)

    Query param: The name of a property whose values are unique for this object type

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/hubspot_sdk/resources/crm/objects/commerce_payments.rb', line 62

def update(commerce_payment_id, params)
  query_params = [:id_property]
  parsed, options = HubSpotSDK::Crm::Objects::CommercePaymentUpdateParams.dump_request(params)
  query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params))
  @client.request(
    method: :patch,
    path: ["crm/objects/2026-03/commerce_payments/%1$s", commerce_payment_id],
    query: query.transform_keys(id_property: "idProperty"),
    body: parsed.except(*query_params),
    model: HubSpotSDK::Crm::SimplePublicObject,
    options: options
  )
end