Class: HubSpotSDK::Resources::Crm::Objects::CommercePayments::Batch

Inherits:
Object
  • Object
show all
Defined in:
lib/hubspot_sdk/resources/crm/objects/commerce_payments/batch.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Batch

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Batch.

Parameters:



141
142
143
# File 'lib/hubspot_sdk/resources/crm/objects/commerce_payments/batch.rb', line 141

def initialize(client:)
  @client = client
end

Instance Method Details

#create(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject

Create multiple commerce payment records in a single request, returning the details of each created payment, including their unique IDs.



20
21
22
23
24
25
26
27
28
29
# File 'lib/hubspot_sdk/resources/crm/objects/commerce_payments/batch.rb', line 20

def create(params)
  parsed, options = HubSpotSDK::Crm::Objects::CommercePayments::BatchCreateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/commerce_payments/batch/create",
    body: parsed,
    model: HubSpotSDK::Crm::BatchResponseSimplePublicObject,
    options: options
  )
end

#delete(inputs:, request_options: {}) ⇒ nil

Archive a batch of commerce payments by their IDs. This operation moves the specified payments to the archive, making them inactive in the system.

Parameters:

Returns:

  • (nil)

See Also:



66
67
68
69
70
71
72
73
74
75
# File 'lib/hubspot_sdk/resources/crm/objects/commerce_payments/batch.rb', line 66

def delete(params)
  parsed, options = HubSpotSDK::Crm::Objects::CommercePayments::BatchDeleteParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/commerce_payments/batch/archive",
    body: parsed,
    model: NilClass,
    options: options
  )
end

#get(inputs:, properties:, properties_with_history:, archived: nil, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject

Some parameter documentations has been truncated, see Models::Crm::Objects::CommercePayments::BatchGetParams for more details.

Retrieve records by record ID or include the ‘idProperty` parameter to retrieve records by a custom unique value property.

Parameters:

  • inputs (Array<HubSpotSDK::Models::Crm::SimplePublicObjectID>)

    Body param

  • properties (Array<String>)

    Body param: Key-value pairs for setting properties for the new object.

  • properties_with_history (Array<String>)

    Body param: Key-value pairs for setting properties for the new object and their

  • archived (Boolean)

    Query param: Whether to return only results that have been archived.

  • id_property (String)

    Body param: When using a custom unique value property to retrieve records, the n

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/hubspot_sdk/resources/crm/objects/commerce_payments/batch.rb', line 101

def get(params)
  query_params = [:archived]
  parsed, options = HubSpotSDK::Crm::Objects::CommercePayments::BatchGetParams.dump_request(params)
  query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params))
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/commerce_payments/batch/read",
    query: query,
    body: parsed.except(*query_params),
    model: HubSpotSDK::Crm::BatchResponseSimplePublicObject,
    options: options
  )
end

#update(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject

Update multiple commerce payment records using their internal IDs or unique property values. This operation allows you to modify existing payment records in bulk by providing a list of records with their respective IDs and updated property values.



44
45
46
47
48
49
50
51
52
53
# File 'lib/hubspot_sdk/resources/crm/objects/commerce_payments/batch.rb', line 44

def update(params)
  parsed, options = HubSpotSDK::Crm::Objects::CommercePayments::BatchUpdateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/commerce_payments/batch/update",
    body: parsed,
    model: HubSpotSDK::Crm::BatchResponseSimplePublicObject,
    options: options
  )
end

#upsert(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject

Create or update records identified by a unique property value as specified by the ‘idProperty` query param. `idProperty` query param refers to a property whose values are unique for the object.



127
128
129
130
131
132
133
134
135
136
# File 'lib/hubspot_sdk/resources/crm/objects/commerce_payments/batch.rb', line 127

def upsert(params)
  parsed, options = HubSpotSDK::Crm::Objects::CommercePayments::BatchUpsertParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/commerce_payments/batch/upsert",
    body: parsed,
    model: HubSpotSDK::Crm::BatchResponseSimplePublicUpsertObject,
    options: options
  )
end