Class: HubSpotSDK::Resources::Crm::Objects::Deals
- Inherits:
-
Object
- Object
- HubSpotSDK::Resources::Crm::Objects::Deals
- Defined in:
- lib/hubspot_sdk/resources/crm/objects/deals.rb,
lib/hubspot_sdk/resources/crm/objects/deals/batch.rb
Defined Under Namespace
Classes: Batch
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#create(associations:, properties:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Create a deal with the given properties and return a copy of the object, including the ID.
-
#delete(deal_id, request_options: {}) ⇒ nil
Move an Object identified by ‘dealId` to the recycling bin.
-
#get(deal_id, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations
Some parameter documentations has been truncated, see Models::Crm::Objects::DealGetParams for more details.
-
#initialize(client:) ⇒ Deals
constructor
private
A new instance of Deals.
-
#list(after: nil, archived: nil, associations: nil, limit: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Internal::Page<HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations>
Some parameter documentations has been truncated, see Models::Crm::Objects::DealListParams for more details.
-
#merge(object_id_to_merge:, primary_object_id:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Combine two deals of the same type into a single deal.
-
#search(after:, filter_groups:, limit:, properties:, sorts:, query: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseWithTotalSimplePublicObject
Search for deals using specified criteria and filters.
-
#update(deal_id, properties:, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::DealUpdateParams for more details.
Constructor Details
#initialize(client:) ⇒ Deals
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Deals.
231 232 233 234 |
# File 'lib/hubspot_sdk/resources/crm/objects/deals.rb', line 231 def initialize(client:) @client = client @batch = HubSpotSDK::Resources::Crm::Objects::Deals::Batch.new(client: client) end |
Instance Attribute Details
#batch ⇒ HubSpotSDK::Resources::Crm::Objects::Deals::Batch (readonly)
9 10 11 |
# File 'lib/hubspot_sdk/resources/crm/objects/deals.rb', line 9 def batch @batch end |
Instance Method Details
#create(associations:, properties:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Create a deal with the given properties and return a copy of the object, including the ID. Documentation and examples for creating standard deals is provided.
26 27 28 29 30 31 32 33 34 35 |
# File 'lib/hubspot_sdk/resources/crm/objects/deals.rb', line 26 def create(params) parsed, = HubSpotSDK::Crm::Objects::DealCreateParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/0-3", body: parsed, model: HubSpotSDK::Crm::SimplePublicObject, options: ) end |
#delete(deal_id, request_options: {}) ⇒ nil
Move an Object identified by ‘dealId` to the recycling bin.
121 122 123 124 125 126 127 128 |
# File 'lib/hubspot_sdk/resources/crm/objects/deals.rb', line 121 def delete(deal_id, params = {}) @client.request( method: :delete, path: ["crm/objects/2026-03/0-3/%1$s", deal_id], model: NilClass, options: params[:request_options] ) end |
#get(deal_id, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations
Some parameter documentations has been truncated, see Models::Crm::Objects::DealGetParams for more details.
Read an Object identified by ‘dealId`. `dealId` refers to the internal object ID by default, or optionally any unique property value as specified by the `idProperty` query param. Control what is returned via the `properties` query param.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/hubspot_sdk/resources/crm/objects/deals.rb', line 157 def get(deal_id, params = {}) parsed, = HubSpotSDK::Crm::Objects::DealGetParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["crm/objects/2026-03/0-3/%1$s", deal_id], query: query.transform_keys( id_property: "idProperty", properties_with_history: "propertiesWithHistory" ), model: HubSpotSDK::Crm::SimplePublicObjectWithAssociations, options: ) end |
#list(after: nil, archived: nil, associations: nil, limit: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Internal::Page<HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations>
Some parameter documentations has been truncated, see Models::Crm::Objects::DealListParams for more details.
Read a page of deals. Control what is returned via the ‘properties` query param.
98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/hubspot_sdk/resources/crm/objects/deals.rb', line 98 def list(params = {}) parsed, = HubSpotSDK::Crm::Objects::DealListParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "crm/objects/2026-03/0-3", query: query.transform_keys(properties_with_history: "propertiesWithHistory"), page: HubSpotSDK::Internal::Page, model: HubSpotSDK::Crm::SimplePublicObjectWithAssociations, options: ) end |
#merge(object_id_to_merge:, primary_object_id:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Combine two deals of the same type into a single deal.
185 186 187 188 189 190 191 192 193 194 |
# File 'lib/hubspot_sdk/resources/crm/objects/deals.rb', line 185 def merge(params) parsed, = HubSpotSDK::Crm::Objects::DealMergeParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/0-3/merge", body: parsed, model: HubSpotSDK::Crm::SimplePublicObject, options: ) end |
#search(after:, filter_groups:, limit:, properties:, sorts:, query: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseWithTotalSimplePublicObject
Search for deals using specified criteria and filters.
217 218 219 220 221 222 223 224 225 226 |
# File 'lib/hubspot_sdk/resources/crm/objects/deals.rb', line 217 def search(params) parsed, = HubSpotSDK::Crm::Objects::DealSearchParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/0-3/search", body: parsed, model: HubSpotSDK::Crm::CollectionResponseWithTotalSimplePublicObject, options: ) end |
#update(deal_id, properties:, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::DealUpdateParams for more details.
Perform a partial update of an Object identified by ‘dealId`or optionally a unique property value as specified by the `idProperty` query param. `dealId` refers to the internal object ID by default, and the `idProperty` query param refers to a property whose values are unique for the object. Provided property values will be overwritten. Read-only and non-existent properties will result in an error. Properties values can be cleared by passing an empty string.
60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/hubspot_sdk/resources/crm/objects/deals.rb', line 60 def update(deal_id, params) query_params = [:id_property] parsed, = HubSpotSDK::Crm::Objects::DealUpdateParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params)) @client.request( method: :patch, path: ["crm/objects/2026-03/0-3/%1$s", deal_id], query: query.transform_keys(id_property: "idProperty"), body: parsed.except(*query_params), model: HubSpotSDK::Crm::SimplePublicObject, options: ) end |