Class: HubSpotSDK::Resources::Crm::Objects::Emails::Batch
- Inherits:
-
Object
- Object
- HubSpotSDK::Resources::Crm::Objects::Emails::Batch
- Defined in:
- lib/hubspot_sdk/resources/crm/objects/emails/batch.rb
Instance Method Summary collapse
-
#create(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Create a batch of emails with specified properties and return the created objects.
-
#delete(inputs:, request_options: {}) ⇒ nil
Archive a batch of emails identified by their IDs.
-
#get(inputs:, properties:, properties_with_history:, archived: nil, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::Emails::BatchGetParams for more details.
-
#initialize(client:) ⇒ Batch
constructor
private
A new instance of Batch.
-
#update(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Update a batch of emails using their internal IDs or unique property values.
-
#upsert(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject
Create or update records identified by a unique property value as specified by the ‘idProperty` query param.
Constructor Details
#initialize(client:) ⇒ Batch
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Batch.
136 137 138 |
# File 'lib/hubspot_sdk/resources/crm/objects/emails/batch.rb', line 136 def initialize(client:) @client = client end |
Instance Method Details
#create(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Create a batch of emails with specified properties and return the created objects.
20 21 22 23 24 25 26 27 28 29 |
# File 'lib/hubspot_sdk/resources/crm/objects/emails/batch.rb', line 20 def create(params) parsed, = HubSpotSDK::Crm::Objects::Emails::BatchCreateParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/emails/batch/create", body: parsed, model: HubSpotSDK::Crm::BatchResponseSimplePublicObject, options: ) end |
#delete(inputs:, request_options: {}) ⇒ nil
Archive a batch of emails identified by their IDs.
62 63 64 65 66 67 68 69 70 71 |
# File 'lib/hubspot_sdk/resources/crm/objects/emails/batch.rb', line 62 def delete(params) parsed, = HubSpotSDK::Crm::Objects::Emails::BatchDeleteParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/emails/batch/archive", body: parsed, model: NilClass, options: ) end |
#get(inputs:, properties:, properties_with_history:, archived: nil, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::Emails::BatchGetParams for more details.
Retrieve records by record ID or include the ‘idProperty` parameter to retrieve records by a custom unique value property.
96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/hubspot_sdk/resources/crm/objects/emails/batch.rb', line 96 def get(params) query_params = [:archived] parsed, = HubSpotSDK::Crm::Objects::Emails::BatchGetParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params)) @client.request( method: :post, path: "crm/objects/2026-03/emails/batch/read", query: query, body: parsed.except(*query_params), model: HubSpotSDK::Crm::BatchResponseSimplePublicObject, options: ) end |
#update(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Update a batch of emails using their internal IDs or unique property values.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/hubspot_sdk/resources/crm/objects/emails/batch.rb', line 41 def update(params) parsed, = HubSpotSDK::Crm::Objects::Emails::BatchUpdateParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/emails/batch/update", body: parsed, model: HubSpotSDK::Crm::BatchResponseSimplePublicObject, options: ) end |
#upsert(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject
Create or update records identified by a unique property value as specified by the ‘idProperty` query param. `idProperty` query param refers to a property whose values are unique for the object.
122 123 124 125 126 127 128 129 130 131 |
# File 'lib/hubspot_sdk/resources/crm/objects/emails/batch.rb', line 122 def upsert(params) parsed, = HubSpotSDK::Crm::Objects::Emails::BatchUpsertParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/emails/batch/upsert", body: parsed, model: HubSpotSDK::Crm::BatchResponseSimplePublicUpsertObject, options: ) end |