Class: HubSpotSDK::Resources::Crm::Objects::GoalTargets::Batch

Inherits:
Object
  • Object
show all
Defined in:
lib/hubspot_sdk/resources/crm/objects/goal_targets/batch.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Batch

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Batch.

Parameters:



136
137
138
# File 'lib/hubspot_sdk/resources/crm/objects/goal_targets/batch.rb', line 136

def initialize(client:)
  @client = client
end

Instance Method Details

#create(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject

Create multiple goal targets in a single batch operation.



19
20
21
22
23
24
25
26
27
28
# File 'lib/hubspot_sdk/resources/crm/objects/goal_targets/batch.rb', line 19

def create(params)
  parsed, options = HubSpotSDK::Crm::Objects::GoalTargets::BatchCreateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/goal_targets/batch/create",
    body: parsed,
    model: HubSpotSDK::Crm::BatchResponseSimplePublicObject,
    options: options
  )
end

#delete(inputs:, request_options: {}) ⇒ nil

Archive multiple goal targets in a single batch operation using their IDs.

Parameters:

Returns:

  • (nil)

See Also:



62
63
64
65
66
67
68
69
70
71
# File 'lib/hubspot_sdk/resources/crm/objects/goal_targets/batch.rb', line 62

def delete(params)
  parsed, options = HubSpotSDK::Crm::Objects::GoalTargets::BatchDeleteParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/goal_targets/batch/archive",
    body: parsed,
    model: NilClass,
    options: options
  )
end

#get(inputs:, properties:, properties_with_history:, archived: nil, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject

Some parameter documentations has been truncated, see Models::Crm::Objects::GoalTargets::BatchGetParams for more details.

Retrieve records by record ID or include the ‘idProperty` parameter to retrieve records by a custom unique value property.

Parameters:

  • inputs (Array<HubSpotSDK::Models::Crm::SimplePublicObjectID>)

    Body param

  • properties (Array<String>)

    Body param: Key-value pairs for setting properties for the new object.

  • properties_with_history (Array<String>)

    Body param: Key-value pairs for setting properties for the new object and their

  • archived (Boolean)

    Query param: Whether to return only results that have been archived.

  • id_property (String)

    Body param: When using a custom unique value property to retrieve records, the n

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/hubspot_sdk/resources/crm/objects/goal_targets/batch.rb', line 97

def get(params)
  query_params = [:archived]
  parsed, options = HubSpotSDK::Crm::Objects::GoalTargets::BatchGetParams.dump_request(params)
  query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params))
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/goal_targets/batch/read",
    query: query,
    body: parsed.except(*query_params),
    model: HubSpotSDK::Crm::BatchResponseSimplePublicObject,
    options: options
  )
end

#update(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject

Update multiple goal targets in a single batch operation using their internal IDs or unique property values.



41
42
43
44
45
46
47
48
49
50
# File 'lib/hubspot_sdk/resources/crm/objects/goal_targets/batch.rb', line 41

def update(params)
  parsed, options = HubSpotSDK::Crm::Objects::GoalTargets::BatchUpdateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/goal_targets/batch/update",
    body: parsed,
    model: HubSpotSDK::Crm::BatchResponseSimplePublicObject,
    options: options
  )
end

#upsert(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject

Create and update a batch of goal targets by a unique property. Goal targets that don’t exist will be created, while existing goal targets will be updated.



122
123
124
125
126
127
128
129
130
131
# File 'lib/hubspot_sdk/resources/crm/objects/goal_targets/batch.rb', line 122

def upsert(params)
  parsed, options = HubSpotSDK::Crm::Objects::GoalTargets::BatchUpsertParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/goal_targets/batch/upsert",
    body: parsed,
    model: HubSpotSDK::Crm::BatchResponseSimplePublicUpsertObject,
    options: options
  )
end