Class: HubSpotSDK::Resources::Crm::Objects::Invoices
- Inherits:
-
Object
- Object
- HubSpotSDK::Resources::Crm::Objects::Invoices
- Defined in:
- lib/hubspot_sdk/resources/crm/objects/invoices.rb,
lib/hubspot_sdk/resources/crm/objects/invoices/batch.rb
Defined Under Namespace
Classes: Batch
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#create(associations:, properties:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Create a invoice with the given properties and return a copy of the object, including the ID.
-
#delete(invoice_id, request_options: {}) ⇒ nil
Move an Object identified by ‘invoiceId` to the recycling bin.
-
#get(invoice_id, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations
Some parameter documentations has been truncated, see Models::Crm::Objects::InvoiceGetParams for more details.
-
#initialize(client:) ⇒ Invoices
constructor
private
A new instance of Invoices.
-
#list(after: nil, archived: nil, associations: nil, limit: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Internal::Page<HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations>
Some parameter documentations has been truncated, see Models::Crm::Objects::InvoiceListParams for more details.
-
#search(after:, filter_groups:, limit:, properties:, sorts:, query: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseWithTotalSimplePublicObject
Execute a search for invoices based on filter criteria, sorting options, and properties to include in the response.
-
#update(invoice_id, properties:, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::InvoiceUpdateParams for more details.
Constructor Details
#initialize(client:) ⇒ Invoices
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Invoices.
211 212 213 214 |
# File 'lib/hubspot_sdk/resources/crm/objects/invoices.rb', line 211 def initialize(client:) @client = client @batch = HubSpotSDK::Resources::Crm::Objects::Invoices::Batch.new(client: client) end |
Instance Attribute Details
#batch ⇒ HubSpotSDK::Resources::Crm::Objects::Invoices::Batch (readonly)
9 10 11 |
# File 'lib/hubspot_sdk/resources/crm/objects/invoices.rb', line 9 def batch @batch end |
Instance Method Details
#create(associations:, properties:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Create a invoice with the given properties and return a copy of the object, including the ID. Documentation and examples for creating standard invoices is provided.
26 27 28 29 30 31 32 33 34 35 |
# File 'lib/hubspot_sdk/resources/crm/objects/invoices.rb', line 26 def create(params) parsed, = HubSpotSDK::Crm::Objects::InvoiceCreateParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/invoices", body: parsed, model: HubSpotSDK::Crm::SimplePublicObject, options: ) end |
#delete(invoice_id, request_options: {}) ⇒ nil
Move an Object identified by ‘invoiceId` to the recycling bin.
123 124 125 126 127 128 129 130 |
# File 'lib/hubspot_sdk/resources/crm/objects/invoices.rb', line 123 def delete(invoice_id, params = {}) @client.request( method: :delete, path: ["crm/objects/2026-03/invoices/%1$s", invoice_id], model: NilClass, options: params[:request_options] ) end |
#get(invoice_id, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations
Some parameter documentations has been truncated, see Models::Crm::Objects::InvoiceGetParams for more details.
Read an Object identified by ‘invoiceId`. `invoiceId` refers to the internal object ID by default, or optionally any unique property value as specified by the `idProperty` query param. Control what is returned via the `properties` query param.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/hubspot_sdk/resources/crm/objects/invoices.rb', line 159 def get(invoice_id, params = {}) parsed, = HubSpotSDK::Crm::Objects::InvoiceGetParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["crm/objects/2026-03/invoices/%1$s", invoice_id], query: query.transform_keys( id_property: "idProperty", properties_with_history: "propertiesWithHistory" ), model: HubSpotSDK::Crm::SimplePublicObjectWithAssociations, options: ) end |
#list(after: nil, archived: nil, associations: nil, limit: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Internal::Page<HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations>
Some parameter documentations has been truncated, see Models::Crm::Objects::InvoiceListParams for more details.
Read a page of invoices. Control what is returned via the ‘properties` query param.
100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/hubspot_sdk/resources/crm/objects/invoices.rb', line 100 def list(params = {}) parsed, = HubSpotSDK::Crm::Objects::InvoiceListParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "crm/objects/2026-03/invoices", query: query.transform_keys(properties_with_history: "propertiesWithHistory"), page: HubSpotSDK::Internal::Page, model: HubSpotSDK::Crm::SimplePublicObjectWithAssociations, options: ) end |
#search(after:, filter_groups:, limit:, properties:, sorts:, query: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseWithTotalSimplePublicObject
Execute a search for invoices based on filter criteria, sorting options, and properties to include in the response. This endpoint supports pagination and allows for complex queries using multiple filter groups.
197 198 199 200 201 202 203 204 205 206 |
# File 'lib/hubspot_sdk/resources/crm/objects/invoices.rb', line 197 def search(params) parsed, = HubSpotSDK::Crm::Objects::InvoiceSearchParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/invoices/search", body: parsed, model: HubSpotSDK::Crm::CollectionResponseWithTotalSimplePublicObject, options: ) end |
#update(invoice_id, properties:, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::InvoiceUpdateParams for more details.
Perform a partial update of an Object identified by ‘invoiceId`or optionally a unique property value as specified by the `idProperty` query param. `invoiceId` refers to the internal object ID by default, and the `idProperty` query param refers to a property whose values are unique for the object. Provided property values will be overwritten. Read-only and non-existent properties will result in an error. Properties values can be cleared by passing an empty string.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/hubspot_sdk/resources/crm/objects/invoices.rb', line 61 def update(invoice_id, params) query_params = [:id_property] parsed, = HubSpotSDK::Crm::Objects::InvoiceUpdateParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params)) @client.request( method: :patch, path: ["crm/objects/2026-03/invoices/%1$s", invoice_id], query: query.transform_keys(id_property: "idProperty"), body: parsed.except(*query_params), model: HubSpotSDK::Crm::SimplePublicObject, options: ) end |