Class: HubSpotSDK::Resources::Crm::Objects::Meetings
- Inherits:
-
Object
- Object
- HubSpotSDK::Resources::Crm::Objects::Meetings
- Defined in:
- lib/hubspot_sdk/resources/crm/objects/meetings.rb,
lib/hubspot_sdk/resources/crm/objects/meetings/batch.rb
Defined Under Namespace
Classes: Batch
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#create(associations:, properties:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Create a meeting with the given properties and return a copy of the object, including the ID.
-
#delete(meeting_id, request_options: {}) ⇒ nil
Move an Object identified by ‘meetingId` to the recycling bin.
-
#get(meeting_id, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations
Some parameter documentations has been truncated, see Models::Crm::Objects::MeetingGetParams for more details.
-
#initialize(client:) ⇒ Meetings
constructor
private
A new instance of Meetings.
-
#list(after: nil, archived: nil, associations: nil, limit: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Internal::Page<HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations>
Some parameter documentations has been truncated, see Models::Crm::Objects::MeetingListParams for more details.
-
#search(after:, filter_groups:, limit:, properties:, sorts:, query: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseWithTotalSimplePublicObject
Search for meetings by filtering on properties, searching through associations, and sorting results.
-
#update(meeting_id, properties:, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::MeetingUpdateParams for more details.
Constructor Details
#initialize(client:) ⇒ Meetings
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Meetings.
210 211 212 213 |
# File 'lib/hubspot_sdk/resources/crm/objects/meetings.rb', line 210 def initialize(client:) @client = client @batch = HubSpotSDK::Resources::Crm::Objects::Meetings::Batch.new(client: client) end |
Instance Attribute Details
#batch ⇒ HubSpotSDK::Resources::Crm::Objects::Meetings::Batch (readonly)
9 10 11 |
# File 'lib/hubspot_sdk/resources/crm/objects/meetings.rb', line 9 def batch @batch end |
Instance Method Details
#create(associations:, properties:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Create a meeting with the given properties and return a copy of the object, including the ID. Documentation and examples for creating standard meetings is provided.
26 27 28 29 30 31 32 33 34 35 |
# File 'lib/hubspot_sdk/resources/crm/objects/meetings.rb', line 26 def create(params) parsed, = HubSpotSDK::Crm::Objects::MeetingCreateParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/meetings", body: parsed, model: HubSpotSDK::Crm::SimplePublicObject, options: ) end |
#delete(meeting_id, request_options: {}) ⇒ nil
Move an Object identified by ‘meetingId` to the recycling bin.
123 124 125 126 127 128 129 130 |
# File 'lib/hubspot_sdk/resources/crm/objects/meetings.rb', line 123 def delete(meeting_id, params = {}) @client.request( method: :delete, path: ["crm/objects/2026-03/meetings/%1$s", meeting_id], model: NilClass, options: params[:request_options] ) end |
#get(meeting_id, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations
Some parameter documentations has been truncated, see Models::Crm::Objects::MeetingGetParams for more details.
Read an Object identified by ‘meetingId`. `meetingId` refers to the internal object ID by default, or optionally any unique property value as specified by the `idProperty` query param. Control what is returned via the `properties` query param.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/hubspot_sdk/resources/crm/objects/meetings.rb', line 159 def get(meeting_id, params = {}) parsed, = HubSpotSDK::Crm::Objects::MeetingGetParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["crm/objects/2026-03/meetings/%1$s", meeting_id], query: query.transform_keys( id_property: "idProperty", properties_with_history: "propertiesWithHistory" ), model: HubSpotSDK::Crm::SimplePublicObjectWithAssociations, options: ) end |
#list(after: nil, archived: nil, associations: nil, limit: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Internal::Page<HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations>
Some parameter documentations has been truncated, see Models::Crm::Objects::MeetingListParams for more details.
Read a page of meetings. Control what is returned via the ‘properties` query param.
100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/hubspot_sdk/resources/crm/objects/meetings.rb', line 100 def list(params = {}) parsed, = HubSpotSDK::Crm::Objects::MeetingListParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "crm/objects/2026-03/meetings", query: query.transform_keys(properties_with_history: "propertiesWithHistory"), page: HubSpotSDK::Internal::Page, model: HubSpotSDK::Crm::SimplePublicObjectWithAssociations, options: ) end |
#search(after:, filter_groups:, limit:, properties:, sorts:, query: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseWithTotalSimplePublicObject
Search for meetings by filtering on properties, searching through associations, and sorting results.
196 197 198 199 200 201 202 203 204 205 |
# File 'lib/hubspot_sdk/resources/crm/objects/meetings.rb', line 196 def search(params) parsed, = HubSpotSDK::Crm::Objects::MeetingSearchParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/meetings/search", body: parsed, model: HubSpotSDK::Crm::CollectionResponseWithTotalSimplePublicObject, options: ) end |
#update(meeting_id, properties:, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::MeetingUpdateParams for more details.
Perform a partial update of an Object identified by ‘meetingId`or optionally a unique property value as specified by the `idProperty` query param. `meetingId` refers to the internal object ID by default, and the `idProperty` query param refers to a property whose values are unique for the object. Provided property values will be overwritten. Read-only and non-existent properties will result in an error. Properties values can be cleared by passing an empty string.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/hubspot_sdk/resources/crm/objects/meetings.rb', line 61 def update(meeting_id, params) query_params = [:id_property] parsed, = HubSpotSDK::Crm::Objects::MeetingUpdateParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params)) @client.request( method: :patch, path: ["crm/objects/2026-03/meetings/%1$s", meeting_id], query: query.transform_keys(id_property: "idProperty"), body: parsed.except(*query_params), model: HubSpotSDK::Crm::SimplePublicObject, options: ) end |