Class: HubSpotSDK::Resources::Crm::Objects::Meetings::Batch

Inherits:
Object
  • Object
show all
Defined in:
lib/hubspot_sdk/resources/crm/objects/meetings/batch.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Batch

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Batch.

Parameters:



140
141
142
# File 'lib/hubspot_sdk/resources/crm/objects/meetings/batch.rb', line 140

def initialize(client:)
  @client = client
end

Instance Method Details

#create(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject

Create a batch of meetings. The ‘inputs` array can contain a `properties` object to define property values for the record, along with an `associations` array to define relationships with other object records.



21
22
23
24
25
26
27
28
29
30
# File 'lib/hubspot_sdk/resources/crm/objects/meetings/batch.rb', line 21

def create(params)
  parsed, options = HubSpotSDK::Crm::Objects::Meetings::BatchCreateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/meetings/batch/create",
    body: parsed,
    model: HubSpotSDK::Crm::BatchResponseSimplePublicObject,
    options: options
  )
end

#delete(inputs:, request_options: {}) ⇒ nil

Delete a batch of meetings by ID.

Parameters:

Returns:

  • (nil)

See Also:



66
67
68
69
70
71
72
73
74
75
# File 'lib/hubspot_sdk/resources/crm/objects/meetings/batch.rb', line 66

def delete(params)
  parsed, options = HubSpotSDK::Crm::Objects::Meetings::BatchDeleteParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/meetings/batch/archive",
    body: parsed,
    model: NilClass,
    options: options
  )
end

#get(inputs:, properties:, properties_with_history:, archived: nil, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject

Some parameter documentations has been truncated, see Models::Crm::Objects::Meetings::BatchGetParams for more details.

Retrieve records by record ID or include the ‘idProperty` parameter to retrieve records by a custom unique value property.

Parameters:

  • inputs (Array<HubSpotSDK::Models::Crm::SimplePublicObjectID>)

    Body param

  • properties (Array<String>)

    Body param: Key-value pairs for setting properties for the new object.

  • properties_with_history (Array<String>)

    Body param: Key-value pairs for setting properties for the new object and their

  • archived (Boolean)

    Query param: Whether to return only results that have been archived.

  • id_property (String)

    Body param: When using a custom unique value property to retrieve records, the n

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/hubspot_sdk/resources/crm/objects/meetings/batch.rb', line 100

def get(params)
  query_params = [:archived]
  parsed, options = HubSpotSDK::Crm::Objects::Meetings::BatchGetParams.dump_request(params)
  query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params))
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/meetings/batch/read",
    query: query,
    body: parsed.except(*query_params),
    model: HubSpotSDK::Crm::BatchResponseSimplePublicObject,
    options: options
  )
end

#update(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject

Update a batch of meetings by ID (‘objectId`) or unique property value (`idProperty`). Provided property values will be overwritten. Read-only and non-existent properties will result in an error. Properties values can be cleared by passing an empty string.



45
46
47
48
49
50
51
52
53
54
# File 'lib/hubspot_sdk/resources/crm/objects/meetings/batch.rb', line 45

def update(params)
  parsed, options = HubSpotSDK::Crm::Objects::Meetings::BatchUpdateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/meetings/batch/update",
    body: parsed,
    model: HubSpotSDK::Crm::BatchResponseSimplePublicObject,
    options: options
  )
end

#upsert(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject

Create or update records identified by a unique property value as specified by the ‘idProperty` query param. `idProperty` query param refers to a property whose values are unique for the object.



126
127
128
129
130
131
132
133
134
135
# File 'lib/hubspot_sdk/resources/crm/objects/meetings/batch.rb', line 126

def upsert(params)
  parsed, options = HubSpotSDK::Crm::Objects::Meetings::BatchUpsertParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/meetings/batch/upsert",
    body: parsed,
    model: HubSpotSDK::Crm::BatchResponseSimplePublicUpsertObject,
    options: options
  )
end