Class: HubSpotSDK::Resources::Crm::Objects::Notes::Batch
- Inherits:
-
Object
- Object
- HubSpotSDK::Resources::Crm::Objects::Notes::Batch
- Defined in:
- lib/hubspot_sdk/resources/crm/objects/notes/batch.rb
Instance Method Summary collapse
-
#create(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Create multiple notes in a single request by providing the necessary properties for each note.
-
#delete(inputs:, request_options: {}) ⇒ nil
Archive multiple notes by their IDs in a single request.
-
#get(inputs:, properties:, properties_with_history:, archived: nil, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::Notes::BatchGetParams for more details.
-
#initialize(client:) ⇒ Batch
constructor
private
A new instance of Batch.
-
#update(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Update multiple notes using their internal IDs or unique property values.
-
#upsert(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject
Create or update records identified by a unique property value as specified by the ‘idProperty` query param.
Constructor Details
#initialize(client:) ⇒ Batch
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Batch.
141 142 143 |
# File 'lib/hubspot_sdk/resources/crm/objects/notes/batch.rb', line 141 def initialize(client:) @client = client end |
Instance Method Details
#create(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Create multiple notes in a single request by providing the necessary properties for each note. This operation returns the created notes with their unique identifiers.
21 22 23 24 25 26 27 28 29 30 |
# File 'lib/hubspot_sdk/resources/crm/objects/notes/batch.rb', line 21 def create(params) parsed, = HubSpotSDK::Crm::Objects::Notes::BatchCreateParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/notes/batch/create", body: parsed, model: HubSpotSDK::Crm::BatchResponseSimplePublicObject, options: ) end |
#delete(inputs:, request_options: {}) ⇒ nil
Archive multiple notes by their IDs in a single request. This operation moves the specified notes to the recycling bin, making them inaccessible from regular queries.
67 68 69 70 71 72 73 74 75 76 |
# File 'lib/hubspot_sdk/resources/crm/objects/notes/batch.rb', line 67 def delete(params) parsed, = HubSpotSDK::Crm::Objects::Notes::BatchDeleteParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/notes/batch/archive", body: parsed, model: NilClass, options: ) end |
#get(inputs:, properties:, properties_with_history:, archived: nil, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::Notes::BatchGetParams for more details.
Retrieve records by record ID or include the ‘idProperty` parameter to retrieve records by a custom unique value property.
101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/hubspot_sdk/resources/crm/objects/notes/batch.rb', line 101 def get(params) query_params = [:archived] parsed, = HubSpotSDK::Crm::Objects::Notes::BatchGetParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params)) @client.request( method: :post, path: "crm/objects/2026-03/notes/batch/read", query: query, body: parsed.except(*query_params), model: HubSpotSDK::Crm::BatchResponseSimplePublicObject, options: ) end |
#update(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Update multiple notes using their internal IDs or unique property values. This operation allows you to modify the properties of several notes in a single request, streamlining the process of managing note data in bulk.
44 45 46 47 48 49 50 51 52 53 |
# File 'lib/hubspot_sdk/resources/crm/objects/notes/batch.rb', line 44 def update(params) parsed, = HubSpotSDK::Crm::Objects::Notes::BatchUpdateParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/notes/batch/update", body: parsed, model: HubSpotSDK::Crm::BatchResponseSimplePublicObject, options: ) end |
#upsert(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject
Create or update records identified by a unique property value as specified by the ‘idProperty` query param. `idProperty` query param refers to a property whose values are unique for the object.
127 128 129 130 131 132 133 134 135 136 |
# File 'lib/hubspot_sdk/resources/crm/objects/notes/batch.rb', line 127 def upsert(params) parsed, = HubSpotSDK::Crm::Objects::Notes::BatchUpsertParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/notes/batch/upsert", body: parsed, model: HubSpotSDK::Crm::BatchResponseSimplePublicUpsertObject, options: ) end |