Class: HubSpotSDK::Resources::Crm::Objects::Orders
- Inherits:
-
Object
- Object
- HubSpotSDK::Resources::Crm::Objects::Orders
- Defined in:
- lib/hubspot_sdk/resources/crm/objects/orders.rb,
lib/hubspot_sdk/resources/crm/objects/orders/batch.rb
Defined Under Namespace
Classes: Batch
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#create(associations:, properties:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Create a order with the given properties and return a copy of the object, including the ID.
-
#delete(order_id, request_options: {}) ⇒ nil
Move an Object identified by ‘orderId` to the recycling bin.
-
#get(order_id, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations
Some parameter documentations has been truncated, see Models::Crm::Objects::OrderGetParams for more details.
-
#initialize(client:) ⇒ Orders
constructor
private
A new instance of Orders.
-
#list(after: nil, archived: nil, associations: nil, limit: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Internal::Page<HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations>
Some parameter documentations has been truncated, see Models::Crm::Objects::OrderListParams for more details.
-
#search(after:, filter_groups:, limit:, properties:, sorts:, query: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseWithTotalSimplePublicObject
Execute a search for orders using specified criteria and return matching results.
-
#update(order_id, properties:, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::OrderUpdateParams for more details.
Constructor Details
#initialize(client:) ⇒ Orders
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Orders.
209 210 211 212 |
# File 'lib/hubspot_sdk/resources/crm/objects/orders.rb', line 209 def initialize(client:) @client = client @batch = HubSpotSDK::Resources::Crm::Objects::Orders::Batch.new(client: client) end |
Instance Attribute Details
#batch ⇒ HubSpotSDK::Resources::Crm::Objects::Orders::Batch (readonly)
9 10 11 |
# File 'lib/hubspot_sdk/resources/crm/objects/orders.rb', line 9 def batch @batch end |
Instance Method Details
#create(associations:, properties:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Create a order with the given properties and return a copy of the object, including the ID. Documentation and examples for creating standard orders is provided.
26 27 28 29 30 31 32 33 34 35 |
# File 'lib/hubspot_sdk/resources/crm/objects/orders.rb', line 26 def create(params) parsed, = HubSpotSDK::Crm::Objects::OrderCreateParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/orders", body: parsed, model: HubSpotSDK::Crm::SimplePublicObject, options: ) end |
#delete(order_id, request_options: {}) ⇒ nil
Move an Object identified by ‘orderId` to the recycling bin.
122 123 124 125 126 127 128 129 |
# File 'lib/hubspot_sdk/resources/crm/objects/orders.rb', line 122 def delete(order_id, params = {}) @client.request( method: :delete, path: ["crm/objects/2026-03/orders/%1$s", order_id], model: NilClass, options: params[:request_options] ) end |
#get(order_id, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations
Some parameter documentations has been truncated, see Models::Crm::Objects::OrderGetParams for more details.
Read an Object identified by ‘orderId`. `orderId` refers to the internal object ID by default, or optionally any unique property value as specified by the `idProperty` query param. Control what is returned via the `properties` query param.
158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/hubspot_sdk/resources/crm/objects/orders.rb', line 158 def get(order_id, params = {}) parsed, = HubSpotSDK::Crm::Objects::OrderGetParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["crm/objects/2026-03/orders/%1$s", order_id], query: query.transform_keys( id_property: "idProperty", properties_with_history: "propertiesWithHistory" ), model: HubSpotSDK::Crm::SimplePublicObjectWithAssociations, options: ) end |
#list(after: nil, archived: nil, associations: nil, limit: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Internal::Page<HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations>
Some parameter documentations has been truncated, see Models::Crm::Objects::OrderListParams for more details.
Read a page of orders. Control what is returned via the ‘properties` query param.
99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/hubspot_sdk/resources/crm/objects/orders.rb', line 99 def list(params = {}) parsed, = HubSpotSDK::Crm::Objects::OrderListParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "crm/objects/2026-03/orders", query: query.transform_keys(properties_with_history: "propertiesWithHistory"), page: HubSpotSDK::Internal::Page, model: HubSpotSDK::Crm::SimplePublicObjectWithAssociations, options: ) end |
#search(after:, filter_groups:, limit:, properties:, sorts:, query: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseWithTotalSimplePublicObject
Execute a search for orders using specified criteria and return matching results.
195 196 197 198 199 200 201 202 203 204 |
# File 'lib/hubspot_sdk/resources/crm/objects/orders.rb', line 195 def search(params) parsed, = HubSpotSDK::Crm::Objects::OrderSearchParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/orders/search", body: parsed, model: HubSpotSDK::Crm::CollectionResponseWithTotalSimplePublicObject, options: ) end |
#update(order_id, properties:, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::OrderUpdateParams for more details.
Perform a partial update of an Object identified by ‘orderId`or optionally a unique property value as specified by the `idProperty` query param. `orderId` refers to the internal object ID by default, and the `idProperty` query param refers to a property whose values are unique for the object. Provided property values will be overwritten. Read-only and non-existent properties will result in an error. Properties values can be cleared by passing an empty string.
60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/hubspot_sdk/resources/crm/objects/orders.rb', line 60 def update(order_id, params) query_params = [:id_property] parsed, = HubSpotSDK::Crm::Objects::OrderUpdateParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params)) @client.request( method: :patch, path: ["crm/objects/2026-03/orders/%1$s", order_id], query: query.transform_keys(id_property: "idProperty"), body: parsed.except(*query_params), model: HubSpotSDK::Crm::SimplePublicObject, options: ) end |