Class: HubSpotSDK::Resources::Crm::Objects::PartnerClients::Batch

Inherits:
Object
  • Object
show all
Defined in:
lib/hubspot_sdk/resources/crm/objects/partner_clients/batch.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Batch

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Batch.

Parameters:



75
76
77
# File 'lib/hubspot_sdk/resources/crm/objects/partner_clients/batch.rb', line 75

def initialize(client:)
  @client = client
end

Instance Method Details

#get(inputs:, properties:, properties_with_history:, archived: nil, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject

Some parameter documentations has been truncated, see Models::Crm::Objects::PartnerClients::BatchGetParams for more details.

Retrieve multiple partner client objects in a single request by specifying their IDs. This endpoint is useful for efficiently accessing data for multiple clients at once, particularly when integrating with third-party systems.

Parameters:

  • inputs (Array<HubSpotSDK::Models::Crm::SimplePublicObjectID>)

    Body param

  • properties (Array<String>)

    Body param: Key-value pairs for setting properties for the new object.

  • properties_with_history (Array<String>)

    Body param: Key-value pairs for setting properties for the new object and their

  • archived (Boolean)

    Query param: Whether to return only results that have been archived.

  • id_property (String)

    Body param: When using a custom unique value property to retrieve records, the n

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/hubspot_sdk/resources/crm/objects/partner_clients/batch.rb', line 58

def get(params)
  query_params = [:archived]
  parsed, options = HubSpotSDK::Crm::Objects::PartnerClients::BatchGetParams.dump_request(params)
  query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params))
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/partner_clients/batch/read",
    query: query,
    body: parsed.except(*query_params),
    model: HubSpotSDK::Crm::BatchResponseSimplePublicObject,
    options: options
  )
end

#update(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject

This endpoint allows you to update several partner client records at once by providing a batch of CRM object records with their respective IDs and properties. It is useful for synchronizing data across systems or making bulk updates efficiently.



22
23
24
25
26
27
28
29
30
31
# File 'lib/hubspot_sdk/resources/crm/objects/partner_clients/batch.rb', line 22

def update(params)
  parsed, options = HubSpotSDK::Crm::Objects::PartnerClients::BatchUpdateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/partner_clients/batch/update",
    body: parsed,
    model: HubSpotSDK::Crm::BatchResponseSimplePublicObject,
    options: options
  )
end