Class: HubSpotSDK::Resources::Crm::Objects::PostalMail

Inherits:
Object
  • Object
show all
Defined in:
lib/hubspot_sdk/resources/crm/objects/postal_mail.rb,
lib/hubspot_sdk/resources/crm/objects/postal_mail/batch.rb

Defined Under Namespace

Classes: Batch

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ PostalMail

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of PostalMail.

Parameters:



192
193
194
195
# File 'lib/hubspot_sdk/resources/crm/objects/postal_mail.rb', line 192

def initialize(client:)
  @client = client
  @batch = HubSpotSDK::Resources::Crm::Objects::PostalMail::Batch.new(client: client)
end

Instance Attribute Details

#batchHubSpotSDK::Resources::Crm::Objects::PostalMail::Batch (readonly)



9
10
11
# File 'lib/hubspot_sdk/resources/crm/objects/postal_mail.rb', line 9

def batch
  @batch
end

Instance Method Details

#create(associations:, properties:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject

Create a postal mail object with the given properties and return a copy of the object, including the ID.

Parameters:

Returns:

See Also:



25
26
27
28
29
30
31
32
33
34
# File 'lib/hubspot_sdk/resources/crm/objects/postal_mail.rb', line 25

def create(params)
  parsed, options = HubSpotSDK::Crm::Objects::PostalMailCreateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/postal_mail",
    body: parsed,
    model: HubSpotSDK::Crm::SimplePublicObject,
    options: options
  )
end

#delete(postal_mail_id, request_options: {}) ⇒ nil

Move the postal mail object with the ID ‘postalMailId` to the recycling bin.

Parameters:

Returns:

  • (nil)

See Also:



111
112
113
114
115
116
117
118
# File 'lib/hubspot_sdk/resources/crm/objects/postal_mail.rb', line 111

def delete(postal_mail_id, params = {})
  @client.request(
    method: :delete,
    path: ["crm/objects/2026-03/postal_mail/%1$s", postal_mail_id],
    model: NilClass,
    options: params[:request_options]
  )
end

#get(postal_mail_id, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations

Some parameter documentations has been truncated, see Models::Crm::Objects::PostalMailGetParams for more details.

Parameters:

  • postal_mail_id (String)
  • archived (Boolean)

    Whether to return only results that have been archived.

  • associations (Array<String>)

    A comma separated list of object types to retrieve associated IDs for. If any of

  • id_property (String)

    The name of a property whose values are unique for this object type

  • properties (Array<String>)

    A comma separated list of the properties to be returned in the response. If any

  • properties_with_history (Array<String>)

    A comma separated list of the properties to be returned along with their history

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/hubspot_sdk/resources/crm/objects/postal_mail.rb', line 142

def get(postal_mail_id, params = {})
  parsed, options = HubSpotSDK::Crm::Objects::PostalMailGetParams.dump_request(params)
  query = HubSpotSDK::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: ["crm/objects/2026-03/postal_mail/%1$s", postal_mail_id],
    query: query.transform_keys(
      id_property: "idProperty",
      properties_with_history: "propertiesWithHistory"
    ),
    model: HubSpotSDK::Crm::SimplePublicObjectWithAssociations,
    options: options
  )
end

#list(after: nil, archived: nil, associations: nil, limit: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Internal::Page<HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations>

Some parameter documentations has been truncated, see Models::Crm::Objects::PostalMailListParams for more details.

Parameters:

  • after (String)

    The paging cursor token of the last successfully read resource will be returned

  • archived (Boolean)

    Whether to return only results that have been archived.

  • associations (Array<String>)

    A comma separated list of object types to retrieve associated IDs for. If any of

  • limit (Integer)

    The maximum number of results to display per page.

  • properties (Array<String>)

    A comma separated list of the properties to be returned in the response. If any

  • properties_with_history (Array<String>)

    A comma separated list of the properties to be returned along with their history

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/hubspot_sdk/resources/crm/objects/postal_mail.rb', line 88

def list(params = {})
  parsed, options = HubSpotSDK::Crm::Objects::PostalMailListParams.dump_request(params)
  query = HubSpotSDK::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "crm/objects/2026-03/postal_mail",
    query: query.transform_keys(properties_with_history: "propertiesWithHistory"),
    page: HubSpotSDK::Internal::Page,
    model: HubSpotSDK::Crm::SimplePublicObjectWithAssociations,
    options: options
  )
end

#search(after:, filter_groups:, limit:, properties:, sorts:, query: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseWithTotalSimplePublicObject

Search for postal mail objects using specific criteria in the request.

Parameters:

  • after (String)

    A paging cursor token for retrieving subsequent pages.

  • filter_groups (Array<HubSpotSDK::Models::Crm::FilterGroup>)

    Up to 6 groups of filters defining additional query criteria.

  • limit (Integer)

    The maximum results to return, up to 200 objects.

  • properties (Array<String>)

    A list of property names to include in the response.

  • sorts (Array<String>)

    Specifies sorting order based on object properties.

  • query (String)

    The search query string, up to 3000 characters.

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



178
179
180
181
182
183
184
185
186
187
# File 'lib/hubspot_sdk/resources/crm/objects/postal_mail.rb', line 178

def search(params)
  parsed, options = HubSpotSDK::Crm::Objects::PostalMailSearchParams.dump_request(params)
  @client.request(
    method: :post,
    path: "crm/objects/2026-03/postal_mail/search",
    body: parsed,
    model: HubSpotSDK::Crm::CollectionResponseWithTotalSimplePublicObject,
    options: options
  )
end

#update(postal_mail_id, properties:, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject

Some parameter documentations has been truncated, see Models::Crm::Objects::PostalMailUpdateParams for more details.

Parameters:

  • postal_mail_id (String)

    Path param

  • properties (Hash{Symbol=>String})

    Body param: Key value pairs representing the properties of the object.

  • id_property (String)

    Query param: The name of a property whose values are unique for this object type

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/hubspot_sdk/resources/crm/objects/postal_mail.rb', line 52

def update(postal_mail_id, params)
  query_params = [:id_property]
  parsed, options = HubSpotSDK::Crm::Objects::PostalMailUpdateParams.dump_request(params)
  query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params))
  @client.request(
    method: :patch,
    path: ["crm/objects/2026-03/postal_mail/%1$s", postal_mail_id],
    query: query.transform_keys(id_property: "idProperty"),
    body: parsed.except(*query_params),
    model: HubSpotSDK::Crm::SimplePublicObject,
    options: options
  )
end