Class: HubSpotSDK::Resources::Crm::Objects::Services::Batch
- Inherits:
-
Object
- Object
- HubSpotSDK::Resources::Crm::Objects::Services::Batch
- Defined in:
- lib/hubspot_sdk/resources/crm/objects/services/batch.rb
Instance Method Summary collapse
-
#create(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Create a batch of objects.
-
#delete(inputs:, request_options: {}) ⇒ nil
Archive a batch of objects.
-
#get(inputs:, properties:, properties_with_history:, archived: nil, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::Services::BatchGetParams for more details.
-
#initialize(client:) ⇒ Batch
constructor
private
A new instance of Batch.
-
#update(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Update a batch of objects.
-
#upsert(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject
Create or update records identified by a unique property value as specified by the ‘idProperty` query param.
Constructor Details
#initialize(client:) ⇒ Batch
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Batch.
135 136 137 |
# File 'lib/hubspot_sdk/resources/crm/objects/services/batch.rb', line 135 def initialize(client:) @client = client end |
Instance Method Details
#create(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Create a batch of objects
19 20 21 22 23 24 25 26 27 28 |
# File 'lib/hubspot_sdk/resources/crm/objects/services/batch.rb', line 19 def create(params) parsed, = HubSpotSDK::Crm::Objects::Services::BatchCreateParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/0-162/batch/create", body: parsed, model: HubSpotSDK::Crm::BatchResponseSimplePublicObject, options: ) end |
#delete(inputs:, request_options: {}) ⇒ nil
Archive a batch of objects
61 62 63 64 65 66 67 68 69 70 |
# File 'lib/hubspot_sdk/resources/crm/objects/services/batch.rb', line 61 def delete(params) parsed, = HubSpotSDK::Crm::Objects::Services::BatchDeleteParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/0-162/batch/archive", body: parsed, model: NilClass, options: ) end |
#get(inputs:, properties:, properties_with_history:, archived: nil, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::Services::BatchGetParams for more details.
Retrieve records by record ID or include the ‘idProperty` parameter to retrieve records by a custom unique value property.
95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/hubspot_sdk/resources/crm/objects/services/batch.rb', line 95 def get(params) query_params = [:archived] parsed, = HubSpotSDK::Crm::Objects::Services::BatchGetParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params)) @client.request( method: :post, path: "crm/objects/2026-03/0-162/batch/read", query: query, body: parsed.except(*query_params), model: HubSpotSDK::Crm::BatchResponseSimplePublicObject, options: ) end |
#update(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Update a batch of objects
40 41 42 43 44 45 46 47 48 49 |
# File 'lib/hubspot_sdk/resources/crm/objects/services/batch.rb', line 40 def update(params) parsed, = HubSpotSDK::Crm::Objects::Services::BatchUpdateParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/0-162/batch/update", body: parsed, model: HubSpotSDK::Crm::BatchResponseSimplePublicObject, options: ) end |
#upsert(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject
Create or update records identified by a unique property value as specified by the ‘idProperty` query param. `idProperty` query param refers to a property whose values are unique for the object.
121 122 123 124 125 126 127 128 129 130 |
# File 'lib/hubspot_sdk/resources/crm/objects/services/batch.rb', line 121 def upsert(params) parsed, = HubSpotSDK::Crm::Objects::Services::BatchUpsertParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/0-162/batch/upsert", body: parsed, model: HubSpotSDK::Crm::BatchResponseSimplePublicUpsertObject, options: ) end |