Class: HubSpotSDK::Resources::Crm::Objects::Users
- Inherits:
-
Object
- Object
- HubSpotSDK::Resources::Crm::Objects::Users
- Defined in:
- lib/hubspot_sdk/resources/crm/objects/users.rb,
lib/hubspot_sdk/resources/crm/objects/users/batch.rb
Defined Under Namespace
Classes: Batch
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#create(associations:, properties:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Create a user with the given properties and return a copy of the object, including the ID.
-
#delete(user_id, request_options: {}) ⇒ nil
Move an Object identified by ‘userId` to the recycling bin.
-
#get(user_id, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations
Some parameter documentations has been truncated, see Models::Crm::Objects::UserGetParams for more details.
-
#initialize(client:) ⇒ Users
constructor
private
A new instance of Users.
-
#list(after: nil, archived: nil, associations: nil, limit: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Internal::Page<HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations>
Some parameter documentations has been truncated, see Models::Crm::Objects::UserListParams for more details.
-
#search(after:, filter_groups:, limit:, properties:, sorts:, query: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseWithTotalSimplePublicObject
Execute a search for users using defined filters, properties, and sorting options.
-
#update(user_id, properties:, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::UserUpdateParams for more details.
Constructor Details
#initialize(client:) ⇒ Users
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Users.
209 210 211 212 |
# File 'lib/hubspot_sdk/resources/crm/objects/users.rb', line 209 def initialize(client:) @client = client @batch = HubSpotSDK::Resources::Crm::Objects::Users::Batch.new(client: client) end |
Instance Attribute Details
#batch ⇒ HubSpotSDK::Resources::Crm::Objects::Users::Batch (readonly)
9 10 11 |
# File 'lib/hubspot_sdk/resources/crm/objects/users.rb', line 9 def batch @batch end |
Instance Method Details
#create(associations:, properties:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Create a user with the given properties and return a copy of the object, including the ID. Documentation and examples for creating standard users is provided.
26 27 28 29 30 31 32 33 34 35 |
# File 'lib/hubspot_sdk/resources/crm/objects/users.rb', line 26 def create(params) parsed, = HubSpotSDK::Crm::Objects::UserCreateParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/users", body: parsed, model: HubSpotSDK::Crm::SimplePublicObject, options: ) end |
#delete(user_id, request_options: {}) ⇒ nil
Move an Object identified by ‘userId` to the recycling bin.
121 122 123 124 125 126 127 128 |
# File 'lib/hubspot_sdk/resources/crm/objects/users.rb', line 121 def delete(user_id, params = {}) @client.request( method: :delete, path: ["crm/objects/2026-03/users/%1$s", user_id], model: NilClass, options: params[:request_options] ) end |
#get(user_id, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations
Some parameter documentations has been truncated, see Models::Crm::Objects::UserGetParams for more details.
Read an Object identified by ‘userId`. `userId` refers to the internal object ID by default, or optionally any unique property value as specified by the `idProperty` query param. Control what is returned via the `properties` query param.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/hubspot_sdk/resources/crm/objects/users.rb', line 157 def get(user_id, params = {}) parsed, = HubSpotSDK::Crm::Objects::UserGetParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["crm/objects/2026-03/users/%1$s", user_id], query: query.transform_keys( id_property: "idProperty", properties_with_history: "propertiesWithHistory" ), model: HubSpotSDK::Crm::SimplePublicObjectWithAssociations, options: ) end |
#list(after: nil, archived: nil, associations: nil, limit: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Internal::Page<HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations>
Some parameter documentations has been truncated, see Models::Crm::Objects::UserListParams for more details.
Read a page of users. Control what is returned via the ‘properties` query param.
98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/hubspot_sdk/resources/crm/objects/users.rb', line 98 def list(params = {}) parsed, = HubSpotSDK::Crm::Objects::UserListParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "crm/objects/2026-03/users", query: query.transform_keys(properties_with_history: "propertiesWithHistory"), page: HubSpotSDK::Internal::Page, model: HubSpotSDK::Crm::SimplePublicObjectWithAssociations, options: ) end |
#search(after:, filter_groups:, limit:, properties:, sorts:, query: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseWithTotalSimplePublicObject
Execute a search for users using defined filters, properties, and sorting options. The request must include a search query and can return up to 200 results per request.
195 196 197 198 199 200 201 202 203 204 |
# File 'lib/hubspot_sdk/resources/crm/objects/users.rb', line 195 def search(params) parsed, = HubSpotSDK::Crm::Objects::UserSearchParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/users/search", body: parsed, model: HubSpotSDK::Crm::CollectionResponseWithTotalSimplePublicObject, options: ) end |
#update(user_id, properties:, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::UserUpdateParams for more details.
Perform a partial update of an Object identified by ‘userId`or optionally a unique property value as specified by the `idProperty` query param. `userId` refers to the internal object ID by default, and the `idProperty` query param refers to a property whose values are unique for the object. Provided property values will be overwritten. Read-only and non-existent properties will result in an error. Properties values can be cleared by passing an empty string.
60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/hubspot_sdk/resources/crm/objects/users.rb', line 60 def update(user_id, params) query_params = [:id_property] parsed, = HubSpotSDK::Crm::Objects::UserUpdateParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params)) @client.request( method: :patch, path: ["crm/objects/2026-03/users/%1$s", user_id], query: query.transform_keys(id_property: "idProperty"), body: parsed.except(*query_params), model: HubSpotSDK::Crm::SimplePublicObject, options: ) end |