Class: HubSpotSDK::Resources::Crm::Timeline
- Inherits:
-
Object
- Object
- HubSpotSDK::Resources::Crm::Timeline
- Defined in:
- lib/hubspot_sdk/resources/crm/timeline.rb,
lib/hubspot_sdk/resources/crm/timeline/batch.rb
Defined Under Namespace
Classes: Batch
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#create_event(id:, event_type_name:, properties:, domain: nil, email: nil, extra_data: nil, object_id_: nil, object_type_fully_qualified_name: nil, timeline_i_frame: nil, timestamp: nil, utk: nil, request_options: {}) ⇒ nil
Send a single instance of event data to a specified event type.
- #create_project_type(developer_symbol:, project_name:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::AppEventResolutionResponse
-
#initialize(client:) ⇒ Timeline
constructor
private
A new instance of Timeline.
Constructor Details
#initialize(client:) ⇒ Timeline
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Timeline.
64 65 66 67 |
# File 'lib/hubspot_sdk/resources/crm/timeline.rb', line 64 def initialize(client:) @client = client @batch = HubSpotSDK::Resources::Crm::Timeline::Batch.new(client: client) end |
Instance Attribute Details
#batch ⇒ HubSpotSDK::Resources::Crm::Timeline::Batch (readonly)
8 9 10 |
# File 'lib/hubspot_sdk/resources/crm/timeline.rb', line 8 def batch @batch end |
Instance Method Details
#create_event(id:, event_type_name:, properties:, domain: nil, email: nil, extra_data: nil, object_id_: nil, object_type_fully_qualified_name: nil, timeline_i_frame: nil, timestamp: nil, utk: nil, request_options: {}) ⇒ nil
Send a single instance of event data to a specified event type.
30 31 32 33 34 35 36 37 38 39 |
# File 'lib/hubspot_sdk/resources/crm/timeline.rb', line 30 def create_event(params) parsed, = HubSpotSDK::Crm::TimelineCreateEventParams.dump_request(params) @client.request( method: :post, path: "integrators/timeline/2026-03/events", body: parsed, model: NilClass, options: ) end |
#create_project_type(developer_symbol:, project_name:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::AppEventResolutionResponse
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/hubspot_sdk/resources/crm/timeline.rb', line 50 def create_project_type(params) parsed, = HubSpotSDK::Crm::TimelineCreateProjectTypeParams.dump_request(params) @client.request( method: :post, path: "integrators/timeline/2026-03/types/projects", body: parsed, model: HubSpotSDK::Crm::AppEventResolutionResponse, options: ) end |