Class: HubSpotSDK::Resources::Marketing::MarketingEvents::Settings

Inherits:
Object
  • Object
show all
Defined in:
lib/hubspot_sdk/resources/marketing/marketing_events/settings.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Settings

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Settings.

Parameters:



59
60
61
# File 'lib/hubspot_sdk/resources/marketing/marketing_events/settings.rb', line 59

def initialize(client:)
  @client = client
end

Instance Method Details

#create_or_update(app_id, event_details_url:, request_options: {}) ⇒ HubSpotSDK::Models::Marketing::EventDetailSettings

Some parameter documentations has been truncated, see Models::Marketing::MarketingEvents::SettingCreateOrUpdateParams for more details.

Create or update the current settings for the application.

Parameters:

  • app_id (Integer)
  • event_details_url (String)

    The url that will be used to fetch marketing event details by id. Must contain a

  • request_options (HubSpotSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



25
26
27
28
29
30
31
32
33
34
35
# File 'lib/hubspot_sdk/resources/marketing/marketing_events/settings.rb', line 25

def create_or_update(app_id, params)
  parsed, options =
    HubSpotSDK::Marketing::MarketingEvents::SettingCreateOrUpdateParams.dump_request(params)
  @client.request(
    method: :post,
    path: ["marketing/marketing-events/2026-03/%1$s/settings", app_id],
    body: parsed,
    model: HubSpotSDK::Marketing::EventDetailSettings,
    options: options
  )
end

#get(app_id, request_options: {}) ⇒ HubSpotSDK::Models::Marketing::EventDetailSettings

Retrieve the current settings for the application.

Parameters:

Returns:

See Also:



47
48
49
50
51
52
53
54
# File 'lib/hubspot_sdk/resources/marketing/marketing_events/settings.rb', line 47

def get(app_id, params = {})
  @client.request(
    method: :get,
    path: ["marketing/marketing-events/2026-03/%1$s/settings", app_id],
    model: HubSpotSDK::Marketing::EventDetailSettings,
    options: params[:request_options]
  )
end