Class: HubSpotSDK::Resources::Scheduler::Meetings::Basic

Inherits:
Object
  • Object
show all
Defined in:
lib/hubspot_sdk/resources/scheduler/meetings/basic.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Basic

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Basic.

Parameters:



93
94
95
# File 'lib/hubspot_sdk/resources/scheduler/meetings/basic.rb', line 93

def initialize(client:)
  @client = client
end

Instance Method Details

#get_availability_by_slug(slug, timezone:, month_offset: nil, request_options: {}) ⇒ HubSpotSDK::Models::Scheduler::ExternalLinkAvailabilityAndBusyTimes

Get the next availability times for a meeting page.

Parameters:

Returns:

See Also:



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/hubspot_sdk/resources/scheduler/meetings/basic.rb', line 55

def get_availability_by_slug(slug, params)
  parsed, options = HubSpotSDK::Scheduler::Meetings::BasicGetAvailabilityBySlugParams.dump_request(params)
  query = HubSpotSDK::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: ["scheduler/2026-03/meetings/meeting-links/book/availability-page/%1$s", slug],
    query: query.transform_keys(month_offset: "monthOffset"),
    model: HubSpotSDK::Scheduler::ExternalLinkAvailabilityAndBusyTimes,
    options: options
  )
end

#get_booking_info_by_slug(slug, timezone:, request_options: {}) ⇒ HubSpotSDK::Models::Scheduler::ExternalBookingInfo

Get details about the initial information necessary for a meeting scheduler.

Parameters:

Returns:

See Also:



78
79
80
81
82
83
84
85
86
87
88
# File 'lib/hubspot_sdk/resources/scheduler/meetings/basic.rb', line 78

def get_booking_info_by_slug(slug, params)
  parsed, options = HubSpotSDK::Scheduler::Meetings::BasicGetBookingInfoBySlugParams.dump_request(params)
  query = HubSpotSDK::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: ["scheduler/2026-03/meetings/meeting-links/book/%1$s", slug],
    query: query,
    model: HubSpotSDK::Scheduler::ExternalBookingInfo,
    options: options
  )
end

#list(after: nil, limit: nil, name: nil, organizer_user_id: nil, type: nil, request_options: {}) ⇒ HubSpotSDK::Internal::Page<HubSpotSDK::Models::Scheduler::ExternalLinkMetadata>

Some parameter documentations has been truncated, see Models::Scheduler::Meetings::BasicListParams for more details.

Get a paged list meeting scheduling pages

Parameters:

Returns:

See Also:



30
31
32
33
34
35
36
37
38
39
40
41
# File 'lib/hubspot_sdk/resources/scheduler/meetings/basic.rb', line 30

def list(params = {})
  parsed, options = HubSpotSDK::Scheduler::Meetings::BasicListParams.dump_request(params)
  query = HubSpotSDK::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "scheduler/2026-03/meetings/meeting-links",
    query: query.transform_keys(organizer_user_id: "organizerUserId"),
    page: HubSpotSDK::Internal::Page,
    model: HubSpotSDK::Scheduler::ExternalLinkMetadata,
    options: options
  )
end