Class: HubSpotSDK::Models::Account::APIUsage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Account::APIUsage
- Defined in:
- lib/hubspot_sdk/models/account/api_usage.rb
Defined Under Namespace
Modules: FetchStatus
Instance Attribute Summary collapse
-
#collected_at ⇒ Time
Indicates when the cache was last updated.
-
#current_usage ⇒ Integer
How many API calls an account has made for the current day.
-
#fetch_status ⇒ Symbol, HubSpotSDK::Models::Account::APIUsage::FetchStatus
Status of fetching the information, including if the data came from the cache.
-
#name ⇒ String
Name of the limit type.
-
#resets_at ⇒ Time?
Time that the limit will reset.
-
#usage_limit ⇒ Integer
Limits by which a single integration can consume the HubSpot public APIs.
Instance Method Summary collapse
- #initialize(collected_at:, current_usage:, fetch_status:, name:, usage_limit:, resets_at: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(collected_at:, current_usage:, fetch_status:, name:, usage_limit:, resets_at: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/account/api_usage.rb', line 47
|
Instance Attribute Details
#collected_at ⇒ Time
Indicates when the cache was last updated.
11 |
# File 'lib/hubspot_sdk/models/account/api_usage.rb', line 11 required :collected_at, Time, api_name: :collectedAt |
#current_usage ⇒ Integer
How many API calls an account has made for the current day.
17 |
# File 'lib/hubspot_sdk/models/account/api_usage.rb', line 17 required :current_usage, Integer, api_name: :currentUsage |
#fetch_status ⇒ Symbol, HubSpotSDK::Models::Account::APIUsage::FetchStatus
Status of fetching the information, including if the data came from the cache.
23 24 25 26 27 |
# File 'lib/hubspot_sdk/models/account/api_usage.rb', line 23 required :fetch_status, enum: -> { HubSpotSDK::Account::APIUsage::FetchStatus }, api_name: :fetchStatus |
#name ⇒ String
Name of the limit type.
33 |
# File 'lib/hubspot_sdk/models/account/api_usage.rb', line 33 required :name, String |
#resets_at ⇒ Time?
Time that the limit will reset.
45 |
# File 'lib/hubspot_sdk/models/account/api_usage.rb', line 45 optional :resets_at, Time, api_name: :resetsAt |
#usage_limit ⇒ Integer
Limits by which a single integration can consume the HubSpot public APIs.
39 |
# File 'lib/hubspot_sdk/models/account/api_usage.rb', line 39 required :usage_limit, Integer, api_name: :usageLimit |