Class: HubSpotSDK::Models::Account::ActivityListAuditLogsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Account::ActivityListAuditLogsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb
Overview
Instance Attribute Summary collapse
- #acting_user_id ⇒ Array<Integer>?
-
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
- #fill_final_timestamp ⇒ Boolean?
-
#limit ⇒ Integer?
The maximum number of results to display per page.
- #occurred_after ⇒ Time?
- #occurred_before ⇒ Time?
- #sort ⇒ Array<String>?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(acting_user_id: nil, after: nil, fill_final_timestamp: nil, limit: nil, occurred_after: nil, occurred_before: nil, sort: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActivityListAuditLogsParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(acting_user_id: nil, after: nil, fill_final_timestamp: nil, limit: nil, occurred_after: nil, occurred_before: nil, sort: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Account::ActivityListAuditLogsParams for more details.
|
|
# File 'lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb', line 50
|
Instance Attribute Details
#acting_user_id ⇒ Array<Integer>?
14 |
# File 'lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb', line 14 optional :acting_user_id, HubSpotSDK::Internal::Type::ArrayOf[Integer] |
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
22 |
# File 'lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb', line 22 optional :after, String |
#fill_final_timestamp ⇒ Boolean?
27 |
# File 'lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb', line 27 optional :fill_final_timestamp, HubSpotSDK::Internal::Type::Boolean |
#limit ⇒ Integer?
The maximum number of results to display per page.
33 |
# File 'lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb', line 33 optional :limit, Integer |
#occurred_after ⇒ Time?
38 |
# File 'lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb', line 38 optional :occurred_after, Time |
#occurred_before ⇒ Time?
43 |
# File 'lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb', line 43 optional :occurred_before, Time |
#sort ⇒ Array<String>?
48 |
# File 'lib/hubspot_sdk/models/account/activity_list_audit_logs_params.rb', line 48 optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String] |