Class: HubSpotSDK::Models::Account::HydratedCriticalAction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Account::HydratedCriticalAction
- Defined in:
- lib/hubspot_sdk/models/account/hydrated_critical_action.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#acting_user ⇒ String?
Email address of the user associated with the activity.
-
#country_code ⇒ String?
The approximate country code.
-
#created_at ⇒ Time
The time the activity took place.
-
#id ⇒ String
The activity’s unique ID.
-
#info_url ⇒ String?
A link to the URL where the action was taken in the account.
-
#ip_address ⇒ String?
IP address where the activity originated.
-
#location ⇒ String?
The approximate location where the activity took place.
-
#object_id_ ⇒ String?
The ID of the affected object.
-
#region_code ⇒ String?
The approximate region code.
-
#type ⇒ Symbol, HubSpotSDK::Models::Account::HydratedCriticalAction::Type
The type of activity.
-
#user_id ⇒ Integer
The user’s unique ID.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, type:, user_id:, acting_user: nil, country_code: nil, info_url: nil, ip_address: nil, location: nil, object_id_: nil, region_code: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 74
|
Instance Attribute Details
#acting_user ⇒ String?
Email address of the user associated with the activity.
36 |
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 36 optional :acting_user, String, api_name: :actingUser |
#country_code ⇒ String?
The approximate country code
42 |
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 42 optional :country_code, String, api_name: :countryCode |
#created_at ⇒ Time
The time the activity took place.
18 |
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 18 required :created_at, Time, api_name: :createdAt |
#id ⇒ String
The activity’s unique ID.
12 |
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 12 required :id, String |
#info_url ⇒ String?
A link to the URL where the action was taken in the account.
48 |
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 48 optional :info_url, String, api_name: :infoUrl |
#ip_address ⇒ String?
IP address where the activity originated.
54 |
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 54 optional :ip_address, String, api_name: :ipAddress |
#location ⇒ String?
The approximate location where the activity took place.
60 |
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 60 optional :location, String |
#object_id_ ⇒ String?
The ID of the affected object.
66 |
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 66 optional :object_id_, String, api_name: :objectId |
#region_code ⇒ String?
The approximate region code
72 |
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 72 optional :region_code, String, api_name: :regionCode |
#type ⇒ Symbol, HubSpotSDK::Models::Account::HydratedCriticalAction::Type
The type of activity.
24 |
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 24 required :type, enum: -> { HubSpotSDK::Account::HydratedCriticalAction::Type } |
#user_id ⇒ Integer
The user’s unique ID.
30 |
# File 'lib/hubspot_sdk/models/account/hydrated_critical_action.rb', line 30 required :user_id, Integer, api_name: :userId |