Class: HubSpotSDK::Models::ActionResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::ActionResponse
- Defined in:
- lib/hubspot_sdk/models/action_response.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The timestamp indicating when the action was completed.
-
#links ⇒ Hash{Symbol=>String}?
A map of link names to associated URIs containing documentation about the error or recommended remediation steps.
-
#requested_at ⇒ Time?
The timestamp indicating when the action was requested.
-
#started_at ⇒ Time
The timestamp indicating when the action was started.
-
#status ⇒ Symbol, HubSpotSDK::Models::ActionResponse::Status
The current status of the action, with possible values: CANCELED, COMPLETE, PENDING, PROCESSING.
Instance Method Summary collapse
-
#initialize(completed_at:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(completed_at:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::ActionResponse for more details.
|
|
# File 'lib/hubspot_sdk/models/action_response.rb', line 38
|
Instance Attribute Details
#completed_at ⇒ Time
The timestamp indicating when the action was completed.
10 |
# File 'lib/hubspot_sdk/models/action_response.rb', line 10 required :completed_at, Time, api_name: :completedAt |
#links ⇒ Hash{Symbol=>String}?
A map of link names to associated URIs containing documentation about the error or recommended remediation steps
30 |
# File 'lib/hubspot_sdk/models/action_response.rb', line 30 optional :links, HubSpotSDK::Internal::Type::HashOf[String] |
#requested_at ⇒ Time?
The timestamp indicating when the action was requested.
36 |
# File 'lib/hubspot_sdk/models/action_response.rb', line 36 optional :requested_at, Time, api_name: :requestedAt |
#started_at ⇒ Time
The timestamp indicating when the action was started.
16 |
# File 'lib/hubspot_sdk/models/action_response.rb', line 16 required :started_at, Time, api_name: :startedAt |
#status ⇒ Symbol, HubSpotSDK::Models::ActionResponse::Status
The current status of the action, with possible values: CANCELED, COMPLETE, PENDING, PROCESSING.
23 |
# File 'lib/hubspot_sdk/models/action_response.rb', line 23 required :status, enum: -> { HubSpotSDK::ActionResponse::Status } |