Class: HubSpotSDK::Models::AssociationDefinition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::AssociationDefinition
- Defined in:
- lib/hubspot_sdk/models/association_definition.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
The timestamp when the association was created, in ISO 8601 format.
-
#from_object_type_id ⇒ String
The ID of the source object type (e.g., 0-1 for contacts).
-
#id ⇒ String
The unique ID of the associated object (e.g., a contact ID).
-
#name ⇒ String?
For labeled association types, the internal name of the association.
-
#to_object_type_id ⇒ String
The ID of the destination object type (e.g., 0-3 for deals).
-
#updated_at ⇒ Time?
The timestamp when the last update was made to an association, in ISO 8601 format.
Instance Method Summary collapse
-
#initialize(id:, from_object_type_id:, to_object_type_id:, created_at: nil, name: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see AssociationDefinition for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, from_object_type_id:, to_object_type_id:, created_at: nil, name: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::AssociationDefinition for more details.
The definition of an association
|
|
# File 'lib/hubspot_sdk/models/association_definition.rb', line 43
|
Instance Attribute Details
#created_at ⇒ Time?
The timestamp when the association was created, in ISO 8601 format.
28 |
# File 'lib/hubspot_sdk/models/association_definition.rb', line 28 optional :created_at, Time, api_name: :createdAt |
#from_object_type_id ⇒ String
The ID of the source object type (e.g., 0-1 for contacts).
16 |
# File 'lib/hubspot_sdk/models/association_definition.rb', line 16 required :from_object_type_id, String, api_name: :fromObjectTypeId |
#id ⇒ String
The unique ID of the associated object (e.g., a contact ID).
10 |
# File 'lib/hubspot_sdk/models/association_definition.rb', line 10 required :id, String |
#name ⇒ String?
For labeled association types, the internal name of the association.
34 |
# File 'lib/hubspot_sdk/models/association_definition.rb', line 34 optional :name, String |
#to_object_type_id ⇒ String
The ID of the destination object type (e.g., 0-3 for deals).
22 |
# File 'lib/hubspot_sdk/models/association_definition.rb', line 22 required :to_object_type_id, String, api_name: :toObjectTypeId |
#updated_at ⇒ Time?
The timestamp when the last update was made to an association, in ISO 8601 format.
41 |
# File 'lib/hubspot_sdk/models/association_definition.rb', line 41 optional :updated_at, Time, api_name: :updatedAt |