Class: HubSpotSDK::Models::Automation::CallbackCompletionBatchRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::CallbackCompletionBatchRequest
- Defined in:
- lib/hubspot_sdk/models/automation/callback_completion_batch_request.rb
Defined Under Namespace
Modules: RequestContext
Instance Attribute Summary collapse
-
#callback_id ⇒ String
The unique identifier for the callback.
-
#failure_reason_type ⇒ String?
Specifies the type of failure reason for the callback completion.
-
#output_fields ⇒ Hash{Symbol=>String}
Holds the output fields for the callback completion.
-
#request_context ⇒ HubSpotSDK::Models::Automation::WorkflowsRequestContext, ...
Defines the context of the request, which can be one of several predefined types.
-
#typed_outputs ⇒ Object
Contains the typed outputs for the callback completion.
Instance Method Summary collapse
-
#initialize(callback_id:, output_fields:, typed_outputs:, failure_reason_type: nil, request_context: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CallbackCompletionBatchRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(callback_id:, output_fields:, typed_outputs:, failure_reason_type: nil, request_context: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Automation::CallbackCompletionBatchRequest for more details.
|
|
# File 'lib/hubspot_sdk/models/automation/callback_completion_batch_request.rb', line 40
|
Instance Attribute Details
#callback_id ⇒ String
The unique identifier for the callback.
11 |
# File 'lib/hubspot_sdk/models/automation/callback_completion_batch_request.rb', line 11 required :callback_id, String, api_name: :callbackId |
#failure_reason_type ⇒ String?
Specifies the type of failure reason for the callback completion.
29 |
# File 'lib/hubspot_sdk/models/automation/callback_completion_batch_request.rb', line 29 optional :failure_reason_type, String, api_name: :failureReasonType |
#output_fields ⇒ Hash{Symbol=>String}
Holds the output fields for the callback completion.
17 |
# File 'lib/hubspot_sdk/models/automation/callback_completion_batch_request.rb', line 17 required :output_fields, HubSpotSDK::Internal::Type::HashOf[String], api_name: :outputFields |
#request_context ⇒ HubSpotSDK::Models::Automation::WorkflowsRequestContext, ...
Defines the context of the request, which can be one of several predefined types.
36 37 38 |
# File 'lib/hubspot_sdk/models/automation/callback_completion_batch_request.rb', line 36 optional :request_context, union: -> { HubSpotSDK::Automation::CallbackCompletionBatchRequest::RequestContext }, api_name: :requestContext |
#typed_outputs ⇒ Object
Contains the typed outputs for the callback completion.
23 |
# File 'lib/hubspot_sdk/models/automation/callback_completion_batch_request.rb', line 23 required :typed_outputs, HubSpotSDK::Internal::Type::Unknown, api_name: :typedOutputs |