Class: HubSpotSDK::Models::Automation::ChirpAIContextObject
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::ChirpAIContextObject
- Defined in:
- lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb
Defined Under Namespace
Modules: UnstructuredSource
Instance Attribute Summary collapse
-
#application_group ⇒ String
The group to which the application belongs.
-
#application_id ⇒ String
The identifier for the application associated with the context.
- #compliance_ids ⇒ HubSpotSDK::Models::Automation::ComplianceIDs?
-
#feature_id ⇒ String?
The identifier for the feature associated with the context.
-
#inference_id ⇒ String?
The identifier for the inference associated with the context.
-
#metadata ⇒ Hash{Symbol=>String}
Additional metadata related to the context, represented as key-value pairs.
-
#otel_context_holder ⇒ Hash{Symbol=>String}
Holds OpenTelemetry context information as key-value pairs.
-
#trajectory_id ⇒ String?
The identifier for the trajectory, formatted as a UUID.
- #unstructured_sources ⇒ Array<Symbol, HubSpotSDK::Models::Automation::ChirpAIContextObject::UnstructuredSource>
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#application_group ⇒ String
The group to which the application belongs.
11 |
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 11 required :application_group, String, api_name: :applicationGroup |
#application_id ⇒ String
The identifier for the application associated with the context.
17 |
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 17 required :application_id, String, api_name: :applicationId |
#compliance_ids ⇒ HubSpotSDK::Models::Automation::ComplianceIDs?
45 |
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 45 optional :compliance_ids, -> { HubSpotSDK::Automation::ComplianceIDs }, api_name: :complianceIds |
#feature_id ⇒ String?
The identifier for the feature associated with the context.
51 |
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 51 optional :feature_id, String, api_name: :featureId |
#inference_id ⇒ String?
The identifier for the inference associated with the context.
57 |
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 57 optional :inference_id, String, api_name: :inferenceId |
#metadata ⇒ Hash{Symbol=>String}
Additional metadata related to the context, represented as key-value pairs.
23 |
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 23 required :metadata, HubSpotSDK::Internal::Type::HashOf[String] |
#otel_context_holder ⇒ Hash{Symbol=>String}
Holds OpenTelemetry context information as key-value pairs.
29 30 31 |
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 29 required :otel_context_holder, HubSpotSDK::Internal::Type::HashOf[String], api_name: :otelContextHolder |
#trajectory_id ⇒ String?
The identifier for the trajectory, formatted as a UUID.
63 |
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 63 optional :trajectory_id, String, api_name: :trajectoryId |
#unstructured_sources ⇒ Array<Symbol, HubSpotSDK::Models::Automation::ChirpAIContextObject::UnstructuredSource>
36 37 38 39 40 |
# File 'lib/hubspot_sdk/models/automation/chirp_ai_context_object.rb', line 36 required :unstructured_sources, -> { HubSpotSDK::Internal::Type::ArrayOf[enum: HubSpotSDK::Automation::ChirpAIContextObject::UnstructuredSource] }, api_name: :unstructuredSources |