Class: HubSpotSDK::Models::Automation::CollectionResponseWithTotalPublicSequenceLiteResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::CollectionResponseWithTotalPublicSequenceLiteResponse
- Defined in:
- lib/hubspot_sdk/models/automation/collection_response_with_total_public_sequence_lite_response.rb
Instance Attribute Summary collapse
- #paging ⇒ HubSpotSDK::Models::Paging?
-
#results ⇒ Array<HubSpotSDK::Models::Automation::PublicSequenceLiteResponse>
An array of PublicSequenceLiteResponse objects, each representing a lightweight version of a sequence.
-
#total ⇒ Integer
An integer representing the total number of sequence items available.
Instance Method Summary collapse
-
#initialize(results:, total:, paging: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CollectionResponseWithTotalPublicSequenceLiteResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(results:, total:, paging: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Automation::CollectionResponseWithTotalPublicSequenceLiteResponse for more details.
|
|
# File 'lib/hubspot_sdk/models/automation/collection_response_with_total_public_sequence_lite_response.rb', line 26
|
Instance Attribute Details
#paging ⇒ HubSpotSDK::Models::Paging?
24 |
# File 'lib/hubspot_sdk/models/automation/collection_response_with_total_public_sequence_lite_response.rb', line 24 optional :paging, -> { HubSpotSDK::Paging } |
#results ⇒ Array<HubSpotSDK::Models::Automation::PublicSequenceLiteResponse>
An array of PublicSequenceLiteResponse objects, each representing a lightweight version of a sequence.
12 13 |
# File 'lib/hubspot_sdk/models/automation/collection_response_with_total_public_sequence_lite_response.rb', line 12 required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Automation::PublicSequenceLiteResponse] } |
#total ⇒ Integer
An integer representing the total number of sequence items available.
19 |
# File 'lib/hubspot_sdk/models/automation/collection_response_with_total_public_sequence_lite_response.rb', line 19 required :total, Integer |