Class: HubSpotSDK::Models::Automation::FieldTypeDefinition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::FieldTypeDefinition
- Defined in:
- lib/hubspot_sdk/models/automation/field_type_definition.rb
Defined Under Namespace
Modules: FieldType, ReferencedObjectType, Schema, Type
Instance Attribute Summary collapse
-
#description ⇒ String?
A detailed explanation of the field’s purpose and usage.
-
#external_options ⇒ Boolean
Indicates whether the field’s options are sourced externally.
-
#external_options_reference_type ⇒ String?
Specifies the type of external reference for options.
-
#field_type ⇒ Symbol, ...
Describes the field’s type in the UI, with accepted values like booleancheckbox, calculation_equation, checkbox, date, file, html, number, phonenumber, radio, select, text, textarea, unknown.
-
#help_text ⇒ String?
Additional information or guidance about the field.
-
#label ⇒ String?
The user-friendly label for the field.
-
#name ⇒ String
The unique identifier for the field.
- #options ⇒ Array<HubSpotSDK::Models::AutomationActionsOption>
-
#options_url ⇒ String?
A URL that provides options for the field.
-
#referenced_object_type ⇒ Symbol, ...
Indicates the type of object that the field references, with accepted values like OWNER.
-
#schema ⇒ HubSpotSDK::Models::Automation::IntegerFieldSchema, ...
Defines the structure and constraints of the field.
-
#type ⇒ Symbol, HubSpotSDK::Models::Automation::FieldTypeDefinition::Type
Specifies the data type of the field, with accepted values like bool, date, datetime, enumeration, json, number, object_coordinates, phone_number, string.
-
#use_chirp ⇒ Boolean
Specifies whether the field uses the Chirp feature.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(HubSpotSDK::Models::Automation::IntegerFieldSchema, HubSpotSDK::Models::Automation::LongFieldSchema, HubSpotSDK::Models::Automation::DoubleFieldSchema, HubSpotSDK::Models::Automation::StringFieldSchema, HubSpotSDK::Models::Automation::BooleanFieldSchema, HubSpotSDK::Models::Automation::ArrayFieldSchema, HubSpotSDK::Models::Automation::ObjectFieldSchema)
Instance Method Summary collapse
-
#initialize(external_options:, name:, options:, schema:, type:, use_chirp:, description: nil, external_options_reference_type: nil, field_type: nil, help_text: nil, label: nil, options_url: nil, referenced_object_type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see FieldTypeDefinition for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(external_options:, name:, options:, schema:, type:, use_chirp:, description: nil, external_options_reference_type: nil, field_type: nil, help_text: nil, label: nil, options_url: nil, referenced_object_type: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Automation::FieldTypeDefinition for more details.
|
|
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 92
|
Instance Attribute Details
#description ⇒ String?
A detailed explanation of the field’s purpose and usage.
47 |
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 47 optional :description, String |
#external_options ⇒ Boolean
Indicates whether the field’s options are sourced externally.
11 |
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 11 required :external_options, HubSpotSDK::Internal::Type::Boolean, api_name: :externalOptions |
#external_options_reference_type ⇒ String?
Specifies the type of external reference for options.
53 |
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 53 optional :external_options_reference_type, String, api_name: :externalOptionsReferenceType |
#field_type ⇒ Symbol, ...
Describes the field’s type in the UI, with accepted values like booleancheckbox, calculation_equation, checkbox, date, file, html, number, phonenumber, radio, select, text, textarea, unknown.
61 62 63 |
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 61 optional :field_type, enum: -> { HubSpotSDK::Automation::FieldTypeDefinition::FieldType }, api_name: :fieldType |
#help_text ⇒ String?
Additional information or guidance about the field.
69 |
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 69 optional :help_text, String, api_name: :helpText |
#label ⇒ String?
The user-friendly label for the field.
75 |
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 75 optional :label, String |
#name ⇒ String
The unique identifier for the field.
17 |
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 17 required :name, String |
#options ⇒ Array<HubSpotSDK::Models::AutomationActionsOption>
22 |
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 22 required :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::AutomationActionsOption] } |
#options_url ⇒ String?
A URL that provides options for the field.
81 |
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 81 optional :options_url, String, api_name: :optionsUrl |
#referenced_object_type ⇒ Symbol, ...
Indicates the type of object that the field references, with accepted values like OWNER.
88 89 90 |
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 88 optional :referenced_object_type, enum: -> { HubSpotSDK::Automation::FieldTypeDefinition::ReferencedObjectType }, api_name: :referencedObjectType |
#schema ⇒ HubSpotSDK::Models::Automation::IntegerFieldSchema, ...
Defines the structure and constraints of the field.
28 |
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 28 required :schema, union: -> { HubSpotSDK::Automation::FieldTypeDefinition::Schema } |
#type ⇒ Symbol, HubSpotSDK::Models::Automation::FieldTypeDefinition::Type
Specifies the data type of the field, with accepted values like bool, date, datetime, enumeration, json, number, object_coordinates, phone_number, string.
35 |
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 35 required :type, enum: -> { HubSpotSDK::Automation::FieldTypeDefinition::Type } |
#use_chirp ⇒ Boolean
Specifies whether the field uses the Chirp feature.
41 |
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 41 required :use_chirp, HubSpotSDK::Internal::Type::Boolean, api_name: :useChirp |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 164
|
.variants ⇒ Array(HubSpotSDK::Models::Automation::IntegerFieldSchema, HubSpotSDK::Models::Automation::LongFieldSchema, HubSpotSDK::Models::Automation::DoubleFieldSchema, HubSpotSDK::Models::Automation::StringFieldSchema, HubSpotSDK::Models::Automation::BooleanFieldSchema, HubSpotSDK::Models::Automation::ArrayFieldSchema, HubSpotSDK::Models::Automation::ObjectFieldSchema)
|
|
# File 'lib/hubspot_sdk/models/automation/field_type_definition.rb', line 142
|