Class: HubSpotSDK::Models::Automation::PublicActionLabels
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::PublicActionLabels
- Defined in:
- lib/hubspot_sdk/models/automation/public_action_labels.rb
Instance Attribute Summary collapse
-
#action_card_content ⇒ String?
Content displayed on the action card.
-
#action_description ⇒ String?
A description of what the action does.
-
#action_name ⇒ String
The name of the action.
-
#app_display_name ⇒ String?
The display name of the application associated with the action.
-
#execution_rules ⇒ Hash{Symbol=>String}?
Rules that govern the execution of the action.
-
#input_field_descriptions ⇒ Hash{Symbol=>String}?
Descriptions for each input field.
-
#input_field_labels ⇒ Hash{Symbol=>String}?
Labels for the input fields.
-
#input_field_option_labels ⇒ Hash{Symbol=>Hash{Symbol=>String}}?
Labels for the options available in input fields.
-
#output_field_labels ⇒ Hash{Symbol=>String}?
Labels for the output fields.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(action_name:, action_card_content: nil, action_description: nil, app_display_name: nil, execution_rules: nil, input_field_descriptions: nil, input_field_labels: nil, input_field_option_labels: nil, output_field_labels: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/automation/public_action_labels.rb', line 67
|
Instance Attribute Details
#action_card_content ⇒ String?
Content displayed on the action card.
17 |
# File 'lib/hubspot_sdk/models/automation/public_action_labels.rb', line 17 optional :action_card_content, String, api_name: :actionCardContent |
#action_description ⇒ String?
A description of what the action does.
23 |
# File 'lib/hubspot_sdk/models/automation/public_action_labels.rb', line 23 optional :action_description, String, api_name: :actionDescription |
#action_name ⇒ String
The name of the action.
11 |
# File 'lib/hubspot_sdk/models/automation/public_action_labels.rb', line 11 required :action_name, String, api_name: :actionName |
#app_display_name ⇒ String?
The display name of the application associated with the action.
29 |
# File 'lib/hubspot_sdk/models/automation/public_action_labels.rb', line 29 optional :app_display_name, String, api_name: :appDisplayName |
#execution_rules ⇒ Hash{Symbol=>String}?
Rules that govern the execution of the action.
35 |
# File 'lib/hubspot_sdk/models/automation/public_action_labels.rb', line 35 optional :execution_rules, HubSpotSDK::Internal::Type::HashOf[String], api_name: :executionRules |
#input_field_descriptions ⇒ Hash{Symbol=>String}?
Descriptions for each input field.
41 42 43 |
# File 'lib/hubspot_sdk/models/automation/public_action_labels.rb', line 41 optional :input_field_descriptions, HubSpotSDK::Internal::Type::HashOf[String], api_name: :inputFieldDescriptions |
#input_field_labels ⇒ Hash{Symbol=>String}?
Labels for the input fields.
49 |
# File 'lib/hubspot_sdk/models/automation/public_action_labels.rb', line 49 optional :input_field_labels, HubSpotSDK::Internal::Type::HashOf[String], api_name: :inputFieldLabels |
#input_field_option_labels ⇒ Hash{Symbol=>Hash{Symbol=>String}}?
Labels for the options available in input fields.
55 56 57 |
# File 'lib/hubspot_sdk/models/automation/public_action_labels.rb', line 55 optional :input_field_option_labels, HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::HashOf[String]], api_name: :inputFieldOptionLabels |
#output_field_labels ⇒ Hash{Symbol=>String}?
Labels for the output fields.
63 64 65 |
# File 'lib/hubspot_sdk/models/automation/public_action_labels.rb', line 63 optional :output_field_labels, HubSpotSDK::Internal::Type::HashOf[String], api_name: :outputFieldLabels |