Class: HubSpotSDK::Models::Automation::PublicExecutionTranslationRule
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::PublicExecutionTranslationRule
- Defined in:
- lib/hubspot_sdk/models/automation/public_execution_translation_rule.rb
Instance Attribute Summary collapse
-
#conditions ⇒ Hash{Symbol=>Object}
Defines the conditions that must be met for the execution rule to apply.
-
#label_name ⇒ String
Specifies the name of the label associated with the execution rule.
Instance Method Summary collapse
- #initialize(conditions:, label_name:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(conditions:, label_name:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/automation/public_execution_translation_rule.rb', line 19
|
Instance Attribute Details
#conditions ⇒ Hash{Symbol=>Object}
Defines the conditions that must be met for the execution rule to apply.
11 |
# File 'lib/hubspot_sdk/models/automation/public_execution_translation_rule.rb', line 11 required :conditions, HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown] |
#label_name ⇒ String
Specifies the name of the label associated with the execution rule.
17 |
# File 'lib/hubspot_sdk/models/automation/public_execution_translation_rule.rb', line 17 required :label_name, String, api_name: :labelName |