Module: HubSpotSDK::Models::Automation::PublicFieldTypeDefinition::Type
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/hubspot_sdk/models/automation/public_field_type_definition.rb
Overview
The data type of the field, with accepted values including bool, date, datetime, enumeration, json, number, object_coordinates, phone_number, and string.
Constant Summary collapse
- BOOL =
:bool- DATE =
:date- DATETIME =
:datetime- ENUMERATION =
:enumeration- JSON =
:json- NUMBER =
:number- OBJECT_COORDINATES =
:object_coordinates- PHONE_NUMBER =
:phone_number- STRING =
:string
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info