Class: HubSpotSDK::Models::Automation::PublicSequenceEnrollmentRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Automation::PublicSequenceEnrollmentRequest
- Defined in:
- lib/hubspot_sdk/models/automation/public_sequence_enrollment_request.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#contact_id ⇒ String
The unique identifier of the contact to be enrolled in the sequence.
-
#sender_alias_address ⇒ String?
The alias email address used by the sender when enrolling the contact.
-
#sender_email ⇒ String
The email address of the sender enrolling the contact in the sequence.
-
#sequence_id ⇒ String
The unique identifier of the sequence in which the contact will be enrolled.
Instance Method Summary collapse
- #initialize(contact_id:, sender_email:, sequence_id:, sender_alias_address: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(contact_id:, sender_email:, sequence_id:, sender_alias_address: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/automation/public_sequence_enrollment_request.rb', line 31
|
Instance Attribute Details
#contact_id ⇒ String
The unique identifier of the contact to be enrolled in the sequence.
11 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_enrollment_request.rb', line 11 required :contact_id, String, api_name: :contactId |
#sender_alias_address ⇒ String?
The alias email address used by the sender when enrolling the contact.
29 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_enrollment_request.rb', line 29 optional :sender_alias_address, String, api_name: :senderAliasAddress |
#sender_email ⇒ String
The email address of the sender enrolling the contact in the sequence.
17 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_enrollment_request.rb', line 17 required :sender_email, String, api_name: :senderEmail |
#sequence_id ⇒ String
The unique identifier of the sequence in which the contact will be enrolled.
23 |
# File 'lib/hubspot_sdk/models/automation/public_sequence_enrollment_request.rb', line 23 required :sequence_id, String, api_name: :sequenceId |