Module: HubSpotSDK::Models::Automation::PublicSequenceSettingsResponse::SellingStrategy
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/hubspot_sdk/models/automation/public_sequence_settings_response.rb
Overview
(deprecated) Defines the unenrollment strategy, with accepted values being ACCOUNT_BASED or LEAD_BASED. If ACCOUNT_BASED is used, all contacts associated with the same company will be unenrolled if one contact meets any of the unenrollment criteria.
Constant Summary collapse
- ACCOUNT_BASED =
:ACCOUNT_BASED- LEAD_BASED =
:LEAD_BASED
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/automation/public_sequence_settings_response.rb', line 121
|