Class: HubSpotSDK::Models::Cms::BatchResponseHubDBTableRowV3
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::BatchResponseHubDBTableRowV3
- Defined in:
- lib/hubspot_sdk/models/cms/batch_response_hub_db_table_row_v3.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The timestamp indicating when the batch processing was completed.
-
#links ⇒ Hash{Symbol=>String}?
A collection of related links associated with the batch response.
-
#requested_at ⇒ Time?
The timestamp indicating when the batch request was made.
- #results ⇒ Array<HubSpotSDK::Models::Cms::HubDBTableRowV3>
-
#started_at ⇒ Time
The timestamp indicating when the batch processing began.
-
#status ⇒ Symbol, HubSpotSDK::Models::Cms::BatchResponseHubDBTableRowV3::Status
The current status of the batch operation, with possible values: CANCELED, COMPLETE, PENDING, PROCESSING.
Instance Method Summary collapse
-
#initialize(completed_at:, results:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BatchResponseHubDBTableRowV3 for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(completed_at:, results:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::BatchResponseHubDBTableRowV3 for more details.
|
|
# File 'lib/hubspot_sdk/models/cms/batch_response_hub_db_table_row_v3.rb', line 43
|
Instance Attribute Details
#completed_at ⇒ Time
The timestamp indicating when the batch processing was completed.
11 |
# File 'lib/hubspot_sdk/models/cms/batch_response_hub_db_table_row_v3.rb', line 11 required :completed_at, Time, api_name: :completedAt |
#links ⇒ Hash{Symbol=>String}?
A collection of related links associated with the batch response.
35 |
# File 'lib/hubspot_sdk/models/cms/batch_response_hub_db_table_row_v3.rb', line 35 optional :links, HubSpotSDK::Internal::Type::HashOf[String] |
#requested_at ⇒ Time?
The timestamp indicating when the batch request was made.
41 |
# File 'lib/hubspot_sdk/models/cms/batch_response_hub_db_table_row_v3.rb', line 41 optional :requested_at, Time, api_name: :requestedAt |
#results ⇒ Array<HubSpotSDK::Models::Cms::HubDBTableRowV3>
16 |
# File 'lib/hubspot_sdk/models/cms/batch_response_hub_db_table_row_v3.rb', line 16 required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Cms::HubDBTableRowV3] } |
#started_at ⇒ Time
The timestamp indicating when the batch processing began.
22 |
# File 'lib/hubspot_sdk/models/cms/batch_response_hub_db_table_row_v3.rb', line 22 required :started_at, Time, api_name: :startedAt |
#status ⇒ Symbol, HubSpotSDK::Models::Cms::BatchResponseHubDBTableRowV3::Status
The current status of the batch operation, with possible values: CANCELED, COMPLETE, PENDING, PROCESSING.
29 |
# File 'lib/hubspot_sdk/models/cms/batch_response_hub_db_table_row_v3.rb', line 29 required :status, enum: -> { HubSpotSDK::Cms::BatchResponseHubDBTableRowV3::Status } |