Class: HubSpotSDK::Models::Cms::Blogs::Blog
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::Blogs::Blog
- Defined in:
- lib/hubspot_sdk/models/cms/blogs/blog.rb
Overview
Defined Under Namespace
Modules: Language
Instance Attribute Summary collapse
-
#absolute_url ⇒ String
Blog’s root URL.
-
#allow_comments ⇒ Boolean
Boolean determining whether or not this blog allows public comments.
-
#created ⇒ Time
The timestamp (ISO8601 format) when this blog was created.
-
#deleted_at ⇒ Time
The timestamp (ISO8601 format) when this Blog was deleted.
-
#description ⇒ String
The Description of this Blog.
-
#html_title ⇒ String
The html title of this Blog.
-
#id ⇒ String
The unique ID of the Blog.
-
#language ⇒ Symbol, HubSpotSDK::Models::Cms::Blogs::Blog::Language
The explicitly defined language of the Blog.
- #listing_page_id ⇒ String
-
#name ⇒ String
The internal name of the blog.
-
#public_access_rules ⇒ Array<Object>
Rules for require member registration to access private content.
-
#public_access_rules_enabled ⇒ Boolean
Boolean to determine whether or not to respect publicAccessRules.
-
#public_title ⇒ String
The public title of this Blog.
-
#slug ⇒ String
The path of the this blog.
-
#translated_from_id ⇒ String
ID of the primary Blog this object was translated from.
-
#updated ⇒ Time
The timestamp (ISO8601 format) when this blog was updated.
Instance Method Summary collapse
-
#initialize(id:, absolute_url:, allow_comments:, created:, deleted_at:, description:, html_title:, language:, listing_page_id:, name:, public_access_rules:, public_access_rules_enabled:, public_title:, slug:, translated_from_id:, updated:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Blog for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, absolute_url:, allow_comments:, created:, deleted_at:, description:, html_title:, language:, listing_page_id:, name:, public_access_rules:, public_access_rules_enabled:, public_title:, slug:, translated_from_id:, updated:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::Blogs::Blog for more details.
|
|
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 110
|
Instance Attribute Details
#absolute_url ⇒ String
Blog’s root URL
19 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 19 required :absolute_url, String, api_name: :absoluteUrl |
#allow_comments ⇒ Boolean
Boolean determining whether or not this blog allows public comments.
25 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 25 required :allow_comments, HubSpotSDK::Internal::Type::Boolean, api_name: :allowComments |
#created ⇒ Time
The timestamp (ISO8601 format) when this blog was created.
31 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 31 required :created, Time |
#deleted_at ⇒ Time
The timestamp (ISO8601 format) when this Blog was deleted.
37 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 37 required :deleted_at, Time, api_name: :deletedAt |
#description ⇒ String
The Description of this Blog.
43 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 43 required :description, String |
#html_title ⇒ String
The html title of this Blog.
49 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 49 required :html_title, String, api_name: :htmlTitle |
#id ⇒ String
The unique ID of the Blog.
13 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 13 required :id, String |
#language ⇒ Symbol, HubSpotSDK::Models::Cms::Blogs::Blog::Language
The explicitly defined language of the Blog. If null, the Blog will default to the language of the Domain.
56 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 56 required :language, enum: -> { HubSpotSDK::Cms::Blogs::Blog::Language } |
#listing_page_id ⇒ String
61 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 61 required :listing_page_id, String, api_name: :listingPageId |
#name ⇒ String
The internal name of the blog.
67 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 67 required :name, String |
#public_access_rules ⇒ Array<Object>
Rules for require member registration to access private content.
73 74 75 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 73 required :public_access_rules, HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Internal::Type::Unknown], api_name: :publicAccessRules |
#public_access_rules_enabled ⇒ Boolean
Boolean to determine whether or not to respect publicAccessRules.
81 82 83 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 81 required :public_access_rules_enabled, HubSpotSDK::Internal::Type::Boolean, api_name: :publicAccessRulesEnabled |
#public_title ⇒ String
The public title of this Blog.
89 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 89 required :public_title, String, api_name: :publicTitle |
#slug ⇒ String
The path of the this blog. This field is appended to the domain to construct the url of this blog.
96 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 96 required :slug, String |
#translated_from_id ⇒ String
ID of the primary Blog this object was translated from.
102 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 102 required :translated_from_id, String, api_name: :translatedFromId |
#updated ⇒ Time
The timestamp (ISO8601 format) when this blog was updated.
108 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog.rb', line 108 required :updated, Time |