Class: HubSpotSDK::Models::Cms::Blogs::BlogAuthor
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::Blogs::BlogAuthor
- Defined in:
- lib/hubspot_sdk/models/cms/blogs/blog_author.rb
Direct Known Subclasses
Defined Under Namespace
Modules: Language
Instance Attribute Summary collapse
-
#avatar ⇒ String
URL to the blog author’s avatar, if supplying a custom one.
-
#bio ⇒ String
A short biography of the blog author.
-
#created ⇒ Time
The timestamp (ISO8601 format) when this Blog Author was created.
-
#deleted_at ⇒ Time
The timestamp (ISO8601 format) when this Blog Author was deleted.
-
#display_name ⇒ String
The full name of the Blog Author to be displayed.
-
#email ⇒ String
Email address of the Blog Author.
-
#facebook ⇒ String
URL to the Blog Author’s Facebook page.
-
#full_name ⇒ String
The full, unabbreviated name of the blog author, typically their first and last name combined.
-
#id ⇒ String
The unique ID of the Blog Author.
-
#language ⇒ Symbol, HubSpotSDK::Models::Cms::Blogs::BlogAuthor::Language
The explicitly defined ISO 639 language code of the blog author.
-
#linkedin ⇒ String
URL to the blog author’s LinkedIn page.
-
#name ⇒ String
The name field for the blog author.
-
#slug ⇒ String
A URL-friendly identifier for the blog author that can be used to reference the author in URLs.
-
#translated_from_id ⇒ Integer
ID of the primary blog author this object was translated from.
-
#twitter ⇒ String
URL or username of the Twitter account associated with the Blog Author.
-
#updated ⇒ Time
The timestamp (ISO8601 format) when this Blog Author was updated.
-
#website ⇒ String
URL to the website of the Blog Author.
Instance Method Summary collapse
-
#initialize(id:, avatar:, bio:, created:, deleted_at:, display_name:, email:, facebook:, full_name:, language:, linkedin:, name:, slug:, translated_from_id:, twitter:, updated:, website:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BlogAuthor for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, avatar:, bio:, created:, deleted_at:, display_name:, email:, facebook:, full_name:, language:, linkedin:, name:, slug:, translated_from_id:, twitter:, updated:, website:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::Blogs::BlogAuthor for more details.
|
|
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 115
|
Instance Attribute Details
#avatar ⇒ String
URL to the blog author’s avatar, if supplying a custom one.
18 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 18 required :avatar, String |
#bio ⇒ String
A short biography of the blog author.
24 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 24 required :bio, String |
#created ⇒ Time
The timestamp (ISO8601 format) when this Blog Author was created.
30 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 30 required :created, Time |
#deleted_at ⇒ Time
The timestamp (ISO8601 format) when this Blog Author was deleted.
36 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 36 required :deleted_at, Time, api_name: :deletedAt |
#display_name ⇒ String
The full name of the Blog Author to be displayed.
42 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 42 required :display_name, String, api_name: :displayName |
#email ⇒ String
Email address of the Blog Author.
48 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 48 required :email, String |
#facebook ⇒ String
URL to the Blog Author’s Facebook page.
54 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 54 required :facebook, String |
#full_name ⇒ String
The full, unabbreviated name of the blog author, typically their first and last name combined.
61 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 61 required :full_name, String, api_name: :fullName |
#id ⇒ String
The unique ID of the Blog Author.
12 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 12 required :id, String |
#language ⇒ Symbol, HubSpotSDK::Models::Cms::Blogs::BlogAuthor::Language
The explicitly defined ISO 639 language code of the blog author.
67 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 67 required :language, enum: -> { HubSpotSDK::Cms::Blogs::BlogAuthor::Language } |
#linkedin ⇒ String
URL to the blog author’s LinkedIn page.
73 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 73 required :linkedin, String |
#name ⇒ String
The name field for the blog author. (This appears to be a shorter or alternative name field compared to fullName.)
80 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 80 required :name, String |
#slug ⇒ String
A URL-friendly identifier for the blog author that can be used to reference the author in URLs. Typically generated from the author’s name and contains lowercase letters, hyphens, and underscores.
88 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 88 required :slug, String |
#translated_from_id ⇒ Integer
ID of the primary blog author this object was translated from.
94 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 94 required :translated_from_id, Integer, api_name: :translatedFromId |
#twitter ⇒ String
URL or username of the Twitter account associated with the Blog Author. This will be normalized into the Twitter url for said user.
101 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 101 required :twitter, String |
#updated ⇒ Time
The timestamp (ISO8601 format) when this Blog Author was updated.
107 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 107 required :updated, Time |
#website ⇒ String
URL to the website of the Blog Author.
113 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_author.rb', line 113 required :website, String |