Class: HubSpotSDK::Models::Cms::Blogs::BlogPost
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::Blogs::BlogPost
- Defined in:
- lib/hubspot_sdk/models/cms/blogs/blog_post.rb
Direct Known Subclasses
Defined Under Namespace
Modules: AbStatus, ContentTypeCategory, CurrentState, Language
Instance Attribute Summary collapse
-
#ab_status ⇒ Symbol, HubSpotSDK::Models::Cms::Blogs::BlogPost::AbStatus
The status of the AB test associated with this blog post, if applicable.
-
#ab_test_id ⇒ String
The ID of the AB test associated with this page, if applicable.
-
#archived_at ⇒ Integer
The timestamp (ISO8601 format) when this Blog Post was deleted.
-
#archived_in_dashboard ⇒ Boolean
If True, the post will not show up in your dashboard, although the post could still be live.
-
#attached_stylesheets ⇒ Array<Hash{Symbol=>Object}>
List of stylesheets to attach to this blog post.
-
#author_name ⇒ String
The name of the user that updated this Blog Post.
-
#blog_author_id ⇒ String
The ID of the Blog Author associated with this Blog Post.
-
#campaign ⇒ String
The GUID of the marketing campaign this Blog Post is a part of.
-
#category_id ⇒ Integer
ID of the type of object this is.
-
#content_group_id ⇒ String
The ID of the parent Blog this Blog Post is associated with.
-
#content_type_category ⇒ Symbol, HubSpotSDK::Models::Cms::Blogs::BlogPost::ContentTypeCategory
An ENUM descibing the type of this object.
-
#created ⇒ Time
The timestamp (ISO8601 format) when this Blog Post was created.
-
#created_by_id ⇒ String
The ID of the user that created this Blog Post.
-
#current_state ⇒ Symbol, HubSpotSDK::Models::Cms::Blogs::BlogPost::CurrentState
A generated ENUM descibing the current state of this Blog Post.
-
#currently_published ⇒ Boolean
Whether the post is published (true or false).
-
#domain ⇒ String
The domain this Blog Post will resolve to.
-
#dynamic_page_data_source_id ⇒ String
The identifier for the data source used by the dynamic page.
-
#dynamic_page_data_source_type ⇒ Integer
The type of data source used by the dynamic page.
-
#dynamic_page_hub_db_table_id ⇒ String
The ID of the HubDB table this Blog Post references, if applicable.
-
#enable_domain_stylesheets ⇒ Boolean
Boolean to determine whether or not the styles from the template should be applied.
-
#enable_google_amp_output_override ⇒ Boolean
Boolean to allow overriding the AMP settings for the blog.
-
#enable_layout_stylesheets ⇒ Boolean
Boolean to determine whether or not the styles from the template should be applied.
-
#featured_image ⇒ String
The featuredImage of this Blog Post.
-
#featured_image_alt_text ⇒ String
Alt Text of the featuredImage.
-
#folder_id ⇒ String
Unique identifier of associated folder.
-
#footer_html ⇒ String
Custom HTML for embed codes, javascript that should be placed before the </body> tag of the page.
-
#head_html ⇒ String
Custom HTML for embed codes, javascript, etc.
-
#html_title ⇒ String
The html title of this Blog Post.
-
#id ⇒ String
The unique ID of the Blog Post.
-
#include_default_custom_css ⇒ Boolean
Boolean to determine whether or not the Primary CSS Files should be applied.
-
#language ⇒ Symbol, HubSpotSDK::Models::Cms::Blogs::BlogPost::Language
The explicitly defined ISO 639 language code of the Blog Post.
-
#layout_sections ⇒ Hash{Symbol=>HubSpotSDK::Models::Cms::LayoutSection}
A structure detailing the layout sections of the blog post.
-
#link_rel_canonical_url ⇒ String
Optional override to set the URL to be used in the rel=canonical link tag on the page.
-
#mab_experiment_id ⇒ String
Unique identifier of the MAB Experiment.
-
#meta_description ⇒ String
A description that goes in <meta> tag on the page.
-
#name ⇒ String
The internal name of the Blog Post.
-
#page_expiry_date ⇒ Integer
The date at which this blog post should expire and begin redirecting to another url or page.
-
#page_expiry_enabled ⇒ Boolean
Boolean describing if the page expiration feature is enabled for this blog post.
-
#page_expiry_redirect_id ⇒ Integer
The ID of another page this blog post’s url should redirect to once this blog post expires.
-
#page_expiry_redirect_url ⇒ String
The URL this blog post’s url should redirect to once it expires.
-
#password ⇒ String
Set this to create a password protected page.
-
#post_body ⇒ String
The HTML of the main post body.
-
#post_summary ⇒ String
The summary of the blog post that will appear on the main listing page.
-
#public_access_rules ⇒ Array<Object>
Rules for require member registration to access private content.
-
#public_access_rules_enabled ⇒ Boolean
Boolean to determine whether or not to respect publicAccessRules.
-
#publish_date ⇒ Time
The date (ISO8601 format) the blog post is to be published at.
-
#publish_immediately ⇒ Boolean
Set this to true if you want to be published immediately when the schedule publish endpoint is called, and to ignore the publish_date setting.
-
#rss_body ⇒ String
The contents of the RSS body for this Blog Post.
-
#rss_summary ⇒ String
The contents of the RSS summary for this Blog Post.
-
#slug ⇒ String
The path of the this blog post.
-
#state ⇒ String
An ENUM descibing the current state of this Blog Post.
-
#tag_ids ⇒ Array<Integer>
List of IDs for the tags associated with this Blog Post.
-
#theme_settings_values ⇒ Hash{Symbol=>Object}
A collection of settings specific to the theme applied to the blog post.
-
#translated_from_id ⇒ String
ID of the primary blog post this object was translated from.
-
#translations ⇒ Hash{Symbol=>HubSpotSDK::Models::Cms::ContentLanguageVariation}
A map of translations for the blog post, each associated with a specific language variation.
-
#updated ⇒ Time
The timestamp (ISO8601 format) when this Blog Post was updated.
-
#updated_by_id ⇒ String
The ID of the user that updated this Blog Post.
-
#url ⇒ String
A generated field representing the URL of this blog post.
-
#use_featured_image ⇒ Boolean
Boolean to determine if this post should use a featuredImage.
-
#widget_containers ⇒ Hash{Symbol=>Object}
A data structure containing the data for all the modules inside the containers for this post.
-
#widgets ⇒ Hash{Symbol=>Object}
A data structure containing the data for all the modules for this page.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, ab_status:, ab_test_id:, archived_at:, archived_in_dashboard:, attached_stylesheets:, author_name:, blog_author_id:, campaign:, category_id:, content_group_id:, content_type_category:, created:, created_by_id:, currently_published:, current_state:, domain:, dynamic_page_data_source_id:, dynamic_page_data_source_type:, dynamic_page_hub_db_table_id:, enable_domain_stylesheets:, enable_google_amp_output_override:, enable_layout_stylesheets:, featured_image:, featured_image_alt_text:, folder_id:, footer_html:, head_html:, html_title:, include_default_custom_css:, language:, layout_sections:, link_rel_canonical_url:, mab_experiment_id:, meta_description:, name:, page_expiry_date:, page_expiry_enabled:, page_expiry_redirect_id:, page_expiry_redirect_url:, password:, post_body:, post_summary:, public_access_rules:, public_access_rules_enabled:, publish_date:, publish_immediately:, rss_body:, rss_summary:, slug:, state:, tag_ids:, theme_settings_values:, translated_from_id:, translations:, updated:, updated_by_id:, url:, use_featured_image:, widget_containers:, widgets:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BlogPost for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, ab_status:, ab_test_id:, archived_at:, archived_in_dashboard:, attached_stylesheets:, author_name:, blog_author_id:, campaign:, category_id:, content_group_id:, content_type_category:, created:, created_by_id:, currently_published:, current_state:, domain:, dynamic_page_data_source_id:, dynamic_page_data_source_type:, dynamic_page_hub_db_table_id:, enable_domain_stylesheets:, enable_google_amp_output_override:, enable_layout_stylesheets:, featured_image:, featured_image_alt_text:, folder_id:, footer_html:, head_html:, html_title:, include_default_custom_css:, language:, layout_sections:, link_rel_canonical_url:, mab_experiment_id:, meta_description:, name:, page_expiry_date:, page_expiry_enabled:, page_expiry_redirect_id:, page_expiry_redirect_url:, password:, post_body:, post_summary:, public_access_rules:, public_access_rules_enabled:, publish_date:, publish_immediately:, rss_body:, rss_summary:, slug:, state:, tag_ids:, theme_settings_values:, translated_from_id:, translations:, updated:, updated_by_id:, url:, use_featured_image:, widget_containers:, widgets:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::Blogs::BlogPost for more details.
|
|
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 420
|
Instance Attribute Details
#ab_status ⇒ Symbol, HubSpotSDK::Models::Cms::Blogs::BlogPost::AbStatus
The status of the AB test associated with this blog post, if applicable
Available options: automated_loser_variant, automated_master, automated_variant, loser_variant, mab_master, mab_variant, master, variant
21 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 21 required :ab_status, enum: -> { HubSpotSDK::Cms::Blogs::BlogPost::AbStatus }, api_name: :abStatus |
#ab_test_id ⇒ String
The ID of the AB test associated with this page, if applicable
27 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 27 required :ab_test_id, String, api_name: :abTestId |
#archived_at ⇒ Integer
The timestamp (ISO8601 format) when this Blog Post was deleted.
33 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 33 required :archived_at, Integer, api_name: :archivedAt |
#archived_in_dashboard ⇒ Boolean
If True, the post will not show up in your dashboard, although the post could still be live.
40 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 40 required :archived_in_dashboard, HubSpotSDK::Internal::Type::Boolean, api_name: :archivedInDashboard |
#attached_stylesheets ⇒ Array<Hash{Symbol=>Object}>
List of stylesheets to attach to this blog post. These stylesheets are attached to just this page. Order of precedence is bottom to top, just like in the HTML.
47 48 49 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 47 required :attached_stylesheets, HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown]], api_name: :attachedStylesheets |
#author_name ⇒ String
The name of the user that updated this Blog Post.
55 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 55 required :author_name, String, api_name: :authorName |
#blog_author_id ⇒ String
The ID of the Blog Author associated with this Blog Post.
61 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 61 required :blog_author_id, String, api_name: :blogAuthorId |
#campaign ⇒ String
The GUID of the marketing campaign this Blog Post is a part of.
67 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 67 required :campaign, String |
#category_id ⇒ Integer
ID of the type of object this is. Should always .
73 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 73 required :category_id, Integer, api_name: :categoryId |
#content_group_id ⇒ String
The ID of the parent Blog this Blog Post is associated with.
79 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 79 required :content_group_id, String, api_name: :contentGroupId |
#content_type_category ⇒ Symbol, HubSpotSDK::Models::Cms::Blogs::BlogPost::ContentTypeCategory
An ENUM descibing the type of this object. Should always be BLOG_POST.
85 86 87 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 85 required :content_type_category, enum: -> { HubSpotSDK::Cms::Blogs::BlogPost::ContentTypeCategory }, api_name: :contentTypeCategory |
#created ⇒ Time
The timestamp (ISO8601 format) when this Blog Post was created.
93 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 93 required :created, Time |
#created_by_id ⇒ String
The ID of the user that created this Blog Post.
99 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 99 required :created_by_id, String, api_name: :createdById |
#current_state ⇒ Symbol, HubSpotSDK::Models::Cms::Blogs::BlogPost::CurrentState
A generated ENUM descibing the current state of this Blog Post. Should always match state.
112 113 114 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 112 required :current_state, enum: -> { HubSpotSDK::Cms::Blogs::BlogPost::CurrentState }, api_name: :currentState |
#currently_published ⇒ Boolean
Whether the post is published (true or false)
105 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 105 required :currently_published, HubSpotSDK::Internal::Type::Boolean, api_name: :currentlyPublished |
#domain ⇒ String
The domain this Blog Post will resolve to. If null, the Blog Post will default to the domain of the ParentBlog.
121 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 121 required :domain, String |
#dynamic_page_data_source_id ⇒ String
The identifier for the data source used by the dynamic page.
127 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 127 required :dynamic_page_data_source_id, String, api_name: :dynamicPageDataSourceId |
#dynamic_page_data_source_type ⇒ Integer
The type of data source used by the dynamic page.
133 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 133 required :dynamic_page_data_source_type, Integer, api_name: :dynamicPageDataSourceType |
#dynamic_page_hub_db_table_id ⇒ String
The ID of the HubDB table this Blog Post references, if applicable
139 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 139 required :dynamic_page_hub_db_table_id, String, api_name: :dynamicPageHubDbTableId |
#enable_domain_stylesheets ⇒ Boolean
Boolean to determine whether or not the styles from the template should be applied.
146 147 148 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 146 required :enable_domain_stylesheets, HubSpotSDK::Internal::Type::Boolean, api_name: :enableDomainStylesheets |
#enable_google_amp_output_override ⇒ Boolean
Boolean to allow overriding the AMP settings for the blog.
154 155 156 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 154 required :enable_google_amp_output_override, HubSpotSDK::Internal::Type::Boolean, api_name: :enableGoogleAmpOutputOverride |
#enable_layout_stylesheets ⇒ Boolean
Boolean to determine whether or not the styles from the template should be applied.
163 164 165 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 163 required :enable_layout_stylesheets, HubSpotSDK::Internal::Type::Boolean, api_name: :enableLayoutStylesheets |
#featured_image ⇒ String
The featuredImage of this Blog Post.
171 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 171 required :featured_image, String, api_name: :featuredImage |
#featured_image_alt_text ⇒ String
Alt Text of the featuredImage.
177 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 177 required :featured_image_alt_text, String, api_name: :featuredImageAltText |
#folder_id ⇒ String
Unique identifier of associated folder
183 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 183 required :folder_id, String, api_name: :folderId |
#footer_html ⇒ String
Custom HTML for embed codes, javascript that should be placed before the </body> tag of the page.
190 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 190 required :footer_html, String, api_name: :footerHtml |
#head_html ⇒ String
Custom HTML for embed codes, javascript, etc. that goes in the <head> tag of the page.
197 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 197 required :head_html, String, api_name: :headHtml |
#html_title ⇒ String
The html title of this Blog Post.
203 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 203 required :html_title, String, api_name: :htmlTitle |
#id ⇒ String
The unique ID of the Blog Post.
12 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 12 required :id, String |
#include_default_custom_css ⇒ Boolean
Boolean to determine whether or not the Primary CSS Files should be applied.
209 210 211 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 209 required :include_default_custom_css, HubSpotSDK::Internal::Type::Boolean, api_name: :includeDefaultCustomCss |
#language ⇒ Symbol, HubSpotSDK::Models::Cms::Blogs::BlogPost::Language
The explicitly defined ISO 639 language code of the Blog Post. If null, the Blog Post will default to the language of the ParentBlog.
218 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 218 required :language, enum: -> { HubSpotSDK::Cms::Blogs::BlogPost::Language } |
#layout_sections ⇒ Hash{Symbol=>HubSpotSDK::Models::Cms::LayoutSection}
A structure detailing the layout sections of the blog post.
224 225 226 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 224 required :layout_sections, -> { HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Cms::LayoutSection] }, api_name: :layoutSections |
#link_rel_canonical_url ⇒ String
Optional override to set the URL to be used in the rel=canonical link tag on the page.
233 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 233 required :link_rel_canonical_url, String, api_name: :linkRelCanonicalUrl |
#mab_experiment_id ⇒ String
Unique identifier of the MAB Experiment
239 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 239 required :mab_experiment_id, String, api_name: :mabExperimentId |
#meta_description ⇒ String
A description that goes in <meta> tag on the page.
245 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 245 required :meta_description, String, api_name: :metaDescription |
#name ⇒ String
The internal name of the Blog Post.
251 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 251 required :name, String |
#page_expiry_date ⇒ Integer
The date at which this blog post should expire and begin redirecting to another url or page.
258 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 258 required :page_expiry_date, Integer, api_name: :pageExpiryDate |
#page_expiry_enabled ⇒ Boolean
Boolean describing if the page expiration feature is enabled for this blog post.
264 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 264 required :page_expiry_enabled, HubSpotSDK::Internal::Type::Boolean, api_name: :pageExpiryEnabled |
#page_expiry_redirect_id ⇒ Integer
The ID of another page this blog post’s url should redirect to once this blog post expires. Should only set this or pageExpiryRedirectUrl.
271 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 271 required :page_expiry_redirect_id, Integer, api_name: :pageExpiryRedirectId |
#page_expiry_redirect_url ⇒ String
The URL this blog post’s url should redirect to once it expires. Should only set this or pageExpiryRedirectId.
278 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 278 required :page_expiry_redirect_url, String, api_name: :pageExpiryRedirectUrl |
#password ⇒ String
Set this to create a password protected page. Entering the password will be required to view the page.
285 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 285 required :password, String |
#post_body ⇒ String
The HTML of the main post body.
291 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 291 required :post_body, String, api_name: :postBody |
#post_summary ⇒ String
The summary of the blog post that will appear on the main listing page.
297 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 297 required :post_summary, String, api_name: :postSummary |
#public_access_rules ⇒ Array<Object>
Rules for require member registration to access private content.
303 304 305 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 303 required :public_access_rules, HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Internal::Type::Unknown], api_name: :publicAccessRules |
#public_access_rules_enabled ⇒ Boolean
Boolean to determine whether or not to respect publicAccessRules.
311 312 313 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 311 required :public_access_rules_enabled, HubSpotSDK::Internal::Type::Boolean, api_name: :publicAccessRulesEnabled |
#publish_date ⇒ Time
The date (ISO8601 format) the blog post is to be published at.
319 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 319 required :publish_date, Time, api_name: :publishDate |
#publish_immediately ⇒ Boolean
Set this to true if you want to be published immediately when the schedule publish endpoint is called, and to ignore the publish_date setting.
326 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 326 required :publish_immediately, HubSpotSDK::Internal::Type::Boolean, api_name: :publishImmediately |
#rss_body ⇒ String
The contents of the RSS body for this Blog Post.
332 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 332 required :rss_body, String, api_name: :rssBody |
#rss_summary ⇒ String
The contents of the RSS summary for this Blog Post.
338 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 338 required :rss_summary, String, api_name: :rssSummary |
#slug ⇒ String
The path of the this blog post. This field is appended to the domain to construct the url of this post.
345 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 345 required :slug, String |
#state ⇒ String
An ENUM descibing the current state of this Blog Post.
351 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 351 required :state, String |
#tag_ids ⇒ Array<Integer>
List of IDs for the tags associated with this Blog Post.
357 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 357 required :tag_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :tagIds |
#theme_settings_values ⇒ Hash{Symbol=>Object}
A collection of settings specific to the theme applied to the blog post.
363 364 365 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 363 required :theme_settings_values, HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown], api_name: :themeSettingsValues |
#translated_from_id ⇒ String
ID of the primary blog post this object was translated from.
371 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 371 required :translated_from_id, String, api_name: :translatedFromId |
#translations ⇒ Hash{Symbol=>HubSpotSDK::Models::Cms::ContentLanguageVariation}
A map of translations for the blog post, each associated with a specific language variation.
378 379 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 378 required :translations, -> { HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Cms::ContentLanguageVariation] } |
#updated ⇒ Time
The timestamp (ISO8601 format) when this Blog Post was updated.
385 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 385 required :updated, Time |
#updated_by_id ⇒ String
The ID of the user that updated this Blog Post.
391 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 391 required :updated_by_id, String, api_name: :updatedById |
#url ⇒ String
A generated field representing the URL of this blog post.
397 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 397 required :url, String |
#use_featured_image ⇒ Boolean
Boolean to determine if this post should use a featuredImage.
403 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 403 required :use_featured_image, HubSpotSDK::Internal::Type::Boolean, api_name: :useFeaturedImage |
#widget_containers ⇒ Hash{Symbol=>Object}
A data structure containing the data for all the modules inside the containers for this post. This will only be populated if the page has widget containers.
410 411 412 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 410 required :widget_containers, HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown], api_name: :widgetContainers |
#widgets ⇒ Hash{Symbol=>Object}
A data structure containing the data for all the modules for this page.
418 |
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 418 required :widgets, HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/cms/blogs/blog_post.rb', line 564
|