Class: HubSpotSDK::Models::Cms::Column
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::Column
- Defined in:
- lib/hubspot_sdk/models/cms/column.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
The timestamp when the column was created.
- #created_by ⇒ HubSpotSDK::Models::Cms::SimpleUser?
-
#created_by_user_id ⇒ Integer?
The ID of the user who created the column.
-
#deleted ⇒ Boolean
Indicates whether the column has been deleted.
-
#description ⇒ String
The description of the column.
-
#foreign_column_id ⇒ Integer?
Foreign Column id.
-
#foreign_ids ⇒ Array<HubSpotSDK::Models::Cms::ForeignID>?
Foreign Ids.
-
#foreign_ids_by_id ⇒ Hash{Symbol=>HubSpotSDK::Models::Cms::ForeignID}?
Foreign ids.
-
#foreign_ids_by_name ⇒ Hash{Symbol=>HubSpotSDK::Models::Cms::ForeignID}?
Foreign ids by name.
-
#foreign_table_id ⇒ Integer?
Foreign table id referenced.
-
#id ⇒ String
Column Id.
-
#label ⇒ String
Label of the column.
-
#name ⇒ String
Name of the column.
-
#option_count ⇒ Integer?
Number of options available.
-
#options ⇒ Array<HubSpotSDK::Models::Cms::Option>?
Options to choose for select and multi-select columns.
-
#type ⇒ Symbol, HubSpotSDK::Models::Cms::Column::Type
Type of the column.
-
#updated_at ⇒ Time?
The timestamp when the column was last updated.
- #updated_by ⇒ HubSpotSDK::Models::Cms::SimpleUser?
-
#updated_by_user_id ⇒ Integer?
The ID of the user who last updated the column.
-
#width ⇒ Integer?
Column width for HubDB UI.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, deleted:, description:, label:, name:, type:, created_at: nil, created_by: nil, created_by_user_id: nil, foreign_column_id: nil, foreign_ids: nil, foreign_ids_by_id: nil, foreign_ids_by_name: nil, foreign_table_id: nil, option_count: nil, options: nil, updated_at: nil, updated_by: nil, updated_by_user_id: nil, width: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/cms/column.rb', line 131
|
Instance Attribute Details
#created_at ⇒ Time?
The timestamp when the column was created.
47 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 47 optional :created_at, Time, api_name: :createdAt |
#created_by ⇒ HubSpotSDK::Models::Cms::SimpleUser?
52 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 52 optional :created_by, -> { HubSpotSDK::Cms::SimpleUser }, api_name: :createdBy |
#created_by_user_id ⇒ Integer?
The ID of the user who created the column.
58 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 58 optional :created_by_user_id, Integer, api_name: :createdByUserId |
#deleted ⇒ Boolean
Indicates whether the column has been deleted.
17 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 17 required :deleted, HubSpotSDK::Internal::Type::Boolean |
#description ⇒ String
The description of the column.
23 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 23 required :description, String |
#foreign_column_id ⇒ Integer?
Foreign Column id
64 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 64 optional :foreign_column_id, Integer, api_name: :foreignColumnId |
#foreign_ids ⇒ Array<HubSpotSDK::Models::Cms::ForeignID>?
Foreign Ids
70 71 72 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 70 optional :foreign_ids, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Cms::ForeignID] }, api_name: :foreignIds |
#foreign_ids_by_id ⇒ Hash{Symbol=>HubSpotSDK::Models::Cms::ForeignID}?
Foreign ids
78 79 80 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 78 optional :foreign_ids_by_id, -> { HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Cms::ForeignID] }, api_name: :foreignIdsById |
#foreign_ids_by_name ⇒ Hash{Symbol=>HubSpotSDK::Models::Cms::ForeignID}?
Foreign ids by name
86 87 88 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 86 optional :foreign_ids_by_name, -> { HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Cms::ForeignID] }, api_name: :foreignIdsByName |
#foreign_table_id ⇒ Integer?
Foreign table id referenced
94 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 94 optional :foreign_table_id, Integer, api_name: :foreignTableId |
#id ⇒ String
Column Id
11 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 11 required :id, String |
#label ⇒ String
Label of the column
29 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 29 required :label, String |
#name ⇒ String
Name of the column
35 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 35 required :name, String |
#option_count ⇒ Integer?
Number of options available
100 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 100 optional :option_count, Integer, api_name: :optionCount |
#options ⇒ Array<HubSpotSDK::Models::Cms::Option>?
Options to choose for select and multi-select columns
106 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 106 optional :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Cms::Option] } |
#type ⇒ Symbol, HubSpotSDK::Models::Cms::Column::Type
Type of the column
41 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 41 required :type, enum: -> { HubSpotSDK::Cms::Column::Type } |
#updated_at ⇒ Time?
The timestamp when the column was last updated.
112 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 112 optional :updated_at, Time, api_name: :updatedAt |
#updated_by ⇒ HubSpotSDK::Models::Cms::SimpleUser?
117 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 117 optional :updated_by, -> { HubSpotSDK::Cms::SimpleUser }, api_name: :updatedBy |
#updated_by_user_id ⇒ Integer?
The ID of the user who last updated the column.
123 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 123 optional :updated_by_user_id, Integer, api_name: :updatedByUserId |
#width ⇒ Integer?
Column width for HubDB UI
129 |
# File 'lib/hubspot_sdk/models/cms/column.rb', line 129 optional :width, Integer |