Class: HubSpotSDK::Models::Cms::ContentFolder
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::ContentFolder
- Defined in:
- lib/hubspot_sdk/models/cms/content_folder.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#category ⇒ Integer
The type of object this folder applies to.
-
#created ⇒ Time
The timestamp indicating when the content folder was created.
-
#deleted_at ⇒ Time
The timestamp (ISO8601 format) when this content folder was deleted.
-
#id ⇒ String
The unique ID of the content folder.
-
#name ⇒ String
The name of the folder which will show up in the app dashboard.
-
#parent_folder_id ⇒ Integer
The ID of the content folder this folder is nested under.
-
#updated ⇒ Time
The timestamp indicating when the content folder was last updated.
Instance Method Summary collapse
- #initialize(id:, category:, created:, deleted_at:, name:, parent_folder_id:, updated:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, category:, created:, deleted_at:, name:, parent_folder_id:, updated:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/cms/content_folder.rb', line 49
|
Instance Attribute Details
#category ⇒ Integer
The type of object this folder applies to. Should always be LANDING_PAGE.
17 |
# File 'lib/hubspot_sdk/models/cms/content_folder.rb', line 17 required :category, Integer |
#created ⇒ Time
The timestamp indicating when the content folder was created.
23 |
# File 'lib/hubspot_sdk/models/cms/content_folder.rb', line 23 required :created, Time |
#deleted_at ⇒ Time
The timestamp (ISO8601 format) when this content folder was deleted.
29 |
# File 'lib/hubspot_sdk/models/cms/content_folder.rb', line 29 required :deleted_at, Time, api_name: :deletedAt |
#id ⇒ String
The unique ID of the content folder.
11 |
# File 'lib/hubspot_sdk/models/cms/content_folder.rb', line 11 required :id, String |
#name ⇒ String
The name of the folder which will show up in the app dashboard
35 |
# File 'lib/hubspot_sdk/models/cms/content_folder.rb', line 35 required :name, String |
#parent_folder_id ⇒ Integer
The ID of the content folder this folder is nested under
41 |
# File 'lib/hubspot_sdk/models/cms/content_folder.rb', line 41 required :parent_folder_id, Integer, api_name: :parentFolderId |
#updated ⇒ Time
The timestamp indicating when the content folder was last updated.
47 |
# File 'lib/hubspot_sdk/models/cms/content_folder.rb', line 47 required :updated, Time |