Class: HubSpotSDK::Models::Cms::ContentLanguageVariation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::ContentLanguageVariation
- Defined in:
- lib/hubspot_sdk/models/cms/content_language_variation.rb
Instance Attribute Summary collapse
-
#archived_in_dashboard ⇒ Boolean
If True, the variant will not show up in your dashboard, although the post could still be live.
-
#author_name ⇒ String
The name of the user who last published the blog post.
-
#campaign ⇒ String
The GUID of the marketing campaign this page is a part of.
-
#campaign_name ⇒ String
Name of the associated marketing campaign.
-
#created ⇒ Time
The timestamp (ISO8601 format) when this Blog Post was created.
-
#id ⇒ Integer
ID of object to set as primary in multi-language group.
-
#name ⇒ String
The internal name of the content language variation.
-
#password ⇒ String
Set this to create a password protected page.
- #public_access_rules ⇒ Array<Object>
-
#public_access_rules_enabled ⇒ Boolean
Boolean to determine whether or not to respect publicAccessRules.
-
#publish_date ⇒ Time
The date (ISO8601 format) the page is to be published at.
-
#slug ⇒ String
The path of the this page.
-
#state ⇒ String
An ENUM describing the current state of this page.
- #tag_ids ⇒ Array<Integer>?
-
#updated ⇒ Time
The timestamp (ISO8601 format) when this Blog Post was updated.
Instance Method Summary collapse
-
#initialize(id:, archived_in_dashboard:, author_name:, campaign:, campaign_name:, created:, name:, password:, public_access_rules:, public_access_rules_enabled:, publish_date:, slug:, state:, updated:, tag_ids: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ContentLanguageVariation for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived_in_dashboard:, author_name:, campaign:, campaign_name:, created:, name:, password:, public_access_rules:, public_access_rules_enabled:, publish_date:, slug:, state:, updated:, tag_ids: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::ContentLanguageVariation for more details.
|
|
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 106
|
Instance Attribute Details
#archived_in_dashboard ⇒ Boolean
If True, the variant will not show up in your dashboard, although the post could still be live.
18 |
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 18 required :archived_in_dashboard, HubSpotSDK::Internal::Type::Boolean, api_name: :archivedInDashboard |
#author_name ⇒ String
The name of the user who last published the blog post. For posts that haven’t been published yet, this property will reflect the user who initially created the draft.
26 |
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 26 required :author_name, String, api_name: :authorName |
#campaign ⇒ String
The GUID of the marketing campaign this page is a part of.
32 |
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 32 required :campaign, String |
#campaign_name ⇒ String
Name of the associated marketing campaign.
38 |
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 38 required :campaign_name, String, api_name: :campaignName |
#created ⇒ Time
The timestamp (ISO8601 format) when this Blog Post was created.
44 |
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 44 required :created, Time |
#id ⇒ Integer
ID of object to set as primary in multi-language group.
11 |
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 11 required :id, Integer |
#name ⇒ String
The internal name of the content language variation.
50 |
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 50 required :name, String |
#password ⇒ String
Set this to create a password protected page. Entering the password will be required to view the page.
57 |
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 57 required :password, String |
#public_access_rules ⇒ Array<Object>
62 63 64 |
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 62 required :public_access_rules, HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Internal::Type::Unknown], api_name: :publicAccessRules |
#public_access_rules_enabled ⇒ Boolean
Boolean to determine whether or not to respect publicAccessRules.
70 71 72 |
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 70 required :public_access_rules_enabled, HubSpotSDK::Internal::Type::Boolean, api_name: :publicAccessRulesEnabled |
#publish_date ⇒ Time
The date (ISO8601 format) the page is to be published at.
78 |
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 78 required :publish_date, Time, api_name: :publishDate |
#slug ⇒ String
The path of the this page. This field is appended to the domain to construct the url of this page.
85 |
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 85 required :slug, String |
#state ⇒ String
An ENUM describing the current state of this page.
Maximum string length: 25
93 |
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 93 required :state, String |
#tag_ids ⇒ Array<Integer>?
104 |
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 104 optional :tag_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :tagIds |
#updated ⇒ Time
The timestamp (ISO8601 format) when this Blog Post was updated.
99 |
# File 'lib/hubspot_sdk/models/cms/content_language_variation.rb', line 99 required :updated, Time |