Class: HubSpotSDK::Models::Cms::ContentSearchResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::ContentSearchResult
- Defined in:
- lib/hubspot_sdk/models/cms/content_search_result.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#author_full_name ⇒ String?
Name of the author.
-
#category ⇒ String?
The error category.
-
#combined_id ⇒ String?
The ID of the document in HubSpot.
- #content_type ⇒ String?
-
#description ⇒ String?
The result’s description.
-
#domain ⇒ String
The domain the document is hosted on.
-
#featured_image_url ⇒ String?
URL of the featured image.
-
#id ⇒ Integer
The ID of the content.
- #in_beta ⇒ Boolean?
- #is_private ⇒ Boolean?
-
#language ⇒ Symbol, ...
The document’s language.
-
#published_date ⇒ Integer?
The date the content was published.
-
#row_id ⇒ Integer?
If a dynamic page, the row ID in the HubDB table.
-
#score ⇒ Float
The matching score of the document.
-
#subcategory ⇒ String?
For knowledge articles, the subcategory of the article.
-
#table_id ⇒ Integer?
If a dynamic page, the ID of the HubDB table.
-
#tags ⇒ Array<String>?
If a blog post, the tags associated with it.
-
#title ⇒ String?
The title of the returned document.
-
#type ⇒ Symbol, HubSpotSDK::Models::Cms::ContentSearchResult::Type
The type of document.
-
#url ⇒ String
The url of the document.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, domain:, score:, type:, url:, author_full_name: nil, category: nil, combined_id: nil, content_type: nil, description: nil, featured_image_url: nil, in_beta: nil, is_private: nil, language: nil, published_date: nil, row_id: nil, subcategory: nil, table_id: nil, tags: nil, title: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ContentSearchResult for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, domain:, score:, type:, url:, author_full_name: nil, category: nil, combined_id: nil, content_type: nil, description: nil, featured_image_url: nil, in_beta: nil, is_private: nil, language: nil, published_date: nil, row_id: nil, subcategory: nil, table_id: nil, tags: nil, title: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::ContentSearchResult for more details.
‘LISTING_
|
|
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 126
|
Instance Attribute Details
#author_full_name ⇒ String?
Name of the author.
42 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 42 optional :author_full_name, String, api_name: :authorFullName |
#category ⇒ String?
The error category
48 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 48 optional :category, String |
#combined_id ⇒ String?
The ID of the document in HubSpot.
54 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 54 optional :combined_id, String, api_name: :combinedId |
#content_type ⇒ String?
59 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 59 optional :content_type, String, api_name: :contentType |
#description ⇒ String?
The result’s description. The content will be determined by the value of ‘length` in the request.
66 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 66 optional :description, String |
#domain ⇒ String
The domain the document is hosted on.
17 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 17 required :domain, String |
#featured_image_url ⇒ String?
URL of the featured image.
72 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 72 optional :featured_image_url, String, api_name: :featuredImageUrl |
#id ⇒ Integer
The ID of the content.
11 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 11 required :id, Integer |
#in_beta ⇒ Boolean?
77 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 77 optional :in_beta, HubSpotSDK::Internal::Type::Boolean, api_name: :inBeta |
#is_private ⇒ Boolean?
82 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 82 optional :is_private, HubSpotSDK::Internal::Type::Boolean, api_name: :isPrivate |
#language ⇒ Symbol, ...
The document’s language.
88 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 88 optional :language, enum: -> { HubSpotSDK::Cms::ContentSearchResult::Language } |
#published_date ⇒ Integer?
The date the content was published.
94 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 94 optional :published_date, Integer, api_name: :publishedDate |
#row_id ⇒ Integer?
If a dynamic page, the row ID in the HubDB table.
100 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 100 optional :row_id, Integer, api_name: :rowId |
#score ⇒ Float
The matching score of the document.
23 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 23 required :score, Float |
#subcategory ⇒ String?
For knowledge articles, the subcategory of the article.
106 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 106 optional :subcategory, String |
#table_id ⇒ Integer?
If a dynamic page, the ID of the HubDB table.
112 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 112 optional :table_id, Integer, api_name: :tableId |
#tags ⇒ Array<String>?
If a blog post, the tags associated with it.
118 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 118 optional :tags, HubSpotSDK::Internal::Type::ArrayOf[String] |
#title ⇒ String?
The title of the returned document.
124 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 124 optional :title, String |
#type ⇒ Symbol, HubSpotSDK::Models::Cms::ContentSearchResult::Type
The type of document. Can be ‘SITE_PAGE`, `LANDING_PAGE`, `BLOG_POST`, `LISTING_PAGE`, or `KNOWLEDGE_ARTICLE`.
30 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 30 required :type, enum: -> { HubSpotSDK::Cms::ContentSearchResult::Type } |
#url ⇒ String
The url of the document.
36 |
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 36 required :url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/cms/content_search_result.rb', line 185
|