Class: HubSpotSDK::Models::Cms::Domain
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::Domain
- Defined in:
- lib/hubspot_sdk/models/cms/domain.rb
Overview
Instance Attribute Summary collapse
-
#correct_cname ⇒ String
The expected CNAME record for the domain.
-
#created ⇒ Time
The date and time when the domain was created.
-
#domain ⇒ String
The actual domain or sub-domain.
-
#id ⇒ String
The unique ID of this domain.
-
#is_resolving ⇒ Boolean
Whether the DNS for this domain is optimally configured for use with HubSpot.
-
#is_ssl_enabled ⇒ Boolean
Indicates whether SSL is enabled for the domain.
-
#is_ssl_only ⇒ Boolean
Indicates whether the domain is accessible only via SSL.
-
#is_used_for_blog_post ⇒ Boolean
Whether the domain is used for CMS blog posts.
-
#is_used_for_email ⇒ Boolean
Whether the domain is used for CMS email web pages.
-
#is_used_for_knowledge ⇒ Boolean
Whether the domain is used for CMS knowledge pages.
-
#is_used_for_landing_page ⇒ Boolean
Whether the domain is used for CMS landing pages.
-
#is_used_for_site_page ⇒ Boolean
Whether the domain is used for CMS site pages.
-
#manually_marked_as_resolving ⇒ Boolean
Indicates whether the domain has been manually marked as resolving.
-
#primary_blog_post ⇒ Boolean
Indicates whether the domain is the primary domain for blog posts.
-
#primary_email ⇒ Boolean
Indicates whether the domain is the primary domain for email pages.
-
#primary_knowledge ⇒ Boolean
Indicates whether the domain is the primary domain for knowledge pages.
-
#primary_landing_page ⇒ Boolean
Indicates whether the domain is the primary domain for landing pages.
-
#primary_site_page ⇒ Boolean
Indicates whether the domain is the primary domain for site pages.
-
#secondary_to_domain ⇒ String
Specifies the domain to which this domain is secondary.
-
#updated ⇒ Time
The date and time when the domain was last updated.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, correct_cname:, created:, domain:, is_resolving:, is_ssl_enabled:, is_ssl_only:, is_used_for_blog_post:, is_used_for_email:, is_used_for_knowledge:, is_used_for_landing_page:, is_used_for_site_page:, manually_marked_as_resolving:, primary_blog_post:, primary_email:, primary_knowledge:, primary_landing_page:, primary_site_page:, secondary_to_domain:, updated:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 132
|
Instance Attribute Details
#correct_cname ⇒ String
The expected CNAME record for the domain.
18 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 18 required :correct_cname, String, api_name: :correctCname |
#created ⇒ Time
The date and time when the domain was created.
24 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 24 required :created, Time |
#domain ⇒ String
The actual domain or sub-domain. e.g. www.hubspot.com
30 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 30 required :domain, String |
#id ⇒ String
The unique ID of this domain.
12 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 12 required :id, String |
#is_resolving ⇒ Boolean
Whether the DNS for this domain is optimally configured for use with HubSpot.
36 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 36 required :is_resolving, HubSpotSDK::Internal::Type::Boolean, api_name: :isResolving |
#is_ssl_enabled ⇒ Boolean
Indicates whether SSL is enabled for the domain.
42 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 42 required :is_ssl_enabled, HubSpotSDK::Internal::Type::Boolean, api_name: :isSslEnabled |
#is_ssl_only ⇒ Boolean
Indicates whether the domain is accessible only via SSL.
48 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 48 required :is_ssl_only, HubSpotSDK::Internal::Type::Boolean, api_name: :isSslOnly |
#is_used_for_blog_post ⇒ Boolean
Whether the domain is used for CMS blog posts.
54 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 54 required :is_used_for_blog_post, HubSpotSDK::Internal::Type::Boolean, api_name: :isUsedForBlogPost |
#is_used_for_email ⇒ Boolean
Whether the domain is used for CMS email web pages.
60 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 60 required :is_used_for_email, HubSpotSDK::Internal::Type::Boolean, api_name: :isUsedForEmail |
#is_used_for_knowledge ⇒ Boolean
Whether the domain is used for CMS knowledge pages.
66 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 66 required :is_used_for_knowledge, HubSpotSDK::Internal::Type::Boolean, api_name: :isUsedForKnowledge |
#is_used_for_landing_page ⇒ Boolean
Whether the domain is used for CMS landing pages.
72 73 74 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 72 required :is_used_for_landing_page, HubSpotSDK::Internal::Type::Boolean, api_name: :isUsedForLandingPage |
#is_used_for_site_page ⇒ Boolean
Whether the domain is used for CMS site pages.
80 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 80 required :is_used_for_site_page, HubSpotSDK::Internal::Type::Boolean, api_name: :isUsedForSitePage |
#manually_marked_as_resolving ⇒ Boolean
Indicates whether the domain has been manually marked as resolving.
86 87 88 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 86 required :manually_marked_as_resolving, HubSpotSDK::Internal::Type::Boolean, api_name: :manuallyMarkedAsResolving |
#primary_blog_post ⇒ Boolean
Indicates whether the domain is the primary domain for blog posts.
94 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 94 required :primary_blog_post, HubSpotSDK::Internal::Type::Boolean, api_name: :primaryBlogPost |
#primary_email ⇒ Boolean
Indicates whether the domain is the primary domain for email pages.
100 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 100 required :primary_email, HubSpotSDK::Internal::Type::Boolean, api_name: :primaryEmail |
#primary_knowledge ⇒ Boolean
Indicates whether the domain is the primary domain for knowledge pages.
106 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 106 required :primary_knowledge, HubSpotSDK::Internal::Type::Boolean, api_name: :primaryKnowledge |
#primary_landing_page ⇒ Boolean
Indicates whether the domain is the primary domain for landing pages.
112 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 112 required :primary_landing_page, HubSpotSDK::Internal::Type::Boolean, api_name: :primaryLandingPage |
#primary_site_page ⇒ Boolean
Indicates whether the domain is the primary domain for site pages.
118 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 118 required :primary_site_page, HubSpotSDK::Internal::Type::Boolean, api_name: :primarySitePage |
#secondary_to_domain ⇒ String
Specifies the domain to which this domain is secondary.
124 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 124 required :secondary_to_domain, String, api_name: :secondaryToDomain |
#updated ⇒ Time
The date and time when the domain was last updated.
130 |
# File 'lib/hubspot_sdk/models/cms/domain.rb', line 130 required :updated, Time |