Class: HubSpotSDK::Models::Cms::HubDBTableRowV3Request
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::HubDBTableRowV3Request
- Defined in:
- lib/hubspot_sdk/models/cms/hub_db_table_row_v3_request.rb
Direct Known Subclasses
HubSpotSDK::Models::Cms::Hubdb::RowCreateParams, HubSpotSDK::Models::Cms::Hubdb::RowReplaceDraftParams, HubSpotSDK::Models::Cms::Hubdb::RowUpdateDraftParams
Instance Attribute Summary collapse
-
#child_table_id ⇒ Integer
Specifies the value for the column child table id.
-
#display_index ⇒ Integer
The index position for displaying the row within the table.
-
#name ⇒ String?
Specifies the value for ‘hs_name` column, which will be used as title in the dynamic pages.
-
#path ⇒ String?
Specifies the value for ‘hs_path` column, which will be used as slug in the dynamic pages.
-
#values ⇒ Hash{Symbol=>Object}
List of key value pairs with the column name and column value.
Instance Method Summary collapse
-
#initialize(child_table_id:, display_index:, values:, name: nil, path: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see HubDBTableRowV3Request for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(child_table_id:, display_index:, values:, name: nil, path: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::HubDBTableRowV3Request for more details.
|
|
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3_request.rb', line 39
|
Instance Attribute Details
#child_table_id ⇒ Integer
Specifies the value for the column child table id
11 |
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3_request.rb', line 11 required :child_table_id, Integer, api_name: :childTableId |
#display_index ⇒ Integer
The index position for displaying the row within the table.
17 |
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3_request.rb', line 17 required :display_index, Integer, api_name: :displayIndex |
#name ⇒ String?
Specifies the value for ‘hs_name` column, which will be used as title in the dynamic pages
30 |
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3_request.rb', line 30 optional :name, String |
#path ⇒ String?
Specifies the value for ‘hs_path` column, which will be used as slug in the dynamic pages
37 |
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3_request.rb', line 37 optional :path, String |
#values ⇒ Hash{Symbol=>Object}
List of key value pairs with the column name and column value
23 |
# File 'lib/hubspot_sdk/models/cms/hub_db_table_row_v3_request.rb', line 23 required :values, HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown] |