Class: HubSpotSDK::Models::Cms::HubDBTableV3Request
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::HubDBTableV3Request
- Defined in:
- lib/hubspot_sdk/models/cms/hub_db_table_v3_request.rb
Direct Known Subclasses
HubSpotSDK::Models::Cms::Hubdb::TableCreateParams, HubSpotSDK::Models::Cms::Hubdb::TableUpdateDraftParams
Instance Attribute Summary collapse
-
#allow_child_tables ⇒ Boolean
Specifies whether child tables can be created.
-
#allow_public_api_access ⇒ Boolean
Specifies whether the table can be read by public without authorization.
-
#columns ⇒ Array<HubSpotSDK::Models::Cms::ColumnRequest>
List of columns in the table.
-
#dynamic_meta_tags ⇒ Hash{Symbol=>Integer}
Specifies the key value pairs of the [metadata fields](developers.hubspot.com/docs/cms/guides/dynamic-pages/hubdb#dynamic-pages) with the associated column IDs.
-
#enable_child_table_pages ⇒ Boolean
Specifies creation of multi-level dynamic pages using child tables.
-
#label ⇒ String
Label of the table.
-
#name ⇒ String
Name of the table.
-
#use_for_pages ⇒ Boolean
Specifies whether the table can be used for creation of dynamic pages.
Instance Method Summary collapse
-
#initialize(allow_child_tables:, allow_public_api_access:, columns:, dynamic_meta_tags:, enable_child_table_pages:, label:, name:, use_for_pages:) ⇒ Object
constructor
Some parameter documentations has been truncated, see HubDBTableV3Request for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allow_child_tables:, allow_public_api_access:, columns:, dynamic_meta_tags:, enable_child_table_pages:, label:, name:, use_for_pages:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::HubDBTableV3Request for more details.
|
|
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3_request.rb', line 61
|
Instance Attribute Details
#allow_child_tables ⇒ Boolean
Specifies whether child tables can be created
11 |
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3_request.rb', line 11 required :allow_child_tables, HubSpotSDK::Internal::Type::Boolean, api_name: :allowChildTables |
#allow_public_api_access ⇒ Boolean
Specifies whether the table can be read by public without authorization
17 18 19 |
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3_request.rb', line 17 required :allow_public_api_access, HubSpotSDK::Internal::Type::Boolean, api_name: :allowPublicApiAccess |
#columns ⇒ Array<HubSpotSDK::Models::Cms::ColumnRequest>
List of columns in the table
25 |
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3_request.rb', line 25 required :columns, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Cms::ColumnRequest] } |
#dynamic_meta_tags ⇒ Hash{Symbol=>Integer}
Specifies the key value pairs of the [metadata fields](developers.hubspot.com/docs/cms/guides/dynamic-pages/hubdb#dynamic-pages) with the associated column IDs.
33 |
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3_request.rb', line 33 required :dynamic_meta_tags, HubSpotSDK::Internal::Type::HashOf[Integer], api_name: :dynamicMetaTags |
#enable_child_table_pages ⇒ Boolean
Specifies creation of multi-level dynamic pages using child tables
39 40 41 |
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3_request.rb', line 39 required :enable_child_table_pages, HubSpotSDK::Internal::Type::Boolean, api_name: :enableChildTablePages |
#label ⇒ String
Label of the table
47 |
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3_request.rb', line 47 required :label, String |
#name ⇒ String
Name of the table
53 |
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3_request.rb', line 53 required :name, String |
#use_for_pages ⇒ Boolean
Specifies whether the table can be used for creation of dynamic pages
59 |
# File 'lib/hubspot_sdk/models/cms/hub_db_table_v3_request.rb', line 59 required :use_for_pages, HubSpotSDK::Internal::Type::Boolean, api_name: :useForPages |