Class: HubSpotSDK::Models::Cms::Hubdb::RowListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::Hubdb::RowListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
-
#archived ⇒ Boolean?
Whether to return only results that have been archived.
-
#limit ⇒ Integer?
The maximum number of results to display per page.
- #offset ⇒ Integer?
- #properties ⇒ Array<String>?
- #sort ⇒ Array<String>?
- #table_id_or_name ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(table_id_or_name:, after: nil, archived: nil, limit: nil, offset: nil, properties: nil, sort: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see RowListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(table_id_or_name:, after: nil, archived: nil, limit: nil, offset: nil, properties: nil, sort: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::Hubdb::RowListParams for more details.
|
|
# File 'lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb', line 52
|
Instance Attribute Details
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
23 |
# File 'lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb', line 23 optional :after, String |
#archived ⇒ Boolean?
Whether to return only results that have been archived.
29 |
# File 'lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb', line 29 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#limit ⇒ Integer?
The maximum number of results to display per page.
35 |
# File 'lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb', line 35 optional :limit, Integer |
#offset ⇒ Integer?
40 |
# File 'lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb', line 40 optional :offset, Integer |
#properties ⇒ Array<String>?
45 |
# File 'lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb', line 45 optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String] |
#sort ⇒ Array<String>?
50 |
# File 'lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb', line 50 optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String] |
#table_id_or_name ⇒ String
15 |
# File 'lib/hubspot_sdk/models/cms/hubdb/row_list_params.rb', line 15 required :table_id_or_name, String |