Class: HubSpotSDK::Models::Cms::MediaPlayedPercentageEvent
Overview
Defined Under Namespace
Modules: ExternalPlayContext, MediaType
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
-
#initialize(contact_id:, media_bridge_id:, media_bridge_object_coordinates:, media_bridge_object_type_id:, media_name:, media_type:, occurred_timestamp:, played_percent:, portal_id:, provider_id:, session_id:, external_play_context: nil, media_url: nil, page_id: nil, page_name: nil, page_object_coordinates: nil, page_url: nil) ⇒ Object
constructor
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(contact_id:, media_bridge_id:, media_bridge_object_coordinates:, media_bridge_object_type_id:, media_name:, media_type:, occurred_timestamp:, played_percent:, portal_id:, provider_id:, session_id:, external_play_context: nil, media_url: nil, page_id: nil, page_name: nil, page_object_coordinates: nil, page_url: nil) ⇒ Object
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 107
|
Instance Attribute Details
The ID of the contact in HubSpot’s system that consumed the media. This can be fetched using HubSpot’s Get contact by usertoken (utk) API. The API also supports supplying a usertoken, and will handle converting this into a contact ID automatically.
15
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 15
required :contact_id, Integer, api_name: :contactId
|
#external_play_context ⇒ Symbol, ...
73
74
75
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 73
optional :external_play_context,
enum: -> { HubSpotSDK::Cms::MediaPlayedPercentageEvent::ExternalPlayContext },
api_name: :externalPlayContext
|
20
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 20
required :media_bridge_id, Integer, api_name: :mediaBridgeId
|
25
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 25
required :media_bridge_object_coordinates, String, api_name: :mediaBridgeObjectCoordinates
|
30
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 30
required :media_bridge_object_type_id, String, api_name: :mediaBridgeObjectTypeId
|
35
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 35
required :media_name, String, api_name: :mediaName
|
40
41
42
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 40
required :media_type,
enum: -> { HubSpotSDK::Cms::MediaPlayedPercentageEvent::MediaType },
api_name: :mediaType
|
80
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 80
optional :media_url, String, api_name: :mediaUrl
|
#occurred_timestamp ⇒ Integer
47
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 47
required :occurred_timestamp, Integer, api_name: :occurredTimestamp
|
#page_id ⇒ Integer?
The content ID of the page that an event happened on, for HubSpot pages. Required if the page is a HubSpot page.
87
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 87
optional :page_id, Integer, api_name: :pageId
|
#page_name ⇒ String?
The name or title of the page that an event happened on. Required for non-HubSpot pages.
94
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 94
optional :page_name, String, api_name: :pageName
|
#page_object_coordinates ⇒ String?
99
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 99
optional :page_object_coordinates, String, api_name: :pageObjectCoordinates
|
#page_url ⇒ String?
The URL of the page that an event happened on. Required for non-HubSpot pages.
105
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 105
optional :page_url, String, api_name: :pageUrl
|
#played_percent ⇒ Integer
52
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 52
required :played_percent, Integer, api_name: :playedPercent
|
#portal_id ⇒ Integer
The ID of the HubSpot account.
58
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 58
required :portal_id, Integer, api_name: :portalId
|
#provider_id ⇒ Integer
63
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 63
required :provider_id, Integer, api_name: :providerId
|
#session_id ⇒ String
68
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 68
required :session_id, String, api_name: :sessionId
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/hubspot_sdk/models/cms/media_played_percentage_event.rb', line 155
|