Class: HubSpotSDK::Models::Cms::Option
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::Option
- Defined in:
- lib/hubspot_sdk/models/cms/option.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the option was created, in ISO 8601 format.
- #created_by ⇒ HubSpotSDK::Models::Cms::SimpleUser?
-
#created_by_user_id ⇒ Integer?
The ID of the user who created the option.
-
#id ⇒ String
The unique ID of the option.
-
#label ⇒ String
A user-friendly label that identifies the option.
-
#name ⇒ String
An internal name assigned to the option, distinct from the label.
-
#order ⇒ Integer
The order in which the option appears, represented as an integer.
-
#type ⇒ String
Indicates the category or data type of the option (e.g., string, number).
-
#updated_at ⇒ Time
The timestamp when the option was last updated, in ISO 8601 format.
- #updated_by ⇒ HubSpotSDK::Models::Cms::SimpleUser?
-
#updated_by_user_id ⇒ Integer?
The ID of the user who last updated the option.
Instance Method Summary collapse
-
#initialize(id:, created_at:, label:, name:, order:, type:, updated_at:, created_by: nil, created_by_user_id: nil, updated_by: nil, updated_by_user_id: nil) ⇒ Object
constructor
A HubSpot property option.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, label:, name:, order:, type:, updated_at:, created_by: nil, created_by_user_id: nil, updated_by: nil, updated_by_user_id: nil) ⇒ Object
A HubSpot property option
|
|
# File 'lib/hubspot_sdk/models/cms/option.rb', line 71
|
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the option was created, in ISO 8601 format.
17 |
# File 'lib/hubspot_sdk/models/cms/option.rb', line 17 required :created_at, Time, api_name: :createdAt |
#created_by ⇒ HubSpotSDK::Models::Cms::SimpleUser?
52 |
# File 'lib/hubspot_sdk/models/cms/option.rb', line 52 optional :created_by, -> { HubSpotSDK::Cms::SimpleUser }, api_name: :createdBy |
#created_by_user_id ⇒ Integer?
The ID of the user who created the option.
58 |
# File 'lib/hubspot_sdk/models/cms/option.rb', line 58 optional :created_by_user_id, Integer, api_name: :createdByUserId |
#id ⇒ String
The unique ID of the option.
11 |
# File 'lib/hubspot_sdk/models/cms/option.rb', line 11 required :id, String |
#label ⇒ String
A user-friendly label that identifies the option.
23 |
# File 'lib/hubspot_sdk/models/cms/option.rb', line 23 required :label, String |
#name ⇒ String
An internal name assigned to the option, distinct from the label.
29 |
# File 'lib/hubspot_sdk/models/cms/option.rb', line 29 required :name, String |
#order ⇒ Integer
The order in which the option appears, represented as an integer.
35 |
# File 'lib/hubspot_sdk/models/cms/option.rb', line 35 required :order, Integer |
#type ⇒ String
Indicates the category or data type of the option (e.g., string, number).
41 |
# File 'lib/hubspot_sdk/models/cms/option.rb', line 41 required :type, String |
#updated_at ⇒ Time
The timestamp when the option was last updated, in ISO 8601 format.
47 |
# File 'lib/hubspot_sdk/models/cms/option.rb', line 47 required :updated_at, Time, api_name: :updatedAt |
#updated_by ⇒ HubSpotSDK::Models::Cms::SimpleUser?
63 |
# File 'lib/hubspot_sdk/models/cms/option.rb', line 63 optional :updated_by, -> { HubSpotSDK::Cms::SimpleUser }, api_name: :updatedBy |
#updated_by_user_id ⇒ Integer?
The ID of the user who last updated the option.
69 |
# File 'lib/hubspot_sdk/models/cms/option.rb', line 69 optional :updated_by_user_id, Integer, api_name: :updatedByUserId |