Class: HubSpotSDK::Models::Cms::Pages::LandingPageListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::Pages::LandingPageListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/cms/pages/landing_page_list_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
A cursor token for pagination.
-
#archived ⇒ Boolean?
Whether to return only results that have been archived.
-
#created_after ⇒ Time?
Filter landing pages created after a specific date and time.
-
#created_at ⇒ Time?
Filter landing pages by their creation timestamp.
-
#created_before ⇒ Time?
Filter landing pages created before a specific date and time.
-
#limit ⇒ Integer?
The maximum number of results to display per page.
-
#property ⇒ String?
Specify which properties of the landing pages to include in the response.
-
#sort ⇒ Array<String>?
Specify the order in which results are returned.
-
#updated_after ⇒ Time?
Filter landing pages updated after a specific date and time.
-
#updated_at ⇒ Time?
Filter landing pages by their last updated timestamp.
-
#updated_before ⇒ Time?
Filter landing pages updated before a specific date and time.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(after: nil, archived: nil, created_after: nil, created_at: nil, created_before: nil, limit: nil, property: nil, sort: nil, updated_after: nil, updated_at: nil, updated_before: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see LandingPageListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, archived: nil, created_after: nil, created_at: nil, created_before: nil, limit: nil, property: nil, sort: nil, updated_after: nil, updated_at: nil, updated_before: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::Pages::LandingPageListParams for more details.
|
|
# File 'lib/hubspot_sdk/models/cms/pages/landing_page_list_params.rb', line 79
|
Instance Attribute Details
#after ⇒ String?
A cursor token for pagination. Use the value from the previous response’s paging.next.after field.
17 |
# File 'lib/hubspot_sdk/models/cms/pages/landing_page_list_params.rb', line 17 optional :after, String |
#archived ⇒ Boolean?
Whether to return only results that have been archived.
23 |
# File 'lib/hubspot_sdk/models/cms/pages/landing_page_list_params.rb', line 23 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#created_after ⇒ Time?
Filter landing pages created after a specific date and time.
29 |
# File 'lib/hubspot_sdk/models/cms/pages/landing_page_list_params.rb', line 29 optional :created_after, Time |
#created_at ⇒ Time?
Filter landing pages by their creation timestamp.
35 |
# File 'lib/hubspot_sdk/models/cms/pages/landing_page_list_params.rb', line 35 optional :created_at, Time |
#created_before ⇒ Time?
Filter landing pages created before a specific date and time.
41 |
# File 'lib/hubspot_sdk/models/cms/pages/landing_page_list_params.rb', line 41 optional :created_before, Time |
#limit ⇒ Integer?
The maximum number of results to display per page.
47 |
# File 'lib/hubspot_sdk/models/cms/pages/landing_page_list_params.rb', line 47 optional :limit, Integer |
#property ⇒ String?
Specify which properties of the landing pages to include in the response.
53 |
# File 'lib/hubspot_sdk/models/cms/pages/landing_page_list_params.rb', line 53 optional :property, String |
#sort ⇒ Array<String>?
Specify the order in which results are returned. Accepts an array of strings.
59 |
# File 'lib/hubspot_sdk/models/cms/pages/landing_page_list_params.rb', line 59 optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String] |
#updated_after ⇒ Time?
Filter landing pages updated after a specific date and time.
65 |
# File 'lib/hubspot_sdk/models/cms/pages/landing_page_list_params.rb', line 65 optional :updated_after, Time |
#updated_at ⇒ Time?
Filter landing pages by their last updated timestamp.
71 |
# File 'lib/hubspot_sdk/models/cms/pages/landing_page_list_params.rb', line 71 optional :updated_at, Time |
#updated_before ⇒ Time?
Filter landing pages updated before a specific date and time.
77 |
# File 'lib/hubspot_sdk/models/cms/pages/landing_page_list_params.rb', line 77 optional :updated_before, Time |