Class: HubSpotSDK::Models::Cms::Pages::WebsitePageListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::Pages::WebsitePageListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
-
#archived ⇒ Boolean?
Whether to return only results that have been archived.
-
#created_after ⇒ Time?
Filter pages created after a specific date and time.
-
#created_at ⇒ Time?
Filter pages by the exact creation timestamp.
-
#created_before ⇒ Time?
Filter pages created before a specific date-time.
-
#limit ⇒ Integer?
The maximum number of results to display per page.
-
#property ⇒ String?
Specify properties to include in the response.
-
#sort ⇒ Array<String>?
Specify the order of results.
-
#updated_after ⇒ Time?
Filter pages updated after the specified date-time.
-
#updated_at ⇒ Time?
Filter pages by their exact update timestamp in ISO 8601 format.
-
#updated_before ⇒ Time?
Filter pages updated before a specific date and time.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(after: nil, archived: nil, created_after: nil, created_at: nil, created_before: nil, limit: nil, property: nil, sort: nil, updated_after: nil, updated_at: nil, updated_before: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebsitePageListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, archived: nil, created_after: nil, created_at: nil, created_before: nil, limit: nil, property: nil, sort: nil, updated_after: nil, updated_at: nil, updated_before: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::Pages::WebsitePageListParams for more details.
|
|
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 81
|
Instance Attribute Details
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
18 |
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 18 optional :after, String |
#archived ⇒ Boolean?
Whether to return only results that have been archived.
24 |
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 24 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#created_after ⇒ Time?
Filter pages created after a specific date and time.
30 |
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 30 optional :created_after, Time |
#created_at ⇒ Time?
Filter pages by the exact creation timestamp. Format is date-time.
36 |
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 36 optional :created_at, Time |
#created_before ⇒ Time?
Filter pages created before a specific date-time.
42 |
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 42 optional :created_before, Time |
#limit ⇒ Integer?
The maximum number of results to display per page.
48 |
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 48 optional :limit, Integer |
#property ⇒ String?
Specify properties to include in the response.
54 |
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 54 optional :property, String |
#sort ⇒ Array<String>?
Specify the order of results. Accepts an array of field names to sort by.
60 |
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 60 optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String] |
#updated_after ⇒ Time?
Filter pages updated after the specified date-time.
66 |
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 66 optional :updated_after, Time |
#updated_at ⇒ Time?
Filter pages by their exact update timestamp in ISO 8601 format.
72 |
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 72 optional :updated_at, Time |
#updated_before ⇒ Time?
Filter pages updated before a specific date and time. Format should be date-time.
79 |
# File 'lib/hubspot_sdk/models/cms/pages/website_page_list_params.rb', line 79 optional :updated_before, Time |