Class: HubSpotSDK::Models::Cms::PagesPage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::PagesPage
- Defined in:
- lib/hubspot_sdk/models/cms/pages_page.rb
Direct Known Subclasses
HubSpotSDK::Models::Cms::Pages::LandingPageCreateParams, HubSpotSDK::Models::Cms::Pages::LandingPageUpdateParams, HubSpotSDK::Models::Cms::Pages::LandingPages::DraftUpdateParams, HubSpotSDK::Models::Cms::Pages::SitePageCreateParams, HubSpotSDK::Models::Cms::Pages::SitePageUpdateParams, HubSpotSDK::Models::Cms::Pages::SitePages::DraftUpdateDraftParams
Defined Under Namespace
Modules: AbStatus, ContentTypeCategory, CurrentState, Language
Instance Attribute Summary collapse
-
#ab_status ⇒ Symbol, HubSpotSDK::Models::Cms::PagesPage::AbStatus
The status of the AB test associated with this page, if applicable.
-
#ab_test_id ⇒ String
The ID of the AB test associated with this page, if applicable.
-
#archived_at ⇒ Time
The timestamp (ISO8601 format) when this page was deleted.
-
#archived_in_dashboard ⇒ Boolean
If True, the page will not show up in your dashboard, although the page could still be live.
-
#attached_stylesheets ⇒ Array<Hash{Symbol=>Object}>
List of stylesheets to attach to this page.
-
#author_name ⇒ String
The name of the user that updated this page.
-
#campaign ⇒ String
The GUID of the marketing campaign this page is a part of.
-
#category_id ⇒ Integer
ID of the type of object this is.
-
#content_group_id ⇒ String
The unique identifier for the content group associated with the page.
-
#content_type_category ⇒ Symbol, HubSpotSDK::Models::Cms::PagesPage::ContentTypeCategory
An ENUM descibing the type of this object.
-
#created ⇒ Time
The timestamp indicating when the page was created.
-
#created_by_id ⇒ String
The ID of the user that created this page.
-
#current_state ⇒ Symbol, HubSpotSDK::Models::Cms::PagesPage::CurrentState
A generated ENUM descibing the current state of this page.
-
#currently_published ⇒ Boolean
Indicates whether the page is currently published.
-
#domain ⇒ String
The domain this page will resolve to.
-
#dynamic_page_data_source_id ⇒ String
The identifier for the data source used by the dynamic page.
-
#dynamic_page_data_source_type ⇒ Integer
The type of data source used by the dynamic page.
-
#dynamic_page_hub_db_table_id ⇒ String
The ID of the HubDB table this page references, if applicable.
-
#enable_domain_stylesheets ⇒ Boolean
Boolean to determine whether or not the styles from the template should be applied.
-
#enable_layout_stylesheets ⇒ Boolean
Boolean to determine whether or not the styles from the template should be applied.
-
#featured_image ⇒ String
The featuredImage of this page.
-
#featured_image_alt_text ⇒ String
Alt Text of the featuredImage.
-
#folder_id ⇒ String
The ID of the associated folder this landing page is organized under in the app dashboard.
-
#footer_html ⇒ String
Custom HTML for embed codes, javascript that should be placed before the </body> tag of the page.
-
#head_html ⇒ String
Custom HTML for embed codes, javascript, etc.
-
#html_title ⇒ String
The html title of this page.
-
#id ⇒ String
The unique ID of the page.
-
#include_default_custom_css ⇒ Boolean
Boolean to determine whether or not the Primary CSS Files should be applied.
-
#language ⇒ Symbol, HubSpotSDK::Models::Cms::PagesPage::Language
The explicitly defined ISO 639 language code of the page.
-
#layout_sections ⇒ Hash{Symbol=>HubSpotSDK::Models::Cms::LayoutSection}
A structure detailing the layout sections of the page.
-
#link_rel_canonical_url ⇒ String
Optional override to set the URL to be used in the rel=canonical link tag on the page.
-
#mab_experiment_id ⇒ String
The ID of the MAB test (or dynamic test) associated with this page, if applicable.
-
#meta_description ⇒ String
A description that goes in <meta> tag on the page.
-
#name ⇒ String
The internal name of the page.
-
#page_expiry_date ⇒ Integer
The date at which this page should expire and begin redirecting to another url or page.
-
#page_expiry_enabled ⇒ Boolean
Boolean describing if the page expiration feature is enabled for this page.
-
#page_expiry_redirect_id ⇒ Integer
The ID of another page this page’s url should redirect to once this page expires.
-
#page_expiry_redirect_url ⇒ String
The URL this page’s url should redirect to once this page expires.
-
#page_redirected ⇒ Boolean
A generated Boolean describing whether or not this page is currently expired and being redirected.
-
#password ⇒ String
Set this to create a password protected page.
-
#public_access_rules ⇒ Array<Object>
Rules for require member registration to access private content.
-
#public_access_rules_enabled ⇒ Boolean
Boolean to determine whether or not to respect publicAccessRules.
-
#publish_date ⇒ Time
The date (ISO8601 format) the page is to be published at.
-
#publish_immediately ⇒ Boolean
Set this to true if you want to be published immediately when the schedule publish endpoint is called, and to ignore the publish_date setting.
-
#slug ⇒ String
The path of the this page.
-
#state ⇒ String
An ENUM descibing the current state of this page.
-
#subcategory ⇒ String
Details the type of page this is.
-
#template_path ⇒ String
String detailing the path of the template used for this page.
-
#theme_settings_values ⇒ Hash{Symbol=>Object}
A collection of settings specific to the theme applied to the page.
-
#translated_from_id ⇒ String
ID of the primary page this object was translated from.
-
#translations ⇒ Hash{Symbol=>HubSpotSDK::Models::Cms::ContentLanguageVariation}
A map of translations for the page, each associated with a specific language variation.
-
#updated ⇒ Time
The timestamp indicating when the page was last updated.
-
#updated_by_id ⇒ String
The ID of the user that updated this page.
-
#url ⇒ String
A generated field representing the URL of this page.
-
#use_featured_image ⇒ Boolean
Boolean to determine if this page should use a featuredImage.
-
#widget_containers ⇒ Hash{Symbol=>Object}
A data structure containing the data for all the modules inside the containers for this page.
-
#widgets ⇒ Hash{Symbol=>Object}
A data structure containing the data for all the modules for this page.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, ab_status:, ab_test_id:, archived_at:, archived_in_dashboard:, attached_stylesheets:, author_name:, campaign:, category_id:, content_group_id:, content_type_category:, created:, created_by_id:, currently_published:, current_state:, domain:, dynamic_page_data_source_id:, dynamic_page_data_source_type:, dynamic_page_hub_db_table_id:, enable_domain_stylesheets:, enable_layout_stylesheets:, featured_image:, featured_image_alt_text:, folder_id:, footer_html:, head_html:, html_title:, include_default_custom_css:, language:, layout_sections:, link_rel_canonical_url:, mab_experiment_id:, meta_description:, name:, page_expiry_date:, page_expiry_enabled:, page_expiry_redirect_id:, page_expiry_redirect_url:, page_redirected:, password:, public_access_rules:, public_access_rules_enabled:, publish_date:, publish_immediately:, slug:, state:, subcategory:, template_path:, theme_settings_values:, translated_from_id:, translations:, updated:, updated_by_id:, url:, use_featured_image:, widget_containers:, widgets:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PagesPage for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, ab_status:, ab_test_id:, archived_at:, archived_in_dashboard:, attached_stylesheets:, author_name:, campaign:, category_id:, content_group_id:, content_type_category:, created:, created_by_id:, currently_published:, current_state:, domain:, dynamic_page_data_source_id:, dynamic_page_data_source_type:, dynamic_page_hub_db_table_id:, enable_domain_stylesheets:, enable_layout_stylesheets:, featured_image:, featured_image_alt_text:, folder_id:, footer_html:, head_html:, html_title:, include_default_custom_css:, language:, layout_sections:, link_rel_canonical_url:, mab_experiment_id:, meta_description:, name:, page_expiry_date:, page_expiry_enabled:, page_expiry_redirect_id:, page_expiry_redirect_url:, page_redirected:, password:, public_access_rules:, public_access_rules_enabled:, publish_date:, publish_immediately:, slug:, state:, subcategory:, template_path:, theme_settings_values:, translated_from_id:, translations:, updated:, updated_by_id:, url:, use_featured_image:, widget_containers:, widgets:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::PagesPage for more details.
|
|
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 395
|
Instance Attribute Details
#ab_status ⇒ Symbol, HubSpotSDK::Models::Cms::PagesPage::AbStatus
The status of the AB test associated with this page, if applicable
17 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 17 required :ab_status, enum: -> { HubSpotSDK::Cms::PagesPage::AbStatus }, api_name: :abStatus |
#ab_test_id ⇒ String
The ID of the AB test associated with this page, if applicable
23 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 23 required :ab_test_id, String, api_name: :abTestId |
#archived_at ⇒ Time
The timestamp (ISO8601 format) when this page was deleted.
29 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 29 required :archived_at, Time, api_name: :archivedAt |
#archived_in_dashboard ⇒ Boolean
If True, the page will not show up in your dashboard, although the page could still be live.
36 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 36 required :archived_in_dashboard, HubSpotSDK::Internal::Type::Boolean, api_name: :archivedInDashboard |
#attached_stylesheets ⇒ Array<Hash{Symbol=>Object}>
List of stylesheets to attach to this page. These stylesheets are attached to just this page. Order of precedence is bottom to top, just like in the HTML.
43 44 45 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 43 required :attached_stylesheets, HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown]], api_name: :attachedStylesheets |
#author_name ⇒ String
The name of the user that updated this page.
51 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 51 required :author_name, String, api_name: :authorName |
#campaign ⇒ String
The GUID of the marketing campaign this page is a part of.
57 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 57 required :campaign, String |
#category_id ⇒ Integer
ID of the type of object this is. Should always .
63 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 63 required :category_id, Integer, api_name: :categoryId |
#content_group_id ⇒ String
The unique identifier for the content group associated with the page.
69 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 69 required :content_group_id, String, api_name: :contentGroupId |
#content_type_category ⇒ Symbol, HubSpotSDK::Models::Cms::PagesPage::ContentTypeCategory
An ENUM descibing the type of this object. Should be either LANDING_PAGE or SITE_PAGE.
76 77 78 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 76 required :content_type_category, enum: -> { HubSpotSDK::Cms::PagesPage::ContentTypeCategory }, api_name: :contentTypeCategory |
#created ⇒ Time
The timestamp indicating when the page was created.
84 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 84 required :created, Time |
#created_by_id ⇒ String
The ID of the user that created this page.
90 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 90 required :created_by_id, String, api_name: :createdById |
#current_state ⇒ Symbol, HubSpotSDK::Models::Cms::PagesPage::CurrentState
A generated ENUM descibing the current state of this page.
102 103 104 105 106 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 102 required :current_state, enum: -> { HubSpotSDK::Cms::PagesPage::CurrentState }, api_name: :currentState |
#currently_published ⇒ Boolean
Indicates whether the page is currently published.
96 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 96 required :currently_published, HubSpotSDK::Internal::Type::Boolean, api_name: :currentlyPublished |
#domain ⇒ String
The domain this page will resolve to. If null, the page will default to the primary domain for this content type.
113 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 113 required :domain, String |
#dynamic_page_data_source_id ⇒ String
The identifier for the data source used by the dynamic page.
119 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 119 required :dynamic_page_data_source_id, String, api_name: :dynamicPageDataSourceId |
#dynamic_page_data_source_type ⇒ Integer
The type of data source used by the dynamic page.
125 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 125 required :dynamic_page_data_source_type, Integer, api_name: :dynamicPageDataSourceType |
#dynamic_page_hub_db_table_id ⇒ String
The ID of the HubDB table this page references, if applicable
131 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 131 required :dynamic_page_hub_db_table_id, String, api_name: :dynamicPageHubDbTableId |
#enable_domain_stylesheets ⇒ Boolean
Boolean to determine whether or not the styles from the template should be applied.
138 139 140 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 138 required :enable_domain_stylesheets, HubSpotSDK::Internal::Type::Boolean, api_name: :enableDomainStylesheets |
#enable_layout_stylesheets ⇒ Boolean
Boolean to determine whether or not the styles from the template should be applied.
147 148 149 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 147 required :enable_layout_stylesheets, HubSpotSDK::Internal::Type::Boolean, api_name: :enableLayoutStylesheets |
#featured_image ⇒ String
The featuredImage of this page.
155 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 155 required :featured_image, String, api_name: :featuredImage |
#featured_image_alt_text ⇒ String
Alt Text of the featuredImage.
161 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 161 required :featured_image_alt_text, String, api_name: :featuredImageAltText |
#folder_id ⇒ String
The ID of the associated folder this landing page is organized under in the app dashboard.
168 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 168 required :folder_id, String, api_name: :folderId |
#footer_html ⇒ String
Custom HTML for embed codes, javascript that should be placed before the </body> tag of the page.
175 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 175 required :footer_html, String, api_name: :footerHtml |
#head_html ⇒ String
Custom HTML for embed codes, javascript, etc. that goes in the <head> tag of the page.
182 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 182 required :head_html, String, api_name: :headHtml |
#html_title ⇒ String
The html title of this page.
188 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 188 required :html_title, String, api_name: :htmlTitle |
#id ⇒ String
The unique ID of the page.
11 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 11 required :id, String |
#include_default_custom_css ⇒ Boolean
Boolean to determine whether or not the Primary CSS Files should be applied.
194 195 196 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 194 required :include_default_custom_css, HubSpotSDK::Internal::Type::Boolean, api_name: :includeDefaultCustomCss |
#language ⇒ Symbol, HubSpotSDK::Models::Cms::PagesPage::Language
The explicitly defined ISO 639 language code of the page. If null, the page will default to the language of the Domain.
203 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 203 required :language, enum: -> { HubSpotSDK::Cms::PagesPage::Language } |
#layout_sections ⇒ Hash{Symbol=>HubSpotSDK::Models::Cms::LayoutSection}
A structure detailing the layout sections of the page.
209 210 211 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 209 required :layout_sections, -> { HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Cms::LayoutSection] }, api_name: :layoutSections |
#link_rel_canonical_url ⇒ String
Optional override to set the URL to be used in the rel=canonical link tag on the page.
218 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 218 required :link_rel_canonical_url, String, api_name: :linkRelCanonicalUrl |
#mab_experiment_id ⇒ String
The ID of the MAB test (or dynamic test) associated with this page, if applicable
225 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 225 required :mab_experiment_id, String, api_name: :mabExperimentId |
#meta_description ⇒ String
A description that goes in <meta> tag on the page.
231 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 231 required :meta_description, String, api_name: :metaDescription |
#name ⇒ String
The internal name of the page.
237 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 237 required :name, String |
#page_expiry_date ⇒ Integer
The date at which this page should expire and begin redirecting to another url or page.
244 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 244 required :page_expiry_date, Integer, api_name: :pageExpiryDate |
#page_expiry_enabled ⇒ Boolean
Boolean describing if the page expiration feature is enabled for this page
250 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 250 required :page_expiry_enabled, HubSpotSDK::Internal::Type::Boolean, api_name: :pageExpiryEnabled |
#page_expiry_redirect_id ⇒ Integer
The ID of another page this page’s url should redirect to once this page expires. Should only set this or pageExpiryRedirectUrl.
257 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 257 required :page_expiry_redirect_id, Integer, api_name: :pageExpiryRedirectId |
#page_expiry_redirect_url ⇒ String
The URL this page’s url should redirect to once this page expires. Should only set this or pageExpiryRedirectId.
264 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 264 required :page_expiry_redirect_url, String, api_name: :pageExpiryRedirectUrl |
#page_redirected ⇒ Boolean
A generated Boolean describing whether or not this page is currently expired and being redirected.
271 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 271 required :page_redirected, HubSpotSDK::Internal::Type::Boolean, api_name: :pageRedirected |
#password ⇒ String
Set this to create a password protected page. Entering the password will be required to view the page.
278 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 278 required :password, String |
#public_access_rules ⇒ Array<Object>
Rules for require member registration to access private content.
284 285 286 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 284 required :public_access_rules, HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Internal::Type::Unknown], api_name: :publicAccessRules |
#public_access_rules_enabled ⇒ Boolean
Boolean to determine whether or not to respect publicAccessRules.
292 293 294 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 292 required :public_access_rules_enabled, HubSpotSDK::Internal::Type::Boolean, api_name: :publicAccessRulesEnabled |
#publish_date ⇒ Time
The date (ISO8601 format) the page is to be published at.
300 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 300 required :publish_date, Time, api_name: :publishDate |
#publish_immediately ⇒ Boolean
Set this to true if you want to be published immediately when the schedule publish endpoint is called, and to ignore the publish_date setting.
307 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 307 required :publish_immediately, HubSpotSDK::Internal::Type::Boolean, api_name: :publishImmediately |
#slug ⇒ String
The path of the this page. This field is appended to the domain to construct the url of this page.
314 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 314 required :slug, String |
#state ⇒ String
An ENUM descibing the current state of this page.
320 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 320 required :state, String |
#subcategory ⇒ String
Details the type of page this is. Should always be landing_page or site_page
326 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 326 required :subcategory, String |
#template_path ⇒ String
String detailing the path of the template used for this page.
332 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 332 required :template_path, String, api_name: :templatePath |
#theme_settings_values ⇒ Hash{Symbol=>Object}
A collection of settings specific to the theme applied to the page.
338 339 340 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 338 required :theme_settings_values, HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown], api_name: :themeSettingsValues |
#translated_from_id ⇒ String
ID of the primary page this object was translated from.
346 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 346 required :translated_from_id, String, api_name: :translatedFromId |
#translations ⇒ Hash{Symbol=>HubSpotSDK::Models::Cms::ContentLanguageVariation}
A map of translations for the page, each associated with a specific language variation.
353 354 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 353 required :translations, -> { HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Cms::ContentLanguageVariation] } |
#updated ⇒ Time
The timestamp indicating when the page was last updated.
360 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 360 required :updated, Time |
#updated_by_id ⇒ String
The ID of the user that updated this page.
366 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 366 required :updated_by_id, String, api_name: :updatedById |
#url ⇒ String
A generated field representing the URL of this page.
372 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 372 required :url, String |
#use_featured_image ⇒ Boolean
Boolean to determine if this page should use a featuredImage.
378 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 378 required :use_featured_image, HubSpotSDK::Internal::Type::Boolean, api_name: :useFeaturedImage |
#widget_containers ⇒ Hash{Symbol=>Object}
A data structure containing the data for all the modules inside the containers for this page. This will only be populated if the page has widget containers.
385 386 387 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 385 required :widget_containers, HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown], api_name: :widgetContainers |
#widgets ⇒ Hash{Symbol=>Object}
A data structure containing the data for all the modules for this page.
393 |
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 393 required :widgets, HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/cms/pages_page.rb', line 528
|