Class: HubSpotSDK::Models::Cms::PublicSearchResults
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::PublicSearchResults
- Defined in:
- lib/hubspot_sdk/models/cms/public_search_results.rb
Overview
Instance Attribute Summary collapse
-
#limit ⇒ Integer
The number of results returned in a single response.
-
#offset ⇒ Integer
The starting point for the next set of results in pagination.
-
#page ⇒ Integer
The current page number in the paginated results.
- #results ⇒ Array<HubSpotSDK::Models::Cms::ContentSearchResult>
-
#search_term ⇒ String?
The term used in the search query.
-
#total ⇒ Integer
The total number of results found for the search term.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(limit:, offset:, page:, results:, total:, search_term: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/cms/public_search_results.rb', line 43
|
Instance Attribute Details
#limit ⇒ Integer
The number of results returned in a single response.
12 |
# File 'lib/hubspot_sdk/models/cms/public_search_results.rb', line 12 required :limit, Integer |
#offset ⇒ Integer
The starting point for the next set of results in pagination.
18 |
# File 'lib/hubspot_sdk/models/cms/public_search_results.rb', line 18 required :offset, Integer |
#page ⇒ Integer
The current page number in the paginated results.
24 |
# File 'lib/hubspot_sdk/models/cms/public_search_results.rb', line 24 required :page, Integer |
#results ⇒ Array<HubSpotSDK::Models::Cms::ContentSearchResult>
29 |
# File 'lib/hubspot_sdk/models/cms/public_search_results.rb', line 29 required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Cms::ContentSearchResult] } |
#search_term ⇒ String?
The term used in the search query.
41 |
# File 'lib/hubspot_sdk/models/cms/public_search_results.rb', line 41 optional :search_term, String, api_name: :searchTerm |
#total ⇒ Integer
The total number of results found for the search term.
35 |
# File 'lib/hubspot_sdk/models/cms/public_search_results.rb', line 35 required :total, Integer |