Class: HubSpotSDK::Models::Cms::URLMappingCreateRequestBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::URLMappingCreateRequestBody
- Defined in:
- lib/hubspot_sdk/models/cms/url_mapping_create_request_body.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#destination ⇒ String
The destination URL, where the target URL should be redirected if it matches the ‘routePrefix`.
-
#is_match_full_url ⇒ Boolean?
Whether the ‘routePrefix` should match on the entire URL, including the domain.
-
#is_match_query_string ⇒ Boolean?
Whether the ‘routePrefix` should match on the entire URL path, including the query string.
-
#is_only_after_not_found ⇒ Boolean?
Whether the URL redirect mapping should apply only if a live page on the URL isn’t found.
-
#is_pattern ⇒ Boolean?
Whether the ‘routePrefix` should match based on pattern.
-
#is_protocol_agnostic ⇒ Boolean?
Whether the ‘routePrefix` should match both HTTP and HTTPS protocols.
-
#is_trailing_slash_optional ⇒ Boolean?
Whether a trailing slash will be ignored.
-
#precedence ⇒ Integer?
Used to prioritize URL redirection.
-
#redirect_style ⇒ Integer
The type of redirect to create.
-
#route_prefix ⇒ String
The target incoming URL, path, or pattern to match for redirection.
Instance Method Summary collapse
-
#initialize(destination:, redirect_style:, route_prefix:, is_match_full_url: nil, is_match_query_string: nil, is_only_after_not_found: nil, is_pattern: nil, is_protocol_agnostic: nil, is_trailing_slash_optional: nil, precedence: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see URLMappingCreateRequestBody for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(destination:, redirect_style:, route_prefix:, is_match_full_url: nil, is_match_query_string: nil, is_only_after_not_found: nil, is_pattern: nil, is_protocol_agnostic: nil, is_trailing_slash_optional: nil, precedence: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::URLMappingCreateRequestBody for more details.
|
|
# File 'lib/hubspot_sdk/models/cms/url_mapping_create_request_body.rb', line 76
|
Instance Attribute Details
#destination ⇒ String
The destination URL, where the target URL should be redirected if it matches the ‘routePrefix`.
12 |
# File 'lib/hubspot_sdk/models/cms/url_mapping_create_request_body.rb', line 12 required :destination, String |
#is_match_full_url ⇒ Boolean?
Whether the ‘routePrefix` should match on the entire URL, including the domain.
32 |
# File 'lib/hubspot_sdk/models/cms/url_mapping_create_request_body.rb', line 32 optional :is_match_full_url, HubSpotSDK::Internal::Type::Boolean, api_name: :isMatchFullUrl |
#is_match_query_string ⇒ Boolean?
Whether the ‘routePrefix` should match on the entire URL path, including the query string.
39 |
# File 'lib/hubspot_sdk/models/cms/url_mapping_create_request_body.rb', line 39 optional :is_match_query_string, HubSpotSDK::Internal::Type::Boolean, api_name: :isMatchQueryString |
#is_only_after_not_found ⇒ Boolean?
Whether the URL redirect mapping should apply only if a live page on the URL isn’t found. If False, the URL redirect mapping will take precedence over any existing page.
47 |
# File 'lib/hubspot_sdk/models/cms/url_mapping_create_request_body.rb', line 47 optional :is_only_after_not_found, HubSpotSDK::Internal::Type::Boolean, api_name: :isOnlyAfterNotFound |
#is_pattern ⇒ Boolean?
Whether the ‘routePrefix` should match based on pattern.
53 |
# File 'lib/hubspot_sdk/models/cms/url_mapping_create_request_body.rb', line 53 optional :is_pattern, HubSpotSDK::Internal::Type::Boolean, api_name: :isPattern |
#is_protocol_agnostic ⇒ Boolean?
Whether the ‘routePrefix` should match both HTTP and HTTPS protocols.
59 |
# File 'lib/hubspot_sdk/models/cms/url_mapping_create_request_body.rb', line 59 optional :is_protocol_agnostic, HubSpotSDK::Internal::Type::Boolean, api_name: :isProtocolAgnostic |
#is_trailing_slash_optional ⇒ Boolean?
Whether a trailing slash will be ignored.
65 66 67 |
# File 'lib/hubspot_sdk/models/cms/url_mapping_create_request_body.rb', line 65 optional :is_trailing_slash_optional, HubSpotSDK::Internal::Type::Boolean, api_name: :isTrailingSlashOptional |
#precedence ⇒ Integer?
Used to prioritize URL redirection. If a given URL matches more than one redirect, the one with the lower precedence will be used.
74 |
# File 'lib/hubspot_sdk/models/cms/url_mapping_create_request_body.rb', line 74 optional :precedence, Integer |
#redirect_style ⇒ Integer
The type of redirect to create. Options include: 301 (permanent), 302 (temporary), or 305 (proxy). Find more details [here](knowledge.hubspot.com/cos-general/how-to-redirect-a-hubspot-page).
20 |
# File 'lib/hubspot_sdk/models/cms/url_mapping_create_request_body.rb', line 20 required :redirect_style, Integer, api_name: :redirectStyle |
#route_prefix ⇒ String
The target incoming URL, path, or pattern to match for redirection.
26 |
# File 'lib/hubspot_sdk/models/cms/url_mapping_create_request_body.rb', line 26 required :route_prefix, String, api_name: :routePrefix |