Class: HubSpotSDK::Models::Cms::URLMappingsURLMapping
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Cms::URLMappingsURLMapping
- Defined in:
- lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb
Direct Known Subclasses
Defined Under Namespace
Modules: CosObjectType
Instance Attribute Summary collapse
-
#cdn_purge_embargo_time ⇒ Integer
A Unix timestamp in milliseconds indicating the embargo time for CDN purge related to the URL mapping.
-
#content_group_id ⇒ Integer
A 64-bit integer representing the content group associated with the URL mapping.
-
#cos_object_type ⇒ Symbol, HubSpotSDK::Models::Cms::URLMappingsURLMapping::CosObjectType
A string representing the type of content object associated with the URL mapping.
-
#created ⇒ Integer
A Unix timestamp in milliseconds indicating when the URL mapping was created.
-
#created_by_id ⇒ Integer
The identifier of the user who created the URL mapping.
-
#deleted_at ⇒ Integer
A Unix timestamp in milliseconds indicating when the URL mapping was deleted.
-
#destination ⇒ String
The destination URL to which the routePrefix is redirected.
-
#id ⇒ Integer
The unique identifier for the URL mapping, represented as a 64-bit integer.
-
#internally_created ⇒ Boolean
A boolean indicating if the URL mapping was created internally by the system.
-
#is_active ⇒ Boolean
A boolean indicating if the URL mapping is currently active.
-
#is_match_full_url ⇒ Boolean
A boolean indicating if the full URL should be matched.
-
#is_match_query_string ⇒ Boolean
A boolean indicating if the query string should be matched.
-
#is_only_after_not_found ⇒ Boolean
A boolean indicating if the mapping should only be applied after a 404 Not Found response.
-
#is_pattern ⇒ Boolean
A boolean indicating if the routePrefix is a pattern.
-
#is_protocol_agnostic ⇒ Boolean
A boolean indicating if the mapping should ignore the URL protocol (http/https).
-
#is_regex ⇒ Boolean
A boolean indicating if the routePrefix should be treated as a regular expression.
-
#is_trailing_slash_optional ⇒ Boolean
A boolean indicating if the trailing slash in the URL is optional.
-
#label ⇒ String
A label for the URL mapping.
-
#name ⇒ String
The name of the URL mapping.
-
#note ⇒ String
A string containing notes about the URL mapping.
-
#portal_id ⇒ Integer
The identifier for the HubSpot portal associated with this URL mapping.
-
#precedence ⇒ Integer
An integer representing the precedence of the URL mapping, used to determine order of evaluation.
-
#redirect_style ⇒ Integer
An integer representing the style of redirection used.
-
#route_prefix ⇒ String
The prefix of the URL path that is being mapped.
-
#updated ⇒ Integer
A Unix timestamp in milliseconds indicating when the URL mapping was last updated.
-
#updated_by_id ⇒ Integer
The identifier of the user who last updated the URL mapping.
Instance Method Summary collapse
-
#initialize(id:, cdn_purge_embargo_time:, content_group_id:, cos_object_type:, created:, created_by_id:, deleted_at:, destination:, internally_created:, is_active:, is_match_full_url:, is_match_query_string:, is_only_after_not_found:, is_pattern:, is_protocol_agnostic:, is_regex:, is_trailing_slash_optional:, label:, name:, note:, portal_id:, precedence:, redirect_style:, route_prefix:, updated:, updated_by_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see URLMappingsURLMapping for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, cdn_purge_embargo_time:, content_group_id:, cos_object_type:, created:, created_by_id:, deleted_at:, destination:, internally_created:, is_active:, is_match_full_url:, is_match_query_string:, is_only_after_not_found:, is_pattern:, is_protocol_agnostic:, is_regex:, is_trailing_slash_optional:, label:, name:, note:, portal_id:, precedence:, redirect_style:, route_prefix:, updated:, updated_by_id:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Cms::URLMappingsURLMapping for more details.
|
|
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 174
|
Instance Attribute Details
#cdn_purge_embargo_time ⇒ Integer
A Unix timestamp in milliseconds indicating the embargo time for CDN purge related to the URL mapping.
18 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 18 required :cdn_purge_embargo_time, Integer, api_name: :cdnPurgeEmbargoTime |
#content_group_id ⇒ Integer
A 64-bit integer representing the content group associated with the URL mapping.
24 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 24 required :content_group_id, Integer, api_name: :contentGroupId |
#cos_object_type ⇒ Symbol, HubSpotSDK::Models::Cms::URLMappingsURLMapping::CosObjectType
A string representing the type of content object associated with the URL mapping. Valid values include various content types such as ‘CONTENT’, ‘LAYOUT’, ‘FILE’, etc.
32 33 34 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 32 required :cos_object_type, enum: -> { HubSpotSDK::Cms::URLMappingsURLMapping::CosObjectType }, api_name: :cosObjectType |
#created ⇒ Integer
A Unix timestamp in milliseconds indicating when the URL mapping was created.
40 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 40 required :created, Integer |
#created_by_id ⇒ Integer
The identifier of the user who created the URL mapping.
46 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 46 required :created_by_id, Integer, api_name: :createdById |
#deleted_at ⇒ Integer
A Unix timestamp in milliseconds indicating when the URL mapping was deleted.
52 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 52 required :deleted_at, Integer, api_name: :deletedAt |
#destination ⇒ String
The destination URL to which the routePrefix is redirected.
58 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 58 required :destination, String |
#id ⇒ Integer
The unique identifier for the URL mapping, represented as a 64-bit integer.
11 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 11 required :id, Integer |
#internally_created ⇒ Boolean
A boolean indicating if the URL mapping was created internally by the system.
64 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 64 required :internally_created, HubSpotSDK::Internal::Type::Boolean, api_name: :internallyCreated |
#is_active ⇒ Boolean
A boolean indicating if the URL mapping is currently active.
70 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 70 required :is_active, HubSpotSDK::Internal::Type::Boolean, api_name: :isActive |
#is_match_full_url ⇒ Boolean
A boolean indicating if the full URL should be matched.
76 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 76 required :is_match_full_url, HubSpotSDK::Internal::Type::Boolean, api_name: :isMatchFullUrl |
#is_match_query_string ⇒ Boolean
A boolean indicating if the query string should be matched.
82 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 82 required :is_match_query_string, HubSpotSDK::Internal::Type::Boolean, api_name: :isMatchQueryString |
#is_only_after_not_found ⇒ Boolean
A boolean indicating if the mapping should only be applied after a 404 Not Found response.
89 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 89 required :is_only_after_not_found, HubSpotSDK::Internal::Type::Boolean, api_name: :isOnlyAfterNotFound |
#is_pattern ⇒ Boolean
A boolean indicating if the routePrefix is a pattern.
95 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 95 required :is_pattern, HubSpotSDK::Internal::Type::Boolean, api_name: :isPattern |
#is_protocol_agnostic ⇒ Boolean
A boolean indicating if the mapping should ignore the URL protocol (http/https).
101 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 101 required :is_protocol_agnostic, HubSpotSDK::Internal::Type::Boolean, api_name: :isProtocolAgnostic |
#is_regex ⇒ Boolean
A boolean indicating if the routePrefix should be treated as a regular expression.
108 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 108 required :is_regex, HubSpotSDK::Internal::Type::Boolean, api_name: :isRegex |
#is_trailing_slash_optional ⇒ Boolean
A boolean indicating if the trailing slash in the URL is optional.
114 115 116 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 114 required :is_trailing_slash_optional, HubSpotSDK::Internal::Type::Boolean, api_name: :isTrailingSlashOptional |
#label ⇒ String
A label for the URL mapping.
122 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 122 required :label, String |
#name ⇒ String
The name of the URL mapping.
128 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 128 required :name, String |
#note ⇒ String
A string containing notes about the URL mapping.
134 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 134 required :note, String |
#portal_id ⇒ Integer
The identifier for the HubSpot portal associated with this URL mapping.
140 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 140 required :portal_id, Integer, api_name: :portalId |
#precedence ⇒ Integer
An integer representing the precedence of the URL mapping, used to determine order of evaluation.
147 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 147 required :precedence, Integer |
#redirect_style ⇒ Integer
An integer representing the style of redirection used.
153 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 153 required :redirect_style, Integer, api_name: :redirectStyle |
#route_prefix ⇒ String
The prefix of the URL path that is being mapped.
159 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 159 required :route_prefix, String, api_name: :routePrefix |
#updated ⇒ Integer
A Unix timestamp in milliseconds indicating when the URL mapping was last updated.
166 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 166 required :updated, Integer |
#updated_by_id ⇒ Integer
The identifier of the user who last updated the URL mapping.
172 |
# File 'lib/hubspot_sdk/models/cms/url_mappings_url_mapping.rb', line 172 required :updated_by_id, Integer, api_name: :updatedById |