Class: HubSpotSDK::Models::CommunicationPreferences::LinkGenerationRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::CommunicationPreferences::LinkGenerationRequest
- Defined in:
- lib/hubspot_sdk/models/communication_preferences/link_generation_request.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#language ⇒ String?
The language in which the generated link should be presented, represented as a string.
-
#subscriber_id_string ⇒ String
A string representing the unique identifier of the subscriber.
-
#subscription_id ⇒ Integer?
The unique identifier for the subscription, represented as an integer in int64 format.
Instance Method Summary collapse
-
#initialize(subscriber_id_string:, language: nil, subscription_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see LinkGenerationRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(subscriber_id_string:, language: nil, subscription_id: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::CommunicationPreferences::LinkGenerationRequest for more details.
|
|
# File 'lib/hubspot_sdk/models/communication_preferences/link_generation_request.rb', line 28
|
Instance Attribute Details
#language ⇒ String?
The language in which the generated link should be presented, represented as a string.
19 |
# File 'lib/hubspot_sdk/models/communication_preferences/link_generation_request.rb', line 19 optional :language, String |
#subscriber_id_string ⇒ String
A string representing the unique identifier of the subscriber. This property is required.
12 |
# File 'lib/hubspot_sdk/models/communication_preferences/link_generation_request.rb', line 12 required :subscriber_id_string, String, api_name: :subscriberIdString |
#subscription_id ⇒ Integer?
The unique identifier for the subscription, represented as an integer in int64 format.
26 |
# File 'lib/hubspot_sdk/models/communication_preferences/link_generation_request.rb', line 26 optional :subscription_id, Integer, api_name: :subscriptionId |