Class: HubSpotSDK::Models::CommunicationPreferences::LinkGenerationResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::CommunicationPreferences::LinkGenerationResponse
- Defined in:
- lib/hubspot_sdk/models/communication_preferences/link_generation_response.rb
Overview
Instance Attribute Summary collapse
-
#manage_preferences_url ⇒ String
The URL where the subscriber can manage their communication preferences.
-
#subscriber_id_string ⇒ String
A string representing the unique identifier of the subscriber.
-
#unsubscribe_all_url ⇒ String
A string containing the URL for unsubscribing the subscriber from all communications.
-
#unsubscribe_single_url ⇒ String?
A string containing the URL to unsubscribe the subscriber from a single communication.
Instance Method Summary collapse
-
#initialize(manage_preferences_url:, subscriber_id_string:, unsubscribe_all_url:, unsubscribe_single_url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see LinkGenerationResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(manage_preferences_url:, subscriber_id_string:, unsubscribe_all_url:, unsubscribe_single_url: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::CommunicationPreferences::LinkGenerationResponse for more details.
|
|
# File 'lib/hubspot_sdk/models/communication_preferences/link_generation_response.rb', line 34
|
Instance Attribute Details
#manage_preferences_url ⇒ String
The URL where the subscriber can manage their communication preferences.
12 |
# File 'lib/hubspot_sdk/models/communication_preferences/link_generation_response.rb', line 12 required :manage_preferences_url, String, api_name: :managePreferencesUrl |
#subscriber_id_string ⇒ String
A string representing the unique identifier of the subscriber.
18 |
# File 'lib/hubspot_sdk/models/communication_preferences/link_generation_response.rb', line 18 required :subscriber_id_string, String, api_name: :subscriberIdString |
#unsubscribe_all_url ⇒ String
A string containing the URL for unsubscribing the subscriber from all communications.
25 |
# File 'lib/hubspot_sdk/models/communication_preferences/link_generation_response.rb', line 25 required :unsubscribe_all_url, String, api_name: :unsubscribeAllUrl |
#unsubscribe_single_url ⇒ String?
A string containing the URL to unsubscribe the subscriber from a single communication.
32 |
# File 'lib/hubspot_sdk/models/communication_preferences/link_generation_response.rb', line 32 optional :unsubscribe_single_url, String, api_name: :unsubscribeSingleUrl |