Class: HubSpotSDK::Models::CommunicationPreferences::PublicSubscriptionTranslation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::CommunicationPreferences::PublicSubscriptionTranslation
- Defined in:
- lib/hubspot_sdk/models/communication_preferences/public_subscription_translation.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Integer
The timestamp indicating when the subscription translation was created.
-
#description ⇒ String
A text description of the subscription translation.
-
#language_code ⇒ String
The code representing the language of the subscription translation.
-
#name ⇒ String
The name of the subscription translation.
-
#subscription_id ⇒ Integer
The unique identifier for the subscription associated with the translation.
-
#updated_at ⇒ Integer
The timestamp indicating when the subscription translation was last updated.
Instance Method Summary collapse
- #initialize(created_at:, description:, language_code:, name:, subscription_id:, updated_at:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(created_at:, description:, language_code:, name:, subscription_id:, updated_at:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/communication_preferences/public_subscription_translation.rb', line 43
|
Instance Attribute Details
#created_at ⇒ Integer
The timestamp indicating when the subscription translation was created.
11 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_subscription_translation.rb', line 11 required :created_at, Integer, api_name: :createdAt |
#description ⇒ String
A text description of the subscription translation.
17 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_subscription_translation.rb', line 17 required :description, String |
#language_code ⇒ String
The code representing the language of the subscription translation.
23 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_subscription_translation.rb', line 23 required :language_code, String, api_name: :languageCode |
#name ⇒ String
The name of the subscription translation.
29 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_subscription_translation.rb', line 29 required :name, String |
#subscription_id ⇒ Integer
The unique identifier for the subscription associated with the translation.
35 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_subscription_translation.rb', line 35 required :subscription_id, Integer, api_name: :subscriptionId |
#updated_at ⇒ Integer
The timestamp indicating when the subscription translation was last updated.
41 |
# File 'lib/hubspot_sdk/models/communication_preferences/public_subscription_translation.rb', line 41 required :updated_at, Integer, api_name: :updatedAt |