Class: HubSpotSDK::Models::CommunicationPreferences::SubscriptionDefinition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::CommunicationPreferences::SubscriptionDefinition
- Defined in:
- lib/hubspot_sdk/models/communication_preferences/subscription_definition.rb
Instance Attribute Summary collapse
-
#business_unit_id ⇒ Integer?
The ID of the business unit associated with the subscription.
-
#communication_method ⇒ String?
The method of communication for the subscription.
-
#created_at ⇒ Time
The date and time when the subscription was created.
-
#description ⇒ String
A description of the subscription.
-
#id ⇒ String
The unique identifier for the subscription.
-
#is_active ⇒ Boolean
Indicates whether the subscription is active.
-
#is_default ⇒ Boolean
Indicates whether the subscription is the default option.
-
#is_internal ⇒ Boolean
Indicates whether the subscription is internal.
-
#name ⇒ String
The name of the subscription.
-
#purpose ⇒ String?
The purpose of the subscription.
-
#subscription_translations ⇒ Array<HubSpotSDK::Models::CommunicationPreferences::PublicSubscriptionTranslation>?
A list of translations associated with the subscription.
-
#updated_at ⇒ Time
The date and time when the subscription was last updated.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, description:, is_active:, is_default:, is_internal:, name:, updated_at:, business_unit_id: nil, communication_method: nil, purpose: nil, subscription_translations: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/communication_preferences/subscription_definition.rb', line 83
|
Instance Attribute Details
#business_unit_id ⇒ Integer?
The ID of the business unit associated with the subscription.
59 |
# File 'lib/hubspot_sdk/models/communication_preferences/subscription_definition.rb', line 59 optional :business_unit_id, Integer, api_name: :businessUnitId |
#communication_method ⇒ String?
The method of communication for the subscription.
65 |
# File 'lib/hubspot_sdk/models/communication_preferences/subscription_definition.rb', line 65 optional :communication_method, String, api_name: :communicationMethod |
#created_at ⇒ Time
The date and time when the subscription was created.
17 |
# File 'lib/hubspot_sdk/models/communication_preferences/subscription_definition.rb', line 17 required :created_at, Time, api_name: :createdAt |
#description ⇒ String
A description of the subscription.
23 |
# File 'lib/hubspot_sdk/models/communication_preferences/subscription_definition.rb', line 23 required :description, String |
#id ⇒ String
The unique identifier for the subscription.
11 |
# File 'lib/hubspot_sdk/models/communication_preferences/subscription_definition.rb', line 11 required :id, String |
#is_active ⇒ Boolean
Indicates whether the subscription is active.
29 |
# File 'lib/hubspot_sdk/models/communication_preferences/subscription_definition.rb', line 29 required :is_active, HubSpotSDK::Internal::Type::Boolean, api_name: :isActive |
#is_default ⇒ Boolean
Indicates whether the subscription is the default option.
35 |
# File 'lib/hubspot_sdk/models/communication_preferences/subscription_definition.rb', line 35 required :is_default, HubSpotSDK::Internal::Type::Boolean, api_name: :isDefault |
#is_internal ⇒ Boolean
Indicates whether the subscription is internal.
41 |
# File 'lib/hubspot_sdk/models/communication_preferences/subscription_definition.rb', line 41 required :is_internal, HubSpotSDK::Internal::Type::Boolean, api_name: :isInternal |
#name ⇒ String
The name of the subscription.
47 |
# File 'lib/hubspot_sdk/models/communication_preferences/subscription_definition.rb', line 47 required :name, String |
#purpose ⇒ String?
The purpose of the subscription.
71 |
# File 'lib/hubspot_sdk/models/communication_preferences/subscription_definition.rb', line 71 optional :purpose, String |
#subscription_translations ⇒ Array<HubSpotSDK::Models::CommunicationPreferences::PublicSubscriptionTranslation>?
A list of translations associated with the subscription.
77 78 79 80 81 |
# File 'lib/hubspot_sdk/models/communication_preferences/subscription_definition.rb', line 77 optional :subscription_translations, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::CommunicationPreferences::PublicSubscriptionTranslation] }, api_name: :subscriptionTranslations |
#updated_at ⇒ Time
The date and time when the subscription was last updated.
53 |
# File 'lib/hubspot_sdk/models/communication_preferences/subscription_definition.rb', line 53 required :updated_at, Time, api_name: :updatedAt |