Class: HubSpotSDK::Models::Conversations::CustomChannels::ChannelAccountListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Conversations::CustomChannels::ChannelAccountListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb
Overview
Defined Under Namespace
Modules: DeliveryIdentifierType
Instance Attribute Summary collapse
-
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
-
#archived ⇒ Boolean?
Whether to return only results that have been archived.
- #channel_id ⇒ Integer
- #default_page_length ⇒ Integer?
- #delivery_identifier_type ⇒ Array<Symbol, HubSpotSDK::Models::Conversations::CustomChannels::ChannelAccountListParams::DeliveryIdentifierType>?
- #delivery_identifier_value ⇒ Array<String>?
-
#limit ⇒ Integer?
The maximum number of results to display per page.
- #sort ⇒ Array<String>?
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
23 |
# File 'lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb', line 23 optional :after, String |
#archived ⇒ Boolean?
Whether to return only results that have been archived.
29 |
# File 'lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb', line 29 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#channel_id ⇒ Integer
15 |
# File 'lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb', line 15 required :channel_id, Integer |
#default_page_length ⇒ Integer?
34 |
# File 'lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb', line 34 optional :default_page_length, Integer |
#delivery_identifier_type ⇒ Array<Symbol, HubSpotSDK::Models::Conversations::CustomChannels::ChannelAccountListParams::DeliveryIdentifierType>?
39 40 |
# File 'lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb', line 39 optional :delivery_identifier_type, -> { HubSpotSDK::Internal::Type::ArrayOf[enum: HubSpotSDK::Conversations::CustomChannels::ChannelAccountListParams::DeliveryIdentifierType] } |
#delivery_identifier_value ⇒ Array<String>?
45 |
# File 'lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb', line 45 optional :delivery_identifier_value, HubSpotSDK::Internal::Type::ArrayOf[String] |
#limit ⇒ Integer?
The maximum number of results to display per page.
51 |
# File 'lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb', line 51 optional :limit, Integer |
#sort ⇒ Array<String>?
56 |
# File 'lib/hubspot_sdk/models/conversations/custom_channels/channel_account_list_params.rb', line 56 optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String] |