Class: HubSpotSDK::Models::Conversations::IdentificationTokenGenerationRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Conversations::IdentificationTokenGenerationRequest
- Defined in:
- lib/hubspot_sdk/models/conversations/identification_token_generation_request.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#email ⇒ String
The email of the visitor that you wish to identify.
-
#first_name ⇒ String?
The first name of the visitor that you wish to identify.
-
#last_name ⇒ String?
The last name of the visitor that you wish to identify.
Instance Method Summary collapse
-
#initialize(email:, first_name: nil, last_name: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see IdentificationTokenGenerationRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(email:, first_name: nil, last_name: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Conversations::IdentificationTokenGenerationRequest for more details.
|
|
# File 'lib/hubspot_sdk/models/conversations/identification_token_generation_request.rb', line 29
|
Instance Attribute Details
#email ⇒ String
The email of the visitor that you wish to identify
11 |
# File 'lib/hubspot_sdk/models/conversations/identification_token_generation_request.rb', line 11 required :email, String |
#first_name ⇒ String?
The first name of the visitor that you wish to identify. This value will only be set in HubSpot for new contacts and existing contacts where first name is unknown. Optional.
19 |
# File 'lib/hubspot_sdk/models/conversations/identification_token_generation_request.rb', line 19 optional :first_name, String, api_name: :firstName |
#last_name ⇒ String?
The last name of the visitor that you wish to identify. This value will only be set in HubSpot for new contacts and existing contacts where last name is unknown. Optional.
27 |
# File 'lib/hubspot_sdk/models/conversations/identification_token_generation_request.rb', line 27 optional :last_name, String, api_name: :lastName |