Class: HubSpotSDK::Models::Crm::ActionResponseWithSingleResultUri
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::ActionResponseWithSingleResultUri
- Defined in:
- lib/hubspot_sdk/models/crm/action_response_with_single_result_uri.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The timestamp when the export was completed, in ISO 8601 format.
- #errors ⇒ Array<HubSpotSDK::Models::StandardError>?
-
#links ⇒ Hash{Symbol=>String}?
A collection of related links associated with the export.
-
#num_errors ⇒ Integer?
The number of errors encountered during the export process.
-
#requested_at ⇒ Time?
The timestamp when the export request was made, in ISO 8601 format.
-
#result ⇒ String?
The URL of the resulting file if the export status is COMPLETE.
-
#started_at ⇒ Time
The timestamp when the export process started, in ISO 8601 format.
-
#status ⇒ Symbol, HubSpotSDK::Models::Crm::ActionResponseWithSingleResultUri::Status
The current status of the export, which can be PENDING, PROCESSING, COMPLETE or CANCELED.
Instance Method Summary collapse
-
#initialize(completed_at:, started_at:, status:, errors: nil, links: nil, num_errors: nil, requested_at: nil, result: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ActionResponseWithSingleResultUri for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(completed_at:, started_at:, status:, errors: nil, links: nil, num_errors: nil, requested_at: nil, result: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::ActionResponseWithSingleResultUri for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/action_response_with_single_result_uri.rb', line 56
|
Instance Attribute Details
#completed_at ⇒ Time
The timestamp when the export was completed, in ISO 8601 format.
12 |
# File 'lib/hubspot_sdk/models/crm/action_response_with_single_result_uri.rb', line 12 required :completed_at, Time, api_name: :completedAt |
#errors ⇒ Array<HubSpotSDK::Models::StandardError>?
30 |
# File 'lib/hubspot_sdk/models/crm/action_response_with_single_result_uri.rb', line 30 optional :errors, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::StandardError] } |
#links ⇒ Hash{Symbol=>String}?
A collection of related links associated with the export.
36 |
# File 'lib/hubspot_sdk/models/crm/action_response_with_single_result_uri.rb', line 36 optional :links, HubSpotSDK::Internal::Type::HashOf[String] |
#num_errors ⇒ Integer?
The number of errors encountered during the export process.
42 |
# File 'lib/hubspot_sdk/models/crm/action_response_with_single_result_uri.rb', line 42 optional :num_errors, Integer, api_name: :numErrors |
#requested_at ⇒ Time?
The timestamp when the export request was made, in ISO 8601 format.
48 |
# File 'lib/hubspot_sdk/models/crm/action_response_with_single_result_uri.rb', line 48 optional :requested_at, Time, api_name: :requestedAt |
#result ⇒ String?
The URL of the resulting file if the export status is COMPLETE.
54 |
# File 'lib/hubspot_sdk/models/crm/action_response_with_single_result_uri.rb', line 54 optional :result, String |
#started_at ⇒ Time
The timestamp when the export process started, in ISO 8601 format.
18 |
# File 'lib/hubspot_sdk/models/crm/action_response_with_single_result_uri.rb', line 18 required :started_at, Time, api_name: :startedAt |
#status ⇒ Symbol, HubSpotSDK::Models::Crm::ActionResponseWithSingleResultUri::Status
The current status of the export, which can be PENDING, PROCESSING, COMPLETE or CANCELED.
25 |
# File 'lib/hubspot_sdk/models/crm/action_response_with_single_result_uri.rb', line 25 required :status, enum: -> { HubSpotSDK::Crm::ActionResponseWithSingleResultUri::Status } |