Class: HubSpotSDK::Models::Crm::AssociationSpecWithLabel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::AssociationSpecWithLabel
- Defined in:
- lib/hubspot_sdk/models/crm/association_spec_with_label.rb
Defined Under Namespace
Modules: Category
Instance Attribute Summary collapse
-
#category ⇒ Symbol, HubSpotSDK::Models::Crm::AssociationSpecWithLabel::Category
Association category.
-
#label ⇒ String?
An optional descriptor that provides additional context about the relationship between associated records, such as “Mentor” and “Mentee”.
-
#type_id ⇒ Integer
An integer value used to uniquely identify a specific association type within its Association Category.
Instance Method Summary collapse
-
#initialize(category:, type_id:, label: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see AssociationSpecWithLabel for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(category:, type_id:, label: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::AssociationSpecWithLabel for more details.
Defines the type, direction, and details of the relationship between two CRM objects.
|
|
# File 'lib/hubspot_sdk/models/crm/association_spec_with_label.rb', line 28
|
Instance Attribute Details
#category ⇒ Symbol, HubSpotSDK::Models::Crm::AssociationSpecWithLabel::Category
Association category. Can be HUBSPOT_DEFINED, USER_DEFINED, INTEGRATOR_DEFINED or WORK
12 |
# File 'lib/hubspot_sdk/models/crm/association_spec_with_label.rb', line 12 required :category, enum: -> { HubSpotSDK::Crm::AssociationSpecWithLabel::Category } |
#label ⇒ String?
An optional descriptor that provides additional context about the relationship between associated records, such as “Mentor” and “Mentee”.
26 |
# File 'lib/hubspot_sdk/models/crm/association_spec_with_label.rb', line 26 optional :label, String |
#type_id ⇒ Integer
An integer value used to uniquely identify a specific association type within its Association Category.
19 |
# File 'lib/hubspot_sdk/models/crm/association_spec_with_label.rb', line 19 required :type_id, Integer, api_name: :typeId |