Class: HubSpotSDK::Models::Crm::BatchReadInputSimplePublicObjectID
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::BatchReadInputSimplePublicObjectID
- Defined in:
- lib/hubspot_sdk/models/crm/batch_read_input_simple_public_object_id.rb
Direct Known Subclasses
Objects::Calls::BatchGetParams, Objects::Carts::BatchGetParams, Objects::CommercePayments::BatchGetParams, Objects::Communications::BatchGetParams, Objects::Companies::BatchGetParams, Objects::Contacts::BatchGetParams, Objects::Contracts::BatchGetParams, Objects::Courses::BatchGetParams, Objects::Custom::BatchGetParams, Objects::Deals::BatchGetParams, Objects::Discounts::BatchGetParams, Objects::Emails::BatchGetParams, Objects::FeedbackSubmissions::BatchGetParams, Objects::Fees::BatchGetParams, Objects::GenericObjects::BatchGetParams, Objects::GoalTargets::BatchGetParams, Objects::Invoices::BatchGetParams, Objects::Leads::BatchGetParams, Objects::LineItems::BatchGetParams, Objects::Listings::BatchGetParams, Objects::Meetings::BatchGetParams, Objects::Notes::BatchGetParams, Objects::Orders::BatchGetParams, Objects::PartnerClients::BatchGetParams, Objects::PartnerServices::BatchGetParams, Objects::PostalMail::BatchGetParams, Objects::Products::BatchGetParams, Objects::Projects::BatchGetParams, Objects::Quotes::BatchGetParams, Objects::Services::BatchGetParams, Objects::Subscriptions::BatchGetParams, Objects::Tasks::BatchGetParams, Objects::Taxes::BatchGetParams, Objects::Tickets::BatchGetParams, Objects::Users::BatchGetParams
Instance Attribute Summary collapse
-
#id_property ⇒ String?
When using a custom unique value property to retrieve records, the name of the property.
- #inputs ⇒ Array<HubSpotSDK::Models::Crm::SimplePublicObjectID>
-
#properties ⇒ Array<String>
Key-value pairs for setting properties for the new object.
-
#properties_with_history ⇒ Array<String>
Key-value pairs for setting properties for the new object and their histories.
Instance Method Summary collapse
-
#initialize(inputs:, properties:, properties_with_history:, id_property: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BatchReadInputSimplePublicObjectID for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(inputs:, properties:, properties_with_history:, id_property: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::BatchReadInputSimplePublicObjectID for more details.
Specifies the input for reading a batch of CRM objects, including arrays of object IDs, requested property names (with optional history), and an optional unique identifying property.
|
|
# File 'lib/hubspot_sdk/models/crm/batch_read_input_simple_public_object_id.rb', line 33
|
Instance Attribute Details
#id_property ⇒ String?
When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID.
31 |
# File 'lib/hubspot_sdk/models/crm/batch_read_input_simple_public_object_id.rb', line 31 optional :id_property, String, api_name: :idProperty |
#inputs ⇒ Array<HubSpotSDK::Models::Crm::SimplePublicObjectID>
10 |
# File 'lib/hubspot_sdk/models/crm/batch_read_input_simple_public_object_id.rb', line 10 required :inputs, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::SimplePublicObjectID] } |
#properties ⇒ Array<String>
Key-value pairs for setting properties for the new object.
16 |
# File 'lib/hubspot_sdk/models/crm/batch_read_input_simple_public_object_id.rb', line 16 required :properties, HubSpotSDK::Internal::Type::ArrayOf[String] |
#properties_with_history ⇒ Array<String>
Key-value pairs for setting properties for the new object and their histories.
22 23 24 |
# File 'lib/hubspot_sdk/models/crm/batch_read_input_simple_public_object_id.rb', line 22 required :properties_with_history, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :propertiesWithHistory |