Class: HubSpotSDK::Models::Crm::BatchResponseSimplePublicObjectWithErrors
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::BatchResponseSimplePublicObjectWithErrors
- Defined in:
- lib/hubspot_sdk/models/crm/batch_response_simple_public_object_with_errors.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The timestamp when the batch process was completed, in ISO 8601 format.
- #errors ⇒ Array<HubSpotSDK::Models::StandardError>?
-
#links ⇒ Hash{Symbol=>String}?
An object containing relevant links related to the batch request.
-
#num_errors ⇒ Integer?
The number of errors encountered during the batch process.
-
#requested_at ⇒ Time?
The timestamp when the batch process was initiated, in ISO 8601 format.
- #results ⇒ Array<HubSpotSDK::Models::Crm::SimplePublicObject>
-
#started_at ⇒ Time
The timestamp when the batch process began execution, in ISO 8601 format.
-
#status ⇒ Symbol, HubSpotSDK::Models::Crm::BatchResponseSimplePublicObjectWithErrors::Status
The status of the batch processing request - “PENDING”, “PROCESSING”, “CANCELLED”, or “COMPLETE”.
Instance Method Summary collapse
-
#initialize(completed_at:, results:, started_at:, status:, errors: nil, links: nil, num_errors: nil, requested_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BatchResponseSimplePublicObjectWithErrors for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(completed_at:, results:, started_at:, status:, errors: nil, links: nil, num_errors: nil, requested_at: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::BatchResponseSimplePublicObjectWithErrors for more details.
Represents the result of a batch operation on CRM objects, including the processing status, batch results, timestamps, and a list of any errors encountered during the operation.
|
|
# File 'lib/hubspot_sdk/models/crm/batch_response_simple_public_object_with_errors.rb', line 54
|
Instance Attribute Details
#completed_at ⇒ Time
The timestamp when the batch process was completed, in ISO 8601 format.
11 |
# File 'lib/hubspot_sdk/models/crm/batch_response_simple_public_object_with_errors.rb', line 11 required :completed_at, Time, api_name: :completedAt |
#errors ⇒ Array<HubSpotSDK::Models::StandardError>?
34 |
# File 'lib/hubspot_sdk/models/crm/batch_response_simple_public_object_with_errors.rb', line 34 optional :errors, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::StandardError] } |
#links ⇒ Hash{Symbol=>String}?
An object containing relevant links related to the batch request.
40 |
# File 'lib/hubspot_sdk/models/crm/batch_response_simple_public_object_with_errors.rb', line 40 optional :links, HubSpotSDK::Internal::Type::HashOf[String] |
#num_errors ⇒ Integer?
The number of errors encountered during the batch process.
46 |
# File 'lib/hubspot_sdk/models/crm/batch_response_simple_public_object_with_errors.rb', line 46 optional :num_errors, Integer, api_name: :numErrors |
#requested_at ⇒ Time?
The timestamp when the batch process was initiated, in ISO 8601 format.
52 |
# File 'lib/hubspot_sdk/models/crm/batch_response_simple_public_object_with_errors.rb', line 52 optional :requested_at, Time, api_name: :requestedAt |
#results ⇒ Array<HubSpotSDK::Models::Crm::SimplePublicObject>
16 |
# File 'lib/hubspot_sdk/models/crm/batch_response_simple_public_object_with_errors.rb', line 16 required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::SimplePublicObject] } |
#started_at ⇒ Time
The timestamp when the batch process began execution, in ISO 8601 format.
22 |
# File 'lib/hubspot_sdk/models/crm/batch_response_simple_public_object_with_errors.rb', line 22 required :started_at, Time, api_name: :startedAt |
#status ⇒ Symbol, HubSpotSDK::Models::Crm::BatchResponseSimplePublicObjectWithErrors::Status
The status of the batch processing request - “PENDING”, “PROCESSING”, “CANCELLED”, or “COMPLETE”
29 |
# File 'lib/hubspot_sdk/models/crm/batch_response_simple_public_object_with_errors.rb', line 29 required :status, enum: -> { HubSpotSDK::Crm::BatchResponseSimplePublicObjectWithErrors::Status } |