Class: HubSpotSDK::Models::Crm::DateTime
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::DateTime
- Defined in:
- lib/hubspot_sdk/models/crm/date_time.rb
Instance Attribute Summary collapse
-
#date_only ⇒ Boolean
Indicates whether the DateTime value represents only a date without a time component.
-
#time_zone_shift ⇒ Integer
The integer value representing the shift in minutes from UTC for the DateTime value.
-
#value ⇒ Integer
The integer value representing a specific point in time.
Instance Method Summary collapse
-
#initialize(date_only:, time_zone_shift:, value:) ⇒ Object
constructor
Some parameter documentations has been truncated, see DateTime for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(date_only:, time_zone_shift:, value:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::DateTime for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/date_time.rb', line 27
|
Instance Attribute Details
#date_only ⇒ Boolean
Indicates whether the DateTime value represents only a date without a time component.
12 |
# File 'lib/hubspot_sdk/models/crm/date_time.rb', line 12 required :date_only, HubSpotSDK::Internal::Type::Boolean, api_name: :dateOnly |
#time_zone_shift ⇒ Integer
The integer value representing the shift in minutes from UTC for the DateTime value.
19 |
# File 'lib/hubspot_sdk/models/crm/date_time.rb', line 19 required :time_zone_shift, Integer, api_name: :timeZoneShift |
#value ⇒ Integer
The integer value representing a specific point in time.
25 |
# File 'lib/hubspot_sdk/models/crm/date_time.rb', line 25 required :value, Integer |