Class: HubSpotSDK::Models::Crm::DealToDealSplits
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::DealToDealSplits
- Defined in:
- lib/hubspot_sdk/models/crm/deal_to_deal_splits.rb
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the deal associated with the deal splits.
-
#splits ⇒ Array<HubSpotSDK::Models::Crm::SimplePublicObject>
An array of deal split objects, each representing a portion of the deal assigned to an owner.
Instance Method Summary collapse
-
#initialize(id:, splits:) ⇒ Object
constructor
Some parameter documentations has been truncated, see DealToDealSplits for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, splits:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::DealToDealSplits for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/deal_to_deal_splits.rb', line 20
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the deal associated with the deal splits.
11 |
# File 'lib/hubspot_sdk/models/crm/deal_to_deal_splits.rb', line 11 required :id, String |
#splits ⇒ Array<HubSpotSDK::Models::Crm::SimplePublicObject>
An array of deal split objects, each representing a portion of the deal assigned to an owner.
18 |
# File 'lib/hubspot_sdk/models/crm/deal_to_deal_splits.rb', line 18 required :splits, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::SimplePublicObject] } |