Class: HubSpotSDK::Models::Crm::Extensions::CardMigrateViewsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Extensions::CardMigrateViewsResponse
- Defined in:
- lib/hubspot_sdk/models/crm/extensions/card_migrate_views_response.rb
Overview
Instance Attribute Summary collapse
-
#ended_at ⇒ Integer?
The timestamp for when the migration ended.
-
#message ⇒ String
A human readable message describing the progress of the migration.
-
#remaining_portal_count ⇒ Integer?
The number of portals that remain to be swapped from the Legacy CRM Card to the App Card.
-
#started_at ⇒ Integer?
The timestamp for when the migration started.
-
#total_portal_count ⇒ Integer?
The total number of portals that have access to the Legacy CRM Card.
Instance Method Summary collapse
-
#initialize(message:, ended_at: nil, remaining_portal_count: nil, started_at: nil, total_portal_count: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CardMigrateViewsResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(message:, ended_at: nil, remaining_portal_count: nil, started_at: nil, total_portal_count: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Extensions::CardMigrateViewsResponse for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/extensions/card_migrate_views_response.rb', line 40
|
Instance Attribute Details
#ended_at ⇒ Integer?
The timestamp for when the migration ended.
19 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_migrate_views_response.rb', line 19 optional :ended_at, Integer, api_name: :endedAt |
#message ⇒ String
A human readable message describing the progress of the migration.
13 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_migrate_views_response.rb', line 13 required :message, String |
#remaining_portal_count ⇒ Integer?
The number of portals that remain to be swapped from the Legacy CRM Card to the App Card
26 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_migrate_views_response.rb', line 26 optional :remaining_portal_count, Integer, api_name: :remainingPortalCount |
#started_at ⇒ Integer?
The timestamp for when the migration started.
32 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_migrate_views_response.rb', line 32 optional :started_at, Integer, api_name: :startedAt |
#total_portal_count ⇒ Integer?
The total number of portals that have access to the Legacy CRM Card
38 |
# File 'lib/hubspot_sdk/models/crm/extensions/card_migrate_views_response.rb', line 38 optional :total_portal_count, Integer, api_name: :totalPortalCount |