Class: HubSpotSDK::Models::Crm::Extensions::CompletedThirdPartyCallRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Extensions::CompletedThirdPartyCallRequest
- Defined in:
- lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb
Direct Known Subclasses
HubSpotSDK::Models::Crm::Extensions::Calling::TranscriptCreateInboundCallParams, CallingCreateInboundCallParams
Defined Under Namespace
Modules: FinalCallStatus
Instance Attribute Summary collapse
-
#call_started_timestamp ⇒ Time?
The timestamp indicating when the call started, formatted as a date-time string.
-
#create_engagement ⇒ Boolean
Indicates whether an engagement should be created for the call.
-
#duration_seconds ⇒ Integer?
The duration of the call in seconds.
-
#engagement_properties ⇒ Hash{Symbol=>String}
Contains additional properties related to the engagement.
-
#external_call_id ⇒ String
The unique identifier for the call from an external system.
-
#final_call_status ⇒ Symbol, HubSpotSDK::Models::Crm::Extensions::CompletedThirdPartyCallRequest::FinalCallStatus
The final status of the call, with accepted values including: BUSY, CALLING_CRM_USER, CANCELED, COMPLETED, CONNECTING, FAILED, HOLD, IN_PROGRESS, MISSED, NO_ANSWER, QUEUED, RINGING, UNKNOWN.
- #from_number ⇒ HubSpotSDK::Models::Crm::Extensions::FormattedPhoneNumber
- #potential_recipient_user_ids ⇒ Array<Integer>
- #to_number ⇒ HubSpotSDK::Models::Crm::Extensions::FormattedPhoneNumber
-
#user_id ⇒ Integer?
The ID of the user associated with the call.
Instance Method Summary collapse
-
#initialize(create_engagement:, engagement_properties:, external_call_id:, final_call_status:, from_number:, potential_recipient_user_ids:, to_number:, call_started_timestamp: nil, duration_seconds: nil, user_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CompletedThirdPartyCallRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(create_engagement:, engagement_properties:, external_call_id:, final_call_status:, from_number:, potential_recipient_user_ids:, to_number:, call_started_timestamp: nil, duration_seconds: nil, user_id: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Extensions::CompletedThirdPartyCallRequest for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 77
|
Instance Attribute Details
#call_started_timestamp ⇒ Time?
The timestamp indicating when the call started, formatted as a date-time string.
63 |
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 63 optional :call_started_timestamp, Time, api_name: :callStartedTimestamp |
#create_engagement ⇒ Boolean
Indicates whether an engagement should be created for the call.
12 |
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 12 required :create_engagement, HubSpotSDK::Internal::Type::Boolean, api_name: :createEngagement |
#duration_seconds ⇒ Integer?
The duration of the call in seconds.
69 |
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 69 optional :duration_seconds, Integer, api_name: :durationSeconds |
#engagement_properties ⇒ Hash{Symbol=>String}
Contains additional properties related to the engagement.
18 19 20 |
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 18 required :engagement_properties, HubSpotSDK::Internal::Type::HashOf[String], api_name: :engagementProperties |
#external_call_id ⇒ String
The unique identifier for the call from an external system.
26 |
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 26 required :external_call_id, String, api_name: :externalCallId |
#final_call_status ⇒ Symbol, HubSpotSDK::Models::Crm::Extensions::CompletedThirdPartyCallRequest::FinalCallStatus
The final status of the call, with accepted values including: BUSY, CALLING_CRM_USER, CANCELED, COMPLETED, CONNECTING, FAILED, HOLD, IN_PROGRESS, MISSED, NO_ANSWER, QUEUED, RINGING, UNKNOWN.
34 35 36 |
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 34 required :final_call_status, enum: -> { HubSpotSDK::Crm::Extensions::CompletedThirdPartyCallRequest::FinalCallStatus }, api_name: :finalCallStatus |
#from_number ⇒ HubSpotSDK::Models::Crm::Extensions::FormattedPhoneNumber
41 42 43 44 45 |
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 41 required :from_number, -> { HubSpotSDK::Crm::Extensions::FormattedPhoneNumber }, api_name: :fromNumber |
#potential_recipient_user_ids ⇒ Array<Integer>
50 51 52 |
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 50 required :potential_recipient_user_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :potentialRecipientUserIds |
#to_number ⇒ HubSpotSDK::Models::Crm::Extensions::FormattedPhoneNumber
57 |
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 57 required :to_number, -> { HubSpotSDK::Crm::Extensions::FormattedPhoneNumber }, api_name: :toNumber |
#user_id ⇒ Integer?
The ID of the user associated with the call.
75 |
# File 'lib/hubspot_sdk/models/crm/extensions/completed_third_party_call_request.rb', line 75 optional :user_id, Integer, api_name: :userId |