Class: HubSpotSDK::Models::Crm::Extensions::IntegratorObjectResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Extensions::IntegratorObjectResult
- Defined in:
- lib/hubspot_sdk/models/crm/extensions/integrator_object_result.rb
Defined Under Namespace
Modules: Action
Instance Attribute Summary collapse
-
#actions ⇒ Array<HubSpotSDK::Models::Crm::Extensions::ActionHookActionBody, HubSpotSDK::Models::Crm::Extensions::IFrameActionBody>
A list of actions associated with the card, which can include action hooks, confirmation action hooks, or iframes.
-
#id ⇒ String
The unique identifier for the card.
-
#link_url ⇒ String?
A URL used on the title of the card.
-
#title ⇒ String
The top-level title for this card.
-
#tokens ⇒ Array<HubSpotSDK::Models::Crm::Extensions::ObjectToken>
A collection of tokens representing specific properties related to the card.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#actions ⇒ Array<HubSpotSDK::Models::Crm::Extensions::ActionHookActionBody, HubSpotSDK::Models::Crm::Extensions::IFrameActionBody>
A list of actions associated with the card, which can include action hooks, confirmation action hooks, or iframes.
19 20 |
# File 'lib/hubspot_sdk/models/crm/extensions/integrator_object_result.rb', line 19 required :actions, -> { HubSpotSDK::Internal::Type::ArrayOf[union: HubSpotSDK::Crm::Extensions::IntegratorObjectResult::Action] } |
#id ⇒ String
The unique identifier for the card.
12 |
# File 'lib/hubspot_sdk/models/crm/extensions/integrator_object_result.rb', line 12 required :id, String |
#link_url ⇒ String?
A URL used on the title of the card
38 |
# File 'lib/hubspot_sdk/models/crm/extensions/integrator_object_result.rb', line 38 optional :link_url, String, api_name: :linkUrl |
#title ⇒ String
The top-level title for this card. Displayed to users in the CRM UI.
26 |
# File 'lib/hubspot_sdk/models/crm/extensions/integrator_object_result.rb', line 26 required :title, String |
#tokens ⇒ Array<HubSpotSDK::Models::Crm::Extensions::ObjectToken>
A collection of tokens representing specific properties related to the card.
32 |
# File 'lib/hubspot_sdk/models/crm/extensions/integrator_object_result.rb', line 32 required :tokens, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::Extensions::ObjectToken] } |