Class: HubSpotSDK::Models::Crm::Extensions::MarkRecordingAsReadyRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Extensions::MarkRecordingAsReadyRequest
- Defined in:
- lib/hubspot_sdk/models/crm/extensions/mark_recording_as_ready_request.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#engagement_id ⇒ Integer
The unique identifier for the engagement associated with the call recording.
Instance Method Summary collapse
- #initialize(engagement_id:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(engagement_id:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/extensions/mark_recording_as_ready_request.rb', line 14
|
Instance Attribute Details
#engagement_id ⇒ Integer
The unique identifier for the engagement associated with the call recording.
12 |
# File 'lib/hubspot_sdk/models/crm/extensions/mark_recording_as_ready_request.rb', line 12 required :engagement_id, Integer, api_name: :engagementId |