Class: HubSpotSDK::Models::Crm::Extensions::PublicCardFetchBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Extensions::PublicCardFetchBody
- Defined in:
- lib/hubspot_sdk/models/crm/extensions/public_card_fetch_body.rb
Instance Attribute Summary collapse
-
#object_types ⇒ Array<HubSpotSDK::Models::Crm::Extensions::CardObjectTypeBody>
An array of CRM object types where this card should be displayed.
-
#target_url ⇒ String
URL to a service endpoint that will respond with details for this card.
Instance Method Summary collapse
-
#initialize(object_types:, target_url:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicCardFetchBody for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(object_types:, target_url:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Extensions::PublicCardFetchBody for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/extensions/public_card_fetch_body.rb', line 28
|
Instance Attribute Details
#object_types ⇒ Array<HubSpotSDK::Models::Crm::Extensions::CardObjectTypeBody>
An array of CRM object types where this card should be displayed. HubSpot will call your target URL whenever a user visits a record page of the types defined here.
14 15 16 17 18 |
# File 'lib/hubspot_sdk/models/crm/extensions/public_card_fetch_body.rb', line 14 required :object_types, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::Extensions::CardObjectTypeBody] }, api_name: :objectTypes |
#target_url ⇒ String
URL to a service endpoint that will respond with details for this card. HubSpot will call this endpoint each time a user visits a CRM record page where this card should be displayed.
26 |
# File 'lib/hubspot_sdk/models/crm/extensions/public_card_fetch_body.rb', line 26 required :target_url, String, api_name: :targetUrl |