Class: HubSpotSDK::Models::Crm::Extensions::SettingsPatchRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Extensions::SettingsPatchRequest
- Defined in:
- lib/hubspot_sdk/models/crm/extensions/settings_patch_request.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#height ⇒ Integer?
The height setting for the calling extension interface.
-
#is_ready ⇒ Boolean?
Specifies whether the calling extension is ready for use.
-
#name ⇒ String?
The name of the calling extension.
-
#supports_custom_objects ⇒ Boolean?
Indicates if the calling extension supports custom objects.
-
#supports_inbound_calling ⇒ Boolean?
Indicates if the calling extension supports inbound calling.
-
#url ⇒ String?
The URL associated with the calling extension settings.
-
#uses_calling_window ⇒ Boolean?
Indicates if the calling extension uses a calling window.
-
#uses_remote ⇒ Boolean?
Indicates if the calling extension uses a remote connection.
-
#width ⇒ Integer?
The width setting for the calling extension interface.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(height: nil, is_ready: nil, name: nil, supports_custom_objects: nil, supports_inbound_calling: nil, url: nil, uses_calling_window: nil, uses_remote: nil, width: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/extensions/settings_patch_request.rb', line 66
|
Instance Attribute Details
#height ⇒ Integer?
The height setting for the calling extension interface.
12 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_patch_request.rb', line 12 optional :height, Integer |
#is_ready ⇒ Boolean?
Specifies whether the calling extension is ready for use.
18 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_patch_request.rb', line 18 optional :is_ready, HubSpotSDK::Internal::Type::Boolean, api_name: :isReady |
#name ⇒ String?
The name of the calling extension.
24 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_patch_request.rb', line 24 optional :name, String |
#supports_custom_objects ⇒ Boolean?
Indicates if the calling extension supports custom objects.
30 31 32 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_patch_request.rb', line 30 optional :supports_custom_objects, HubSpotSDK::Internal::Type::Boolean, api_name: :supportsCustomObjects |
#supports_inbound_calling ⇒ Boolean?
Indicates if the calling extension supports inbound calling.
38 39 40 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_patch_request.rb', line 38 optional :supports_inbound_calling, HubSpotSDK::Internal::Type::Boolean, api_name: :supportsInboundCalling |
#url ⇒ String?
The URL associated with the calling extension settings.
46 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_patch_request.rb', line 46 optional :url, String |
#uses_calling_window ⇒ Boolean?
Indicates if the calling extension uses a calling window.
52 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_patch_request.rb', line 52 optional :uses_calling_window, HubSpotSDK::Internal::Type::Boolean, api_name: :usesCallingWindow |
#uses_remote ⇒ Boolean?
Indicates if the calling extension uses a remote connection.
58 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_patch_request.rb', line 58 optional :uses_remote, HubSpotSDK::Internal::Type::Boolean, api_name: :usesRemote |
#width ⇒ Integer?
The width setting for the calling extension interface.
64 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_patch_request.rb', line 64 optional :width, Integer |