Class: HubSpotSDK::Models::Crm::Extensions::SettingsRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Extensions::SettingsRequest
- Defined in:
- lib/hubspot_sdk/models/crm/extensions/settings_request.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#height ⇒ Integer
Specifies the height of the calling extension interface.
-
#is_ready ⇒ Boolean
Indicates if the calling extension is ready for use.
-
#name ⇒ String
The name of the calling extension.
-
#supports_custom_objects ⇒ Boolean
Indicates if the calling extension supports custom objects.
-
#supports_inbound_calling ⇒ Boolean
Indicates if the calling extension supports inbound calling.
-
#url ⇒ String
The URL associated with the calling extension.
-
#uses_calling_window ⇒ Boolean
Indicates if the calling extension uses a separate calling window.
-
#uses_remote ⇒ Boolean
Indicates if the calling extension uses remote services.
-
#width ⇒ Integer
Specifies the width of the calling extension interface.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(height:, is_ready:, name:, supports_custom_objects:, supports_inbound_calling:, url:, uses_calling_window:, uses_remote:, width:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/extensions/settings_request.rb', line 66
|
Instance Attribute Details
#height ⇒ Integer
Specifies the height of the calling extension interface.
12 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_request.rb', line 12 required :height, Integer |
#is_ready ⇒ Boolean
Indicates if the calling extension is ready for use.
18 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_request.rb', line 18 required :is_ready, HubSpotSDK::Internal::Type::Boolean, api_name: :isReady |
#name ⇒ String
The name of the calling extension.
24 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_request.rb', line 24 required :name, String |
#supports_custom_objects ⇒ Boolean
Indicates if the calling extension supports custom objects.
30 31 32 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_request.rb', line 30 required :supports_custom_objects, HubSpotSDK::Internal::Type::Boolean, api_name: :supportsCustomObjects |
#supports_inbound_calling ⇒ Boolean
Indicates if the calling extension supports inbound calling.
38 39 40 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_request.rb', line 38 required :supports_inbound_calling, HubSpotSDK::Internal::Type::Boolean, api_name: :supportsInboundCalling |
#url ⇒ String
The URL associated with the calling extension.
46 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_request.rb', line 46 required :url, String |
#uses_calling_window ⇒ Boolean
Indicates if the calling extension uses a separate calling window.
52 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_request.rb', line 52 required :uses_calling_window, HubSpotSDK::Internal::Type::Boolean, api_name: :usesCallingWindow |
#uses_remote ⇒ Boolean
Indicates if the calling extension uses remote services.
58 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_request.rb', line 58 required :uses_remote, HubSpotSDK::Internal::Type::Boolean, api_name: :usesRemote |
#width ⇒ Integer
Specifies the width of the calling extension interface.
64 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_request.rb', line 64 required :width, Integer |