Class: HubSpotSDK::Models::Crm::Extensions::SettingsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Extensions::SettingsResponse
- Defined in:
- lib/hubspot_sdk/models/crm/extensions/settings_response.rb
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time when the calling extension settings were created.
-
#height ⇒ Integer
The height of the calling extension interface.
-
#is_ready ⇒ Boolean
Specifies whether the calling extension settings are ready for use.
-
#name ⇒ String
The name of the calling extension.
-
#supports_custom_objects ⇒ Boolean
Indicates if the calling extension supports custom objects.
-
#supports_inbound_calling ⇒ Boolean
Indicates if the calling extension supports inbound calling.
-
#updated_at ⇒ Time
The date and time when the calling extension settings were last updated.
-
#url ⇒ String
The URL associated with the calling extension.
-
#uses_calling_window ⇒ Boolean
Specifies if the calling extension uses a dedicated calling window.
-
#uses_remote ⇒ Boolean
Indicates if the calling extension uses a remote service.
-
#width ⇒ Integer
The width of the calling extension interface.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(created_at:, height:, is_ready:, name:, supports_custom_objects:, supports_inbound_calling:, updated_at:, url:, uses_calling_window:, uses_remote:, width:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 79
|
Instance Attribute Details
#created_at ⇒ Time
The date and time when the calling extension settings were created.
13 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 13 required :created_at, Time, api_name: :createdAt |
#height ⇒ Integer
The height of the calling extension interface.
19 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 19 required :height, Integer |
#is_ready ⇒ Boolean
Specifies whether the calling extension settings are ready for use.
25 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 25 required :is_ready, HubSpotSDK::Internal::Type::Boolean, api_name: :isReady |
#name ⇒ String
The name of the calling extension.
31 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 31 required :name, String |
#supports_custom_objects ⇒ Boolean
Indicates if the calling extension supports custom objects.
37 38 39 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 37 required :supports_custom_objects, HubSpotSDK::Internal::Type::Boolean, api_name: :supportsCustomObjects |
#supports_inbound_calling ⇒ Boolean
Indicates if the calling extension supports inbound calling.
45 46 47 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 45 required :supports_inbound_calling, HubSpotSDK::Internal::Type::Boolean, api_name: :supportsInboundCalling |
#updated_at ⇒ Time
The date and time when the calling extension settings were last updated.
53 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 53 required :updated_at, Time, api_name: :updatedAt |
#url ⇒ String
The URL associated with the calling extension.
59 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 59 required :url, String |
#uses_calling_window ⇒ Boolean
Specifies if the calling extension uses a dedicated calling window.
65 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 65 required :uses_calling_window, HubSpotSDK::Internal::Type::Boolean, api_name: :usesCallingWindow |
#uses_remote ⇒ Boolean
Indicates if the calling extension uses a remote service.
71 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 71 required :uses_remote, HubSpotSDK::Internal::Type::Boolean, api_name: :usesRemote |
#width ⇒ Integer
The width of the calling extension interface.
77 |
# File 'lib/hubspot_sdk/models/crm/extensions/settings_response.rb', line 77 required :width, Integer |