Class: HubSpotSDK::Models::Crm::ImportRowCore
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::ImportRowCore
- Defined in:
- lib/hubspot_sdk/models/crm/import_row_core.rb
Instance Attribute Summary collapse
- #additional_row_data ⇒ Array<String>
-
#contains_encrypted_properties ⇒ Boolean
Indicates whether this row contains values that were encrypted.
-
#file_id ⇒ Integer
The unique identifier of the uploaded file containing this row.
-
#line_number ⇒ Integer
The 1-indexed line number of this row in the source file.
-
#page_name ⇒ String?
The name of the spreadsheet sheet/page containing this row.
- #row_data ⇒ Array<String>
Instance Method Summary collapse
-
#initialize(additional_row_data:, contains_encrypted_properties:, file_id:, line_number:, row_data:, page_name: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ImportRowCore for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(additional_row_data:, contains_encrypted_properties:, file_id:, line_number:, row_data:, page_name: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::ImportRowCore for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/import_row_core.rb', line 46
|
Instance Attribute Details
#additional_row_data ⇒ Array<String>
10 11 12 |
# File 'lib/hubspot_sdk/models/crm/import_row_core.rb', line 10 required :additional_row_data, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :additionalRowData |
#contains_encrypted_properties ⇒ Boolean
Indicates whether this row contains values that were encrypted.
18 19 20 |
# File 'lib/hubspot_sdk/models/crm/import_row_core.rb', line 18 required :contains_encrypted_properties, HubSpotSDK::Internal::Type::Boolean, api_name: :containsEncryptedProperties |
#file_id ⇒ Integer
The unique identifier of the uploaded file containing this row.
26 |
# File 'lib/hubspot_sdk/models/crm/import_row_core.rb', line 26 required :file_id, Integer, api_name: :fileId |
#line_number ⇒ Integer
The 1-indexed line number of this row in the source file. Line number 0 is reserved for file-wide errors that don’t correspond to a specific row.
33 |
# File 'lib/hubspot_sdk/models/crm/import_row_core.rb', line 33 required :line_number, Integer, api_name: :lineNumber |
#page_name ⇒ String?
The name of the spreadsheet sheet/page containing this row.
44 |
# File 'lib/hubspot_sdk/models/crm/import_row_core.rb', line 44 optional :page_name, String, api_name: :pageName |
#row_data ⇒ Array<String>
38 |
# File 'lib/hubspot_sdk/models/crm/import_row_core.rb', line 38 required :row_data, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :rowData |