Class: HubSpotSDK::Models::Crm::LabelsBetweenObjectPair
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::LabelsBetweenObjectPair
- Defined in:
- lib/hubspot_sdk/models/crm/labels_between_object_pair.rb
Instance Attribute Summary collapse
-
#from_object_id ⇒ String
The ID of the source object in the association.
-
#from_object_type_id ⇒ String
The type ID of the source object in the association.
-
#labels ⇒ Array<String>
An array of labels associated with the relationship between the objects.
-
#to_object_id ⇒ String
The ID of the target object in the association.
-
#to_object_type_id ⇒ String
The type ID of the target object in the association.
Instance Method Summary collapse
-
#initialize(from_object_id:, from_object_type_id:, labels:, to_object_id:, to_object_type_id:) ⇒ Object
constructor
The relationship descriptors applicable between two object types.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(from_object_id:, from_object_type_id:, labels:, to_object_id:, to_object_type_id:) ⇒ Object
The relationship descriptors applicable between two object types.
|
|
# File 'lib/hubspot_sdk/models/crm/labels_between_object_pair.rb', line 37
|
Instance Attribute Details
#from_object_id ⇒ String
The ID of the source object in the association.
11 |
# File 'lib/hubspot_sdk/models/crm/labels_between_object_pair.rb', line 11 required :from_object_id, String, api_name: :fromObjectId |
#from_object_type_id ⇒ String
The type ID of the source object in the association.
17 |
# File 'lib/hubspot_sdk/models/crm/labels_between_object_pair.rb', line 17 required :from_object_type_id, String, api_name: :fromObjectTypeId |
#labels ⇒ Array<String>
An array of labels associated with the relationship between the objects.
23 |
# File 'lib/hubspot_sdk/models/crm/labels_between_object_pair.rb', line 23 required :labels, HubSpotSDK::Internal::Type::ArrayOf[String] |
#to_object_id ⇒ String
The ID of the target object in the association.
29 |
# File 'lib/hubspot_sdk/models/crm/labels_between_object_pair.rb', line 29 required :to_object_id, String, api_name: :toObjectId |
#to_object_type_id ⇒ String
The type ID of the target object in the association.
35 |
# File 'lib/hubspot_sdk/models/crm/labels_between_object_pair.rb', line 35 required :to_object_type_id, String, api_name: :toObjectTypeId |