Class: HubSpotSDK::Models::Crm::LimitAndUsageForObjectType
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::LimitAndUsageForObjectType
- Defined in:
- lib/hubspot_sdk/models/crm/limit_and_usage_for_object_type.rb
Instance Attribute Summary collapse
-
#limit ⇒ Integer
The maximum allowed count for the object type.
-
#object_type_id ⇒ String
The unique identifier for the object type.
-
#percentage ⇒ Float
The percentage of the limit that has been used.
-
#plural_label ⇒ String
The plural label for the object type.
-
#singular_label ⇒ String
The singular label for the object type.
-
#usage ⇒ Integer
The current usage count for the object type.
Instance Method Summary collapse
- #initialize(limit:, object_type_id:, percentage:, plural_label:, singular_label:, usage:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(limit:, object_type_id:, percentage:, plural_label:, singular_label:, usage:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/limit_and_usage_for_object_type.rb', line 43
|
Instance Attribute Details
#limit ⇒ Integer
The maximum allowed count for the object type.
11 |
# File 'lib/hubspot_sdk/models/crm/limit_and_usage_for_object_type.rb', line 11 required :limit, Integer |
#object_type_id ⇒ String
The unique identifier for the object type.
17 |
# File 'lib/hubspot_sdk/models/crm/limit_and_usage_for_object_type.rb', line 17 required :object_type_id, String, api_name: :objectTypeId |
#percentage ⇒ Float
The percentage of the limit that has been used.
23 |
# File 'lib/hubspot_sdk/models/crm/limit_and_usage_for_object_type.rb', line 23 required :percentage, Float |
#plural_label ⇒ String
The plural label for the object type.
29 |
# File 'lib/hubspot_sdk/models/crm/limit_and_usage_for_object_type.rb', line 29 required :plural_label, String, api_name: :pluralLabel |
#singular_label ⇒ String
The singular label for the object type.
35 |
# File 'lib/hubspot_sdk/models/crm/limit_and_usage_for_object_type.rb', line 35 required :singular_label, String, api_name: :singularLabel |
#usage ⇒ Integer
The current usage count for the object type.
41 |
# File 'lib/hubspot_sdk/models/crm/limit_and_usage_for_object_type.rb', line 41 required :usage, Integer |