Class: HubSpotSDK::Models::Crm::ListCreateRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::ListCreateRequest
- Defined in:
- lib/hubspot_sdk/models/crm/list_create_request.rb
Direct Known Subclasses
Defined Under Namespace
Modules: FilterBranch
Instance Attribute Summary collapse
-
#custom_properties ⇒ Hash{Symbol=>String}?
The list of custom properties to tie to the list.
-
#filter_branch ⇒ HubSpotSDK::Models::Crm::PublicOrFilterBranch, ...
Filter branch object containing filtering criteria for the list.
-
#list_folder_id ⇒ Integer?
The ID of the folder that the list should be created in.
- #list_permissions ⇒ HubSpotSDK::Models::Crm::PublicListPermissions?
- #membership_settings ⇒ HubSpotSDK::Models::Crm::PublicMembershipSettings?
-
#name ⇒ String
The name of the list, which must be globally unique across all public lists in the portal.
-
#object_type_id ⇒ String
The object type ID of the type of objects that the list will store.
-
#processing_type ⇒ String
The processing type of the list.
Instance Method Summary collapse
-
#initialize(name:, object_type_id:, processing_type:, custom_properties: nil, filter_branch: nil, list_folder_id: nil, list_permissions: nil, membership_settings: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ListCreateRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, object_type_id:, processing_type:, custom_properties: nil, filter_branch: nil, list_folder_id: nil, list_permissions: nil, membership_settings: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::ListCreateRequest for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/list_create_request.rb', line 60
|
Instance Attribute Details
#custom_properties ⇒ Hash{Symbol=>String}?
The list of custom properties to tie to the list. Custom property name is the key, the value is the value.
31 |
# File 'lib/hubspot_sdk/models/crm/list_create_request.rb', line 31 optional :custom_properties, HubSpotSDK::Internal::Type::HashOf[String], api_name: :customProperties |
#filter_branch ⇒ HubSpotSDK::Models::Crm::PublicOrFilterBranch, ...
Filter branch object containing filtering criteria for the list
37 38 39 |
# File 'lib/hubspot_sdk/models/crm/list_create_request.rb', line 37 optional :filter_branch, union: -> { HubSpotSDK::Crm::ListCreateRequest::FilterBranch }, api_name: :filterBranch |
#list_folder_id ⇒ Integer?
The ID of the folder that the list should be created in. If left blank, then the list will be created in the root of the list folder structure.
46 |
# File 'lib/hubspot_sdk/models/crm/list_create_request.rb', line 46 optional :list_folder_id, Integer, api_name: :listFolderId |
#list_permissions ⇒ HubSpotSDK::Models::Crm::PublicListPermissions?
51 |
# File 'lib/hubspot_sdk/models/crm/list_create_request.rb', line 51 optional :list_permissions, -> { HubSpotSDK::Crm::PublicListPermissions }, api_name: :listPermissions |
#membership_settings ⇒ HubSpotSDK::Models::Crm::PublicMembershipSettings?
56 57 58 |
# File 'lib/hubspot_sdk/models/crm/list_create_request.rb', line 56 optional :membership_settings, -> { HubSpotSDK::Crm::PublicMembershipSettings }, api_name: :membershipSettings |
#name ⇒ String
The name of the list, which must be globally unique across all public lists in the portal.
12 |
# File 'lib/hubspot_sdk/models/crm/list_create_request.rb', line 12 required :name, String |
#object_type_id ⇒ String
The object type ID of the type of objects that the list will store.
18 |
# File 'lib/hubspot_sdk/models/crm/list_create_request.rb', line 18 required :object_type_id, String, api_name: :objectTypeId |
#processing_type ⇒ String
The processing type of the list. One of: ‘SNAPSHOT`, `MANUAL`, or `DYNAMIC`.
24 |
# File 'lib/hubspot_sdk/models/crm/list_create_request.rb', line 24 required :processing_type, String, api_name: :processingType |