Class: HubSpotSDK::Models::Crm::ListMoveRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::ListMoveRequest
- Defined in:
- lib/hubspot_sdk/models/crm/list_move_request.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#list_id ⇒ String
The Id of the list to move.
-
#new_folder_id ⇒ String
The Id of folder to move the list to, the root folder is Id 0.
Instance Method Summary collapse
- #initialize(list_id:, new_folder_id:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(list_id:, new_folder_id:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/list_move_request.rb', line 19
|
Instance Attribute Details
#list_id ⇒ String
The Id of the list to move.
11 |
# File 'lib/hubspot_sdk/models/crm/list_move_request.rb', line 11 required :list_id, String, api_name: :listId |
#new_folder_id ⇒ String
The Id of folder to move the list to, the root folder is Id 0.
17 |
# File 'lib/hubspot_sdk/models/crm/list_move_request.rb', line 17 required :new_folder_id, String, api_name: :newFolderId |