Class: HubSpotSDK::Models::Crm::ListSearchRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::ListSearchRequest
- Defined in:
- lib/hubspot_sdk/models/crm/list_search_request.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#additional_filter_properties ⇒ Array<String>?
The property names of any additional list properties to include in the response.
-
#count ⇒ Integer?
The number of lists to include in the response.
-
#list_ids ⇒ Array<String>
ILS list ids to be included in search results.
- #object_type_id ⇒ String?
-
#offset ⇒ Integer
Value used to paginate through lists.
-
#processing_types ⇒ Array<String>
List processing types to be included in search results.
-
#query ⇒ String?
The ‘query` that will be used to search for lists by list name.
-
#sort ⇒ String?
Sort field and order.
Instance Method Summary collapse
-
#initialize(list_ids:, offset:, processing_types:, additional_filter_properties: nil, count: nil, object_type_id: nil, query: nil, sort: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ListSearchRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(list_ids:, offset:, processing_types:, additional_filter_properties: nil, count: nil, object_type_id: nil, query: nil, sort: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::ListSearchRequest for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 66
|
Instance Attribute Details
#additional_filter_properties ⇒ Array<String>?
The property names of any additional list properties to include in the response. Properties that do not exist or that are empty for a particular list are not included in the response.
By default, all requests will fetch the following properties for each list: ‘hs_list_size`, `hs_last_record_added_at`, `hs_last_record_removed_at`, `hs_folder_name`, and `hs_list_reference_count`.
39 |
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 39 optional :additional_filter_properties, HubSpotSDK::Internal::Type::ArrayOf[String] |
#count ⇒ Integer?
The number of lists to include in the response. Defaults to ‘20` if no value is provided. The max `count` is `500`.
46 |
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 46 optional :count, Integer |
#list_ids ⇒ Array<String>
ILS list ids to be included in search results. If not specified, all lists matching other criteria will be included
12 |
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 12 required :list_ids, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :listIds |
#object_type_id ⇒ String?
51 |
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 51 optional :object_type_id, String, api_name: :objectTypeId |
#offset ⇒ Integer
Value used to paginate through lists. The ‘offset` provided in the response can be used in the next request to fetch the next page of results. Defaults to `0` if no offset is provided.
20 |
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 20 required :offset, Integer |
#processing_types ⇒ Array<String>
List processing types to be included in search results. If not specified, all lists with all processing types will be included.
27 |
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 27 required :processing_types, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :processingTypes |
#query ⇒ String?
The ‘query` that will be used to search for lists by list name. If no `query` is provided, then the results will include all lists.
58 |
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 58 optional :query, String |
#sort ⇒ String?
Sort field and order
64 |
# File 'lib/hubspot_sdk/models/crm/list_search_request.rb', line 64 optional :sort, String |