Class: HubSpotSDK::Models::Crm::ObjectSchemaBatchReadRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::ObjectSchemaBatchReadRequest
- Defined in:
- lib/hubspot_sdk/models/crm/object_schema_batch_read_request.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#include_association_definitions ⇒ Boolean
Indicates whether to include association definitions in the response.
-
#include_audit_metadata ⇒ Boolean
Indicates whether to include audit metadata in the response.
-
#include_property_definitions ⇒ Boolean
Indicates whether to include property definitions in the response.
- #inputs ⇒ Array<String>
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(include_association_definitions:, include_audit_metadata:, include_property_definitions:, inputs:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/object_schema_batch_read_request.rb', line 34
|
Instance Attribute Details
#include_association_definitions ⇒ Boolean
Indicates whether to include association definitions in the response.
11 12 13 |
# File 'lib/hubspot_sdk/models/crm/object_schema_batch_read_request.rb', line 11 required :include_association_definitions, HubSpotSDK::Internal::Type::Boolean, api_name: :includeAssociationDefinitions |
#include_audit_metadata ⇒ Boolean
Indicates whether to include audit metadata in the response.
19 |
# File 'lib/hubspot_sdk/models/crm/object_schema_batch_read_request.rb', line 19 required :include_audit_metadata, HubSpotSDK::Internal::Type::Boolean, api_name: :includeAuditMetadata |
#include_property_definitions ⇒ Boolean
Indicates whether to include property definitions in the response.
25 26 27 |
# File 'lib/hubspot_sdk/models/crm/object_schema_batch_read_request.rb', line 25 required :include_property_definitions, HubSpotSDK::Internal::Type::Boolean, api_name: :includePropertyDefinitions |
#inputs ⇒ Array<String>
32 |
# File 'lib/hubspot_sdk/models/crm/object_schema_batch_read_request.rb', line 32 required :inputs, HubSpotSDK::Internal::Type::ArrayOf[String] |