Class: HubSpotSDK::Models::Crm::ObjectTypePropertyCreate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::ObjectTypePropertyCreate
- Defined in:
- lib/hubspot_sdk/models/crm/object_type_property_create.rb
Defined Under Namespace
Modules: NumberDisplayHint, OptionSortStrategy, TextDisplayHint, Type
Instance Attribute Summary collapse
-
#description ⇒ String?
A description of the property that will be shown as help text in HubSpot.
-
#display_order ⇒ Integer?
The order that this property should be displayed in the HubSpot UI relative to other properties for this object type.
-
#external_options_reference_type ⇒ String?
Specifies the reference type for external options associated with the property.
-
#field_type ⇒ String
Controls how the property appears in HubSpot.
-
#form_field ⇒ Boolean?
Whether the property can be used in a HubSpot form.
-
#group_name ⇒ String?
The name of the group this property belongs to.
-
#has_unique_value ⇒ Boolean?
Whether or not the property’s value must be unique.
-
#hidden ⇒ Boolean?
Hidden options won’t be shown in HubSpot.
-
#label ⇒ String
A human-readable property label that will be shown in HubSpot.
-
#name ⇒ String
The internal property name, which must be used when referencing the property from the API.
-
#number_display_hint ⇒ Symbol, ...
Controls how numeric properties are formatted in the HubSpot UI.
-
#option_sort_strategy ⇒ Symbol, ...
Controls how the property options will be sorted in the HubSpot UI.
-
#options ⇒ Array<HubSpotSDK::Models::OptionInput>?
A list of available options for the property.
-
#referenced_object_type ⇒ String?
Defines the options this property will return, e.g.
-
#searchable_in_global_search ⇒ Boolean?
Allow users to search for information entered to this field (limited to 3 properties).
-
#show_currency_symbol ⇒ Boolean?
Whether the property will display the currency symbol in the HubSpot UI.
-
#text_display_hint ⇒ Symbol, ...
Controls how text properties are formatted in the HubSpot UI.
-
#type ⇒ Symbol, HubSpotSDK::Models::Crm::ObjectTypePropertyCreate::Type
The data type of the property.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(field_type:, label:, name:, type:, description: nil, display_order: nil, external_options_reference_type: nil, form_field: nil, group_name: nil, has_unique_value: nil, hidden: nil, number_display_hint: nil, options: nil, option_sort_strategy: nil, referenced_object_type: nil, searchable_in_global_search: nil, show_currency_symbol: nil, text_display_hint: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ObjectTypePropertyCreate for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(field_type:, label:, name:, type:, description: nil, display_order: nil, external_options_reference_type: nil, form_field: nil, group_name: nil, has_unique_value: nil, hidden: nil, number_display_hint: nil, options: nil, option_sort_strategy: nil, referenced_object_type: nil, searchable_in_global_search: nil, show_currency_symbol: nil, text_display_hint: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::ObjectTypePropertyCreate for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 131
|
Instance Attribute Details
#description ⇒ String?
A description of the property that will be shown as help text in HubSpot.
36 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 36 optional :description, String |
#display_order ⇒ Integer?
The order that this property should be displayed in the HubSpot UI relative to other properties for this object type. Properties are displayed in order starting with the lowest positive integer value. A value of -1 will cause the property to be displayed after any positive values.
45 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 45 optional :display_order, Integer, api_name: :displayOrder |
#external_options_reference_type ⇒ String?
Specifies the reference type for external options associated with the property.
51 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 51 optional :external_options_reference_type, String, api_name: :externalOptionsReferenceType |
#field_type ⇒ String
Controls how the property appears in HubSpot.
11 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 11 required :field_type, String, api_name: :fieldType |
#form_field ⇒ Boolean?
Whether the property can be used in a HubSpot form.
57 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 57 optional :form_field, HubSpotSDK::Internal::Type::Boolean, api_name: :formField |
#group_name ⇒ String?
The name of the group this property belongs to.
63 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 63 optional :group_name, String, api_name: :groupName |
#has_unique_value ⇒ Boolean?
Whether or not the property’s value must be unique. Once set, this can’t be changed.
70 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 70 optional :has_unique_value, HubSpotSDK::Internal::Type::Boolean, api_name: :hasUniqueValue |
#hidden ⇒ Boolean?
Hidden options won’t be shown in HubSpot.
76 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 76 optional :hidden, HubSpotSDK::Internal::Type::Boolean |
#label ⇒ String
A human-readable property label that will be shown in HubSpot.
17 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 17 required :label, String |
#name ⇒ String
The internal property name, which must be used when referencing the property from the API.
24 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 24 required :name, String |
#number_display_hint ⇒ Symbol, ...
Controls how numeric properties are formatted in the HubSpot UI
82 83 84 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 82 optional :number_display_hint, enum: -> { HubSpotSDK::Crm::ObjectTypePropertyCreate::NumberDisplayHint }, api_name: :numberDisplayHint |
#option_sort_strategy ⇒ Symbol, ...
Controls how the property options will be sorted in the HubSpot UI.
97 98 99 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 97 optional :option_sort_strategy, enum: -> { HubSpotSDK::Crm::ObjectTypePropertyCreate::OptionSortStrategy }, api_name: :optionSortStrategy |
#options ⇒ Array<HubSpotSDK::Models::OptionInput>?
A list of available options for the property. This field is only required for enumerated properties.
91 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 91 optional :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::OptionInput] } |
#referenced_object_type ⇒ String?
Defines the options this property will return, e.g. OWNER would return name of users on the portal.
106 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 106 optional :referenced_object_type, String, api_name: :referencedObjectType |
#searchable_in_global_search ⇒ Boolean?
Allow users to search for information entered to this field (limited to 3 properties)
113 114 115 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 113 optional :searchable_in_global_search, HubSpotSDK::Internal::Type::Boolean, api_name: :searchableInGlobalSearch |
#show_currency_symbol ⇒ Boolean?
Whether the property will display the currency symbol in the HubSpot UI.
121 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 121 optional :show_currency_symbol, HubSpotSDK::Internal::Type::Boolean, api_name: :showCurrencySymbol |
#text_display_hint ⇒ Symbol, ...
Controls how text properties are formatted in the HubSpot UI
127 128 129 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 127 optional :text_display_hint, enum: -> { HubSpotSDK::Crm::ObjectTypePropertyCreate::TextDisplayHint }, api_name: :textDisplayHint |
#type ⇒ Symbol, HubSpotSDK::Models::Crm::ObjectTypePropertyCreate::Type
The data type of the property.
30 |
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 30 required :type, enum: -> { HubSpotSDK::Crm::ObjectTypePropertyCreate::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/crm/object_type_property_create.rb', line 185
|