Class: HubSpotSDK::Models::Crm::Objects::PublicGdprDeleteInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Objects::PublicGdprDeleteInput
- Defined in:
- lib/hubspot_sdk/models/crm/objects/public_gdpr_delete_input.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#id_property ⇒ String?
The name of a property whose values are unique for this object.
-
#object_id_ ⇒ String
The ID of the contact to permanently delete.
Instance Method Summary collapse
-
#initialize(object_id_:, id_property: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicGdprDeleteInput for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(object_id_:, id_property: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Objects::PublicGdprDeleteInput for more details.
An input that contains the information required to process a public GDPR data deletion request.
|
|
# File 'lib/hubspot_sdk/models/crm/objects/public_gdpr_delete_input.rb', line 21
|
Instance Attribute Details
#id_property ⇒ String?
The name of a property whose values are unique for this object. An alternative to identifying a contact by ID.
19 |
# File 'lib/hubspot_sdk/models/crm/objects/public_gdpr_delete_input.rb', line 19 optional :id_property, String, api_name: :idProperty |
#object_id_ ⇒ String
The ID of the contact to permanently delete.
12 |
# File 'lib/hubspot_sdk/models/crm/objects/public_gdpr_delete_input.rb', line 12 required :object_id_, String, api_name: :objectId |