Class: HubSpotSDK::Models::Crm::OwnerListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::OwnerListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/crm/owner_list_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
-
#archived ⇒ Boolean?
Whether to return only results that have been archived.
-
#email ⇒ String?
Filter by email address (optional).
-
#limit ⇒ Integer?
The maximum number of results to display per page.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(after: nil, archived: nil, email: nil, limit: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see OwnerListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, archived: nil, email: nil, limit: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::OwnerListParams for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/owner_list_params.rb', line 37
|
Instance Attribute Details
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
17 |
# File 'lib/hubspot_sdk/models/crm/owner_list_params.rb', line 17 optional :after, String |
#archived ⇒ Boolean?
Whether to return only results that have been archived.
23 |
# File 'lib/hubspot_sdk/models/crm/owner_list_params.rb', line 23 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#email ⇒ String?
Filter by email address (optional)
29 |
# File 'lib/hubspot_sdk/models/crm/owner_list_params.rb', line 29 optional :email, String |
#limit ⇒ Integer?
The maximum number of results to display per page.
35 |
# File 'lib/hubspot_sdk/models/crm/owner_list_params.rb', line 35 optional :limit, Integer |