Class: HubSpotSDK::Models::Crm::Pipeline
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Pipeline
- Defined in:
- lib/hubspot_sdk/models/crm/pipeline.rb
Overview
Instance Attribute Summary collapse
-
#archived ⇒ Boolean
Whether the pipeline is archived.
-
#archived_at ⇒ Time?
The date the pipeline was archived.
-
#created_at ⇒ Time
The date the pipeline was created.
-
#display_order ⇒ Integer
The order for displaying this pipeline.
-
#id ⇒ String
A unique identifier generated by HubSpot that can be used to retrieve and update the pipeline.
-
#label ⇒ String
A unique label used to organize pipelines in HubSpot’s UI.
-
#stages ⇒ Array<HubSpotSDK::Models::Crm::PipelineStage>
The stages associated with the pipeline.
-
#updated_at ⇒ Time
The date the pipeline was last updated.
Instance Method Summary collapse
-
#initialize(id:, archived:, created_at:, display_order:, label:, stages:, updated_at:, archived_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Pipeline for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived:, created_at:, display_order:, label:, stages:, updated_at:, archived_at: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Pipeline for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/pipeline.rb', line 61
|
Instance Attribute Details
#archived ⇒ Boolean
Whether the pipeline is archived.
19 |
# File 'lib/hubspot_sdk/models/crm/pipeline.rb', line 19 required :archived, HubSpotSDK::Internal::Type::Boolean |
#archived_at ⇒ Time?
The date the pipeline was archived. ‘archivedAt` will only be present if the pipeline is archived.
59 |
# File 'lib/hubspot_sdk/models/crm/pipeline.rb', line 59 optional :archived_at, Time, api_name: :archivedAt |
#created_at ⇒ Time
The date the pipeline was created. The default pipelines will have createdAt
0.
26 |
# File 'lib/hubspot_sdk/models/crm/pipeline.rb', line 26 required :created_at, Time, api_name: :createdAt |
#display_order ⇒ Integer
The order for displaying this pipeline. If two pipelines have a matching ‘displayOrder`, they will be sorted alphabetically by label.
33 |
# File 'lib/hubspot_sdk/models/crm/pipeline.rb', line 33 required :display_order, Integer, api_name: :displayOrder |
#id ⇒ String
A unique identifier generated by HubSpot that can be used to retrieve and update the pipeline.
13 |
# File 'lib/hubspot_sdk/models/crm/pipeline.rb', line 13 required :id, String |
#label ⇒ String
A unique label used to organize pipelines in HubSpot’s UI
39 |
# File 'lib/hubspot_sdk/models/crm/pipeline.rb', line 39 required :label, String |
#stages ⇒ Array<HubSpotSDK::Models::Crm::PipelineStage>
The stages associated with the pipeline. They can be retrieved and updated via the pipeline stages endpoints.
46 |
# File 'lib/hubspot_sdk/models/crm/pipeline.rb', line 46 required :stages, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::PipelineStage] } |
#updated_at ⇒ Time
The date the pipeline was last updated.
52 |
# File 'lib/hubspot_sdk/models/crm/pipeline.rb', line 52 required :updated_at, Time, api_name: :updatedAt |