Class: HubSpotSDK::Models::Crm::PipelineInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PipelineInput
- Defined in:
- lib/hubspot_sdk/models/crm/pipeline_input.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#display_order ⇒ Integer
The order for displaying this pipeline.
-
#label ⇒ String
A unique label used to organize pipelines in HubSpot’s UI.
- #pipeline_id ⇒ String?
-
#stages ⇒ Array<HubSpotSDK::Models::Crm::PipelineStageInput>
Pipeline stage inputs used to create the new or replacement pipeline.
Instance Method Summary collapse
-
#initialize(display_order:, label:, stages:, pipeline_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PipelineInput for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(display_order:, label:, stages:, pipeline_id: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PipelineInput for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/pipeline_input.rb', line 31
|
Instance Attribute Details
#display_order ⇒ Integer
The order for displaying this pipeline. If two pipelines have a matching ‘displayOrder`, they will be sorted alphabetically by label.
12 |
# File 'lib/hubspot_sdk/models/crm/pipeline_input.rb', line 12 required :display_order, Integer, api_name: :displayOrder |
#label ⇒ String
A unique label used to organize pipelines in HubSpot’s UI
18 |
# File 'lib/hubspot_sdk/models/crm/pipeline_input.rb', line 18 required :label, String |
#pipeline_id ⇒ String?
29 |
# File 'lib/hubspot_sdk/models/crm/pipeline_input.rb', line 29 optional :pipeline_id, String, api_name: :pipelineId |
#stages ⇒ Array<HubSpotSDK::Models::Crm::PipelineStageInput>
Pipeline stage inputs used to create the new or replacement pipeline.
24 |
# File 'lib/hubspot_sdk/models/crm/pipeline_input.rb', line 24 required :stages, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::PipelineStageInput] } |