Class: HubSpotSDK::Models::Crm::PipelinePatchInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PipelinePatchInput
- Defined in:
- lib/hubspot_sdk/models/crm/pipeline_patch_input.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#archived ⇒ Boolean?
Whether the pipeline is archived.
-
#display_order ⇒ Integer?
The order for displaying this pipeline.
-
#label ⇒ String?
A unique label used to organize pipelines in HubSpot’s UI.
Instance Method Summary collapse
-
#initialize(archived: nil, display_order: nil, label: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PipelinePatchInput for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(archived: nil, display_order: nil, label: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PipelinePatchInput for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/pipeline_patch_input.rb', line 28
|
Instance Attribute Details
#archived ⇒ Boolean?
Whether the pipeline is archived. This property should only be provided when restoring an archived pipeline. If it’s provided in any other call, the request will fail and a ‘400 Bad Request` will be returned.
13 |
# File 'lib/hubspot_sdk/models/crm/pipeline_patch_input.rb', line 13 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#display_order ⇒ Integer?
The order for displaying this pipeline. If two pipelines have a matching ‘displayOrder`, they will be sorted alphabetically by label.
20 |
# File 'lib/hubspot_sdk/models/crm/pipeline_patch_input.rb', line 20 optional :display_order, Integer, api_name: :displayOrder |
#label ⇒ String?
A unique label used to organize pipelines in HubSpot’s UI
26 |
# File 'lib/hubspot_sdk/models/crm/pipeline_patch_input.rb', line 26 optional :label, String |