Class: HubSpotSDK::Models::Crm::PipelineReplaceInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PipelineReplaceInput
- Defined in:
- lib/hubspot_sdk/models/crm/pipeline_replace_input.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#display_order ⇒ Integer
The order for displaying this pipeline stage.
-
#label ⇒ String
A label used to organize pipeline stages in HubSpot’s UI.
-
#stages ⇒ Array<HubSpotSDK::Models::Crm::PipelineStageInput>
The stages associated with the pipeline.
Instance Method Summary collapse
-
#initialize(display_order:, label:, stages:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PipelineReplaceInput for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(display_order:, label:, stages:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PipelineReplaceInput for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/pipeline_replace_input.rb', line 28
|
Instance Attribute Details
#display_order ⇒ Integer
The order for displaying this pipeline stage. If two pipeline stages have a matching ‘displayOrder`, they will be sorted alphabetically by label.
12 |
# File 'lib/hubspot_sdk/models/crm/pipeline_replace_input.rb', line 12 required :display_order, Integer, api_name: :displayOrder |
#label ⇒ String
A label used to organize pipeline stages in HubSpot’s UI. Each pipeline stage’s label must be unique within that pipeline.
19 |
# File 'lib/hubspot_sdk/models/crm/pipeline_replace_input.rb', line 19 required :label, String |
#stages ⇒ Array<HubSpotSDK::Models::Crm::PipelineStageInput>
The stages associated with the pipeline. They can be retrieved and updated via the pipeline stages endpoints.
26 |
# File 'lib/hubspot_sdk/models/crm/pipeline_replace_input.rb', line 26 required :stages, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::PipelineStageInput] } |