Class: HubSpotSDK::Models::Crm::PipelineStage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PipelineStage
- Defined in:
- lib/hubspot_sdk/models/crm/pipeline_stage.rb
Overview
Defined Under Namespace
Modules: WritePermissions
Instance Attribute Summary collapse
-
#archived ⇒ Boolean
Whether the pipeline is archived.
-
#archived_at ⇒ Time?
The date the pipeline was archived.
-
#created_at ⇒ Time
The date the pipeline stage was created.
-
#display_order ⇒ Integer
The order for displaying this pipeline stage.
-
#id ⇒ String
A unique identifier generated by HubSpot that can be used to retrieve and update the pipeline stage.
-
#label ⇒ String
A label used to organize pipeline stages in HubSpot’s UI.
-
#metadata ⇒ Hash{Symbol=>String}
A JSON object containing properties that are not present on all object pipelines.
-
#updated_at ⇒ Time
The date the pipeline stage was last updated.
-
#write_permissions ⇒ Symbol, HubSpotSDK::Models::Crm::PipelineStage::WritePermissions
Defines the level of write access for the pipeline stage, with possible values being CRM_PERMISSIONS_ENFORCEMENT, READ_ONLY, or INTERNAL_ONLY.
Instance Method Summary collapse
-
#initialize(id:, archived:, created_at:, display_order:, label:, metadata:, updated_at:, write_permissions:, archived_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PipelineStage for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived:, created_at:, display_order:, label:, metadata:, updated_at:, write_permissions:, archived_at: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PipelineStage for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 80
|
Instance Attribute Details
#archived ⇒ Boolean
Whether the pipeline is archived.
19 |
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 19 required :archived, HubSpotSDK::Internal::Type::Boolean |
#archived_at ⇒ Time?
The date the pipeline was archived. ‘archivedAt` will only be present if the pipeline is archived.
78 |
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 78 optional :archived_at, Time, api_name: :archivedAt |
#created_at ⇒ Time
The date the pipeline stage was created. The stages on default pipelines will have createdAt = 0.
26 |
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 26 required :created_at, Time, api_name: :createdAt |
#display_order ⇒ Integer
The order for displaying this pipeline stage. If two pipeline stages have a matching ‘displayOrder`, they will be sorted alphabetically by label.
33 |
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 33 required :display_order, Integer, api_name: :displayOrder |
#id ⇒ String
A unique identifier generated by HubSpot that can be used to retrieve and update the pipeline stage.
13 |
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 13 required :id, String |
#label ⇒ String
A label used to organize pipeline stages in HubSpot’s UI. Each pipeline stage’s label must be unique within that pipeline.
40 |
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 40 required :label, String |
#metadata ⇒ Hash{Symbol=>String}
A JSON object containing properties that are not present on all object pipelines.
For ‘deals` pipelines, the `probability` field is required (`{ “probability”: 0.5 }`), and represents the likelihood a deal will close. Possible values are between 0.0 and 1.0 in increments of 0.1.
For ‘tickets` pipelines, the `ticketState` field is optional (`{ “ticketState”: “OPEN” }`), and represents whether the ticket remains open or has been closed by a member of your Support team. Possible values are `OPEN` or `CLOSED`.
56 |
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 56 required :metadata, HubSpotSDK::Internal::Type::HashOf[String] |
#updated_at ⇒ Time
The date the pipeline stage was last updated.
62 |
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 62 required :updated_at, Time, api_name: :updatedAt |
#write_permissions ⇒ Symbol, HubSpotSDK::Models::Crm::PipelineStage::WritePermissions
Defines the level of write access for the pipeline stage, with possible values being CRM_PERMISSIONS_ENFORCEMENT, READ_ONLY, or INTERNAL_ONLY.
69 70 71 |
# File 'lib/hubspot_sdk/models/crm/pipeline_stage.rb', line 69 required :write_permissions, enum: -> { HubSpotSDK::Crm::PipelineStage::WritePermissions }, api_name: :writePermissions |