Class: HubSpotSDK::Models::Crm::PipelineStageInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PipelineStageInput
- Defined in:
- lib/hubspot_sdk/models/crm/pipeline_stage_input.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#display_order ⇒ Integer
The order for displaying this pipeline stage.
-
#label ⇒ String
A label used to organize pipeline stages in HubSpot’s UI.
-
#metadata ⇒ Hash{Symbol=>String}
A JSON object containing properties that are not present on all object pipelines.
- #stage_id ⇒ String?
Instance Method Summary collapse
-
#initialize(display_order:, label:, metadata:, stage_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PipelineStageInput for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(display_order:, label:, metadata:, stage_id: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PipelineStageInput for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/pipeline_stage_input.rb', line 42
|
Instance Attribute Details
#display_order ⇒ Integer
The order for displaying this pipeline stage. If two pipeline stages have a matching ‘displayOrder`, they will be sorted alphabetically by label.
12 |
# File 'lib/hubspot_sdk/models/crm/pipeline_stage_input.rb', line 12 required :display_order, Integer, api_name: :displayOrder |
#label ⇒ String
A label used to organize pipeline stages in HubSpot’s UI. Each pipeline stage’s label must be unique within that pipeline.
19 |
# File 'lib/hubspot_sdk/models/crm/pipeline_stage_input.rb', line 19 required :label, String |
#metadata ⇒ Hash{Symbol=>String}
A JSON object containing properties that are not present on all object pipelines.
For ‘deals` pipelines, the `probability` field is required (`{ “probability”: 0.5 }`), and represents the likelihood a deal will close. Possible values are between 0.0 and 1.0 in increments of 0.1.
For ‘tickets` pipelines, the `ticketState` field is optional (`{ “ticketState”: “OPEN” }`), and represents whether the ticket remains open or has been closed by a member of your Support team. Possible values are `OPEN` or `CLOSED`.
35 |
# File 'lib/hubspot_sdk/models/crm/pipeline_stage_input.rb', line 35 required :metadata, HubSpotSDK::Internal::Type::HashOf[String] |
#stage_id ⇒ String?
40 |
# File 'lib/hubspot_sdk/models/crm/pipeline_stage_input.rb', line 40 optional :stage_id, String, api_name: :stageId |