Class: HubSpotSDK::Models::Crm::Property
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::Property
- Defined in:
- lib/hubspot_sdk/models/crm/property.rb
Defined Under Namespace
Modules: DataSensitivity, DateDisplayHint
Instance Attribute Summary collapse
-
#archived ⇒ Boolean?
Whether or not the property is archived.
-
#archived_at ⇒ Time?
When the property was archived.
-
#calculated ⇒ Boolean?
For default properties, true indicates that the property is calculated by a HubSpot process.
-
#calculation_formula ⇒ String?
The formula used for calculated properties.
-
#created_at ⇒ Time?
When the property was created.
-
#created_user_id ⇒ String?
The internal ID of the user who created the property in HubSpot.
-
#currency_property_name ⇒ String?
The name of the related currency property.
-
#data_sensitivity ⇒ Symbol, ...
Indicates the sensitivity level of the property, such as “non_sensitive”, “sensitive”, or “highly_sensitive”.
-
#date_display_hint ⇒ Symbol, ...
Controls how date properties are displayed in the HubSpot UI, with options such as ‘absolute’, ‘absolute_with_relative’, ‘time_since’, and ‘time_until’.
-
#description ⇒ String
A description of the property that will be shown as help text in HubSpot.
-
#display_order ⇒ Integer?
The order that this property should be displayed in the HubSpot UI relative to other properties for this object type.
-
#external_options ⇒ Boolean?
For default properties, true indicates that the options are stored externally to the property settings.
-
#field_type ⇒ String
Controls how the property appears in HubSpot.
-
#form_field ⇒ Boolean?
Whether or not the property can be used in a HubSpot form.
-
#group_name ⇒ String
The name of the property group the property belongs to.
-
#has_unique_value ⇒ Boolean?
Whether or not the property’s value must be unique.
-
#hidden ⇒ Boolean?
Hidden options won’t be shown in HubSpot.
-
#hubspot_defined ⇒ Boolean?
This will be true for default object properties built into HubSpot.
-
#label ⇒ String
A human-readable property label that will be shown in HubSpot.
- #modification_metadata ⇒ HubSpotSDK::Models::PropertyModificationMetadata?
-
#name ⇒ String
The internal property name, which must be used when referencing the property via the API.
-
#options ⇒ Array<HubSpotSDK::Models::Option>
A list of valid options for the property.
-
#referenced_object_type ⇒ String?
If this property is related to other object(s), they’ll be listed here.
-
#sensitive_data_categories ⇒ Array<String>?
When sensitiveData is true, lists the type of sensitive data contained in the property (e.g., “HIPAA”).
-
#show_currency_symbol ⇒ Boolean?
Whether the property will display the currency symbol set in the account settings.
-
#type ⇒ String
The property data type.
-
#updated_at ⇒ Time?
When the object type was last updated.
-
#updated_user_id ⇒ String?
The internal user ID of the user who updated the property in HubSpot.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(description:, field_type:, group_name:, label:, name:, options:, type:, archived: nil, archived_at: nil, calculated: nil, calculation_formula: nil, created_at: nil, created_user_id: nil, currency_property_name: nil, data_sensitivity: nil, date_display_hint: nil, display_order: nil, external_options: nil, form_field: nil, has_unique_value: nil, hidden: nil, hubspot_defined: nil, modification_metadata: nil, referenced_object_type: nil, sensitive_data_categories: nil, show_currency_symbol: nil, updated_at: nil, updated_user_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Property for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(description:, field_type:, group_name:, label:, name:, options:, type:, archived: nil, archived_at: nil, calculated: nil, calculation_formula: nil, created_at: nil, created_user_id: nil, currency_property_name: nil, data_sensitivity: nil, date_display_hint: nil, display_order: nil, external_options: nil, form_field: nil, has_unique_value: nil, hidden: nil, hubspot_defined: nil, modification_metadata: nil, referenced_object_type: nil, sensitive_data_categories: nil, show_currency_symbol: nil, updated_at: nil, updated_user_id: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::Property for more details.
A HubSpot property
|
|
# File 'lib/hubspot_sdk/models/crm/property.rb', line 196
|
Instance Attribute Details
#archived ⇒ Boolean?
Whether or not the property is archived.
55 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 55 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#archived_at ⇒ Time?
When the property was archived.
61 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 61 optional :archived_at, Time, api_name: :archivedAt |
#calculated ⇒ Boolean?
For default properties, true indicates that the property is calculated by a HubSpot process. It has no effect for custom properties.
68 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 68 optional :calculated, HubSpotSDK::Internal::Type::Boolean |
#calculation_formula ⇒ String?
The formula used for calculated properties.
74 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 74 optional :calculation_formula, String, api_name: :calculationFormula |
#created_at ⇒ Time?
When the property was created
80 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 80 optional :created_at, Time, api_name: :createdAt |
#created_user_id ⇒ String?
The internal ID of the user who created the property in HubSpot. This field may not exist if the property was created outside of HubSpot.
87 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 87 optional :created_user_id, String, api_name: :createdUserId |
#currency_property_name ⇒ String?
The name of the related currency property.
93 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 93 optional :currency_property_name, String, api_name: :currencyPropertyName |
#data_sensitivity ⇒ Symbol, ...
Indicates the sensitivity level of the property, such as “non_sensitive”, “sensitive”, or “highly_sensitive”.
100 101 102 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 100 optional :data_sensitivity, enum: -> { HubSpotSDK::Crm::Property::DataSensitivity }, api_name: :dataSensitivity |
#date_display_hint ⇒ Symbol, ...
Controls how date properties are displayed in the HubSpot UI, with options such as ‘absolute’, ‘absolute_with_relative’, ‘time_since’, and ‘time_until’.
109 110 111 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 109 optional :date_display_hint, enum: -> { HubSpotSDK::Crm::Property::DateDisplayHint }, api_name: :dateDisplayHint |
#description ⇒ String
A description of the property that will be shown as help text in HubSpot.
11 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 11 required :description, String |
#display_order ⇒ Integer?
The order that this property should be displayed in the HubSpot UI relative to other properties for this object type. Properties are displayed in order starting with the lowest positive integer value. A value of -1 will cause the property to be displayed after any positive values.
120 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 120 optional :display_order, Integer, api_name: :displayOrder |
#external_options ⇒ Boolean?
For default properties, true indicates that the options are stored externally to the property settings.
127 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 127 optional :external_options, HubSpotSDK::Internal::Type::Boolean, api_name: :externalOptions |
#field_type ⇒ String
Controls how the property appears in HubSpot.
17 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 17 required :field_type, String, api_name: :fieldType |
#form_field ⇒ Boolean?
Whether or not the property can be used in a HubSpot form.
133 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 133 optional :form_field, HubSpotSDK::Internal::Type::Boolean, api_name: :formField |
#group_name ⇒ String
The name of the property group the property belongs to.
23 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 23 required :group_name, String, api_name: :groupName |
#has_unique_value ⇒ Boolean?
Whether or not the property’s value must be unique. Once set, this can’t be changed.
140 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 140 optional :has_unique_value, HubSpotSDK::Internal::Type::Boolean, api_name: :hasUniqueValue |
#hidden ⇒ Boolean?
Hidden options won’t be shown in HubSpot.
146 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 146 optional :hidden, HubSpotSDK::Internal::Type::Boolean |
#hubspot_defined ⇒ Boolean?
This will be true for default object properties built into HubSpot.
152 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 152 optional :hubspot_defined, HubSpotSDK::Internal::Type::Boolean, api_name: :hubspotDefined |
#label ⇒ String
A human-readable property label that will be shown in HubSpot.
29 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 29 required :label, String |
#modification_metadata ⇒ HubSpotSDK::Models::PropertyModificationMetadata?
157 158 159 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 157 optional :modification_metadata, -> { HubSpotSDK::PropertyModificationMetadata }, api_name: :modificationMetadata |
#name ⇒ String
The internal property name, which must be used when referencing the property via the API.
36 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 36 required :name, String |
#options ⇒ Array<HubSpotSDK::Models::Option>
A list of valid options for the property. This field is required for enumerated properties, but will be empty for other property types.
43 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 43 required :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Option] } |
#referenced_object_type ⇒ String?
If this property is related to other object(s), they’ll be listed here.
165 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 165 optional :referenced_object_type, String, api_name: :referencedObjectType |
#sensitive_data_categories ⇒ Array<String>?
When sensitiveData is true, lists the type of sensitive data contained in the property (e.g., “HIPAA”).
172 173 174 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 172 optional :sensitive_data_categories, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :sensitiveDataCategories |
#show_currency_symbol ⇒ Boolean?
Whether the property will display the currency symbol set in the account settings.
181 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 181 optional :show_currency_symbol, HubSpotSDK::Internal::Type::Boolean, api_name: :showCurrencySymbol |
#type ⇒ String
The property data type.
49 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 49 required :type, String |
#updated_at ⇒ Time?
When the object type was last updated.
187 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 187 optional :updated_at, Time, api_name: :updatedAt |
#updated_user_id ⇒ String?
The internal user ID of the user who updated the property in HubSpot. This field may not exist if the property was updated outside of HubSpot.
194 |
# File 'lib/hubspot_sdk/models/crm/property.rb', line 194 optional :updated_user_id, String, api_name: :updatedUserId |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/crm/property.rb', line 269
|