Class: HubSpotSDK::Models::Crm::PropertyUpdate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PropertyUpdate
- Defined in:
- lib/hubspot_sdk/models/crm/property_update.rb
Direct Known Subclasses
Defined Under Namespace
Instance Attribute Summary collapse
-
#calculation_formula ⇒ String?
Represents a formula that is used to compute a calculated property.
- #currency_property_name ⇒ String?
-
#description ⇒ String?
A description of the property that will be shown as help text in HubSpot.
-
#display_order ⇒ Integer?
Properties are displayed in order starting with the lowest positive integer value.
-
#field_type ⇒ Symbol, ...
Controls how the property appears in HubSpot.
-
#form_field ⇒ Boolean?
Whether or not the property can be used in a HubSpot form.
-
#group_name ⇒ String?
The name of the property group the property belongs to.
-
#hidden ⇒ Boolean?
If true, the property won’t be visible and can’t be used in HubSpot.
-
#label ⇒ String?
A human-readable property label that will be shown in HubSpot.
-
#options ⇒ Array<HubSpotSDK::Models::OptionInput>?
A list of valid options for the property.
- #show_currency_symbol ⇒ Boolean?
-
#type ⇒ Symbol, ...
The data type of the property.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(calculation_formula: nil, currency_property_name: nil, description: nil, display_order: nil, field_type: nil, form_field: nil, group_name: nil, hidden: nil, label: nil, options: nil, show_currency_symbol: nil, type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PropertyUpdate for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(calculation_formula: nil, currency_property_name: nil, description: nil, display_order: nil, field_type: nil, form_field: nil, group_name: nil, hidden: nil, label: nil, options: nil, show_currency_symbol: nil, type: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PropertyUpdate for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/property_update.rb', line 79
|
Instance Attribute Details
#calculation_formula ⇒ String?
Represents a formula that is used to compute a calculated property.
11 |
# File 'lib/hubspot_sdk/models/crm/property_update.rb', line 11 optional :calculation_formula, String, api_name: :calculationFormula |
#currency_property_name ⇒ String?
16 |
# File 'lib/hubspot_sdk/models/crm/property_update.rb', line 16 optional :currency_property_name, String, api_name: :currencyPropertyName |
#description ⇒ String?
A description of the property that will be shown as help text in HubSpot.
22 |
# File 'lib/hubspot_sdk/models/crm/property_update.rb', line 22 optional :description, String |
#display_order ⇒ Integer?
Properties are displayed in order starting with the lowest positive integer value. Values of -1 will cause the Property to be displayed after any positive values.
30 |
# File 'lib/hubspot_sdk/models/crm/property_update.rb', line 30 optional :display_order, Integer, api_name: :displayOrder |
#field_type ⇒ Symbol, ...
Controls how the property appears in HubSpot.
36 |
# File 'lib/hubspot_sdk/models/crm/property_update.rb', line 36 optional :field_type, enum: -> { HubSpotSDK::Crm::PropertyUpdate::FieldType }, api_name: :fieldType |
#form_field ⇒ Boolean?
Whether or not the property can be used in a HubSpot form.
42 |
# File 'lib/hubspot_sdk/models/crm/property_update.rb', line 42 optional :form_field, HubSpotSDK::Internal::Type::Boolean, api_name: :formField |
#group_name ⇒ String?
The name of the property group the property belongs to.
48 |
# File 'lib/hubspot_sdk/models/crm/property_update.rb', line 48 optional :group_name, String, api_name: :groupName |
#hidden ⇒ Boolean?
If true, the property won’t be visible and can’t be used in HubSpot.
54 |
# File 'lib/hubspot_sdk/models/crm/property_update.rb', line 54 optional :hidden, HubSpotSDK::Internal::Type::Boolean |
#label ⇒ String?
A human-readable property label that will be shown in HubSpot.
60 |
# File 'lib/hubspot_sdk/models/crm/property_update.rb', line 60 optional :label, String |
#options ⇒ Array<HubSpotSDK::Models::OptionInput>?
A list of valid options for the property.
66 |
# File 'lib/hubspot_sdk/models/crm/property_update.rb', line 66 optional :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::OptionInput] } |
#show_currency_symbol ⇒ Boolean?
71 |
# File 'lib/hubspot_sdk/models/crm/property_update.rb', line 71 optional :show_currency_symbol, HubSpotSDK::Internal::Type::Boolean, api_name: :showCurrencySymbol |
#type ⇒ Symbol, ...
The data type of the property.
77 |
# File 'lib/hubspot_sdk/models/crm/property_update.rb', line 77 optional :type, enum: -> { HubSpotSDK::Crm::PropertyUpdate::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/crm/property_update.rb', line 126
|