Class: HubSpotSDK::Models::Crm::PublicAssociationDefinitionCreateRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicAssociationDefinitionCreateRequest
- Defined in:
- lib/hubspot_sdk/models/crm/public_association_definition_create_request.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#inverse_label ⇒ String?
An optional descriptor that clarifies the reverse relationship in the association.
-
#label ⇒ String
A descriptor that provides context about the relationship between two associated CRM objects.
-
#name ⇒ String
The unique identifier for the association definition.
Instance Method Summary collapse
-
#initialize(label:, name:, inverse_label: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicAssociationDefinitionCreateRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(label:, name:, inverse_label: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicAssociationDefinitionCreateRequest for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_association_definition_create_request.rb', line 27
|
Instance Attribute Details
#inverse_label ⇒ String?
An optional descriptor that clarifies the reverse relationship in the association.
25 |
# File 'lib/hubspot_sdk/models/crm/public_association_definition_create_request.rb', line 25 optional :inverse_label, String, api_name: :inverseLabel |
#label ⇒ String
A descriptor that provides context about the relationship between two associated CRM objects.
12 |
# File 'lib/hubspot_sdk/models/crm/public_association_definition_create_request.rb', line 12 required :label, String |
#name ⇒ String
The unique identifier for the association definition.
18 |
# File 'lib/hubspot_sdk/models/crm/public_association_definition_create_request.rb', line 18 required :name, String |