Class: HubSpotSDK::Models::Crm::PublicAuditInfo
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicAuditInfo
- Defined in:
- lib/hubspot_sdk/models/crm/public_audit_info.rb
Instance Attribute Summary collapse
-
#action ⇒ String
The action performed that triggered the audit event.
-
#from_user_id ⇒ Integer?
The ID of the user who initiated the audit event.
-
#identifier ⇒ String
A unique string identifier for the audit event.
-
#message ⇒ String?
A descriptive message related to the audit event.
-
#portal_id ⇒ Integer
The unique identifier for the HubSpot portal where the audit event occurred.
-
#raw_object ⇒ Object?
An object containing the raw data associated with the audit event.
-
#timestamp ⇒ Time?
The date and time when the audit event took place.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(action:, identifier:, portal_id:, from_user_id: nil, message: nil, raw_object: nil, timestamp: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/public_audit_info.rb', line 49
|
Instance Attribute Details
#action ⇒ String
The action performed that triggered the audit event.
11 |
# File 'lib/hubspot_sdk/models/crm/public_audit_info.rb', line 11 required :action, String |
#from_user_id ⇒ Integer?
The ID of the user who initiated the audit event.
29 |
# File 'lib/hubspot_sdk/models/crm/public_audit_info.rb', line 29 optional :from_user_id, Integer, api_name: :fromUserId |
#identifier ⇒ String
A unique string identifier for the audit event.
17 |
# File 'lib/hubspot_sdk/models/crm/public_audit_info.rb', line 17 required :identifier, String |
#message ⇒ String?
A descriptive message related to the audit event.
35 |
# File 'lib/hubspot_sdk/models/crm/public_audit_info.rb', line 35 optional :message, String |
#portal_id ⇒ Integer
The unique identifier for the HubSpot portal where the audit event occurred.
23 |
# File 'lib/hubspot_sdk/models/crm/public_audit_info.rb', line 23 required :portal_id, Integer, api_name: :portalId |
#raw_object ⇒ Object?
An object containing the raw data associated with the audit event.
41 |
# File 'lib/hubspot_sdk/models/crm/public_audit_info.rb', line 41 optional :raw_object, HubSpotSDK::Internal::Type::Unknown, api_name: :rawObject |
#timestamp ⇒ Time?
The date and time when the audit event took place.
47 |
# File 'lib/hubspot_sdk/models/crm/public_audit_info.rb', line 47 optional :timestamp, Time |