Class: HubSpotSDK::Models::Crm::PublicCalendarDatePropertyOperation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicCalendarDatePropertyOperation
- Defined in:
- lib/hubspot_sdk/models/crm/public_calendar_date_property_operation.rb
Defined Under Namespace
Modules: FiscalYearStart, OperationType
Instance Attribute Summary collapse
-
#fiscal_year_start ⇒ Symbol, ...
The month in which the fiscal year starts.
-
#include_objects_with_no_value_set ⇒ Boolean
Indicates whether objects with no value set for the property should be included.
-
#operation_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicCalendarDatePropertyOperation::OperationType
The type of operation, which is (CALENDAR_DATE).
-
#operator ⇒ String
Defines the operation to be applied to the calendar date property (IN_THIS_TIME_UNIT, IN_THIS_TIME_UNIT_SO_FAR, IN_NEXT_TIME_UNIT, IN_LAST_TIME_UNIT).
-
#time_unit ⇒ String
The unit of time to be used in the operation (DAY, WEEK, MONTH, QUARTER, YEAR).
-
#time_unit_count ⇒ Integer?
The count of time units to be applied in the operation (1).
-
#use_fiscal_year ⇒ Boolean?
Specifies whether the fiscal year should be used in the operation.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(include_objects_with_no_value_set:, operation_type:, operator:, time_unit:, fiscal_year_start: nil, time_unit_count: nil, use_fiscal_year: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicCalendarDatePropertyOperation for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(include_objects_with_no_value_set:, operation_type:, operator:, time_unit:, fiscal_year_start: nil, time_unit_count: nil, use_fiscal_year: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicCalendarDatePropertyOperation for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_calendar_date_property_operation.rb', line 57
|
Instance Attribute Details
#fiscal_year_start ⇒ Symbol, ...
The month in which the fiscal year starts.
41 42 43 |
# File 'lib/hubspot_sdk/models/crm/public_calendar_date_property_operation.rb', line 41 optional :fiscal_year_start, enum: -> { HubSpotSDK::Crm::PublicCalendarDatePropertyOperation::FiscalYearStart }, api_name: :fiscalYearStart |
#include_objects_with_no_value_set ⇒ Boolean
Indicates whether objects with no value set for the property should be included.
11 12 13 |
# File 'lib/hubspot_sdk/models/crm/public_calendar_date_property_operation.rb', line 11 required :include_objects_with_no_value_set, HubSpotSDK::Internal::Type::Boolean, api_name: :includeObjectsWithNoValueSet |
#operation_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicCalendarDatePropertyOperation::OperationType
The type of operation, which is (CALENDAR_DATE).
19 20 21 |
# File 'lib/hubspot_sdk/models/crm/public_calendar_date_property_operation.rb', line 19 required :operation_type, enum: -> { HubSpotSDK::Crm::PublicCalendarDatePropertyOperation::OperationType }, api_name: :operationType |
#operator ⇒ String
Defines the operation to be applied to the calendar date property (IN_THIS_TIME_UNIT, IN_THIS_TIME_UNIT_SO_FAR, IN_NEXT_TIME_UNIT, IN_LAST_TIME_UNIT).
29 |
# File 'lib/hubspot_sdk/models/crm/public_calendar_date_property_operation.rb', line 29 required :operator, String |
#time_unit ⇒ String
The unit of time to be used in the operation (DAY, WEEK, MONTH, QUARTER, YEAR).
35 |
# File 'lib/hubspot_sdk/models/crm/public_calendar_date_property_operation.rb', line 35 required :time_unit, String, api_name: :timeUnit |
#time_unit_count ⇒ Integer?
The count of time units to be applied in the operation (1).
49 |
# File 'lib/hubspot_sdk/models/crm/public_calendar_date_property_operation.rb', line 49 optional :time_unit_count, Integer, api_name: :timeUnitCount |
#use_fiscal_year ⇒ Boolean?
Specifies whether the fiscal year should be used in the operation.
55 |
# File 'lib/hubspot_sdk/models/crm/public_calendar_date_property_operation.rb', line 55 optional :use_fiscal_year, HubSpotSDK::Internal::Type::Boolean, api_name: :useFiscalYear |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/crm/public_calendar_date_property_operation.rb', line 83
|