Class: HubSpotSDK::Models::Crm::PublicDatePropertyOperation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicDatePropertyOperation
- Defined in:
- lib/hubspot_sdk/models/crm/public_date_property_operation.rb
Defined Under Namespace
Modules: OperationType
Instance Attribute Summary collapse
-
#day ⇒ Integer
The day of the month for the date operation.
-
#include_objects_with_no_value_set ⇒ Boolean
Indicates whether objects with no value set for the property should be included.
-
#month ⇒ String
The month for the date operation.
-
#operation_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicDatePropertyOperation::OperationType
Specifies the type of operation (DATE).
-
#operator ⇒ String
Defines the operation to be applied in the date property operation (IS_LESS_THAN_X_DAYS_AGO, IS_MORE_THAN_X_DAYS_AGO, IS_LESS_THAN_X_DAYS_FROM_NOW, IS_MORE_THAN_X_DAYS_FROM_NOW).
-
#year ⇒ Integer
The year for the date operation.
Instance Method Summary collapse
-
#initialize(day:, include_objects_with_no_value_set:, month:, operation_type:, operator:, year:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicDatePropertyOperation for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(day:, include_objects_with_no_value_set:, month:, operation_type:, operator:, year:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicDatePropertyOperation for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_date_property_operation.rb', line 49
|
Instance Attribute Details
#day ⇒ Integer
The day of the month for the date operation.
11 |
# File 'lib/hubspot_sdk/models/crm/public_date_property_operation.rb', line 11 required :day, Integer |
#include_objects_with_no_value_set ⇒ Boolean
Indicates whether objects with no value set for the property should be included.
17 18 19 |
# File 'lib/hubspot_sdk/models/crm/public_date_property_operation.rb', line 17 required :include_objects_with_no_value_set, HubSpotSDK::Internal::Type::Boolean, api_name: :includeObjectsWithNoValueSet |
#month ⇒ String
The month for the date operation.
25 |
# File 'lib/hubspot_sdk/models/crm/public_date_property_operation.rb', line 25 required :month, String |
#operation_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicDatePropertyOperation::OperationType
Specifies the type of operation (DATE).
31 32 33 |
# File 'lib/hubspot_sdk/models/crm/public_date_property_operation.rb', line 31 required :operation_type, enum: -> { HubSpotSDK::Crm::PublicDatePropertyOperation::OperationType }, api_name: :operationType |
#operator ⇒ String
Defines the operation to be applied in the date property operation (IS_LESS_THAN_X_DAYS_AGO, IS_MORE_THAN_X_DAYS_AGO, IS_LESS_THAN_X_DAYS_FROM_NOW, IS_MORE_THAN_X_DAYS_FROM_NOW).
41 |
# File 'lib/hubspot_sdk/models/crm/public_date_property_operation.rb', line 41 required :operator, String |
#year ⇒ Integer
The year for the date operation.
47 |
# File 'lib/hubspot_sdk/models/crm/public_date_property_operation.rb', line 47 required :year, Integer |