Class: HubSpotSDK::Models::Crm::PublicEmailEventFilter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicEmailEventFilter
- Defined in:
- lib/hubspot_sdk/models/crm/public_email_event_filter.rb
Defined Under Namespace
Modules: FilterType, Operator, PruningRefineBy
Instance Attribute Summary collapse
-
#app_id ⇒ String
The ID of the application associated with the email event filter.
-
#click_url ⇒ String?
The URL that was clicked in the email event.
-
#email_id ⇒ String
The ID of the email associated with the event filter.
-
#filter_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicEmailEventFilter::FilterType
Indicates the type of filter (EMAIL_EVENT).
-
#level ⇒ String
Specifies the level of the email event, such as EMAIL_API_CAMPAIGN_GROUP.
-
#operator ⇒ Symbol, HubSpotSDK::Models::Crm::PublicEmailEventFilter::Operator
Defines the operation to be applied within the filter (BOUNCED, LINK_CLICKED, MARKED_SPAM, OPENED, OPENED_BUT_LINK_NOT_CLICKED, OPENED_BUT_NOT_REPLIED, RECEIVED, RECEIVED_BUT_NOT_OPENED, REPLIED, SENT, SENT_BUT_LINK_NOT_CLICKED, SENT_BUT_NOT_RECEIVED, UNSUBSCRIBED).
-
#pruning_refine_by ⇒ HubSpotSDK::Models::Crm::PublicNumOccurrencesRefineBy, ...
Specifies the criteria for refining the filter by pruning.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(app_id:, email_id:, filter_type:, level:, operator:, click_url: nil, pruning_refine_by: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicEmailEventFilter for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(app_id:, email_id:, filter_type:, level:, operator:, click_url: nil, pruning_refine_by: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicEmailEventFilter for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_email_event_filter.rb', line 56
|
Instance Attribute Details
#app_id ⇒ String
The ID of the application associated with the email event filter.
11 |
# File 'lib/hubspot_sdk/models/crm/public_email_event_filter.rb', line 11 required :app_id, String, api_name: :appId |
#click_url ⇒ String?
The URL that was clicked in the email event.
46 |
# File 'lib/hubspot_sdk/models/crm/public_email_event_filter.rb', line 46 optional :click_url, String, api_name: :clickUrl |
#email_id ⇒ String
The ID of the email associated with the event filter.
17 |
# File 'lib/hubspot_sdk/models/crm/public_email_event_filter.rb', line 17 required :email_id, String, api_name: :emailId |
#filter_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicEmailEventFilter::FilterType
Indicates the type of filter (EMAIL_EVENT).
23 24 25 |
# File 'lib/hubspot_sdk/models/crm/public_email_event_filter.rb', line 23 required :filter_type, enum: -> { HubSpotSDK::Crm::PublicEmailEventFilter::FilterType }, api_name: :filterType |
#level ⇒ String
Specifies the level of the email event, such as EMAIL_API_CAMPAIGN_GROUP.
31 |
# File 'lib/hubspot_sdk/models/crm/public_email_event_filter.rb', line 31 required :level, String |
#operator ⇒ Symbol, HubSpotSDK::Models::Crm::PublicEmailEventFilter::Operator
Defines the operation to be applied within the filter (BOUNCED, LINK_CLICKED, MARKED_SPAM, OPENED, OPENED_BUT_LINK_NOT_CLICKED, OPENED_BUT_NOT_REPLIED, RECEIVED, RECEIVED_BUT_NOT_OPENED, REPLIED, SENT, SENT_BUT_LINK_NOT_CLICKED, SENT_BUT_NOT_RECEIVED, UNSUBSCRIBED).
40 |
# File 'lib/hubspot_sdk/models/crm/public_email_event_filter.rb', line 40 required :operator, enum: -> { HubSpotSDK::Crm::PublicEmailEventFilter::Operator } |
#pruning_refine_by ⇒ HubSpotSDK::Models::Crm::PublicNumOccurrencesRefineBy, ...
Specifies the criteria for refining the filter by pruning.
52 53 54 |
# File 'lib/hubspot_sdk/models/crm/public_email_event_filter.rb', line 52 optional :pruning_refine_by, union: -> { HubSpotSDK::Crm::PublicEmailEventFilter::PruningRefineBy }, api_name: :pruningRefineBy |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/crm/public_email_event_filter.rb', line 82
|