Class: HubSpotSDK::Models::Crm::PublicExportResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicExportResponse
- Defined in:
- lib/hubspot_sdk/models/crm/public_export_response.rb
Overview
Defined Under Namespace
Modules: ExportState, ExportType
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the export was created, in ISO 8601 format.
-
#export_name ⇒ String?
The name assigned to the export.
-
#export_state ⇒ Symbol, HubSpotSDK::Models::Crm::PublicExportResponse::ExportState
The current state of the export process.
-
#export_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicExportResponse::ExportType
The type of export, which can be either VIEW or LIST.
-
#id ⇒ String
The unique ID of the export.
-
#object_properties ⇒ Array<String>
The list of properties exported for the associated object.
-
#object_type ⇒ String
The associated CRM object being exported.
-
#record_count ⇒ Integer?
The total number of records included in the export.
-
#updated_at ⇒ Time
The timestamp when the export was last updated, in ISO 8601 format.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, export_state:, export_type:, object_properties:, object_type:, updated_at:, export_name: nil, record_count: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/public_export_response.rb', line 66
|
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the export was created, in ISO 8601 format.
18 |
# File 'lib/hubspot_sdk/models/crm/public_export_response.rb', line 18 required :created_at, Time, api_name: :createdAt |
#export_name ⇒ String?
The name assigned to the export.
58 |
# File 'lib/hubspot_sdk/models/crm/public_export_response.rb', line 58 optional :export_name, String, api_name: :exportName |
#export_state ⇒ Symbol, HubSpotSDK::Models::Crm::PublicExportResponse::ExportState
The current state of the export process.
24 25 26 |
# File 'lib/hubspot_sdk/models/crm/public_export_response.rb', line 24 required :export_state, enum: -> { HubSpotSDK::Crm::PublicExportResponse::ExportState }, api_name: :exportState |
#export_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicExportResponse::ExportType
The type of export, which can be either VIEW or LIST.
32 33 34 |
# File 'lib/hubspot_sdk/models/crm/public_export_response.rb', line 32 required :export_type, enum: -> { HubSpotSDK::Crm::PublicExportResponse::ExportType }, api_name: :exportType |
#id ⇒ String
The unique ID of the export.
12 |
# File 'lib/hubspot_sdk/models/crm/public_export_response.rb', line 12 required :id, String |
#object_properties ⇒ Array<String>
The list of properties exported for the associated object.
40 |
# File 'lib/hubspot_sdk/models/crm/public_export_response.rb', line 40 required :object_properties, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :objectProperties |
#object_type ⇒ String
The associated CRM object being exported.
46 |
# File 'lib/hubspot_sdk/models/crm/public_export_response.rb', line 46 required :object_type, String, api_name: :objectType |
#record_count ⇒ Integer?
The total number of records included in the export.
64 |
# File 'lib/hubspot_sdk/models/crm/public_export_response.rb', line 64 optional :record_count, Integer, api_name: :recordCount |
#updated_at ⇒ Time
The timestamp when the export was last updated, in ISO 8601 format.
52 |
# File 'lib/hubspot_sdk/models/crm/public_export_response.rb', line 52 required :updated_at, Time, api_name: :updatedAt |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/crm/public_export_response.rb', line 101
|