Class: HubSpotSDK::Models::Crm::PublicImportError
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicImportError
- Defined in:
- lib/hubspot_sdk/models/crm/public_import_error.rb
Overview
Defined Under Namespace
Modules: ErrorType, ObjectType
Instance Attribute Summary collapse
-
#created_at ⇒ Integer
The epoch millisecond timestamp when this error was recorded.
-
#error_message ⇒ String?
A human-readable error message.
-
#error_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicImportError::ErrorType
The classification of what went wrong during import processing.
-
#extra_context ⇒ String?
Additional human-readable context about the error.
-
#id ⇒ String
A unique, stable identifier for this specific error.
-
#invalid_property_value ⇒ HubSpotSDK::Models::PropertyValue?
Represents a single custom property of a marketing event, storing its name, value, metadata (like source, timestamp, and sensitivity), and related audit information for tracking changes.
-
#invalid_value ⇒ String?
The raw string value from the import file that caused the validation failure.
-
#invalid_value_to_display ⇒ String?
A convenience accessor that returns either the value from ‘invalidPropertyValue` or `invalidValue`, whichever is present (preferring the property value).
-
#known_column_number ⇒ Integer?
The zero-based column index in the import file where the error occurred.
-
#object_type ⇒ Symbol, ...
The CRM object type affected by this error.
-
#object_type_id ⇒ String?
The modern object type identifier for the CRM object affected by this error.
- #source_data ⇒ HubSpotSDK::Models::Crm::ImportRowCore
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, created_at:, error_type:, source_data:, error_message: nil, extra_context: nil, invalid_property_value: nil, invalid_value: nil, invalid_value_to_display: nil, known_column_number: nil, object_type: nil, object_type_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicImportError for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, error_type:, source_data:, error_message: nil, extra_context: nil, invalid_property_value: nil, invalid_value: nil, invalid_value_to_display: nil, known_column_number: nil, object_type: nil, object_type_id: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicImportError for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_import_error.rb', line 86
|
Instance Attribute Details
#created_at ⇒ Integer
The epoch millisecond timestamp when this error was recorded.
18 |
# File 'lib/hubspot_sdk/models/crm/public_import_error.rb', line 18 required :created_at, Integer, api_name: :createdAt |
#error_message ⇒ String?
A human-readable error message.
35 |
# File 'lib/hubspot_sdk/models/crm/public_import_error.rb', line 35 optional :error_message, String, api_name: :errorMessage |
#error_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicImportError::ErrorType
The classification of what went wrong during import processing.
24 |
# File 'lib/hubspot_sdk/models/crm/public_import_error.rb', line 24 required :error_type, enum: -> { HubSpotSDK::Crm::PublicImportError::ErrorType }, api_name: :errorType |
#extra_context ⇒ String?
Additional human-readable context about the error.
41 |
# File 'lib/hubspot_sdk/models/crm/public_import_error.rb', line 41 optional :extra_context, String, api_name: :extraContext |
#id ⇒ String
A unique, stable identifier for this specific error.
12 |
# File 'lib/hubspot_sdk/models/crm/public_import_error.rb', line 12 required :id, String |
#invalid_property_value ⇒ HubSpotSDK::Models::PropertyValue?
Represents a single custom property of a marketing event, storing its name, value, metadata (like source, timestamp, and sensitivity), and related audit information for tracking changes.
49 |
# File 'lib/hubspot_sdk/models/crm/public_import_error.rb', line 49 optional :invalid_property_value, -> { HubSpotSDK::PropertyValue }, api_name: :invalidPropertyValue |
#invalid_value ⇒ String?
The raw string value from the import file that caused the validation failure.
55 |
# File 'lib/hubspot_sdk/models/crm/public_import_error.rb', line 55 optional :invalid_value, String, api_name: :invalidValue |
#invalid_value_to_display ⇒ String?
A convenience accessor that returns either the value from ‘invalidPropertyValue` or `invalidValue`, whichever is present (preferring the property value).
62 |
# File 'lib/hubspot_sdk/models/crm/public_import_error.rb', line 62 optional :invalid_value_to_display, String, api_name: :invalidValueToDisplay |
#known_column_number ⇒ Integer?
The zero-based column index in the import file where the error occurred
68 |
# File 'lib/hubspot_sdk/models/crm/public_import_error.rb', line 68 optional :known_column_number, Integer, api_name: :knownColumnNumber |
#object_type ⇒ Symbol, ...
The CRM object type affected by this error.
74 75 76 77 78 |
# File 'lib/hubspot_sdk/models/crm/public_import_error.rb', line 74 optional :object_type, enum: -> { HubSpotSDK::Crm::PublicImportError::ObjectType }, api_name: :objectType |
#object_type_id ⇒ String?
The modern object type identifier for the CRM object affected by this error.
84 |
# File 'lib/hubspot_sdk/models/crm/public_import_error.rb', line 84 optional :object_type_id, String, api_name: :objectTypeId |
#source_data ⇒ HubSpotSDK::Models::Crm::ImportRowCore
29 |
# File 'lib/hubspot_sdk/models/crm/public_import_error.rb', line 29 required :source_data, -> { HubSpotSDK::Crm::ImportRowCore }, api_name: :sourceData |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/crm/public_import_error.rb', line 189
|