Class: HubSpotSDK::Models::Crm::PublicIndexedTimePoint
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicIndexedTimePoint
- Defined in:
- lib/hubspot_sdk/models/crm/public_indexed_time_point.rb
Defined Under Namespace
Modules: IndexReference, TimeType
Instance Attribute Summary collapse
-
#index_reference ⇒ HubSpotSDK::Models::Crm::PublicNowReference, ...
Specifies the reference point in time for the indexed time point.
- #offset ⇒ HubSpotSDK::Models::Crm::PublicIndexOffset?
-
#time_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicIndexedTimePoint::TimeType
Defines the type of time (INDEXED).
-
#timezone_source ⇒ String?
Specifies the source of the time zone information for the indexed time point (CUSTOM, USER, PORTAL).
-
#zone_id ⇒ String
Indicates the identifier for the time zone associated with the indexed time point.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(index_reference:, time_type:, zone_id:, offset: nil, timezone_source: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicIndexedTimePoint for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(index_reference:, time_type:, zone_id:, offset: nil, timezone_source: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicIndexedTimePoint for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_indexed_time_point.rb', line 44
|
Instance Attribute Details
#index_reference ⇒ HubSpotSDK::Models::Crm::PublicNowReference, ...
Specifies the reference point in time for the indexed time point.
11 12 13 |
# File 'lib/hubspot_sdk/models/crm/public_indexed_time_point.rb', line 11 required :index_reference, union: -> { HubSpotSDK::Crm::PublicIndexedTimePoint::IndexReference }, api_name: :indexReference |
#offset ⇒ HubSpotSDK::Models::Crm::PublicIndexOffset?
35 |
# File 'lib/hubspot_sdk/models/crm/public_indexed_time_point.rb', line 35 optional :offset, -> { HubSpotSDK::Crm::PublicIndexOffset } |
#time_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicIndexedTimePoint::TimeType
Defines the type of time (INDEXED).
19 20 21 22 23 |
# File 'lib/hubspot_sdk/models/crm/public_indexed_time_point.rb', line 19 required :time_type, enum: -> { HubSpotSDK::Crm::PublicIndexedTimePoint::TimeType }, api_name: :timeType |
#timezone_source ⇒ String?
Specifies the source of the time zone information for the indexed time point (CUSTOM, USER, PORTAL).
42 |
# File 'lib/hubspot_sdk/models/crm/public_indexed_time_point.rb', line 42 optional :timezone_source, String, api_name: :timezoneSource |
#zone_id ⇒ String
Indicates the identifier for the time zone associated with the indexed time point.
30 |
# File 'lib/hubspot_sdk/models/crm/public_indexed_time_point.rb', line 30 required :zone_id, String, api_name: :zoneId |
Class Method Details
.variants ⇒ Array(HubSpotSDK::Models::Crm::PublicNowReference, HubSpotSDK::Models::Crm::PublicTodayReference, HubSpotSDK::Models::Crm::PublicWeekReference, HubSpotSDK::Models::Crm::PublicFiscalQuarterReference, HubSpotSDK::Models::Crm::PublicFiscalYearReference, HubSpotSDK::Models::Crm::PublicYearReference, HubSpotSDK::Models::Crm::PublicQuarterReference, HubSpotSDK::Models::Crm::PublicMonthReference)
|
|
# File 'lib/hubspot_sdk/models/crm/public_indexed_time_point.rb', line 80
|