Class: HubSpotSDK::Models::Crm::PublicListConversionResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicListConversionResponse
- Defined in:
- lib/hubspot_sdk/models/crm/public_list_conversion_response.rb
Overview
Defined Under Namespace
Modules: RequestedConversionTime
Instance Attribute Summary collapse
-
#converted_at ⇒ Time?
The date and time when the list was converted.
-
#list_id ⇒ String
The unique identifier of the list for which the conversion details are provided.
-
#requested_conversion_time ⇒ HubSpotSDK::Models::Crm::PublicListConversionDate, ...
The scheduled time for the list conversion, which can be based on a specific date or inactivity period.
Instance Method Summary collapse
-
#initialize(list_id:, converted_at: nil, requested_conversion_time: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicListConversionResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(list_id:, converted_at: nil, requested_conversion_time: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicListConversionResponse for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_list_conversion_response.rb', line 29
|
Instance Attribute Details
#converted_at ⇒ Time?
The date and time when the list was converted.
18 |
# File 'lib/hubspot_sdk/models/crm/public_list_conversion_response.rb', line 18 optional :converted_at, Time, api_name: :convertedAt |
#list_id ⇒ String
The unique identifier of the list for which the conversion details are provided.
12 |
# File 'lib/hubspot_sdk/models/crm/public_list_conversion_response.rb', line 12 required :list_id, String, api_name: :listId |
#requested_conversion_time ⇒ HubSpotSDK::Models::Crm::PublicListConversionDate, ...
The scheduled time for the list conversion, which can be based on a specific date or inactivity period.
25 26 27 |
# File 'lib/hubspot_sdk/models/crm/public_list_conversion_response.rb', line 25 optional :requested_conversion_time, union: -> { HubSpotSDK::Crm::PublicListConversionResponse::RequestedConversionTime }, api_name: :requestedConversionTime |