Class: HubSpotSDK::Models::Crm::PublicListFolder
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicListFolder
- Defined in:
- lib/hubspot_sdk/models/crm/public_list_folder.rb
Instance Attribute Summary collapse
-
#child_lists ⇒ Array<Integer>
An array of list Id’s contained in this folder.
- #child_nodes ⇒ Array<HubSpotSDK::Models::Crm::PublicListFolder>
-
#created_at ⇒ Time?
The time the folder was created at.
-
#id ⇒ String
The Id of the folder.
-
#name ⇒ String?
The name of the folder.
-
#parent_folder_id ⇒ String
The Id of the folder this folder is in, the root folder is represented as 0.
-
#updated_at ⇒ Time?
The time the folder was last updated at.
-
#updated_contents_at ⇒ Time?
The time that the contents of the folder was last updated at.
-
#user_id ⇒ Integer?
The user Id of the owner of the folder.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, child_lists:, child_nodes:, parent_folder_id:, created_at: nil, name: nil, updated_at: nil, updated_contents_at: nil, user_id: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/public_list_folder.rb', line 62
|
Instance Attribute Details
#child_lists ⇒ Array<Integer>
An array of list Id’s contained in this folder.
17 |
# File 'lib/hubspot_sdk/models/crm/public_list_folder.rb', line 17 required :child_lists, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :childLists |
#child_nodes ⇒ Array<HubSpotSDK::Models::Crm::PublicListFolder>
22 23 24 |
# File 'lib/hubspot_sdk/models/crm/public_list_folder.rb', line 22 required :child_nodes, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::PublicListFolder] }, api_name: :childNodes |
#created_at ⇒ Time?
The time the folder was created at.
36 |
# File 'lib/hubspot_sdk/models/crm/public_list_folder.rb', line 36 optional :created_at, Time, api_name: :createdAt |
#id ⇒ String
The Id of the folder.
11 |
# File 'lib/hubspot_sdk/models/crm/public_list_folder.rb', line 11 required :id, String |
#name ⇒ String?
The name of the folder.
42 |
# File 'lib/hubspot_sdk/models/crm/public_list_folder.rb', line 42 optional :name, String |
#parent_folder_id ⇒ String
The Id of the folder this folder is in, the root folder is represented as 0.
30 |
# File 'lib/hubspot_sdk/models/crm/public_list_folder.rb', line 30 required :parent_folder_id, String, api_name: :parentFolderId |
#updated_at ⇒ Time?
The time the folder was last updated at.
48 |
# File 'lib/hubspot_sdk/models/crm/public_list_folder.rb', line 48 optional :updated_at, Time, api_name: :updatedAt |
#updated_contents_at ⇒ Time?
The time that the contents of the folder was last updated at.
54 |
# File 'lib/hubspot_sdk/models/crm/public_list_folder.rb', line 54 optional :updated_contents_at, Time, api_name: :updatedContentsAt |
#user_id ⇒ Integer?
The user Id of the owner of the folder.
60 |
# File 'lib/hubspot_sdk/models/crm/public_list_folder.rb', line 60 optional :user_id, Integer, api_name: :userId |