Class: HubSpotSDK::Models::Crm::PublicMultiStringPropertyOperation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicMultiStringPropertyOperation
- Defined in:
- lib/hubspot_sdk/models/crm/public_multi_string_property_operation.rb
Defined Under Namespace
Modules: OperationType
Instance Attribute Summary collapse
-
#include_objects_with_no_value_set ⇒ Boolean
Indicates whether objects with no value set for the property should be included in the operation.
-
#operation_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicMultiStringPropertyOperation::OperationType
Specifies the type of operation (MULTISTRING).
-
#operator ⇒ String
Defines the operation to be applied in the multi-string property operation (IS_EQUAL_TO, IS_NOT_EQUAL_TO, CONTAINS, CONTAINS_EXACTLY, DOES_NOT_CONTAIN, DOES_NOT_CONTAIN_EXACTLY, STARTS_WITH, ENDS_WITH).
- #values ⇒ Array<String>
Instance Method Summary collapse
-
#initialize(include_objects_with_no_value_set:, operation_type:, operator:, values:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicMultiStringPropertyOperation for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(include_objects_with_no_value_set:, operation_type:, operator:, values:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicMultiStringPropertyOperation for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_multi_string_property_operation.rb', line 37
|
Instance Attribute Details
#include_objects_with_no_value_set ⇒ Boolean
Indicates whether objects with no value set for the property should be included in the operation.
12 13 14 |
# File 'lib/hubspot_sdk/models/crm/public_multi_string_property_operation.rb', line 12 required :include_objects_with_no_value_set, HubSpotSDK::Internal::Type::Boolean, api_name: :includeObjectsWithNoValueSet |
#operation_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicMultiStringPropertyOperation::OperationType
Specifies the type of operation (MULTISTRING).
20 21 22 |
# File 'lib/hubspot_sdk/models/crm/public_multi_string_property_operation.rb', line 20 required :operation_type, enum: -> { HubSpotSDK::Crm::PublicMultiStringPropertyOperation::OperationType }, api_name: :operationType |
#operator ⇒ String
Defines the operation to be applied in the multi-string property operation (IS_EQUAL_TO, IS_NOT_EQUAL_TO, CONTAINS, CONTAINS_EXACTLY, DOES_NOT_CONTAIN, DOES_NOT_CONTAIN_EXACTLY, STARTS_WITH, ENDS_WITH).
30 |
# File 'lib/hubspot_sdk/models/crm/public_multi_string_property_operation.rb', line 30 required :operator, String |
#values ⇒ Array<String>
35 |
# File 'lib/hubspot_sdk/models/crm/public_multi_string_property_operation.rb', line 35 required :values, HubSpotSDK::Internal::Type::ArrayOf[String] |