Class: HubSpotSDK::Models::Crm::PublicObjectListSearchResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicObjectListSearchResult
- Defined in:
- lib/hubspot_sdk/models/crm/public_object_list_search_result.rb
Instance Attribute Summary collapse
-
#additional_filter_properties ⇒ Hash{Symbol=>String}?
The name and value of any additional properties that exist for this list and that were included in the search request.
-
#created_at ⇒ Time?
The time when the list was created.
-
#created_by_id ⇒ String?
The ID of the user that created the list.
-
#deleted_at ⇒ Time?
The time when the list was deleted.
-
#filters_updated_at ⇒ Time?
The time when the filters for this list were last updated.
-
#list_id ⇒ String
The **ILS ID** of the list.
-
#list_version ⇒ Integer
The version of the list.
-
#name ⇒ String
The name of the list.
-
#object_type_id ⇒ String
The object type of the list.
-
#processing_status ⇒ String
The processing status of the list.
-
#processing_type ⇒ String
The processing type of the list.
-
#updated_at ⇒ Time?
The time the list was last updated.
-
#updated_by_id ⇒ String?
The ID of the user that last updated the list.
Instance Method Summary collapse
-
#initialize(list_id:, list_version:, name:, object_type_id:, processing_status:, processing_type:, additional_filter_properties: nil, created_at: nil, created_by_id: nil, deleted_at: nil, filters_updated_at: nil, updated_at: nil, updated_by_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicObjectListSearchResult for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(list_id:, list_version:, name:, object_type_id:, processing_status:, processing_type:, additional_filter_properties: nil, created_at: nil, created_by_id: nil, deleted_at: nil, filters_updated_at: nil, updated_at: nil, updated_by_id: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicObjectListSearchResult for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_object_list_search_result.rb', line 86
|
Instance Attribute Details
#additional_filter_properties ⇒ Hash{Symbol=>String}?
The name and value of any additional properties that exist for this list and that were included in the search request.
48 |
# File 'lib/hubspot_sdk/models/crm/public_object_list_search_result.rb', line 48 optional :additional_filter_properties, HubSpotSDK::Internal::Type::HashOf[String] |
#created_at ⇒ Time?
The time when the list was created.
54 |
# File 'lib/hubspot_sdk/models/crm/public_object_list_search_result.rb', line 54 optional :created_at, Time, api_name: :createdAt |
#created_by_id ⇒ String?
The ID of the user that created the list.
60 |
# File 'lib/hubspot_sdk/models/crm/public_object_list_search_result.rb', line 60 optional :created_by_id, String, api_name: :createdById |
#deleted_at ⇒ Time?
The time when the list was deleted.
66 |
# File 'lib/hubspot_sdk/models/crm/public_object_list_search_result.rb', line 66 optional :deleted_at, Time, api_name: :deletedAt |
#filters_updated_at ⇒ Time?
The time when the filters for this list were last updated.
72 |
# File 'lib/hubspot_sdk/models/crm/public_object_list_search_result.rb', line 72 optional :filters_updated_at, Time, api_name: :filtersUpdatedAt |
#list_id ⇒ String
The **ILS ID** of the list.
11 |
# File 'lib/hubspot_sdk/models/crm/public_object_list_search_result.rb', line 11 required :list_id, String, api_name: :listId |
#list_version ⇒ Integer
The version of the list.
17 |
# File 'lib/hubspot_sdk/models/crm/public_object_list_search_result.rb', line 17 required :list_version, Integer, api_name: :listVersion |
#name ⇒ String
The name of the list.
23 |
# File 'lib/hubspot_sdk/models/crm/public_object_list_search_result.rb', line 23 required :name, String |
#object_type_id ⇒ String
The object type of the list.
29 |
# File 'lib/hubspot_sdk/models/crm/public_object_list_search_result.rb', line 29 required :object_type_id, String, api_name: :objectTypeId |
#processing_status ⇒ String
The processing status of the list.
35 |
# File 'lib/hubspot_sdk/models/crm/public_object_list_search_result.rb', line 35 required :processing_status, String, api_name: :processingStatus |
#processing_type ⇒ String
The processing type of the list.
41 |
# File 'lib/hubspot_sdk/models/crm/public_object_list_search_result.rb', line 41 required :processing_type, String, api_name: :processingType |
#updated_at ⇒ Time?
The time the list was last updated.
78 |
# File 'lib/hubspot_sdk/models/crm/public_object_list_search_result.rb', line 78 optional :updated_at, Time, api_name: :updatedAt |
#updated_by_id ⇒ String?
The ID of the user that last updated the list.
84 |
# File 'lib/hubspot_sdk/models/crm/public_object_list_search_result.rb', line 84 optional :updated_by_id, String, api_name: :updatedById |