Class: HubSpotSDK::Models::Crm::PublicOwner
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicOwner
- Defined in:
- lib/hubspot_sdk/models/crm/public_owner.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#archived ⇒ Boolean
Indicates whether the owner is archived.
-
#created_at ⇒ Time
The date and time when the owner was created.
-
#email ⇒ String?
The email address of the owner.
-
#first_name ⇒ String?
The first name of the owner.
-
#id ⇒ String
The unique identifier of the owner.
-
#last_name ⇒ String?
The last name of the owner.
- #teams ⇒ Array<HubSpotSDK::Models::Crm::PublicTeam>?
-
#type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicOwner::Type
The type of the owner, which can be either PERSON or QUEUE.
-
#updated_at ⇒ Time
The date and time when the owner was last updated.
-
#user_id ⇒ Integer?
The user ID of the owner.
-
#user_id_including_inactive ⇒ Integer?
The user ID of the owner, including inactive users.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived:, created_at:, type:, updated_at:, email: nil, first_name: nil, last_name: nil, teams: nil, user_id: nil, user_id_including_inactive: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/public_owner.rb', line 73
|
Instance Attribute Details
#archived ⇒ Boolean
Indicates whether the owner is archived.
18 |
# File 'lib/hubspot_sdk/models/crm/public_owner.rb', line 18 required :archived, HubSpotSDK::Internal::Type::Boolean |
#created_at ⇒ Time
The date and time when the owner was created.
24 |
# File 'lib/hubspot_sdk/models/crm/public_owner.rb', line 24 required :created_at, Time, api_name: :createdAt |
#email ⇒ String?
The email address of the owner.
42 |
# File 'lib/hubspot_sdk/models/crm/public_owner.rb', line 42 optional :email, String |
#first_name ⇒ String?
The first name of the owner.
48 |
# File 'lib/hubspot_sdk/models/crm/public_owner.rb', line 48 optional :first_name, String, api_name: :firstName |
#id ⇒ String
The unique identifier of the owner.
12 |
# File 'lib/hubspot_sdk/models/crm/public_owner.rb', line 12 required :id, String |
#last_name ⇒ String?
The last name of the owner.
54 |
# File 'lib/hubspot_sdk/models/crm/public_owner.rb', line 54 optional :last_name, String, api_name: :lastName |
#teams ⇒ Array<HubSpotSDK::Models::Crm::PublicTeam>?
59 |
# File 'lib/hubspot_sdk/models/crm/public_owner.rb', line 59 optional :teams, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::PublicTeam] } |
#type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicOwner::Type
The type of the owner, which can be either PERSON or QUEUE.
30 |
# File 'lib/hubspot_sdk/models/crm/public_owner.rb', line 30 required :type, enum: -> { HubSpotSDK::Crm::PublicOwner::Type } |
#updated_at ⇒ Time
The date and time when the owner was last updated.
36 |
# File 'lib/hubspot_sdk/models/crm/public_owner.rb', line 36 required :updated_at, Time, api_name: :updatedAt |
#user_id ⇒ Integer?
The user ID of the owner.
65 |
# File 'lib/hubspot_sdk/models/crm/public_owner.rb', line 65 optional :user_id, Integer, api_name: :userId |
#user_id_including_inactive ⇒ Integer?
The user ID of the owner, including inactive users.
71 |
# File 'lib/hubspot_sdk/models/crm/public_owner.rb', line 71 optional :user_id_including_inactive, Integer, api_name: :userIdIncludingInactive |