Class: HubSpotSDK::Models::Crm::PublicPropertyReferencedTime
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicPropertyReferencedTime
- Defined in:
- lib/hubspot_sdk/models/crm/public_property_referenced_time.rb
Defined Under Namespace
Modules: TimeType
Instance Attribute Summary collapse
-
#property ⇒ String
Specifies the name of the property that the time reference is applied to.
-
#reference_type ⇒ String
Specifies the type of reference for the property (VALUE, UPDATED_AT, ANNIVERSARY, VALUE_WITH_ZONE_SAME_LOCAL_CONVERSION, ANNIVERSARY_WITH_ZONE_SAME_LOCAL_CONVERSION).
-
#time_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicPropertyReferencedTime::TimeType
Defines the type of time (PROPERTY_REFERENCED).
-
#timezone_source ⇒ String?
Specifies the source of the time zone information for the property (CUSTOM, USER, PORTAL).
-
#zone_id ⇒ String
Indicates the identifier for the time zone associated with the property.
Instance Method Summary collapse
-
#initialize(property:, reference_type:, time_type:, zone_id:, timezone_source: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicPropertyReferencedTime for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(property:, reference_type:, time_type:, zone_id:, timezone_source: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicPropertyReferencedTime for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_property_referenced_time.rb', line 42
|
Instance Attribute Details
#property ⇒ String
Specifies the name of the property that the time reference is applied to.
11 |
# File 'lib/hubspot_sdk/models/crm/public_property_referenced_time.rb', line 11 required :property, String |
#reference_type ⇒ String
Specifies the type of reference for the property (VALUE, UPDATED_AT, ANNIVERSARY, VALUE_WITH_ZONE_SAME_LOCAL_CONVERSION, ANNIVERSARY_WITH_ZONE_SAME_LOCAL_CONVERSION).
19 |
# File 'lib/hubspot_sdk/models/crm/public_property_referenced_time.rb', line 19 required :reference_type, String, api_name: :referenceType |
#time_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicPropertyReferencedTime::TimeType
Defines the type of time (PROPERTY_REFERENCED).
25 26 27 |
# File 'lib/hubspot_sdk/models/crm/public_property_referenced_time.rb', line 25 required :time_type, enum: -> { HubSpotSDK::Crm::PublicPropertyReferencedTime::TimeType }, api_name: :timeType |
#timezone_source ⇒ String?
Specifies the source of the time zone information for the property (CUSTOM, USER, PORTAL).
40 |
# File 'lib/hubspot_sdk/models/crm/public_property_referenced_time.rb', line 40 optional :timezone_source, String, api_name: :timezoneSource |
#zone_id ⇒ String
Indicates the identifier for the time zone associated with the property.
33 |
# File 'lib/hubspot_sdk/models/crm/public_property_referenced_time.rb', line 33 required :zone_id, String, api_name: :zoneId |