Class: HubSpotSDK::Models::Crm::PublicPropertyValidationRuleMap
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicPropertyValidationRuleMap
- Defined in:
- lib/hubspot_sdk/models/crm/public_property_validation_rule_map.rb
Instance Attribute Summary collapse
-
#property_name ⇒ String
The name of the property for which validation rules are defined.
-
#property_validation_rules ⇒ Array<HubSpotSDK::Models::Crm::PublicPropertyValidationRule>
A list of validation rules applicable to the property.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(property_name:, property_validation_rules:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/public_property_validation_rule_map.rb', line 21
|
Instance Attribute Details
#property_name ⇒ String
The name of the property for which validation rules are defined.
11 |
# File 'lib/hubspot_sdk/models/crm/public_property_validation_rule_map.rb', line 11 required :property_name, String, api_name: :propertyName |
#property_validation_rules ⇒ Array<HubSpotSDK::Models::Crm::PublicPropertyValidationRule>
A list of validation rules applicable to the property.
17 18 19 |
# File 'lib/hubspot_sdk/models/crm/public_property_validation_rule_map.rb', line 17 required :property_validation_rules, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::PublicPropertyValidationRule] }, api_name: :propertyValidationRules |