Class: HubSpotSDK::Models::Crm::PublicRangedNumberPropertyOperation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicRangedNumberPropertyOperation
- Defined in:
- lib/hubspot_sdk/models/crm/public_ranged_number_property_operation.rb
Defined Under Namespace
Modules: OperationType
Instance Attribute Summary collapse
-
#include_objects_with_no_value_set ⇒ Boolean
Indicates whether objects with no value set for the property should be included in the operation.
-
#lower_bound ⇒ Integer
The lower limit of the number range for the operation.
-
#operation_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicRangedNumberPropertyOperation::OperationType
Specifies the type of operation (NUMBER_RANGED).
-
#operator ⇒ String
Defines the operation to be applied in the ranged number property operation (IS_BETWEEN, IS_NOT_BETWEEN).
-
#upper_bound ⇒ Integer
The upper limit of the number range for the operation.
Instance Method Summary collapse
-
#initialize(include_objects_with_no_value_set:, lower_bound:, operation_type:, operator:, upper_bound:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicRangedNumberPropertyOperation for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(include_objects_with_no_value_set:, lower_bound:, operation_type:, operator:, upper_bound:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicRangedNumberPropertyOperation for more details.
(IS_
|
|
# File 'lib/hubspot_sdk/models/crm/public_ranged_number_property_operation.rb', line 43
|
Instance Attribute Details
#include_objects_with_no_value_set ⇒ Boolean
Indicates whether objects with no value set for the property should be included in the operation.
12 13 14 |
# File 'lib/hubspot_sdk/models/crm/public_ranged_number_property_operation.rb', line 12 required :include_objects_with_no_value_set, HubSpotSDK::Internal::Type::Boolean, api_name: :includeObjectsWithNoValueSet |
#lower_bound ⇒ Integer
The lower limit of the number range for the operation.
20 |
# File 'lib/hubspot_sdk/models/crm/public_ranged_number_property_operation.rb', line 20 required :lower_bound, Integer, api_name: :lowerBound |
#operation_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicRangedNumberPropertyOperation::OperationType
Specifies the type of operation (NUMBER_RANGED).
26 27 28 |
# File 'lib/hubspot_sdk/models/crm/public_ranged_number_property_operation.rb', line 26 required :operation_type, enum: -> { HubSpotSDK::Crm::PublicRangedNumberPropertyOperation::OperationType }, api_name: :operationType |
#operator ⇒ String
Defines the operation to be applied in the ranged number property operation (IS_BETWEEN, IS_NOT_BETWEEN).
35 |
# File 'lib/hubspot_sdk/models/crm/public_ranged_number_property_operation.rb', line 35 required :operator, String |
#upper_bound ⇒ Integer
The upper limit of the number range for the operation.
41 |
# File 'lib/hubspot_sdk/models/crm/public_ranged_number_property_operation.rb', line 41 required :upper_bound, Integer, api_name: :upperBound |