Class: HubSpotSDK::Models::Crm::PublicRangedTimeOperation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicRangedTimeOperation
- Defined in:
- lib/hubspot_sdk/models/crm/public_ranged_time_operation.rb
Defined Under Namespace
Modules: LowerBoundTimePoint, Type, UpperBoundTimePoint
Instance Attribute Summary collapse
-
#include_objects_with_no_value_set ⇒ Boolean
Indicates whether objects with no value set for the property should be included in the operation.
-
#lower_bound_endpoint_behavior ⇒ String?
Describes the behavior at the lower bound endpoint of the time range.
-
#lower_bound_time_point ⇒ HubSpotSDK::Models::Crm::PublicDatePoint, ...
Defines the lower bound time point for the operation.
-
#operation_type ⇒ String
Specifies the type of operation (TIME_RANGED).
-
#operator ⇒ String
Defines the operation to be applied within the time range (IS_BETWEEN, IS_NOT_BETWEEN).
-
#property_parser ⇒ String?
Specifies the parser used for the property in the operation.
-
#type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicRangedTimeOperation::Type
Specifies the type of operation (TIME_RANGED).
-
#upper_bound_endpoint_behavior ⇒ String?
Describes the behavior at the upper bound endpoint of the time range.
-
#upper_bound_time_point ⇒ HubSpotSDK::Models::Crm::PublicDatePoint, ...
Defines the upper bound time point for the operation.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(HubSpotSDK::Models::Crm::PublicDatePoint, HubSpotSDK::Models::Crm::PublicIndexedTimePoint, HubSpotSDK::Models::Crm::PublicPropertyReferencedTime)
Instance Method Summary collapse
-
#initialize(include_objects_with_no_value_set:, lower_bound_time_point:, operation_type:, operator:, type:, upper_bound_time_point:, lower_bound_endpoint_behavior: nil, property_parser: nil, upper_bound_endpoint_behavior: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicRangedTimeOperation for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(include_objects_with_no_value_set:, lower_bound_time_point:, operation_type:, operator:, type:, upper_bound_time_point:, lower_bound_endpoint_behavior: nil, property_parser: nil, upper_bound_endpoint_behavior: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicRangedTimeOperation for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_ranged_time_operation.rb', line 69
|
Instance Attribute Details
#include_objects_with_no_value_set ⇒ Boolean
Indicates whether objects with no value set for the property should be included in the operation.
12 13 14 |
# File 'lib/hubspot_sdk/models/crm/public_ranged_time_operation.rb', line 12 required :include_objects_with_no_value_set, HubSpotSDK::Internal::Type::Boolean, api_name: :includeObjectsWithNoValueSet |
#lower_bound_endpoint_behavior ⇒ String?
Describes the behavior at the lower bound endpoint of the time range.
55 |
# File 'lib/hubspot_sdk/models/crm/public_ranged_time_operation.rb', line 55 optional :lower_bound_endpoint_behavior, String, api_name: :lowerBoundEndpointBehavior |
#lower_bound_time_point ⇒ HubSpotSDK::Models::Crm::PublicDatePoint, ...
Defines the lower bound time point for the operation.
20 21 22 |
# File 'lib/hubspot_sdk/models/crm/public_ranged_time_operation.rb', line 20 required :lower_bound_time_point, union: -> { HubSpotSDK::Crm::PublicRangedTimeOperation::LowerBoundTimePoint }, api_name: :lowerBoundTimePoint |
#operation_type ⇒ String
Specifies the type of operation (TIME_RANGED).
28 |
# File 'lib/hubspot_sdk/models/crm/public_ranged_time_operation.rb', line 28 required :operation_type, String, api_name: :operationType |
#operator ⇒ String
Defines the operation to be applied within the time range (IS_BETWEEN, IS_NOT_BETWEEN).
35 |
# File 'lib/hubspot_sdk/models/crm/public_ranged_time_operation.rb', line 35 required :operator, String |
#property_parser ⇒ String?
Specifies the parser used for the property in the operation.
61 |
# File 'lib/hubspot_sdk/models/crm/public_ranged_time_operation.rb', line 61 optional :property_parser, String, api_name: :propertyParser |
#type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicRangedTimeOperation::Type
Specifies the type of operation (TIME_RANGED).
41 |
# File 'lib/hubspot_sdk/models/crm/public_ranged_time_operation.rb', line 41 required :type, enum: -> { HubSpotSDK::Crm::PublicRangedTimeOperation::Type } |
#upper_bound_endpoint_behavior ⇒ String?
Describes the behavior at the upper bound endpoint of the time range.
67 |
# File 'lib/hubspot_sdk/models/crm/public_ranged_time_operation.rb', line 67 optional :upper_bound_endpoint_behavior, String, api_name: :upperBoundEndpointBehavior |
#upper_bound_time_point ⇒ HubSpotSDK::Models::Crm::PublicDatePoint, ...
Defines the upper bound time point for the operation.
47 48 49 |
# File 'lib/hubspot_sdk/models/crm/public_ranged_time_operation.rb', line 47 required :upper_bound_time_point, union: -> { HubSpotSDK::Crm::PublicRangedTimeOperation::UpperBoundTimePoint }, api_name: :upperBoundTimePoint |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/crm/public_ranged_time_operation.rb', line 115
|
.variants ⇒ Array(HubSpotSDK::Models::Crm::PublicDatePoint, HubSpotSDK::Models::Crm::PublicIndexedTimePoint, HubSpotSDK::Models::Crm::PublicPropertyReferencedTime)
|
|
# File 'lib/hubspot_sdk/models/crm/public_ranged_time_operation.rb', line 103
|