Class: HubSpotSDK::Models::Crm::PublicSurveyMonkeyFilter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicSurveyMonkeyFilter
- Defined in:
- lib/hubspot_sdk/models/crm/public_survey_monkey_filter.rb
Defined Under Namespace
Modules: FilterType
Instance Attribute Summary collapse
-
#filter_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicSurveyMonkeyFilter::FilterType
Indicates the type of filter being applied (SURVEY_MONKEY).
-
#operator ⇒ String
Specifies the operation to be performed by the filter (HAS_RESPONDED_TO_SURVEY, HAS_NOT_RESPONDED_TO_SURVEY).
-
#survey_id ⇒ String
The ID of the survey associated with the filter.
Instance Method Summary collapse
-
#initialize(filter_type:, operator:, survey_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicSurveyMonkeyFilter for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(filter_type:, operator:, survey_id:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicSurveyMonkeyFilter for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_survey_monkey_filter.rb', line 28
|
Instance Attribute Details
#filter_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicSurveyMonkeyFilter::FilterType
Indicates the type of filter being applied (SURVEY_MONKEY).
11 12 13 |
# File 'lib/hubspot_sdk/models/crm/public_survey_monkey_filter.rb', line 11 required :filter_type, enum: -> { HubSpotSDK::Crm::PublicSurveyMonkeyFilter::FilterType }, api_name: :filterType |
#operator ⇒ String
Specifies the operation to be performed by the filter (HAS_RESPONDED_TO_SURVEY, HAS_NOT_RESPONDED_TO_SURVEY).
20 |
# File 'lib/hubspot_sdk/models/crm/public_survey_monkey_filter.rb', line 20 required :operator, String |
#survey_id ⇒ String
The ID of the survey associated with the filter.
26 |
# File 'lib/hubspot_sdk/models/crm/public_survey_monkey_filter.rb', line 26 required :survey_id, String, api_name: :surveyId |