Class: HubSpotSDK::Models::Crm::PublicTimeOffset
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicTimeOffset
- Defined in:
- lib/hubspot_sdk/models/crm/public_time_offset.rb
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The numerical value representing the quantity of the time offset.
-
#offset_direction ⇒ String
Indicates the direction of the time offset, such as forward or backward.
-
#time_unit ⇒ String
Specifies the unit of time for the offset, such as days, hours, or minutes.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, offset_direction:, time_unit:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/crm/public_time_offset.rb', line 25
|
Instance Attribute Details
#amount ⇒ Integer
The numerical value representing the quantity of the time offset.
11 |
# File 'lib/hubspot_sdk/models/crm/public_time_offset.rb', line 11 required :amount, Integer |
#offset_direction ⇒ String
Indicates the direction of the time offset, such as forward or backward.
17 |
# File 'lib/hubspot_sdk/models/crm/public_time_offset.rb', line 17 required :offset_direction, String, api_name: :offsetDirection |
#time_unit ⇒ String
Specifies the unit of time for the offset, such as days, hours, or minutes.
23 |
# File 'lib/hubspot_sdk/models/crm/public_time_offset.rb', line 23 required :time_unit, String, api_name: :timeUnit |