Class: HubSpotSDK::Models::Crm::PublicWebinarFilter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::PublicWebinarFilter
- Defined in:
- lib/hubspot_sdk/models/crm/public_webinar_filter.rb
Defined Under Namespace
Modules: FilterType
Instance Attribute Summary collapse
-
#filter_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicWebinarFilter::FilterType
Indicates the type of filter, (WEBINAR).
-
#operator ⇒ String
Specifies the operation to be performed by the filter (HAS_WEBINAR_REGISTRATION, NOT_HAS_WEBINAR_REGISTRATION, HAS_WEBINAR_ATTENDANCE, NOT_HAS_WEBINAR_ATTENDANCE).
-
#webinar_id ⇒ String?
The ID of the webinar associated with the filter.
Instance Method Summary collapse
-
#initialize(filter_type:, operator:, webinar_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicWebinarFilter for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(filter_type:, operator:, webinar_id: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::PublicWebinarFilter for more details.
|
|
# File 'lib/hubspot_sdk/models/crm/public_webinar_filter.rb', line 29
|
Instance Attribute Details
#filter_type ⇒ Symbol, HubSpotSDK::Models::Crm::PublicWebinarFilter::FilterType
Indicates the type of filter, (WEBINAR).
11 12 13 |
# File 'lib/hubspot_sdk/models/crm/public_webinar_filter.rb', line 11 required :filter_type, enum: -> { HubSpotSDK::Crm::PublicWebinarFilter::FilterType }, api_name: :filterType |
#operator ⇒ String
Specifies the operation to be performed by the filter (HAS_WEBINAR_REGISTRATION, NOT_HAS_WEBINAR_REGISTRATION, HAS_WEBINAR_ATTENDANCE, NOT_HAS_WEBINAR_ATTENDANCE).
21 |
# File 'lib/hubspot_sdk/models/crm/public_webinar_filter.rb', line 21 required :operator, String |
#webinar_id ⇒ String?
The ID of the webinar associated with the filter.
27 |
# File 'lib/hubspot_sdk/models/crm/public_webinar_filter.rb', line 27 optional :webinar_id, String, api_name: :webinarId |