Class: HubSpotSDK::Models::Crm::SimplePublicObjectBatchInputForCreate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::SimplePublicObjectBatchInputForCreate
- Defined in:
- lib/hubspot_sdk/models/crm/simple_public_object_batch_input_for_create.rb
Instance Attribute Summary collapse
- #associations ⇒ Array<HubSpotSDK::Models::Crm::PublicAssociationsForObject>
-
#object_write_trace_id ⇒ String?
An identifier used for tracing the creation or update request of the object.
-
#properties ⇒ Hash{Symbol=>String}
Key value pairs representing the properties of the object.
Instance Method Summary collapse
-
#initialize(associations:, properties:, object_write_trace_id: nil) ⇒ Object
constructor
An input object that contains a collection of objects to be created together in a batch.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(associations:, properties:, object_write_trace_id: nil) ⇒ Object
An input object that contains a collection of objects to be created together in a batch.
|
|
# File 'lib/hubspot_sdk/models/crm/simple_public_object_batch_input_for_create.rb', line 25
|
Instance Attribute Details
#associations ⇒ Array<HubSpotSDK::Models::Crm::PublicAssociationsForObject>
10 11 |
# File 'lib/hubspot_sdk/models/crm/simple_public_object_batch_input_for_create.rb', line 10 required :associations, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::PublicAssociationsForObject] } |
#object_write_trace_id ⇒ String?
An identifier used for tracing the creation or update request of the object.
23 |
# File 'lib/hubspot_sdk/models/crm/simple_public_object_batch_input_for_create.rb', line 23 optional :object_write_trace_id, String, api_name: :objectWriteTraceId |
#properties ⇒ Hash{Symbol=>String}
Key value pairs representing the properties of the object.
17 |
# File 'lib/hubspot_sdk/models/crm/simple_public_object_batch_input_for_create.rb', line 17 required :properties, HubSpotSDK::Internal::Type::HashOf[String] |