Class: HubSpotSDK::Models::Crm::SimplePublicUpsertObject
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::SimplePublicUpsertObject
- Defined in:
- lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb
Instance Attribute Summary collapse
-
#archived ⇒ Boolean
Whether the object is archived.
-
#archived_at ⇒ Time?
The timestamp when the object was archived, in ISO 8601 format.
-
#created_at ⇒ Time
The timestamp when the object was created, in ISO 8601 format.
-
#id ⇒ String
The unique ID of the object.
-
#new ⇒ Boolean
Whether the property is new.
-
#object_write_trace_id ⇒ String?
An identifier used for tracing the write request for the object.
-
#properties ⇒ Hash{Symbol=>String}
Key value pairs representing the properties of the object.
-
#properties_with_history ⇒ Hash{Symbol=>Array<HubSpotSDK::Models::Crm::ValueWithTimestamp>}?
Key-value pairs representing the properties of the object along with their history.
-
#updated_at ⇒ Time
The timestamp when the object was last updated, in ISO 8601 format.
-
#url ⇒ String?
The URL associated with the object.
Instance Method Summary collapse
-
#initialize(id:, archived:, created_at:, new:, properties:, updated_at:, archived_at: nil, object_write_trace_id: nil, properties_with_history: nil, url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SimplePublicUpsertObject for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived:, created_at:, new:, properties:, updated_at:, archived_at: nil, object_write_trace_id: nil, properties_with_history: nil, url: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Crm::SimplePublicUpsertObject for more details.
Represents a CRM object that has either been created or updated (upserted)
|
|
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 72
|
Instance Attribute Details
#archived ⇒ Boolean
Whether the object is archived.
17 |
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 17 required :archived, HubSpotSDK::Internal::Type::Boolean |
#archived_at ⇒ Time?
The timestamp when the object was archived, in ISO 8601 format.
47 |
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 47 optional :archived_at, Time, api_name: :archivedAt |
#created_at ⇒ Time
The timestamp when the object was created, in ISO 8601 format.
23 |
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 23 required :created_at, Time, api_name: :createdAt |
#id ⇒ String
The unique ID of the object.
11 |
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 11 required :id, String |
#new ⇒ Boolean
Whether the property is new.
29 |
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 29 required :new, HubSpotSDK::Internal::Type::Boolean |
#object_write_trace_id ⇒ String?
An identifier used for tracing the write request for the object.
53 |
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 53 optional :object_write_trace_id, String, api_name: :objectWriteTraceId |
#properties ⇒ Hash{Symbol=>String}
Key value pairs representing the properties of the object.
35 |
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 35 required :properties, HubSpotSDK::Internal::Type::HashOf[String] |
#properties_with_history ⇒ Hash{Symbol=>Array<HubSpotSDK::Models::Crm::ValueWithTimestamp>}?
Key-value pairs representing the properties of the object along with their history.
60 61 62 63 64 |
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 60 optional :properties_with_history, -> { HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Crm::ValueWithTimestamp]] }, api_name: :propertiesWithHistory |
#updated_at ⇒ Time
The timestamp when the object was last updated, in ISO 8601 format.
41 |
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 41 required :updated_at, Time, api_name: :updatedAt |
#url ⇒ String?
The URL associated with the object.
70 |
# File 'lib/hubspot_sdk/models/crm/simple_public_upsert_object.rb', line 70 optional :url, String |