Class: HubSpotSDK::Models::Crm::ValueWithTimestamp
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Crm::ValueWithTimestamp
- Defined in:
- lib/hubspot_sdk/models/crm/value_with_timestamp.rb
Instance Attribute Summary collapse
-
#source_id ⇒ String?
The unique ID of the property.
-
#source_label ⇒ String?
A human-readable label.
-
#source_type ⇒ String
The property type.
-
#timestamp ⇒ Time
The timestamp when the property was updated, in ISO 8601 format.
-
#updated_by_user_id ⇒ Integer?
The ID of the user who last updated the property.
-
#value ⇒ String
The property value.
Instance Method Summary collapse
-
#initialize(source_type:, timestamp:, value:, source_id: nil, source_label: nil, updated_by_user_id: nil) ⇒ Object
constructor
Property model that includes timestamp.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(source_type:, timestamp:, value:, source_id: nil, source_label: nil, updated_by_user_id: nil) ⇒ Object
Property model that includes timestamp.
|
|
# File 'lib/hubspot_sdk/models/crm/value_with_timestamp.rb', line 43
|
Instance Attribute Details
#source_id ⇒ String?
The unique ID of the property.
29 |
# File 'lib/hubspot_sdk/models/crm/value_with_timestamp.rb', line 29 optional :source_id, String, api_name: :sourceId |
#source_label ⇒ String?
A human-readable label.
35 |
# File 'lib/hubspot_sdk/models/crm/value_with_timestamp.rb', line 35 optional :source_label, String, api_name: :sourceLabel |
#source_type ⇒ String
The property type.
11 |
# File 'lib/hubspot_sdk/models/crm/value_with_timestamp.rb', line 11 required :source_type, String, api_name: :sourceType |
#timestamp ⇒ Time
The timestamp when the property was updated, in ISO 8601 format.
17 |
# File 'lib/hubspot_sdk/models/crm/value_with_timestamp.rb', line 17 required :timestamp, Time |
#updated_by_user_id ⇒ Integer?
The ID of the user who last updated the property.
41 |
# File 'lib/hubspot_sdk/models/crm/value_with_timestamp.rb', line 41 optional :updated_by_user_id, Integer, api_name: :updatedByUserId |
#value ⇒ String
The property value.
23 |
# File 'lib/hubspot_sdk/models/crm/value_with_timestamp.rb', line 23 required :value, String |