Class: HubSpotSDK::Models::Error
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Error
- Defined in:
- lib/hubspot_sdk/models/error.rb
Instance Attribute Summary collapse
-
#category ⇒ String
The error category.
-
#context ⇒ Hash{Symbol=>Array<String>}?
Context about the error condition.
-
#correlation_id ⇒ String
A unique identifier for the request.
-
#errors ⇒ Array<HubSpotSDK::Models::ErrorDetail>?
further information about the error.
-
#links ⇒ Hash{Symbol=>String}?
A map of link names to associated URIs containing documentation about the error or recommended remediation steps.
-
#message ⇒ String
A human readable message describing the error along with remediation steps where appropriate.
-
#sub_category ⇒ String?
A specific category that contains more specific detail about the error.
Instance Method Summary collapse
-
#initialize(category:, correlation_id:, message:, context: nil, errors: nil, links: nil, sub_category: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Error for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(category:, correlation_id:, message:, context: nil, errors: nil, links: nil, sub_category: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Error for more details.
|
|
# File 'lib/hubspot_sdk/models/error.rb', line 51
|
Instance Attribute Details
#category ⇒ String
The error category
10 |
# File 'lib/hubspot_sdk/models/error.rb', line 10 required :category, String |
#context ⇒ Hash{Symbol=>Array<String>}?
Context about the error condition
30 |
# File 'lib/hubspot_sdk/models/error.rb', line 30 optional :context, HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::ArrayOf[String]] |
#correlation_id ⇒ String
A unique identifier for the request. Include this value with any error reports or support tickets
17 |
# File 'lib/hubspot_sdk/models/error.rb', line 17 required :correlation_id, String, api_name: :correlationId |
#errors ⇒ Array<HubSpotSDK::Models::ErrorDetail>?
further information about the error
36 |
# File 'lib/hubspot_sdk/models/error.rb', line 36 optional :errors, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::ErrorDetail] } |
#links ⇒ Hash{Symbol=>String}?
A map of link names to associated URIs containing documentation about the error or recommended remediation steps
43 |
# File 'lib/hubspot_sdk/models/error.rb', line 43 optional :links, HubSpotSDK::Internal::Type::HashOf[String] |
#message ⇒ String
A human readable message describing the error along with remediation steps where appropriate
24 |
# File 'lib/hubspot_sdk/models/error.rb', line 24 required :message, String |
#sub_category ⇒ String?
A specific category that contains more specific detail about the error
49 |
# File 'lib/hubspot_sdk/models/error.rb', line 49 optional :sub_category, String, api_name: :subCategory |