Class: HubSpotSDK::Models::Events::BehavioralEventHTTPCompletionRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Events::BehavioralEventHTTPCompletionRequest
- Defined in:
- lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#email ⇒ String?
Email of visitor.
-
#event_name ⇒ String
Internal name of the event-type to trigger.
-
#object_id_ ⇒ String?
The object id that this event occurred on.
-
#occurred_at ⇒ Time?
The time when this event occurred (if any).
-
#properties ⇒ Hash{Symbol=>String}
Map of properties for the event in the format property internal name - property value.
-
#utk ⇒ String?
User token.
- #uuid ⇒ String?
Instance Method Summary collapse
-
#initialize(event_name:, properties:, email: nil, object_id_: nil, occurred_at: nil, utk: nil, uuid: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BehavioralEventHTTPCompletionRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(event_name:, properties:, email: nil, object_id_: nil, occurred_at: nil, utk: nil, uuid: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Events::BehavioralEventHTTPCompletionRequest for more details.
|
|
# File 'lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb', line 51
|
Instance Attribute Details
#email ⇒ String?
Email of visitor
24 |
# File 'lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb', line 24 optional :email, String |
#event_name ⇒ String
Internal name of the event-type to trigger
11 |
# File 'lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb', line 11 required :event_name, String, api_name: :eventName |
#object_id_ ⇒ String?
The object id that this event occurred on. Could be a contact id or a visitor id.
31 |
# File 'lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb', line 31 optional :object_id_, String, api_name: :objectId |
#occurred_at ⇒ Time?
The time when this event occurred (if any). If this isn’t set, the current time will be used
38 |
# File 'lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb', line 38 optional :occurred_at, Time, api_name: :occurredAt |
#properties ⇒ Hash{Symbol=>String}
Map of properties for the event in the format property internal name - property value
18 |
# File 'lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb', line 18 required :properties, HubSpotSDK::Internal::Type::HashOf[String] |
#utk ⇒ String?
User token
44 |
# File 'lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb', line 44 optional :utk, String |
#uuid ⇒ String?
49 |
# File 'lib/hubspot_sdk/models/events/behavioral_event_http_completion_request.rb', line 49 optional :uuid, String |