Class: HubSpotSDK::Models::Events::ExternalBehavioralEventPropertyCreate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Events::ExternalBehavioralEventPropertyCreate
- Defined in:
- lib/hubspot_sdk/models/events/external_behavioral_event_property_create.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#description ⇒ String?
A description of the property that will be shown as help text in HubSpot.
-
#label ⇒ String
Human readable label for the property.
-
#name ⇒ String?
Internal property name, which must be used when referencing the property from the API.
-
#options ⇒ Array<HubSpotSDK::Models::OptionInput>?
A list of available options for the property if it is an enumeration.
-
#type ⇒ String
The data type of the property.
Instance Method Summary collapse
-
#initialize(label:, type:, description: nil, name: nil, options: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalBehavioralEventPropertyCreate for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(label:, type:, description: nil, name: nil, options: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Events::ExternalBehavioralEventPropertyCreate for more details.
|
|
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_property_create.rb', line 40
|
Instance Attribute Details
#description ⇒ String?
A description of the property that will be shown as help text in HubSpot.
24 |
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_property_create.rb', line 24 optional :description, String |
#label ⇒ String
Human readable label for the property. Used in HubSpot UI
11 |
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_property_create.rb', line 11 required :label, String |
#name ⇒ String?
Internal property name, which must be used when referencing the property from the API
31 |
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_property_create.rb', line 31 optional :name, String |
#options ⇒ Array<HubSpotSDK::Models::OptionInput>?
A list of available options for the property if it is an enumeration. NOTE: This field is only applicable for enumerated properties.
38 |
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_property_create.rb', line 38 optional :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::OptionInput] } |
#type ⇒ String
The data type of the property. Can be one of the following: [string, number, enumeration, datetime]
18 |
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_property_create.rb', line 18 required :type, String |