Class: HubSpotSDK::Models::Events::ExternalBehavioralEventTypeDefinitionPatch
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Events::ExternalBehavioralEventTypeDefinitionPatch
- Defined in:
- lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_patch.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#description ⇒ String?
A description of the event that will be shown as help text in HubSpot.
-
#label ⇒ String?
Human readable label for the event.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(description: nil, label: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_patch.rb', line 19
|
Instance Attribute Details
#description ⇒ String?
A description of the event that will be shown as help text in HubSpot.
11 |
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_patch.rb', line 11 optional :description, String |
#label ⇒ String?
Human readable label for the event. Used in HubSpot UI
17 |
# File 'lib/hubspot_sdk/models/events/external_behavioral_event_type_definition_patch.rb', line 17 optional :label, String |