Class: HubSpotSDK::Models::Events::OccurrenceListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Events::OccurrenceListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/events/occurrence_list_params.rb
Overview
Defined Under Namespace
Classes: ObjectProperty, Property
Instance Attribute Summary collapse
-
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
- #before ⇒ String?
- #event_type ⇒ String?
- #id ⇒ Array<String>?
-
#limit ⇒ Integer?
The maximum number of results to display per page.
- #object_id_ ⇒ Integer?
- #object_property ⇒ HubSpotSDK::Models::Events::OccurrenceListParams::ObjectProperty?
- #object_type ⇒ String?
- #occurred_after ⇒ Time?
- #occurred_before ⇒ Time?
- #properties ⇒ Array<String>?
- #property ⇒ HubSpotSDK::Models::Events::OccurrenceListParams::Property?
- #sort ⇒ Array<String>?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(propname: nil) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(propname: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 118
|
Instance Attribute Details
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
22 |
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 22 optional :after, String |
#before ⇒ String?
27 |
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 27 optional :before, String |
#event_type ⇒ String?
32 |
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 32 optional :event_type, String |
#id ⇒ Array<String>?
14 |
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 14 optional :id, HubSpotSDK::Internal::Type::ArrayOf[String] |
#limit ⇒ Integer?
The maximum number of results to display per page.
38 |
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 38 optional :limit, Integer |
#object_id_ ⇒ Integer?
43 |
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 43 optional :object_id_, Integer |
#object_property ⇒ HubSpotSDK::Models::Events::OccurrenceListParams::ObjectProperty?
48 |
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 48 optional :object_property, -> { HubSpotSDK::Events::OccurrenceListParams::ObjectProperty } |
#object_type ⇒ String?
53 |
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 53 optional :object_type, String |
#occurred_after ⇒ Time?
58 |
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 58 optional :occurred_after, Time |
#occurred_before ⇒ Time?
63 |
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 63 optional :occurred_before, Time |
#properties ⇒ Array<String>?
68 |
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 68 optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String] |
#property ⇒ HubSpotSDK::Models::Events::OccurrenceListParams::Property?
73 |
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 73 optional :property, -> { HubSpotSDK::Events::OccurrenceListParams::Property } |
#sort ⇒ Array<String>?
78 |
# File 'lib/hubspot_sdk/models/events/occurrence_list_params.rb', line 78 optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String] |