Class: HubSpotSDK::Models::Events::Property
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Events::Property
- Defined in:
- lib/hubspot_sdk/models/events/property.rb
Overview
Defined Under Namespace
Modules: DataSensitivity, DateDisplayHint
Instance Attribute Summary collapse
-
#archived ⇒ Boolean?
Whether the property is archived.
-
#archived_at ⇒ Time?
The timestamp when the property was archived, in ISO 8601 format.
-
#calculated ⇒ Boolean?
Whether the property is a calculated field.
-
#calculation_formula ⇒ String?
The formula used for calculated properties.
-
#created_at ⇒ Time?
The timestamp when the property was created, in ISO 8601 format.
-
#created_user_id ⇒ String?
The ID of the user who created the property.
-
#data_sensitivity ⇒ Symbol, ...
Indicates the sensitivity level of the property, such as “non_sensitive”, “sensitive”, or “highly_sensitive”.
- #date_display_hint ⇒ Symbol, ...
-
#description ⇒ String
A summary of the property’s purpose.
-
#display_order ⇒ Integer?
The position of the item relative to others in the list.
-
#external_options ⇒ Boolean?
Applicable only for enumeration type properties.
-
#field_type ⇒ String
Determines how the property will appear in HubSpot’s UI or on a form.
-
#form_field ⇒ Boolean?
Whether the property can appear on forms.
-
#group_name ⇒ String
The name of the group to which the property is assigned.
-
#has_unique_value ⇒ Boolean?
Whether the property is a unique identifier property.
-
#hidden ⇒ Boolean?
Whether or not the property will be hidden from the HubSpot UI.
-
#hubspot_defined ⇒ Boolean?
A boolean value set to true for HubSpot default properties.
-
#label ⇒ String
The display label for the property.
- #modification_metadata ⇒ HubSpotSDK::Models::PropertyModificationMetadata?
-
#name ⇒ String
The internal name for the property.
-
#options ⇒ Array<HubSpotSDK::Models::Option>
A list of valid options for the property.
-
#referenced_object_type ⇒ String?
Deprecated.
-
#sensitive_data_categories ⇒ Array<String>?
When sensitiveData is true, lists the type of sensitive data contained in the property (e.g., “HIPAA”).
-
#show_currency_symbol ⇒ Boolean?
Whether to show the currency symbol in HubSpot’s UI.
-
#type ⇒ String
The data type of the property, such as string or number.
-
#updated_at ⇒ Time?
The timestamp when the property was last updated, in ISO 8601 format.
- #updated_user_id ⇒ String?
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(description:, field_type:, group_name:, label:, name:, options:, type:, archived: nil, archived_at: nil, calculated: nil, calculation_formula: nil, created_at: nil, created_user_id: nil, data_sensitivity: nil, date_display_hint: nil, display_order: nil, external_options: nil, form_field: nil, has_unique_value: nil, hidden: nil, hubspot_defined: nil, modification_metadata: nil, referenced_object_type: nil, sensitive_data_categories: nil, show_currency_symbol: nil, updated_at: nil, updated_user_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Property for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(description:, field_type:, group_name:, label:, name:, options:, type:, archived: nil, archived_at: nil, calculated: nil, calculation_formula: nil, created_at: nil, created_user_id: nil, data_sensitivity: nil, date_display_hint: nil, display_order: nil, external_options: nil, form_field: nil, has_unique_value: nil, hidden: nil, hubspot_defined: nil, modification_metadata: nil, referenced_object_type: nil, sensitive_data_categories: nil, show_currency_symbol: nil, updated_at: nil, updated_user_id: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Events::Property for more details.
A HubSpot property
|
|
# File 'lib/hubspot_sdk/models/events/property.rb', line 181
|
Instance Attribute Details
#archived ⇒ Boolean?
Whether the property is archived.
56 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 56 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#archived_at ⇒ Time?
The timestamp when the property was archived, in ISO 8601 format.
62 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 62 optional :archived_at, Time, api_name: :archivedAt |
#calculated ⇒ Boolean?
Whether the property is a calculated field.
68 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 68 optional :calculated, HubSpotSDK::Internal::Type::Boolean |
#calculation_formula ⇒ String?
The formula used for calculated properties.
74 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 74 optional :calculation_formula, String, api_name: :calculationFormula |
#created_at ⇒ Time?
The timestamp when the property was created, in ISO 8601 format.
80 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 80 optional :created_at, Time, api_name: :createdAt |
#created_user_id ⇒ String?
The ID of the user who created the property.
86 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 86 optional :created_user_id, String, api_name: :createdUserId |
#data_sensitivity ⇒ Symbol, ...
Indicates the sensitivity level of the property, such as “non_sensitive”, “sensitive”, or “highly_sensitive”.
93 94 95 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 93 optional :data_sensitivity, enum: -> { HubSpotSDK::Events::Property::DataSensitivity }, api_name: :dataSensitivity |
#date_display_hint ⇒ Symbol, ...
100 101 102 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 100 optional :date_display_hint, enum: -> { HubSpotSDK::Events::Property::DateDisplayHint }, api_name: :dateDisplayHint |
#description ⇒ String
A summary of the property’s purpose.
12 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 12 required :description, String |
#display_order ⇒ Integer?
The position of the item relative to others in the list.
108 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 108 optional :display_order, Integer, api_name: :displayOrder |
#external_options ⇒ Boolean?
Applicable only for enumeration type properties. Should be set to true with a ‘referencedObjectType’ of ‘OWNER’. Otherwise false.
115 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 115 optional :external_options, HubSpotSDK::Internal::Type::Boolean, api_name: :externalOptions |
#field_type ⇒ String
Determines how the property will appear in HubSpot’s UI or on a form. Learn more in the properties API guide.
19 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 19 required :field_type, String, api_name: :fieldType |
#form_field ⇒ Boolean?
Whether the property can appear on forms.
121 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 121 optional :form_field, HubSpotSDK::Internal::Type::Boolean, api_name: :formField |
#group_name ⇒ String
The name of the group to which the property is assigned.
25 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 25 required :group_name, String, api_name: :groupName |
#has_unique_value ⇒ Boolean?
Whether the property is a unique identifier property.
127 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 127 optional :has_unique_value, HubSpotSDK::Internal::Type::Boolean, api_name: :hasUniqueValue |
#hidden ⇒ Boolean?
Whether or not the property will be hidden from the HubSpot UI. It’s recommended that this be set to false for custom properties.
134 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 134 optional :hidden, HubSpotSDK::Internal::Type::Boolean |
#hubspot_defined ⇒ Boolean?
A boolean value set to true for HubSpot default properties.
140 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 140 optional :hubspot_defined, HubSpotSDK::Internal::Type::Boolean, api_name: :hubspotDefined |
#label ⇒ String
The display label for the property.
31 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 31 required :label, String |
#modification_metadata ⇒ HubSpotSDK::Models::PropertyModificationMetadata?
145 146 147 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 145 optional :modification_metadata, -> { HubSpotSDK::PropertyModificationMetadata }, api_name: :modificationMetadata |
#name ⇒ String
The internal name for the property.
37 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 37 required :name, String |
#options ⇒ Array<HubSpotSDK::Models::Option>
A list of valid options for the property. This field is required for enumerated properties.
44 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 44 required :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Option] } |
#referenced_object_type ⇒ String?
Deprecated. Use externalOptionsReferenceType instead.
153 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 153 optional :referenced_object_type, String, api_name: :referencedObjectType |
#sensitive_data_categories ⇒ Array<String>?
When sensitiveData is true, lists the type of sensitive data contained in the property (e.g., “HIPAA”).
160 161 162 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 160 optional :sensitive_data_categories, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :sensitiveDataCategories |
#show_currency_symbol ⇒ Boolean?
Whether to show the currency symbol in HubSpot’s UI.
168 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 168 optional :show_currency_symbol, HubSpotSDK::Internal::Type::Boolean, api_name: :showCurrencySymbol |
#type ⇒ String
The data type of the property, such as string or number.
50 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 50 required :type, String |
#updated_at ⇒ Time?
The timestamp when the property was last updated, in ISO 8601 format.
174 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 174 optional :updated_at, Time, api_name: :updatedAt |
#updated_user_id ⇒ String?
179 |
# File 'lib/hubspot_sdk/models/events/property.rb', line 179 optional :updated_user_id, String, api_name: :updatedUserId |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/events/property.rb', line 252
|