Class: HubSpotSDK::Models::Files::File
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Files::File
- Defined in:
- lib/hubspot_sdk/models/files/file.rb
Defined Under Namespace
Modules: Access, SourceGroup
Instance Attribute Summary collapse
-
#access ⇒ Symbol, ...
File access.
-
#archived ⇒ Boolean
If the file is deleted.
-
#archived_at ⇒ Time?
Deletion time of the file object.
-
#created_at ⇒ Time
Creation time of the file object.
-
#default_hosting_url ⇒ String?
Default hosting URL of the file.
-
#encoding ⇒ String?
Encoding of the file.
- #expires_at ⇒ Integer?
-
#extension ⇒ String?
Extension of the file.
-
#file_md5 ⇒ String?
The MD5 hash of the file.
-
#height ⇒ Integer?
For image and video files, the height of the content.
-
#id ⇒ String
File ID.
-
#is_usable_in_content ⇒ Boolean?
Previously “archied”.
-
#name ⇒ String?
Name of the file.
-
#parent_folder_id ⇒ String?
ID of the folder the file is in.
-
#path ⇒ String?
Path of the file in the file manager.
-
#size ⇒ Integer?
Size of the file in bytes.
- #source_group ⇒ Symbol, ...
-
#type ⇒ String?
Type of the file.
-
#updated_at ⇒ Time
Timestamp of the latest update to the file.
-
#url ⇒ String?
URL of the given file.
-
#width ⇒ Integer?
For image and video files, the width of the content.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, archived:, created_at:, updated_at:, access: nil, archived_at: nil, default_hosting_url: nil, encoding: nil, expires_at: nil, extension: nil, file_md5: nil, height: nil, is_usable_in_content: nil, name: nil, parent_folder_id: nil, path: nil, size: nil, source_group: nil, type: nil, url: nil, width: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see File for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived:, created_at:, updated_at:, access: nil, archived_at: nil, default_hosting_url: nil, encoding: nil, expires_at: nil, extension: nil, file_md5: nil, height: nil, is_usable_in_content: nil, name: nil, parent_folder_id: nil, path: nil, size: nil, source_group: nil, type: nil, url: nil, width: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Files::File for more details.
|
|
# File 'lib/hubspot_sdk/models/files/file.rb', line 134
|
Instance Attribute Details
#access ⇒ Symbol, ...
File access. Can be PUBLIC_INDEXABLE, PUBLIC_NOT_INDEXABLE, PRIVATE.
35 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 35 optional :access, enum: -> { HubSpotSDK::Files::File::Access } |
#archived ⇒ Boolean
If the file is deleted.
17 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 17 required :archived, HubSpotSDK::Internal::Type::Boolean |
#archived_at ⇒ Time?
Deletion time of the file object.
41 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 41 optional :archived_at, Time, api_name: :archivedAt |
#created_at ⇒ Time
Creation time of the file object.
23 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 23 required :created_at, Time, api_name: :createdAt |
#default_hosting_url ⇒ String?
Default hosting URL of the file. This will use one of HubSpot’s provided URLs to serve the file.
48 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 48 optional :default_hosting_url, String, api_name: :defaultHostingUrl |
#encoding ⇒ String?
Encoding of the file.
54 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 54 optional :encoding, String |
#expires_at ⇒ Integer?
59 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 59 optional :expires_at, Integer, api_name: :expiresAt |
#extension ⇒ String?
Extension of the file. ex: .jpg, .png, .gif, .pdf, etc.
65 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 65 optional :extension, String |
#file_md5 ⇒ String?
The MD5 hash of the file.
71 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 71 optional :file_md5, String, api_name: :fileMd5 |
#height ⇒ Integer?
For image and video files, the height of the content.
77 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 77 optional :height, Integer |
#id ⇒ String
File ID.
11 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 11 required :id, String |
#is_usable_in_content ⇒ Boolean?
Previously “archied”. Indicates if the file should be used when creating new content like web pages.
84 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 84 optional :is_usable_in_content, HubSpotSDK::Internal::Type::Boolean, api_name: :isUsableInContent |
#name ⇒ String?
Name of the file.
90 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 90 optional :name, String |
#parent_folder_id ⇒ String?
ID of the folder the file is in.
96 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 96 optional :parent_folder_id, String, api_name: :parentFolderId |
#path ⇒ String?
Path of the file in the file manager.
102 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 102 optional :path, String |
#size ⇒ Integer?
Size of the file in bytes.
108 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 108 optional :size, Integer |
#source_group ⇒ Symbol, ...
113 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 113 optional :source_group, enum: -> { HubSpotSDK::Files::File::SourceGroup }, api_name: :sourceGroup |
#type ⇒ String?
Type of the file. Can be IMG, DOCUMENT, AUDIO, MOVIE, or OTHER.
119 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 119 optional :type, String |
#updated_at ⇒ Time
Timestamp of the latest update to the file.
29 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 29 required :updated_at, Time, api_name: :updatedAt |
#url ⇒ String?
URL of the given file. This URL can change depending on the domain settings of the account. Will use the select file hosting domain.
126 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 126 optional :url, String |
#width ⇒ Integer?
For image and video files, the width of the content.
132 |
# File 'lib/hubspot_sdk/models/files/file.rb', line 132 optional :width, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/files/file.rb', line 195
|