Class: HubSpotSDK::Models::Files::FileUpdateInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Files::FileUpdateInput
- Defined in:
- lib/hubspot_sdk/models/files/file_update_input.rb
Direct Known Subclasses
Defined Under Namespace
Modules: Access
Instance Attribute Summary collapse
-
#access ⇒ Symbol, ...
NONE: Do not run any duplicate validation.
- #clear_expires ⇒ Boolean
- #expires_at ⇒ Time?
-
#is_usable_in_content ⇒ Boolean?
Mark whether the file should be used in new content or not.
-
#name ⇒ String?
New name for the file.
-
#parent_folder_id ⇒ String?
FolderId where the file should be moved to.
-
#parent_folder_path ⇒ String?
Folder path where the file should be moved to.
Instance Method Summary collapse
-
#initialize(clear_expires:, access: nil, expires_at: nil, is_usable_in_content: nil, name: nil, parent_folder_id: nil, parent_folder_path: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see FileUpdateInput for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(clear_expires:, access: nil, expires_at: nil, is_usable_in_content: nil, name: nil, parent_folder_id: nil, parent_folder_path: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Files::FileUpdateInput for more details.
|
|
# File 'lib/hubspot_sdk/models/files/file_update_input.rb', line 51
|
Instance Attribute Details
#access ⇒ Symbol, ...
NONE: Do not run any duplicate validation. REJECT: Reject the upload if a duplicate is found. RETURN_EXISTING: If a duplicate file is found, do not upload a new file and return the found duplicate instead.
18 |
# File 'lib/hubspot_sdk/models/files/file_update_input.rb', line 18 optional :access, enum: -> { HubSpotSDK::Files::FileUpdateInput::Access } |
#clear_expires ⇒ Boolean
10 |
# File 'lib/hubspot_sdk/models/files/file_update_input.rb', line 10 required :clear_expires, HubSpotSDK::Internal::Type::Boolean, api_name: :clearExpires |
#expires_at ⇒ Time?
23 |
# File 'lib/hubspot_sdk/models/files/file_update_input.rb', line 23 optional :expires_at, Time, api_name: :expiresAt |
#is_usable_in_content ⇒ Boolean?
Mark whether the file should be used in new content or not.
29 |
# File 'lib/hubspot_sdk/models/files/file_update_input.rb', line 29 optional :is_usable_in_content, HubSpotSDK::Internal::Type::Boolean, api_name: :isUsableInContent |
#name ⇒ String?
New name for the file.
35 |
# File 'lib/hubspot_sdk/models/files/file_update_input.rb', line 35 optional :name, String |
#parent_folder_id ⇒ String?
FolderId where the file should be moved to. folderId and folderPath parameters cannot be set at the same time.
42 |
# File 'lib/hubspot_sdk/models/files/file_update_input.rb', line 42 optional :parent_folder_id, String, api_name: :parentFolderId |
#parent_folder_path ⇒ String?
Folder path where the file should be moved to. folderId and folderPath parameters cannot be set at the same time.
49 |
# File 'lib/hubspot_sdk/models/files/file_update_input.rb', line 49 optional :parent_folder_path, String, api_name: :parentFolderPath |