Class: HubSpotSDK::Models::Files::FolderInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Files::FolderInput
- Defined in:
- lib/hubspot_sdk/models/files/folder_input.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#name ⇒ String
Desired name for the folder.
-
#parent_folder_id ⇒ String?
FolderId of the parent of the created folder.
-
#parent_path ⇒ String?
Path of the parent of the created folder.
Instance Method Summary collapse
-
#initialize(name:, parent_folder_id: nil, parent_path: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see FolderInput for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, parent_folder_id: nil, parent_path: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Files::FolderInput for more details.
|
|
# File 'lib/hubspot_sdk/models/files/folder_input.rb', line 29
|
Instance Attribute Details
#name ⇒ String
Desired name for the folder.
11 |
# File 'lib/hubspot_sdk/models/files/folder_input.rb', line 11 required :name, String |
#parent_folder_id ⇒ String?
FolderId of the parent of the created folder. If not specified, the folder will be created at the root level. parentFolderId and parentFolderPath cannot be set at the same time.
19 |
# File 'lib/hubspot_sdk/models/files/folder_input.rb', line 19 optional :parent_folder_id, String, api_name: :parentFolderId |
#parent_path ⇒ String?
Path of the parent of the created folder. If not specified the folder will be created at the root level. parentFolderPath and parentFolderId cannot be set at the same time.
27 |
# File 'lib/hubspot_sdk/models/files/folder_input.rb', line 27 optional :parent_path, String, api_name: :parentPath |