Class: HubSpotSDK::Models::Files::ImportFromURLInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Files::ImportFromURLInput
- Defined in:
- lib/hubspot_sdk/models/files/import_from_url_input.rb
Direct Known Subclasses
Defined Under Namespace
Modules: Access, DuplicateValidationScope, DuplicateValidationStrategy
Instance Attribute Summary collapse
-
#access ⇒ Symbol, HubSpotSDK::Models::Files::ImportFromURLInput::Access
PUBLIC_INDEXABLE: File is publicly accessible by anyone who has the URL.
-
#duplicate_validation_scope ⇒ Symbol, HubSpotSDK::Models::Files::ImportFromURLInput::DuplicateValidationScope
ENTIRE_PORTAL: Look for a duplicate file in the entire account.
-
#duplicate_validation_strategy ⇒ Symbol, HubSpotSDK::Models::Files::ImportFromURLInput::DuplicateValidationStrategy
NONE: Do not run any duplicate validation.
-
#expires_at ⇒ Time?
Specifies the date and time when the file will expire.
-
#folder_id ⇒ String?
One of folderId or folderPath is required.
-
#folder_path ⇒ String?
One of folderPath or folderId is required.
-
#name ⇒ String?
Name to give the resulting file in the file manager.
-
#overwrite ⇒ Boolean
If true, will overwrite existing file if one with the same name and extension exists in the given folder.
-
#ttl ⇒ String?
Time to live.
-
#url ⇒ String?
URL to download the new file from.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(access:, duplicate_validation_scope:, duplicate_validation_strategy:, overwrite:, expires_at: nil, folder_id: nil, folder_path: nil, name: nil, ttl: nil, url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ImportFromURLInput for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(access:, duplicate_validation_scope:, duplicate_validation_strategy:, overwrite:, expires_at: nil, folder_id: nil, folder_path: nil, name: nil, ttl: nil, url: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Files::ImportFromURLInput for more details.
|
|
# File 'lib/hubspot_sdk/models/files/import_from_url_input.rb', line 86
|
Instance Attribute Details
#access ⇒ Symbol, HubSpotSDK::Models::Files::ImportFromURLInput::Access
PUBLIC_INDEXABLE: File is publicly accessible by anyone who has the URL. Search engines can index the file. PUBLIC_NOT_INDEXABLE: File is publicly accessible by anyone who has the URL. Search engines _can’t_ index the file. PRIVATE: File is NOT publicly accessible. Requires a signed URL to see content. Search engines _can’t_ index the file.
15 |
# File 'lib/hubspot_sdk/models/files/import_from_url_input.rb', line 15 required :access, enum: -> { HubSpotSDK::Files::ImportFromURLInput::Access } |
#duplicate_validation_scope ⇒ Symbol, HubSpotSDK::Models::Files::ImportFromURLInput::DuplicateValidationScope
ENTIRE_PORTAL: Look for a duplicate file in the entire account. EXACT_FOLDER: Look for a duplicate file in the provided folder.
22 23 24 |
# File 'lib/hubspot_sdk/models/files/import_from_url_input.rb', line 22 required :duplicate_validation_scope, enum: -> { HubSpotSDK::Files::ImportFromURLInput::DuplicateValidationScope }, api_name: :duplicateValidationScope |
#duplicate_validation_strategy ⇒ Symbol, HubSpotSDK::Models::Files::ImportFromURLInput::DuplicateValidationStrategy
NONE: Do not run any duplicate validation. REJECT: Reject the upload if a duplicate is found. RETURN_EXISTING: If a duplicate file is found, do not upload a new file and return the found duplicate instead.
32 33 34 |
# File 'lib/hubspot_sdk/models/files/import_from_url_input.rb', line 32 required :duplicate_validation_strategy, enum: -> { HubSpotSDK::Files::ImportFromURLInput::DuplicateValidationStrategy }, api_name: :duplicateValidationStrategy |
#expires_at ⇒ Time?
Specifies the date and time when the file will expire.
50 |
# File 'lib/hubspot_sdk/models/files/import_from_url_input.rb', line 50 optional :expires_at, Time, api_name: :expiresAt |
#folder_id ⇒ String?
One of folderId or folderPath is required. Destination folderId for the uploaded file.
57 |
# File 'lib/hubspot_sdk/models/files/import_from_url_input.rb', line 57 optional :folder_id, String, api_name: :folderId |
#folder_path ⇒ String?
One of folderPath or folderId is required. Destination folder path for the uploaded file. If the folder path does not exist, there will be an attempt to create the folder path.
65 |
# File 'lib/hubspot_sdk/models/files/import_from_url_input.rb', line 65 optional :folder_path, String, api_name: :folderPath |
#name ⇒ String?
Name to give the resulting file in the file manager.
71 |
# File 'lib/hubspot_sdk/models/files/import_from_url_input.rb', line 71 optional :name, String |
#overwrite ⇒ Boolean
If true, will overwrite existing file if one with the same name and extension exists in the given folder. The overwritten file will be deleted and the uploaded file will take its place with a new ID. If unset or set as false, the new file’s name will be updated to prevent colliding with existing file if one exists with the same path, name, and extension
44 |
# File 'lib/hubspot_sdk/models/files/import_from_url_input.rb', line 44 required :overwrite, HubSpotSDK::Internal::Type::Boolean |
#ttl ⇒ String?
Time to live. If specified the file will be deleted after the given time frame. If left unset, the file will exist indefinitely
78 |
# File 'lib/hubspot_sdk/models/files/import_from_url_input.rb', line 78 optional :ttl, String |
#url ⇒ String?
URL to download the new file from.
84 |
# File 'lib/hubspot_sdk/models/files/import_from_url_input.rb', line 84 optional :url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/files/import_from_url_input.rb', line 129
|