Class: HubSpotSDK::Models::Files::SignedURL
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Files::SignedURL
- Defined in:
- lib/hubspot_sdk/models/files/signed_url.rb
Instance Attribute Summary collapse
-
#expires_at ⇒ Time
Timestamp of when the URL will no longer grant access to the file.
-
#extension ⇒ String?
Extension of the requested file.
-
#height ⇒ Integer?
For image and video files.
-
#name ⇒ String?
Name of the requested file.
-
#size ⇒ Integer?
Size in bytes of the requested file.
-
#type ⇒ String?
Type of the file.
-
#url ⇒ String
Signed URL with access to the specified file.
-
#width ⇒ Integer?
For image and video files.
Instance Method Summary collapse
-
#initialize(expires_at:, url:, extension: nil, height: nil, name: nil, size: nil, type: nil, width: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SignedURL for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(expires_at:, url:, extension: nil, height: nil, name: nil, size: nil, type: nil, width: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Files::SignedURL for more details.
|
|
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 56
|
Instance Attribute Details
#expires_at ⇒ Time
Timestamp of when the URL will no longer grant access to the file.
11 |
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 11 required :expires_at, Time, api_name: :expiresAt |
#extension ⇒ String?
Extension of the requested file.
24 |
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 24 optional :extension, String |
#height ⇒ Integer?
For image and video files. The height of the file.
30 |
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 30 optional :height, Integer |
#name ⇒ String?
Name of the requested file.
36 |
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 36 optional :name, String |
#size ⇒ Integer?
Size in bytes of the requested file.
42 |
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 42 optional :size, Integer |
#type ⇒ String?
Type of the file. Can be IMG, DOCUMENT, AUDIO, MOVIE, or OTHER.
48 |
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 48 optional :type, String |
#url ⇒ String
Signed URL with access to the specified file. Anyone with this URL will be able to access the file until it expires.
18 |
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 18 required :url, String |
#width ⇒ Integer?
For image and video files. The width of the file.
54 |
# File 'lib/hubspot_sdk/models/files/signed_url.rb', line 54 optional :width, Integer |