Class: HubSpotSDK::Models::Marketing::Campaigns::AssetListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::Campaigns::AssetListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/marketing/campaigns/asset_list_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
- #asset_type ⇒ String
- #campaign_guid ⇒ String
- #end_date ⇒ String?
-
#limit ⇒ String?
The maximum number of results to display per page.
- #start_date ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(campaign_guid:, asset_type:, after: nil, end_date: nil, limit: nil, start_date: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AssetListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(campaign_guid:, asset_type:, after: nil, end_date: nil, limit: nil, start_date: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::Campaigns::AssetListParams for more details.
|
|
# File 'lib/hubspot_sdk/models/marketing/campaigns/asset_list_params.rb', line 46
|
Instance Attribute Details
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
28 |
# File 'lib/hubspot_sdk/models/marketing/campaigns/asset_list_params.rb', line 28 optional :after, String |
#asset_type ⇒ String
20 |
# File 'lib/hubspot_sdk/models/marketing/campaigns/asset_list_params.rb', line 20 required :asset_type, String |
#campaign_guid ⇒ String
15 |
# File 'lib/hubspot_sdk/models/marketing/campaigns/asset_list_params.rb', line 15 required :campaign_guid, String |
#end_date ⇒ String?
33 |
# File 'lib/hubspot_sdk/models/marketing/campaigns/asset_list_params.rb', line 33 optional :end_date, String |
#limit ⇒ String?
The maximum number of results to display per page.
39 |
# File 'lib/hubspot_sdk/models/marketing/campaigns/asset_list_params.rb', line 39 optional :limit, String |
#start_date ⇒ String?
44 |
# File 'lib/hubspot_sdk/models/marketing/campaigns/asset_list_params.rb', line 44 optional :start_date, String |