Class: HubSpotSDK::Models::Marketing::EmailListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::EmailListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/marketing/email_list_params.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
-
#archived ⇒ Boolean?
Whether to return only results that have been archived.
- #campaign ⇒ String?
- #created_after ⇒ Time?
- #created_at ⇒ Time?
- #created_before ⇒ Time?
- #include_stats ⇒ Boolean?
- #included_properties ⇒ Array<String>?
- #is_published ⇒ Boolean?
-
#limit ⇒ Integer?
The maximum number of results to display per page.
- #marketing_campaign_names ⇒ Boolean?
- #published_after ⇒ Time?
- #published_at ⇒ Time?
- #published_before ⇒ Time?
- #sort ⇒ Array<String>?
- #type ⇒ Symbol, ...
- #updated_after ⇒ Time?
- #updated_at ⇒ Time?
- #updated_before ⇒ Time?
- #variant_stats ⇒ Boolean?
- #workflow_names ⇒ Boolean?
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
17 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 17 optional :after, String |
#archived ⇒ Boolean?
Whether to return only results that have been archived.
23 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 23 optional :archived, HubSpotSDK::Internal::Type::Boolean |
#campaign ⇒ String?
28 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 28 optional :campaign, String |
#created_after ⇒ Time?
33 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 33 optional :created_after, Time |
#created_at ⇒ Time?
38 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 38 optional :created_at, Time |
#created_before ⇒ Time?
43 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 43 optional :created_before, Time |
#include_stats ⇒ Boolean?
53 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 53 optional :include_stats, HubSpotSDK::Internal::Type::Boolean |
#included_properties ⇒ Array<String>?
48 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 48 optional :included_properties, HubSpotSDK::Internal::Type::ArrayOf[String] |
#is_published ⇒ Boolean?
58 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 58 optional :is_published, HubSpotSDK::Internal::Type::Boolean |
#limit ⇒ Integer?
The maximum number of results to display per page.
64 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 64 optional :limit, Integer |
#marketing_campaign_names ⇒ Boolean?
69 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 69 optional :marketing_campaign_names, HubSpotSDK::Internal::Type::Boolean |
#published_after ⇒ Time?
74 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 74 optional :published_after, Time |
#published_at ⇒ Time?
79 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 79 optional :published_at, Time |
#published_before ⇒ Time?
84 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 84 optional :published_before, Time |
#sort ⇒ Array<String>?
89 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 89 optional :sort, HubSpotSDK::Internal::Type::ArrayOf[String] |
#type ⇒ Symbol, ...
94 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 94 optional :type, enum: -> { HubSpotSDK::Marketing::EmailListParams::Type } |
#updated_after ⇒ Time?
99 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 99 optional :updated_after, Time |
#updated_at ⇒ Time?
104 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 104 optional :updated_at, Time |
#updated_before ⇒ Time?
109 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 109 optional :updated_before, Time |
#variant_stats ⇒ Boolean?
114 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 114 optional :variant_stats, HubSpotSDK::Internal::Type::Boolean |
#workflow_names ⇒ Boolean?
119 |
# File 'lib/hubspot_sdk/models/marketing/email_list_params.rb', line 119 optional :workflow_names, HubSpotSDK::Internal::Type::Boolean |