Class: HubSpotSDK::Models::Marketing::MarketingEventCompleteRequestParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::MarketingEventCompleteRequestParams
- Defined in:
- lib/hubspot_sdk/models/marketing/marketing_event_complete_request_params.rb
Direct Known Subclasses
HubSpotSDK::Models::Marketing::MarketingEvents::EventCompleteByExternalEventIDParams
Instance Attribute Summary collapse
-
#end_date_time ⇒ Time
The end date and time of the marketing event in ISO 8601 format.
-
#start_date_time ⇒ Time
The start date and time of the marketing event in ISO 8601 format.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#end_date_time ⇒ Time
The end date and time of the marketing event in ISO 8601 format
11 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_complete_request_params.rb', line 11 required :end_date_time, Time, api_name: :endDateTime |
#start_date_time ⇒ Time
The start date and time of the marketing event in ISO 8601 format
17 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_complete_request_params.rb', line 17 required :start_date_time, Time, api_name: :startDateTime |