Class: HubSpotSDK::Models::Marketing::MarketingEventCreateRequestParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::MarketingEventCreateRequestParams
- Defined in:
- lib/hubspot_sdk/models/marketing/marketing_event_create_request_params.rb
Direct Known Subclasses
MarketingEventCreateParams, MarketingEventUpsertByExternalEventIDParams
Instance Attribute Summary collapse
-
#custom_properties ⇒ Array<HubSpotSDK::Models::PropertyValue>
A list of PropertyValues.
-
#end_date_time ⇒ Time?
The end date and time of the marketing event.
-
#event_cancelled ⇒ Boolean?
Indicates if the marketing event has been cancelled.
-
#event_completed ⇒ Boolean?
Indicates if the marketing event has been completed.
-
#event_description ⇒ String?
The description of the marketing event.
-
#event_name ⇒ String
The name of the marketing event.
-
#event_organizer ⇒ String
The name of the organizer of the marketing event.
-
#event_type ⇒ String?
Describes what type of event this is.
-
#event_url ⇒ String?
A URL in the external event application where the marketing event can be managed.
-
#external_account_id ⇒ String
The accountId that is associated with this marketing event in the external event application.
-
#external_event_id ⇒ String
The id of the marketing event in the external event application.
-
#start_date_time ⇒ Time?
The start date and time of the marketing event.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#custom_properties ⇒ Array<HubSpotSDK::Models::PropertyValue>
A list of PropertyValues. These can be whatever kind of property names and values you want. However, they must already exist on the HubSpot account’s definition of the MarketingEvent Object. If they don’t they will be filtered out and not set. In order to do this you’ll need to create a new PropertyGroup on the HubSpot account’s MarketingEvent object for your specific app and create the Custom Property you want to track on that HubSpot account. Do not create any new default properties on the MarketingEvent object as that will apply to all HubSpot accounts.
18 19 20 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_create_request_params.rb', line 18 required :custom_properties, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::PropertyValue] }, api_name: :customProperties |
#end_date_time ⇒ Time?
The end date and time of the marketing event.
51 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_create_request_params.rb', line 51 optional :end_date_time, Time, api_name: :endDateTime |
#event_cancelled ⇒ Boolean?
Indicates if the marketing event has been cancelled. Defaults to ‘false`
57 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_create_request_params.rb', line 57 optional :event_cancelled, HubSpotSDK::Internal::Type::Boolean, api_name: :eventCancelled |
#event_completed ⇒ Boolean?
Indicates if the marketing event has been completed. Defaults to ‘false`
63 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_create_request_params.rb', line 63 optional :event_completed, HubSpotSDK::Internal::Type::Boolean, api_name: :eventCompleted |
#event_description ⇒ String?
The description of the marketing event.
69 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_create_request_params.rb', line 69 optional :event_description, String, api_name: :eventDescription |
#event_name ⇒ String
The name of the marketing event.
26 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_create_request_params.rb', line 26 required :event_name, String, api_name: :eventName |
#event_organizer ⇒ String
The name of the organizer of the marketing event.
32 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_create_request_params.rb', line 32 required :event_organizer, String, api_name: :eventOrganizer |
#event_type ⇒ String?
Describes what type of event this is. For example: ‘WEBINAR`, `CONFERENCE`, `WORKSHOP`
76 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_create_request_params.rb', line 76 optional :event_type, String, api_name: :eventType |
#event_url ⇒ String?
A URL in the external event application where the marketing event can be managed.
83 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_create_request_params.rb', line 83 optional :event_url, String, api_name: :eventUrl |
#external_account_id ⇒ String
The accountId that is associated with this marketing event in the external event application.
39 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_create_request_params.rb', line 39 required :external_account_id, String, api_name: :externalAccountId |
#external_event_id ⇒ String
The id of the marketing event in the external event application.
45 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_create_request_params.rb', line 45 required :external_event_id, String, api_name: :externalEventId |
#start_date_time ⇒ Time?
The start date and time of the marketing event.
89 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_create_request_params.rb', line 89 optional :start_date_time, Time, api_name: :startDateTime |