Class: HubSpotSDK::Models::Marketing::MarketingEventPublicDefaultResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::MarketingEventPublicDefaultResponse
- Defined in:
- lib/hubspot_sdk/models/marketing/marketing_event_public_default_response.rb
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The creation date and time of the marketing event.
-
#custom_properties ⇒ Array<HubSpotSDK::Models::PropertyValue>
A list of PropertyValues.
-
#end_date_time ⇒ Time?
The end date and time of the marketing event.
-
#event_cancelled ⇒ Boolean?
Indicates if the marketing event has been cancelled.
-
#event_completed ⇒ Boolean?
Indicates if the marketing event has been completed.
-
#event_description ⇒ String?
The description of the marketing event.
-
#event_name ⇒ String
The name of the marketing event.
-
#event_organizer ⇒ String
The name of the organizer of the marketing event.
-
#event_type ⇒ String?
The type of the marketing event.
-
#event_url ⇒ String?
A URL in the external event application where the marketing event can be managed.
-
#id ⇒ String
The ID of the marketing event CRM object.
-
#object_id_ ⇒ String?
The ID of the marketing event CRM object.
-
#start_date_time ⇒ Time?
The start date and time of the marketing event.
-
#updated_at ⇒ Time
The update date and time of the marketing event.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#created_at ⇒ Time
The creation date and time of the marketing event.
18 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_default_response.rb', line 18 required :created_at, Time, api_name: :createdAt |
#custom_properties ⇒ Array<HubSpotSDK::Models::PropertyValue>
A list of PropertyValues. These can be whatever kind of property names and values you want. However, they must already exist on the HubSpot account’s definition of the MarketingEvent Object. If they don’t they will be filtered out and not set. In order to do this you’ll need to create a new PropertyGroup on the HubSpot account’s MarketingEvent object for your specific app and create the Custom Property you want to track on that HubSpot account. Do not create any new default properties on the MarketingEvent object as that will apply to all HubSpot accounts.
31 32 33 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_default_response.rb', line 31 required :custom_properties, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::PropertyValue] }, api_name: :customProperties |
#end_date_time ⇒ Time?
The end date and time of the marketing event.
57 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_default_response.rb', line 57 optional :end_date_time, Time, api_name: :endDateTime |
#event_cancelled ⇒ Boolean?
Indicates if the marketing event has been cancelled.
63 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_default_response.rb', line 63 optional :event_cancelled, HubSpotSDK::Internal::Type::Boolean, api_name: :eventCancelled |
#event_completed ⇒ Boolean?
Indicates if the marketing event has been completed.
69 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_default_response.rb', line 69 optional :event_completed, HubSpotSDK::Internal::Type::Boolean, api_name: :eventCompleted |
#event_description ⇒ String?
The description of the marketing event.
75 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_default_response.rb', line 75 optional :event_description, String, api_name: :eventDescription |
#event_name ⇒ String
The name of the marketing event.
39 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_default_response.rb', line 39 required :event_name, String, api_name: :eventName |
#event_organizer ⇒ String
The name of the organizer of the marketing event.
45 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_default_response.rb', line 45 required :event_organizer, String, api_name: :eventOrganizer |
#event_type ⇒ String?
The type of the marketing event.
81 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_default_response.rb', line 81 optional :event_type, String, api_name: :eventType |
#event_url ⇒ String?
A URL in the external event application where the marketing event can be managed.
88 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_default_response.rb', line 88 optional :event_url, String, api_name: :eventUrl |
#id ⇒ String
The ID of the marketing event CRM object.
12 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_default_response.rb', line 12 required :id, String |
#object_id_ ⇒ String?
The ID of the marketing event CRM object.
94 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_default_response.rb', line 94 optional :object_id_, String, api_name: :objectId |
#start_date_time ⇒ Time?
The start date and time of the marketing event.
100 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_default_response.rb', line 100 optional :start_date_time, Time, api_name: :startDateTime |
#updated_at ⇒ Time
The update date and time of the marketing event.
51 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_default_response.rb', line 51 required :updated_at, Time, api_name: :updatedAt |