Class: HubSpotSDK::Models::Marketing::MarketingEventPublicReadResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::MarketingEventPublicReadResponse
- Defined in:
- lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb
Overview
Instance Attribute Summary collapse
-
#attendees ⇒ Integer
The number of HubSpot contacts that attended this marketing event.
-
#cancellations ⇒ Integer
The number of HubSpot contacts that registered for this marketing event, but later cancelled their registration.
-
#created_at ⇒ Time
The creation date and time of the marketing event.
-
#custom_properties ⇒ Array<HubSpotSDK::Models::PropertyValue>
A list of PropertyValues.
-
#end_date_time ⇒ Time?
The end date and time of the marketing event.
-
#event_cancelled ⇒ Boolean?
Indicates if the marketing event has been cancelled.
-
#event_completed ⇒ Boolean?
Indicates if the marketing event has been completed.
-
#event_description ⇒ String?
The description of the marketing event.
-
#event_name ⇒ String
The name of the marketing event.
-
#event_organizer ⇒ String
The name of the organizer of the marketing event.
-
#event_type ⇒ String?
The type of the marketing event.
-
#event_url ⇒ String?
A URL in the external event application where the marketing event can be managed.
-
#external_event_id ⇒ String
The id of the marketing event in the external event application.
-
#id ⇒ String
The ID of the marketing event CRM object.
-
#no_shows ⇒ Integer
The number of HubSpot contacts that registered for this marketing event, but did not attend.
-
#object_id_ ⇒ String?
The ID of the marketing event CRM object.
-
#registrants ⇒ Integer
The number of HubSpot contacts that registered for this marketing event.
-
#start_date_time ⇒ Time?
The start date and time of the marketing event.
-
#updated_at ⇒ Time
The update date and time of the marketing event.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#attendees ⇒ Integer
The number of HubSpot contacts that attended this marketing event.
18 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 18 required :attendees, Integer |
#cancellations ⇒ Integer
The number of HubSpot contacts that registered for this marketing event, but later cancelled their registration.
25 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 25 required :cancellations, Integer |
#created_at ⇒ Time
The creation date and time of the marketing event.
31 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 31 required :created_at, Time, api_name: :createdAt |
#custom_properties ⇒ Array<HubSpotSDK::Models::PropertyValue>
A list of PropertyValues. These can be whatever kind of property names and values you want. However, they must already exist on the HubSpot account’s definition of the MarketingEvent Object. If they don’t they will be filtered out and not set. In order to do this you’ll need to create a new PropertyGroup on the HubSpot account’s MarketingEvent object for your specific app and create the Custom Property you want to track on that HubSpot account. Do not create any new default properties on the MarketingEvent object as that will apply to all HubSpot accounts.
44 45 46 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 44 required :custom_properties, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::PropertyValue] }, api_name: :customProperties |
#end_date_time ⇒ Time?
The end date and time of the marketing event.
89 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 89 optional :end_date_time, Time, api_name: :endDateTime |
#event_cancelled ⇒ Boolean?
Indicates if the marketing event has been cancelled.
95 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 95 optional :event_cancelled, HubSpotSDK::Internal::Type::Boolean, api_name: :eventCancelled |
#event_completed ⇒ Boolean?
Indicates if the marketing event has been completed.
101 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 101 optional :event_completed, HubSpotSDK::Internal::Type::Boolean, api_name: :eventCompleted |
#event_description ⇒ String?
The description of the marketing event.
107 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 107 optional :event_description, String, api_name: :eventDescription |
#event_name ⇒ String
The name of the marketing event.
52 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 52 required :event_name, String, api_name: :eventName |
#event_organizer ⇒ String
The name of the organizer of the marketing event.
58 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 58 required :event_organizer, String, api_name: :eventOrganizer |
#event_type ⇒ String?
The type of the marketing event.
113 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 113 optional :event_type, String, api_name: :eventType |
#event_url ⇒ String?
A URL in the external event application where the marketing event can be managed.
120 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 120 optional :event_url, String, api_name: :eventUrl |
#external_event_id ⇒ String
The id of the marketing event in the external event application.
64 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 64 required :external_event_id, String, api_name: :externalEventId |
#id ⇒ String
The ID of the marketing event CRM object.
12 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 12 required :id, String |
#no_shows ⇒ Integer
The number of HubSpot contacts that registered for this marketing event, but did not attend. This field only had a value when the event is over.
71 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 71 required :no_shows, Integer, api_name: :noShows |
#object_id_ ⇒ String?
The ID of the marketing event CRM object.
126 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 126 optional :object_id_, String, api_name: :objectId |
#registrants ⇒ Integer
The number of HubSpot contacts that registered for this marketing event.
77 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 77 required :registrants, Integer |
#start_date_time ⇒ Time?
The start date and time of the marketing event.
132 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 132 optional :start_date_time, Time, api_name: :startDateTime |
#updated_at ⇒ Time
The update date and time of the marketing event.
83 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_read_response.rb', line 83 required :updated_at, Time, api_name: :updatedAt |