Class: HubSpotSDK::Models::Marketing::MarketingEventPublicUpdateRequestFullV2
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::MarketingEventPublicUpdateRequestFullV2
- Defined in:
- lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb
Instance Attribute Summary collapse
- #custom_properties ⇒ Array<HubSpotSDK::Models::PropertyValue>
-
#end_date_time ⇒ Time?
The end date and time of the marketing event.
-
#event_cancelled ⇒ Boolean?
Indicates if the marketing event has been cancelled.
-
#event_description ⇒ String?
The description of the marketing event.
-
#event_name ⇒ String?
The name of the marketing event.
-
#event_organizer ⇒ String?
The name of the organizer of the marketing event.
-
#event_type ⇒ String?
The type of the marketing event.
-
#event_url ⇒ String?
A URL in the external event application where the marketing event can be managed.
-
#object_id_ ⇒ String
The internal ID of the marketing event in HubSpot.
-
#start_date_time ⇒ Time?
The start date and time of the marketing event.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#custom_properties ⇒ Array<HubSpotSDK::Models::PropertyValue>
10 11 12 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 10 required :custom_properties, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::PropertyValue] }, api_name: :customProperties |
#end_date_time ⇒ Time?
The end date and time of the marketing event
24 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 24 optional :end_date_time, Time, api_name: :endDateTime |
#event_cancelled ⇒ Boolean?
Indicates if the marketing event has been cancelled
30 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 30 optional :event_cancelled, HubSpotSDK::Internal::Type::Boolean, api_name: :eventCancelled |
#event_description ⇒ String?
The description of the marketing event
36 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 36 optional :event_description, String, api_name: :eventDescription |
#event_name ⇒ String?
The name of the marketing event
42 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 42 optional :event_name, String, api_name: :eventName |
#event_organizer ⇒ String?
The name of the organizer of the marketing event
48 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 48 optional :event_organizer, String, api_name: :eventOrganizer |
#event_type ⇒ String?
The type of the marketing event
54 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 54 optional :event_type, String, api_name: :eventType |
#event_url ⇒ String?
A URL in the external event application where the marketing event can be managed
60 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 60 optional :event_url, String, api_name: :eventUrl |
#object_id_ ⇒ String
The internal ID of the marketing event in HubSpot
18 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 18 required :object_id_, String, api_name: :objectId |
#start_date_time ⇒ Time?
The start date and time of the marketing event
66 |
# File 'lib/hubspot_sdk/models/marketing/marketing_event_public_update_request_full_v2.rb', line 66 optional :start_date_time, Time, api_name: :startDateTime |