Class: HubSpotSDK::Models::Marketing::ParticipationProperties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::ParticipationProperties
- Defined in:
- lib/hubspot_sdk/models/marketing/participation_properties.rb
Defined Under Namespace
Modules: AttendanceState
Instance Attribute Summary collapse
-
#attendance_duration_seconds ⇒ Integer?
The number of seconds the participation lasted.
-
#attendance_percentage ⇒ String?
Percentage of the participation duration relative to the event duration.
-
#attendance_state ⇒ Symbol, HubSpotSDK::Models::Marketing::ParticipationProperties::AttendanceState
The state of the participation.
-
#occurred_at ⇒ Integer
Timestamp of when the participation occurred.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(attendance_state:, occurred_at:, attendance_duration_seconds: nil, attendance_percentage: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/marketing/participation_properties.rb', line 33
|
Instance Attribute Details
#attendance_duration_seconds ⇒ Integer?
The number of seconds the participation lasted
25 |
# File 'lib/hubspot_sdk/models/marketing/participation_properties.rb', line 25 optional :attendance_duration_seconds, Integer, api_name: :attendanceDurationSeconds |
#attendance_percentage ⇒ String?
Percentage of the participation duration relative to the event duration
31 |
# File 'lib/hubspot_sdk/models/marketing/participation_properties.rb', line 31 optional :attendance_percentage, String, api_name: :attendancePercentage |
#attendance_state ⇒ Symbol, HubSpotSDK::Models::Marketing::ParticipationProperties::AttendanceState
The state of the participation
11 12 13 |
# File 'lib/hubspot_sdk/models/marketing/participation_properties.rb', line 11 required :attendance_state, enum: -> { HubSpotSDK::Marketing::ParticipationProperties::AttendanceState }, api_name: :attendanceState |
#occurred_at ⇒ Integer
Timestamp of when the participation occurred
19 |
# File 'lib/hubspot_sdk/models/marketing/participation_properties.rb', line 19 required :occurred_at, Integer, api_name: :occurredAt |