Class: HubSpotSDK::Models::Marketing::PublicBudgetTotals
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::PublicBudgetTotals
- Defined in:
- lib/hubspot_sdk/models/marketing/public_budget_totals.rb
Defined Under Namespace
Modules: CurrencyCode
Instance Attribute Summary collapse
-
#budget_items ⇒ Array<HubSpotSDK::Models::Marketing::PublicBudgetItem>
An array of budget items associated with the campaign.
-
#budget_total ⇒ Float?
The total budget allocated for the campaign.
-
#currency_code ⇒ Symbol, HubSpotSDK::Models::Marketing::PublicBudgetTotals::CurrencyCode
The currency code used for the budget and spend amounts, following ISO 4217 standards.
-
#remaining_budget ⇒ Float?
The remaining budget available for the campaign after accounting for all spend items.
-
#spend_items ⇒ Array<HubSpotSDK::Models::Marketing::PublicSpendItem>
An array of spend items associated with the campaign.
-
#spend_total ⇒ Float?
The total amount spent across all spend items in the campaign.
Instance Method Summary collapse
-
#initialize(budget_items:, currency_code:, spend_items:, budget_total: nil, remaining_budget: nil, spend_total: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicBudgetTotals for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(budget_items:, currency_code:, spend_items:, budget_total: nil, remaining_budget: nil, spend_total: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::PublicBudgetTotals for more details.
|
|
# File 'lib/hubspot_sdk/models/marketing/public_budget_totals.rb', line 53
|
Instance Attribute Details
#budget_items ⇒ Array<HubSpotSDK::Models::Marketing::PublicBudgetItem>
An array of budget items associated with the campaign. Each item is represented by a PublicBudgetItem object.
12 13 14 |
# File 'lib/hubspot_sdk/models/marketing/public_budget_totals.rb', line 12 required :budget_items, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Marketing::PublicBudgetItem] }, api_name: :budgetItems |
#budget_total ⇒ Float?
The total budget allocated for the campaign.
38 |
# File 'lib/hubspot_sdk/models/marketing/public_budget_totals.rb', line 38 optional :budget_total, Float, api_name: :budgetTotal |
#currency_code ⇒ Symbol, HubSpotSDK::Models::Marketing::PublicBudgetTotals::CurrencyCode
The currency code used for the budget and spend amounts, following ISO 4217 standards.
21 22 23 |
# File 'lib/hubspot_sdk/models/marketing/public_budget_totals.rb', line 21 required :currency_code, enum: -> { HubSpotSDK::Marketing::PublicBudgetTotals::CurrencyCode }, api_name: :currencyCode |
#remaining_budget ⇒ Float?
The remaining budget available for the campaign after accounting for all spend items.
45 |
# File 'lib/hubspot_sdk/models/marketing/public_budget_totals.rb', line 45 optional :remaining_budget, Float, api_name: :remainingBudget |
#spend_items ⇒ Array<HubSpotSDK::Models::Marketing::PublicSpendItem>
An array of spend items associated with the campaign. Each item is represented by a PublicSpendItem object.
30 31 32 |
# File 'lib/hubspot_sdk/models/marketing/public_budget_totals.rb', line 30 required :spend_items, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Marketing::PublicSpendItem] }, api_name: :spendItems |
#spend_total ⇒ Float?
The total amount spent across all spend items in the campaign.
51 |
# File 'lib/hubspot_sdk/models/marketing/public_budget_totals.rb', line 51 optional :spend_total, Float, api_name: :spendTotal |