Class: HubSpotSDK::Models::Marketing::PublicEmailFromDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::PublicEmailFromDetails
- Defined in:
- lib/hubspot_sdk/models/marketing/public_email_from_details.rb
Instance Attribute Summary collapse
-
#custom_reply_to ⇒ String?
The reply to recipients will see.
-
#from_name ⇒ String?
The name recipients will see.
-
#reply_to ⇒ String?
The from address and reply to email address (if no customReplyTo defined) recipients will see.
Instance Method Summary collapse
-
#initialize(custom_reply_to: nil, from_name: nil, reply_to: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicEmailFromDetails for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(custom_reply_to: nil, from_name: nil, reply_to: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::PublicEmailFromDetails for more details.
|
|
# File 'lib/hubspot_sdk/models/marketing/public_email_from_details.rb', line 26
|
Instance Attribute Details
#custom_reply_to ⇒ String?
The reply to recipients will see.
11 |
# File 'lib/hubspot_sdk/models/marketing/public_email_from_details.rb', line 11 optional :custom_reply_to, String, api_name: :customReplyTo |
#from_name ⇒ String?
The name recipients will see.
17 |
# File 'lib/hubspot_sdk/models/marketing/public_email_from_details.rb', line 17 optional :from_name, String, api_name: :fromName |
#reply_to ⇒ String?
The from address and reply to email address (if no customReplyTo defined) recipients will see.
24 |
# File 'lib/hubspot_sdk/models/marketing/public_email_from_details.rb', line 24 optional :reply_to, String, api_name: :replyTo |