Class: HubSpotSDK::Models::Marketing::PublicList
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::PublicList
- Defined in:
- lib/hubspot_sdk/models/marketing/public_list.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
Timestamp of the creation of the list.
-
#created_by_id ⇒ String?
The ID of the user who created the list.
-
#deleted_at ⇒ Time?
Timestamp of the deletion of the list.
-
#filters_updated_at ⇒ Time?
Timestamp of the last update of the list filters.
-
#list_id ⇒ String
An internal ID of the list.
-
#list_version ⇒ Integer
A number that represents a version of the list.
-
#name ⇒ String
The name of the list.
-
#object_type_id ⇒ String
The internal ID of the object type of the list.
-
#processing_status ⇒ String
Represents the current processing status of the list.
-
#processing_type ⇒ String
Processing type of the list.
-
#size ⇒ Integer?
The size of the result list.
-
#updated_at ⇒ Time?
Timestamp of the last update of the list.
-
#updated_by_id ⇒ String?
The ID of the user who last updated the list.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(list_id:, list_version:, name:, object_type_id:, processing_status:, processing_type:, created_at: nil, created_by_id: nil, deleted_at: nil, filters_updated_at: nil, size: nil, updated_at: nil, updated_by_id: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/marketing/public_list.rb', line 85
|
Instance Attribute Details
#created_at ⇒ Time?
Timestamp of the creation of the list
47 |
# File 'lib/hubspot_sdk/models/marketing/public_list.rb', line 47 optional :created_at, Time, api_name: :createdAt |
#created_by_id ⇒ String?
The ID of the user who created the list
53 |
# File 'lib/hubspot_sdk/models/marketing/public_list.rb', line 53 optional :created_by_id, String, api_name: :createdById |
#deleted_at ⇒ Time?
Timestamp of the deletion of the list
59 |
# File 'lib/hubspot_sdk/models/marketing/public_list.rb', line 59 optional :deleted_at, Time, api_name: :deletedAt |
#filters_updated_at ⇒ Time?
Timestamp of the last update of the list filters
65 |
# File 'lib/hubspot_sdk/models/marketing/public_list.rb', line 65 optional :filters_updated_at, Time, api_name: :filtersUpdatedAt |
#list_id ⇒ String
An internal ID of the list
11 |
# File 'lib/hubspot_sdk/models/marketing/public_list.rb', line 11 required :list_id, String, api_name: :listId |
#list_version ⇒ Integer
A number that represents a version of the list
17 |
# File 'lib/hubspot_sdk/models/marketing/public_list.rb', line 17 required :list_version, Integer, api_name: :listVersion |
#name ⇒ String
The name of the list
23 |
# File 'lib/hubspot_sdk/models/marketing/public_list.rb', line 23 required :name, String |
#object_type_id ⇒ String
The internal ID of the object type of the list
29 |
# File 'lib/hubspot_sdk/models/marketing/public_list.rb', line 29 required :object_type_id, String, api_name: :objectTypeId |
#processing_status ⇒ String
Represents the current processing status of the list
35 |
# File 'lib/hubspot_sdk/models/marketing/public_list.rb', line 35 required :processing_status, String, api_name: :processingStatus |
#processing_type ⇒ String
Processing type of the list
41 |
# File 'lib/hubspot_sdk/models/marketing/public_list.rb', line 41 required :processing_type, String, api_name: :processingType |
#size ⇒ Integer?
The size of the result list
71 |
# File 'lib/hubspot_sdk/models/marketing/public_list.rb', line 71 optional :size, Integer |
#updated_at ⇒ Time?
Timestamp of the last update of the list
77 |
# File 'lib/hubspot_sdk/models/marketing/public_list.rb', line 77 optional :updated_at, Time, api_name: :updatedAt |
#updated_by_id ⇒ String?
The ID of the user who last updated the list
83 |
# File 'lib/hubspot_sdk/models/marketing/public_list.rb', line 83 optional :updated_by_id, String, api_name: :updatedById |