Class: HubSpotSDK::Models::Marketing::PublicSingleSendRequestEgg
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::PublicSingleSendRequestEgg
- Defined in:
- lib/hubspot_sdk/models/marketing/public_single_send_request_egg.rb
Direct Known Subclasses
SingleSendCreateParams, Transactional::SingleEmailSendParams
Instance Attribute Summary collapse
-
#contact_properties ⇒ Hash{Symbol=>String}
The contactProperties field is a map of contact property values.
-
#custom_properties ⇒ Hash{Symbol=>Object}
The customProperties field is a map of property values.
-
#email_id ⇒ Integer
The content ID for the email, which can be found in email tool UI.
- #message ⇒ HubSpotSDK::Models::Marketing::PublicSingleSendEmail
Instance Method Summary collapse
-
#initialize(contact_properties:, custom_properties:, email_id:, message:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublicSingleSendRequestEgg for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(contact_properties:, custom_properties:, email_id:, message:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::PublicSingleSendRequestEgg for more details.
|
|
# File 'lib/hubspot_sdk/models/marketing/public_single_send_request_egg.rb', line 42
|
Instance Attribute Details
#contact_properties ⇒ Hash{Symbol=>String}
The contactProperties field is a map of contact property values. Each contact property value contains a name and value property. Each property will get set on the contact record and will be visible in the template under contact.NAME }. Use these properties when you want to set a contact property while you’re sending the email. For example, when sending a receipt you may want to set a last_paid_date property, as the sending of the receipt will have information about the last payment.
17 |
# File 'lib/hubspot_sdk/models/marketing/public_single_send_request_egg.rb', line 17 required :contact_properties, HubSpotSDK::Internal::Type::HashOf[String], api_name: :contactProperties |
#custom_properties ⇒ Hash{Symbol=>Object}
The customProperties field is a map of property values. Each property value contains a name and value property. Each property will be visible in the template under custom.NAME }. Note: Custom properties do not currently support arrays. To provide a listing in an email, one workaround is to build an HTML list (either with tables or ul) and specify it as a custom property.
27 28 29 |
# File 'lib/hubspot_sdk/models/marketing/public_single_send_request_egg.rb', line 27 required :custom_properties, HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Internal::Type::Unknown], api_name: :customProperties |
#email_id ⇒ Integer
The content ID for the email, which can be found in email tool UI.
35 |
# File 'lib/hubspot_sdk/models/marketing/public_single_send_request_egg.rb', line 35 required :email_id, Integer, api_name: :emailId |
#message ⇒ HubSpotSDK::Models::Marketing::PublicSingleSendEmail
40 |
# File 'lib/hubspot_sdk/models/marketing/public_single_send_request_egg.rb', line 40 required :message, -> { HubSpotSDK::Marketing::PublicSingleSendEmail } |