Class: HubSpotSDK::Models::Marketing::PublicSpendItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::PublicSpendItem
- Defined in:
- lib/hubspot_sdk/models/marketing/public_spend_item.rb
Instance Attribute Summary collapse
-
#amount ⇒ Float
The monetary value associated with the spend item.
-
#created_at ⇒ Integer
The timestamp indicating when the spend item was created.
-
#description ⇒ String?
A detailed explanation or notes about the spend item.
-
#id ⇒ String
Unique identifier for the spend item.
-
#name ⇒ String
The name assigned to the spend item.
-
#order ⇒ Integer
The sequence order of the spend item, where 0 is the oldest.
-
#updated_at ⇒ Integer
The timestamp indicating when the spend item was last updated.
Instance Method Summary collapse
- #initialize(id:, amount:, created_at:, name:, order:, updated_at:, description: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount:, created_at:, name:, order:, updated_at:, description: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/marketing/public_spend_item.rb', line 49
|
Instance Attribute Details
#amount ⇒ Float
The monetary value associated with the spend item.
17 |
# File 'lib/hubspot_sdk/models/marketing/public_spend_item.rb', line 17 required :amount, Float |
#created_at ⇒ Integer
The timestamp indicating when the spend item was created.
23 |
# File 'lib/hubspot_sdk/models/marketing/public_spend_item.rb', line 23 required :created_at, Integer, api_name: :createdAt |
#description ⇒ String?
A detailed explanation or notes about the spend item.
47 |
# File 'lib/hubspot_sdk/models/marketing/public_spend_item.rb', line 47 optional :description, String |
#id ⇒ String
Unique identifier for the spend item.
11 |
# File 'lib/hubspot_sdk/models/marketing/public_spend_item.rb', line 11 required :id, String |
#name ⇒ String
The name assigned to the spend item.
29 |
# File 'lib/hubspot_sdk/models/marketing/public_spend_item.rb', line 29 required :name, String |
#order ⇒ Integer
The sequence order of the spend item, where 0 is the oldest.
35 |
# File 'lib/hubspot_sdk/models/marketing/public_spend_item.rb', line 35 required :order, Integer |
#updated_at ⇒ Integer
The timestamp indicating when the spend item was last updated.
41 |
# File 'lib/hubspot_sdk/models/marketing/public_spend_item.rb', line 41 required :updated_at, Integer, api_name: :updatedAt |