Class: HubSpotSDK::Models::Marketing::RevenueAttributionAggregate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Marketing::RevenueAttributionAggregate
- Defined in:
- lib/hubspot_sdk/models/marketing/revenue_attribution_aggregate.rb
Defined Under Namespace
Modules: CurrencyCode
Instance Attribute Summary collapse
-
#contacts_number ⇒ Integer?
The number of contacts attributed to the campaign.
-
#currency_code ⇒ Symbol, ...
The currency code used for the revenue attribution, with accepted values including AED, AFN, ALL, and others.
-
#deal_amount ⇒ Float?
The total amount of deals attributed to the campaign.
-
#deals_number ⇒ Integer?
The number of deals attributed to the campaign.
-
#revenue_amount ⇒ Float?
The total revenue amount attributed to the campaign.
Instance Method Summary collapse
-
#initialize(contacts_number: nil, currency_code: nil, deal_amount: nil, deals_number: nil, revenue_amount: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RevenueAttributionAggregate for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(contacts_number: nil, currency_code: nil, deal_amount: nil, deals_number: nil, revenue_amount: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Marketing::RevenueAttributionAggregate for more details.
|
|
# File 'lib/hubspot_sdk/models/marketing/revenue_attribution_aggregate.rb', line 40
|
Instance Attribute Details
#contacts_number ⇒ Integer?
The number of contacts attributed to the campaign.
11 |
# File 'lib/hubspot_sdk/models/marketing/revenue_attribution_aggregate.rb', line 11 optional :contacts_number, Integer, api_name: :contactsNumber |
#currency_code ⇒ Symbol, ...
The currency code used for the revenue attribution, with accepted values including AED, AFN, ALL, and others.
18 19 20 |
# File 'lib/hubspot_sdk/models/marketing/revenue_attribution_aggregate.rb', line 18 optional :currency_code, enum: -> { HubSpotSDK::Marketing::RevenueAttributionAggregate::CurrencyCode }, api_name: :currencyCode |
#deal_amount ⇒ Float?
The total amount of deals attributed to the campaign.
26 |
# File 'lib/hubspot_sdk/models/marketing/revenue_attribution_aggregate.rb', line 26 optional :deal_amount, Float, api_name: :dealAmount |
#deals_number ⇒ Integer?
The number of deals attributed to the campaign.
32 |
# File 'lib/hubspot_sdk/models/marketing/revenue_attribution_aggregate.rb', line 32 optional :deals_number, Integer, api_name: :dealsNumber |
#revenue_amount ⇒ Float?
The total revenue amount attributed to the campaign.
38 |
# File 'lib/hubspot_sdk/models/marketing/revenue_attribution_aggregate.rb', line 38 optional :revenue_amount, Float, api_name: :revenueAmount |