Class: HubSpotSDK::Models::PropertyValue
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::PropertyValue
- Defined in:
- lib/hubspot_sdk/models/property_value.rb
Defined Under Namespace
Modules: DataSensitivity, Source
Instance Attribute Summary collapse
-
#data_sensitivity ⇒ Symbol, HubSpotSDK::Models::PropertyValue::DataSensitivity
The sensitivity level of the property, such as “non_sensitive”, “sensitive”, and “highly_sensitive”.
-
#is_encrypted ⇒ Boolean
Whether the property value is encrypted.
-
#is_large_value ⇒ Boolean
Indicates if the value exceeds normal size limits.
-
#name ⇒ String
The unique property name.
-
#persistence_timestamp ⇒ Integer
When the value was persisted to database, in epoch milliseconds.
-
#request_id ⇒ String
A unique ID associated with this request.
-
#selected_by_user ⇒ Boolean
Whether the value was selected by a user.
-
#selected_by_user_timestamp ⇒ Integer
The timestamp when the value was selected by a user, if applicable.
-
#source ⇒ Symbol, HubSpotSDK::Models::PropertyValue::Source
The origin of the property value, such as “IMPORT” or “API”.
-
#source_id ⇒ String
The ID of the property source indicating where it was created.
-
#source_label ⇒ String
A human-readable label.
-
#source_metadata ⇒ String
Metadata providing additional context about the source.
- #source_upstream_deployable ⇒ String
-
#source_vid ⇒ Array<Integer>
The unique identifier associated with the source.
-
#timestamp ⇒ Integer
When the value was set, as a 64-bit integer.
-
#unit ⇒ String
The unit of measurement or context for the value.
-
#updated_by_user_id ⇒ Integer
The ID of the user who updated the property.
-
#use_timestamp_as_persistence_timestamp ⇒ Boolean
Flag indicating whether to use the timestamp field as the persistence timestamp.
-
#value ⇒ String
The property value.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(data_sensitivity:, is_encrypted:, is_large_value:, name:, persistence_timestamp:, request_id:, selected_by_user:, selected_by_user_timestamp:, source:, source_id:, source_label:, source_metadata:, source_upstream_deployable:, source_vid:, timestamp:, unit:, updated_by_user_id:, use_timestamp_as_persistence_timestamp:, value:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PropertyValue for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data_sensitivity:, is_encrypted:, is_large_value:, name:, persistence_timestamp:, request_id:, selected_by_user:, selected_by_user_timestamp:, source:, source_id:, source_label:, source_metadata:, source_upstream_deployable:, source_vid:, timestamp:, unit:, updated_by_user_id:, use_timestamp_as_persistence_timestamp:, value:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::PropertyValue for more details.
Represents a single custom property of a marketing event, storing its name, value, metadata (like source, timestamp, and sensitivity), and related audit information for tracking changes.
|
|
# File 'lib/hubspot_sdk/models/property_value.rb', line 124
|
Instance Attribute Details
#data_sensitivity ⇒ Symbol, HubSpotSDK::Models::PropertyValue::DataSensitivity
The sensitivity level of the property, such as “non_sensitive”, “sensitive”, and “highly_sensitive”.
11 12 13 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 11 required :data_sensitivity, enum: -> { HubSpotSDK::PropertyValue::DataSensitivity }, api_name: :dataSensitivity |
#is_encrypted ⇒ Boolean
Whether the property value is encrypted.
19 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 19 required :is_encrypted, HubSpotSDK::Internal::Type::Boolean, api_name: :isEncrypted |
#is_large_value ⇒ Boolean
Indicates if the value exceeds normal size limits.
25 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 25 required :is_large_value, HubSpotSDK::Internal::Type::Boolean, api_name: :isLargeValue |
#name ⇒ String
The unique property name.
31 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 31 required :name, String |
#persistence_timestamp ⇒ Integer
When the value was persisted to database, in epoch milliseconds.
37 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 37 required :persistence_timestamp, Integer, api_name: :persistenceTimestamp |
#request_id ⇒ String
A unique ID associated with this request.
43 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 43 required :request_id, String, api_name: :requestId |
#selected_by_user ⇒ Boolean
Whether the value was selected by a user.
49 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 49 required :selected_by_user, HubSpotSDK::Internal::Type::Boolean, api_name: :selectedByUser |
#selected_by_user_timestamp ⇒ Integer
The timestamp when the value was selected by a user, if applicable.
55 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 55 required :selected_by_user_timestamp, Integer, api_name: :selectedByUserTimestamp |
#source ⇒ Symbol, HubSpotSDK::Models::PropertyValue::Source
The origin of the property value, such as “IMPORT” or “API”.
61 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 61 required :source, enum: -> { HubSpotSDK::PropertyValue::Source } |
#source_id ⇒ String
The ID of the property source indicating where it was created.
67 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 67 required :source_id, String, api_name: :sourceId |
#source_label ⇒ String
A human-readable label.
73 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 73 required :source_label, String, api_name: :sourceLabel |
#source_metadata ⇒ String
Metadata providing additional context about the source.
79 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 79 required :source_metadata, String, api_name: :sourceMetadata |
#source_upstream_deployable ⇒ String
84 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 84 required :source_upstream_deployable, String, api_name: :sourceUpstreamDeployable |
#source_vid ⇒ Array<Integer>
The unique identifier associated with the source.
90 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 90 required :source_vid, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :sourceVid |
#timestamp ⇒ Integer
When the value was set, as a 64-bit integer.
96 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 96 required :timestamp, Integer |
#unit ⇒ String
The unit of measurement or context for the value.
102 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 102 required :unit, String |
#updated_by_user_id ⇒ Integer
The ID of the user who updated the property.
108 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 108 required :updated_by_user_id, Integer, api_name: :updatedByUserId |
#use_timestamp_as_persistence_timestamp ⇒ Boolean
Flag indicating whether to use the timestamp field as the persistence timestamp.
114 115 116 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 114 required :use_timestamp_as_persistence_timestamp, HubSpotSDK::Internal::Type::Boolean, api_name: :useTimestampAsPersistenceTimestamp |
#value ⇒ String
The property value.
122 |
# File 'lib/hubspot_sdk/models/property_value.rb', line 122 required :value, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/property_value.rb', line 181
|