Class: HubSpotSDK::Models::Scheduler::ExternalCalendarMeetingEventCreateProperties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Scheduler::ExternalCalendarMeetingEventCreateProperties
- Defined in:
- lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_create_properties.rb
Defined Under Namespace
Modules: HsMeetingLocationType
Instance Attribute Summary collapse
-
#hs_activity_type ⇒ String?
The activity type of the meeting.
- #hs_attachment_ids ⇒ Array<String>?
- #hs_attendee_owner_ids ⇒ Array<String>?
-
#hs_internal_meeting_notes ⇒ String?
Internal notes related to the meeting.
-
#hs_meeting_body ⇒ String?
The description of the meeting and calendar event.
-
#hs_meeting_end_time ⇒ Time
The time that the meeting should end in ISO 8601 format.
-
#hs_meeting_location ⇒ String?
The physical address, virtual location, or phone number where the meeting will take place.
-
#hs_meeting_location_type ⇒ Symbol, ...
The type of location for the meeting.
-
#hs_meeting_outcome ⇒ String
The outcome of the meeting.
-
#hs_meeting_start_time ⇒ Time
The time that the meeting should start in ISO 8601 format.
-
#hs_meeting_title ⇒ String
The title of the meeting and calendar event.
-
#hs_timestamp ⇒ Time
The time that the meeting should start in ISO 8601 format.
-
#hubspot_owner_id ⇒ String
The ownerId of the HubSpot user who will host the meeting.
Instance Method Summary collapse
-
#initialize(hs_meeting_end_time:, hs_meeting_outcome:, hs_meeting_start_time:, hs_meeting_title:, hs_timestamp:, hubspot_owner_id:, hs_activity_type: nil, hs_attachment_ids: nil, hs_attendee_owner_ids: nil, hs_internal_meeting_notes: nil, hs_meeting_body: nil, hs_meeting_location: nil, hs_meeting_location_type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalCalendarMeetingEventCreateProperties for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(hs_meeting_end_time:, hs_meeting_outcome:, hs_meeting_start_time:, hs_meeting_title:, hs_timestamp:, hubspot_owner_id:, hs_activity_type: nil, hs_attachment_ids: nil, hs_attendee_owner_ids: nil, hs_internal_meeting_notes: nil, hs_meeting_body: nil, hs_meeting_location: nil, hs_meeting_location_type: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Scheduler::ExternalCalendarMeetingEventCreateProperties for more details.
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_create_properties.rb', line 90
|
Instance Attribute Details
#hs_activity_type ⇒ String?
The activity type of the meeting. Acceptable values are based on portal defined call and meeting types.
51 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_create_properties.rb', line 51 optional :hs_activity_type, String |
#hs_attachment_ids ⇒ Array<String>?
56 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_create_properties.rb', line 56 optional :hs_attachment_ids, HubSpotSDK::Internal::Type::ArrayOf[String] |
#hs_attendee_owner_ids ⇒ Array<String>?
61 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_create_properties.rb', line 61 optional :hs_attendee_owner_ids, HubSpotSDK::Internal::Type::ArrayOf[String] |
#hs_internal_meeting_notes ⇒ String?
Internal notes related to the meeting.
67 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_create_properties.rb', line 67 optional :hs_internal_meeting_notes, String |
#hs_meeting_body ⇒ String?
The description of the meeting and calendar event.
73 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_create_properties.rb', line 73 optional :hs_meeting_body, String |
#hs_meeting_end_time ⇒ Time
The time that the meeting should end in ISO 8601 format.
11 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_create_properties.rb', line 11 required :hs_meeting_end_time, Time |
#hs_meeting_location ⇒ String?
The physical address, virtual location, or phone number where the meeting will take place.
80 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_create_properties.rb', line 80 optional :hs_meeting_location, String |
#hs_meeting_location_type ⇒ Symbol, ...
The type of location for the meeting. Acceptable values are: ADDRESS, CUSTOM, PHONE.
87 88 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_create_properties.rb', line 87 optional :hs_meeting_location_type, enum: -> { HubSpotSDK::Scheduler::ExternalCalendarMeetingEventCreateProperties::HsMeetingLocationType } |
#hs_meeting_outcome ⇒ String
The outcome of the meeting. Acceptable default values are: SCHEDULED, COMPLETED, RESCHEDULED, NO_SHOW, CANCELED. This property can be changed to include additional custom values.
19 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_create_properties.rb', line 19 required :hs_meeting_outcome, String |
#hs_meeting_start_time ⇒ Time
The time that the meeting should start in ISO 8601 format.
25 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_create_properties.rb', line 25 required :hs_meeting_start_time, Time |
#hs_meeting_title ⇒ String
The title of the meeting and calendar event.
31 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_create_properties.rb', line 31 required :hs_meeting_title, String |
#hs_timestamp ⇒ Time
The time that the meeting should start in ISO 8601 format. This value should be the same as ‘hs_meeting_start_time`.
38 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_create_properties.rb', line 38 required :hs_timestamp, Time |
#hubspot_owner_id ⇒ String
The ownerId of the HubSpot user who will host the meeting.
44 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_create_properties.rb', line 44 required :hubspot_owner_id, String |