Class: HubSpotSDK::Models::Scheduler::ExternalCalendarMeetingEventResponseProperties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Scheduler::ExternalCalendarMeetingEventResponseProperties
- Defined in:
- lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb
Defined Under Namespace
Modules: HsEngagementSource, HsMeetingLocationType
Instance Attribute Summary collapse
-
#hs_activity_type ⇒ String?
The activity type of the meeting.
- #hs_attachment_ids ⇒ Array<String>?
- #hs_attendee_owner_ids ⇒ Array<String>?
-
#hs_engagement_source ⇒ Symbol, HubSpotSDK::Models::Scheduler::ExternalCalendarMeetingEventResponseProperties::HsEngagementSource
The source of the engagement, will always be ‘MEETINGS`.
-
#hs_engagement_source_id ⇒ String
The ID associated with the process created the engagement.
-
#hs_include_description_in_reminder ⇒ String?
Whether to include the meeting description in the reminder.
-
#hs_internal_meeting_notes ⇒ String?
Internal notes related to the meeting.
-
#hs_meeting_body ⇒ String?
The description of the meeting and calendar event.
-
#hs_meeting_end_time ⇒ Time
The end time of the meeting in ISO 8601 format.
-
#hs_meeting_external_url ⇒ String?
The calendar event URL for the meeting.
-
#hs_meeting_location ⇒ String?
The physical address, virtual location, or phone number where the meeting will take place.
-
#hs_meeting_location_type ⇒ Symbol, ...
The type of location for the meeting.
-
#hs_meeting_outcome ⇒ String
The outcome of the meeting.
-
#hs_meeting_start_time ⇒ Time
The start time of the meeting in ISO 8601 format.
-
#hs_meeting_title ⇒ String
The title of the meeting and calendar event.
-
#hs_timestamp ⇒ Time
The time that the meeting should start in ISO 8601 format.
-
#hs_unique_id ⇒ String?
The unique ID of the created calendar event.
-
#hubspot_owner_id ⇒ String?
The owner ID of the HubSpot user hosting the meeting.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(hs_engagement_source:, hs_engagement_source_id:, hs_meeting_end_time:, hs_meeting_outcome:, hs_meeting_start_time:, hs_meeting_title:, hs_timestamp:, hs_activity_type: nil, hs_attachment_ids: nil, hs_attendee_owner_ids: nil, hs_include_description_in_reminder: nil, hs_internal_meeting_notes: nil, hs_meeting_body: nil, hs_meeting_external_url: nil, hs_meeting_location: nil, hs_meeting_location_type: nil, hs_unique_id: nil, hubspot_owner_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalCalendarMeetingEventResponseProperties for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(hs_engagement_source:, hs_engagement_source_id:, hs_meeting_end_time:, hs_meeting_outcome:, hs_meeting_start_time:, hs_meeting_title:, hs_timestamp:, hs_activity_type: nil, hs_attachment_ids: nil, hs_attendee_owner_ids: nil, hs_include_description_in_reminder: nil, hs_internal_meeting_notes: nil, hs_meeting_body: nil, hs_meeting_external_url: nil, hs_meeting_location: nil, hs_meeting_location_type: nil, hs_unique_id: nil, hubspot_owner_id: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Scheduler::ExternalCalendarMeetingEventResponseProperties for more details.
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 122
|
Instance Attribute Details
#hs_activity_type ⇒ String?
The activity type of the meeting. Acceptable values are based on portal defined call and meeting types.
59 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 59 optional :hs_activity_type, String |
#hs_attachment_ids ⇒ Array<String>?
64 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 64 optional :hs_attachment_ids, HubSpotSDK::Internal::Type::ArrayOf[String] |
#hs_attendee_owner_ids ⇒ Array<String>?
69 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 69 optional :hs_attendee_owner_ids, HubSpotSDK::Internal::Type::ArrayOf[String] |
#hs_engagement_source ⇒ Symbol, HubSpotSDK::Models::Scheduler::ExternalCalendarMeetingEventResponseProperties::HsEngagementSource
The source of the engagement, will always be ‘MEETINGS`.
11 12 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 11 required :hs_engagement_source, enum: -> { HubSpotSDK::Scheduler::ExternalCalendarMeetingEventResponseProperties::HsEngagementSource } |
#hs_engagement_source_id ⇒ String
The ID associated with the process created the engagement. Should always be empty when creating meeting events through this API.
19 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 19 required :hs_engagement_source_id, String |
#hs_include_description_in_reminder ⇒ String?
Whether to include the meeting description in the reminder.
75 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 75 optional :hs_include_description_in_reminder, String |
#hs_internal_meeting_notes ⇒ String?
Internal notes related to the meeting.
81 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 81 optional :hs_internal_meeting_notes, String |
#hs_meeting_body ⇒ String?
The description of the meeting and calendar event.
87 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 87 optional :hs_meeting_body, String |
#hs_meeting_end_time ⇒ Time
The end time of the meeting in ISO 8601 format.
25 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 25 required :hs_meeting_end_time, Time |
#hs_meeting_external_url ⇒ String?
The calendar event URL for the meeting.
93 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 93 optional :hs_meeting_external_url, String |
#hs_meeting_location ⇒ String?
The physical address, virtual location, or phone number where the meeting will take place.
100 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 100 optional :hs_meeting_location, String |
#hs_meeting_location_type ⇒ Symbol, ...
The type of location for the meeting. Acceptable values are: ADDRESS, CUSTOM, PHONE.
107 108 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 107 optional :hs_meeting_location_type, enum: -> { HubSpotSDK::Scheduler::ExternalCalendarMeetingEventResponseProperties::HsMeetingLocationType } |
#hs_meeting_outcome ⇒ String
The outcome of the meeting. Acceptable default values are: SCHEDULED, COMPLETED, RESCHEDULED, NO_SHOW, CANCELED. This property can be changed to include additional custom values.
33 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 33 required :hs_meeting_outcome, String |
#hs_meeting_start_time ⇒ Time
The start time of the meeting in ISO 8601 format.
39 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 39 required :hs_meeting_start_time, Time |
#hs_meeting_title ⇒ String
The title of the meeting and calendar event.
45 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 45 required :hs_meeting_title, String |
#hs_timestamp ⇒ Time
The time that the meeting should start in ISO 8601 format. This value should be the same as ‘hs_meeting_start_time`.
52 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 52 required :hs_timestamp, Time |
#hs_unique_id ⇒ String?
The unique ID of the created calendar event.
114 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 114 optional :hs_unique_id, String |
#hubspot_owner_id ⇒ String?
The owner ID of the HubSpot user hosting the meeting.
120 |
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 120 optional :hubspot_owner_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_calendar_meeting_event_response_properties.rb', line 283
|