Class: HubSpotSDK::Models::Scheduler::ExternalLegalConsentOptions
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Scheduler::ExternalLegalConsentOptions
- Defined in:
- lib/hubspot_sdk/models/scheduler/external_legal_consent_options.rb
Defined Under Namespace
Modules: LegitimateInterestLegalBasis, ProcessingConsentType
Instance Attribute Summary collapse
- #communication_consent_checkboxes ⇒ Array<HubSpotSDK::Models::Scheduler::ExternalCommunicationConsentCheckbox>
-
#communication_consent_text ⇒ String
The text that describes the consent for communication preferences.
-
#is_legitimate_interest ⇒ Boolean
Whether the legal basis for processing is legitimate interest.
-
#legitimate_interest_legal_basis ⇒ Symbol, ...
The legal basis for processing under legitimate interest.
- #legitimate_interest_subscription_types ⇒ Array<Integer>
-
#privacy_policy_text ⇒ String
The text that describes the data processing privacy policy.
-
#processing_consent_checkbox_label ⇒ String
The label for the checkbox used to obtain consent for data processing.
-
#processing_consent_footer_text ⇒ String
The footer text accompanying the consent for data processing.
-
#processing_consent_text ⇒ String
The text that describes the consent for processing personal data.
-
#processing_consent_type ⇒ Symbol, HubSpotSDK::Models::Scheduler::ExternalLegalConsentOptions::ProcessingConsentType
The type of consent required for processing.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(communication_consent_checkboxes:, communication_consent_text:, is_legitimate_interest:, legitimate_interest_subscription_types:, privacy_policy_text:, processing_consent_checkbox_label:, processing_consent_footer_text:, processing_consent_text:, processing_consent_type:, legitimate_interest_legal_basis: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalLegalConsentOptions for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(communication_consent_checkboxes:, communication_consent_text:, is_legitimate_interest:, legitimate_interest_subscription_types:, privacy_policy_text:, processing_consent_checkbox_label:, processing_consent_footer_text:, processing_consent_text:, processing_consent_type:, legitimate_interest_legal_basis: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Scheduler::ExternalLegalConsentOptions for more details.
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_legal_consent_options.rb', line 81
|
Instance Attribute Details
#communication_consent_checkboxes ⇒ Array<HubSpotSDK::Models::Scheduler::ExternalCommunicationConsentCheckbox>
10 11 12 13 14 |
# File 'lib/hubspot_sdk/models/scheduler/external_legal_consent_options.rb', line 10 required :communication_consent_checkboxes, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Scheduler::ExternalCommunicationConsentCheckbox] }, api_name: :communicationConsentCheckboxes |
#communication_consent_text ⇒ String
The text that describes the consent for communication preferences.
20 |
# File 'lib/hubspot_sdk/models/scheduler/external_legal_consent_options.rb', line 20 required :communication_consent_text, String, api_name: :communicationConsentText |
#is_legitimate_interest ⇒ Boolean
Whether the legal basis for processing is legitimate interest.
26 |
# File 'lib/hubspot_sdk/models/scheduler/external_legal_consent_options.rb', line 26 required :is_legitimate_interest, HubSpotSDK::Internal::Type::Boolean, api_name: :isLegitimateInterest |
#legitimate_interest_legal_basis ⇒ Symbol, ...
The legal basis for processing under legitimate interest. Accepted values are: LEGITIMATE_INTEREST_PQL, LEGITIMATE_INTEREST_CLIENT, PERFORMANCE_OF_CONTRACT, CONSENT_WITH_NOTICE, NON_GDPR, PROCESS_AND_STORE, LEGITIMATE_INTEREST_OTHER.
75 76 77 78 79 |
# File 'lib/hubspot_sdk/models/scheduler/external_legal_consent_options.rb', line 75 optional :legitimate_interest_legal_basis, enum: -> { HubSpotSDK::Scheduler::ExternalLegalConsentOptions::LegitimateInterestLegalBasis }, api_name: :legitimateInterestLegalBasis |
#legitimate_interest_subscription_types ⇒ Array<Integer>
31 32 33 |
# File 'lib/hubspot_sdk/models/scheduler/external_legal_consent_options.rb', line 31 required :legitimate_interest_subscription_types, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :legitimateInterestSubscriptionTypes |
#privacy_policy_text ⇒ String
The text that describes the data processing privacy policy.
39 |
# File 'lib/hubspot_sdk/models/scheduler/external_legal_consent_options.rb', line 39 required :privacy_policy_text, String, api_name: :privacyPolicyText |
#processing_consent_checkbox_label ⇒ String
The label for the checkbox used to obtain consent for data processing.
45 |
# File 'lib/hubspot_sdk/models/scheduler/external_legal_consent_options.rb', line 45 required :processing_consent_checkbox_label, String, api_name: :processingConsentCheckboxLabel |
#processing_consent_footer_text ⇒ String
The footer text accompanying the consent for data processing. This field is not used by the meeting platform and will always be empty.
52 |
# File 'lib/hubspot_sdk/models/scheduler/external_legal_consent_options.rb', line 52 required :processing_consent_footer_text, String, api_name: :processingConsentFooterText |
#processing_consent_text ⇒ String
The text that describes the consent for processing personal data.
58 |
# File 'lib/hubspot_sdk/models/scheduler/external_legal_consent_options.rb', line 58 required :processing_consent_text, String, api_name: :processingConsentText |
#processing_consent_type ⇒ Symbol, HubSpotSDK::Models::Scheduler::ExternalLegalConsentOptions::ProcessingConsentType
The type of consent required for processing. Accepted values are: IMPLICIT, REQUIRED_CHECKBOX.
65 66 67 |
# File 'lib/hubspot_sdk/models/scheduler/external_legal_consent_options.rb', line 65 required :processing_consent_type, enum: -> { HubSpotSDK::Scheduler::ExternalLegalConsentOptions::ProcessingConsentType }, api_name: :processingConsentType |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_legal_consent_options.rb', line 115
|