Class: HubSpotSDK::Models::Scheduler::ExternalLinkDisplayInfo
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Scheduler::ExternalLinkDisplayInfo
- Defined in:
- lib/hubspot_sdk/models/scheduler/external_link_display_info.rb
Defined Under Namespace
Modules: PublicDisplayAvatarOption
Instance Attribute Summary collapse
-
#avatar ⇒ String?
The URL of the user’s custom uploaded avatar image.
-
#company_avatar ⇒ String?
The URL of the company’s avatar image.
-
#headline ⇒ String?
Deprecated field with no impact of link display info.
-
#public_display_avatar_option ⇒ Symbol, ...
Option for determining which avatar to display on scheduling page.
Instance Method Summary collapse
-
#initialize(avatar: nil, company_avatar: nil, headline: nil, public_display_avatar_option: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalLinkDisplayInfo for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(avatar: nil, company_avatar: nil, headline: nil, public_display_avatar_option: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Scheduler::ExternalLinkDisplayInfo for more details.
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_link_display_info.rb', line 34
|
Instance Attribute Details
#avatar ⇒ String?
The URL of the user’s custom uploaded avatar image.
11 |
# File 'lib/hubspot_sdk/models/scheduler/external_link_display_info.rb', line 11 optional :avatar, String |
#company_avatar ⇒ String?
The URL of the company’s avatar image.
17 |
# File 'lib/hubspot_sdk/models/scheduler/external_link_display_info.rb', line 17 optional :company_avatar, String, api_name: :companyAvatar |
#headline ⇒ String?
Deprecated field with no impact of link display info.
23 |
# File 'lib/hubspot_sdk/models/scheduler/external_link_display_info.rb', line 23 optional :headline, String |
#public_display_avatar_option ⇒ Symbol, ...
Option for determining which avatar to display on scheduling page. Accepted values are: PROFILE_IMAGE, COMPANY_LOGO, CUSTOM_AVATAR,
30 31 32 |
# File 'lib/hubspot_sdk/models/scheduler/external_link_display_info.rb', line 30 optional :public_display_avatar_option, enum: -> { HubSpotSDK::Scheduler::ExternalLinkDisplayInfo::PublicDisplayAvatarOption }, api_name: :publicDisplayAvatarOption |