Class: HubSpotSDK::Models::Scheduler::ExternalLinkFormField
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Scheduler::ExternalLinkFormField
- Defined in:
- lib/hubspot_sdk/models/scheduler/external_link_form_field.rb
Instance Attribute Summary collapse
-
#field_type ⇒ String
The specific field type of the form field.
-
#is_custom ⇒ Boolean
Whether the form field is a custom field.
-
#is_required ⇒ Boolean
Whether the form field is mandatory.
-
#label ⇒ String
The text label for the form field.
-
#name ⇒ String
The name identifier for the form field.
- #options ⇒ Array<HubSpotSDK::Models::Scheduler::ExternalOption>
-
#type ⇒ String
The data type of the form field accepts (e.g. ‘date`, `enumeration`, etc).
Instance Method Summary collapse
-
#initialize(field_type:, is_custom:, is_required:, label:, name:, options:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalLinkFormField for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(field_type:, is_custom:, is_required:, label:, name:, options:, type:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Scheduler::ExternalLinkFormField for more details.
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_link_form_field.rb', line 49
|
Instance Attribute Details
#field_type ⇒ String
The specific field type of the form field. Corresponds to property types (e.g., ‘select`, `radio`, `date`, etc)
12 |
# File 'lib/hubspot_sdk/models/scheduler/external_link_form_field.rb', line 12 required :field_type, String, api_name: :fieldType |
#is_custom ⇒ Boolean
Whether the form field is a custom field.
18 |
# File 'lib/hubspot_sdk/models/scheduler/external_link_form_field.rb', line 18 required :is_custom, HubSpotSDK::Internal::Type::Boolean, api_name: :isCustom |
#is_required ⇒ Boolean
Whether the form field is mandatory.
24 |
# File 'lib/hubspot_sdk/models/scheduler/external_link_form_field.rb', line 24 required :is_required, HubSpotSDK::Internal::Type::Boolean, api_name: :isRequired |
#label ⇒ String
The text label for the form field.
30 |
# File 'lib/hubspot_sdk/models/scheduler/external_link_form_field.rb', line 30 required :label, String |
#name ⇒ String
The name identifier for the form field.
36 |
# File 'lib/hubspot_sdk/models/scheduler/external_link_form_field.rb', line 36 required :name, String |
#options ⇒ Array<HubSpotSDK::Models::Scheduler::ExternalOption>
41 |
# File 'lib/hubspot_sdk/models/scheduler/external_link_form_field.rb', line 41 required :options, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Scheduler::ExternalOption] } |
#type ⇒ String
The data type of the form field accepts (e.g. ‘date`, `enumeration`, etc)
47 |
# File 'lib/hubspot_sdk/models/scheduler/external_link_form_field.rb', line 47 required :type, String |