Class: HubSpotSDK::Models::Scheduler::ExternalMeetingAvailability
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Scheduler::ExternalMeetingAvailability
- Defined in:
- lib/hubspot_sdk/models/scheduler/external_meeting_availability.rb
Instance Attribute Summary collapse
-
#end_millis_utc ⇒ Integer
The end time of the meeting availability, represented as Unix time in milliseconds.
-
#start_millis_utc ⇒ Integer
The start time of the meeting availability, represented as Unix time in milliseconds.
Instance Method Summary collapse
-
#initialize(end_millis_utc:, start_millis_utc:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalMeetingAvailability for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_millis_utc:, start_millis_utc:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Scheduler::ExternalMeetingAvailability for more details.
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_availability.rb', line 21
|
Instance Attribute Details
#end_millis_utc ⇒ Integer
The end time of the meeting availability, represented as Unix time in milliseconds.
12 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_availability.rb', line 12 required :end_millis_utc, Integer, api_name: :endMillisUtc |
#start_millis_utc ⇒ Integer
The start time of the meeting availability, represented as Unix time in milliseconds.
19 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_availability.rb', line 19 required :start_millis_utc, Integer, api_name: :startMillisUtc |