Class: HubSpotSDK::Models::Scheduler::ExternalMeetingBooking
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Scheduler::ExternalMeetingBooking
- Defined in:
- lib/hubspot_sdk/models/scheduler/external_meeting_booking.rb
Direct Known Subclasses
Instance Attribute Summary collapse
-
#duration ⇒ Integer
The duration of the meeting in milliseconds.
-
#email ⇒ String
The email address of the person booking the meeting.
-
#first_name ⇒ String
The first name of the person booking the meeting.
- #form_fields ⇒ Array<HubSpotSDK::Models::Scheduler::ExternalBookingFormField>
-
#last_name ⇒ String
The last name of the person booking the meeting.
- #legal_consent_responses ⇒ Array<HubSpotSDK::Models::Scheduler::ExternalLegalConsentResponse>
- #likely_available_user_ids ⇒ Array<String>
-
#locale ⇒ String?
The locale used for formatting dates and times in the meeting booking.
-
#slug ⇒ String
The unique path identifier for the meeting page.
-
#start_time ⇒ Time
The date and time when the meeting is scheduled to start, in ISO 8601 format.
-
#timezone ⇒ String?
The timezone in which the meeting is scheduled.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(duration:, email:, first_name:, form_fields:, last_name:, legal_consent_responses:, likely_available_user_ids:, slug:, start_time:, locale: nil, timezone: nil) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking.rb', line 78
|
Instance Attribute Details
#duration ⇒ Integer
The duration of the meeting in milliseconds.
11 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking.rb', line 11 required :duration, Integer |
#email ⇒ String
The email address of the person booking the meeting.
17 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking.rb', line 17 required :email, String |
#first_name ⇒ String
The first name of the person booking the meeting.
23 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking.rb', line 23 required :first_name, String, api_name: :firstName |
#form_fields ⇒ Array<HubSpotSDK::Models::Scheduler::ExternalBookingFormField>
28 29 30 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking.rb', line 28 required :form_fields, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Scheduler::ExternalBookingFormField] }, api_name: :formFields |
#last_name ⇒ String
The last name of the person booking the meeting.
36 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking.rb', line 36 required :last_name, String, api_name: :lastName |
#legal_consent_responses ⇒ Array<HubSpotSDK::Models::Scheduler::ExternalLegalConsentResponse>
41 42 43 44 45 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking.rb', line 41 required :legal_consent_responses, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Scheduler::ExternalLegalConsentResponse] }, api_name: :legalConsentResponses |
#likely_available_user_ids ⇒ Array<String>
50 51 52 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking.rb', line 50 required :likely_available_user_ids, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :likelyAvailableUserIds |
#locale ⇒ String?
The locale used for formatting dates and times in the meeting booking.
70 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking.rb', line 70 optional :locale, String |
#slug ⇒ String
The unique path identifier for the meeting page.
58 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking.rb', line 58 required :slug, String |
#start_time ⇒ Time
The date and time when the meeting is scheduled to start, in ISO 8601 format.
64 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking.rb', line 64 required :start_time, Time, api_name: :startTime |
#timezone ⇒ String?
The timezone in which the meeting is scheduled.
76 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking.rb', line 76 optional :timezone, String |