Class: HubSpotSDK::Models::Scheduler::ExternalMeetingBookingResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Scheduler::ExternalMeetingBookingResponse
- Defined in:
- lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb
Instance Attribute Summary collapse
-
#booking_timezone ⇒ String
The timezone the meeting was booked from.
-
#calendar_event_id ⇒ String
The unique identifier for the meeting’s calendar event.
-
#contact_id ⇒ String
The ID of the contact associated to the meeting.
-
#duration ⇒ Integer
The duration of the meeting in milliseconds.
-
#end_ ⇒ Time
The date and time when the meeting is scheduled to end, in ISO 8601 format.
- #form_fields ⇒ Array<HubSpotSDK::Models::Scheduler::ExternalValidatedFormField>
- #guest_emails ⇒ Array<String>
-
#is_offline ⇒ Boolean
Whether the meeting was booked offline and no associated calendar event was created.
- #legal_consent_responses ⇒ Array<HubSpotSDK::Models::Scheduler::ExternalLegalConsentResponse>
-
#locale ⇒ String?
The locale the meeting was booked with, used to determine date formatting in calendar event description.
-
#location ⇒ String?
The physical or virtual location where the meeting will take place.
-
#start ⇒ Time
The date and time when the meeting is scheduled to start, in ISO 8601 format.
-
#subject ⇒ String
The title of the meeting and calendar event.
-
#web_conference_meeting_id ⇒ String?
The unique identifier for the web conference meeting.
-
#web_conference_url ⇒ String?
The URL for accessing the meeting’s web conference.
Instance Method Summary collapse
-
#initialize(booking_timezone:, calendar_event_id:, contact_id:, duration:, end_:, form_fields:, guest_emails:, is_offline:, legal_consent_responses:, start:, subject:, locale: nil, location: nil, web_conference_meeting_id: nil, web_conference_url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalMeetingBookingResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(booking_timezone:, calendar_event_id:, contact_id:, duration:, end_:, form_fields:, guest_emails:, is_offline:, legal_consent_responses:, start:, subject:, locale: nil, location: nil, web_conference_meeting_id: nil, web_conference_url: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Scheduler::ExternalMeetingBookingResponse for more details.
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 104
|
Instance Attribute Details
#booking_timezone ⇒ String
The timezone the meeting was booked from.
11 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 11 required :booking_timezone, String, api_name: :bookingTimezone |
#calendar_event_id ⇒ String
The unique identifier for the meeting’s calendar event.
17 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 17 required :calendar_event_id, String, api_name: :calendarEventId |
#contact_id ⇒ String
The ID of the contact associated to the meeting.
23 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 23 required :contact_id, String, api_name: :contactId |
#duration ⇒ Integer
The duration of the meeting in milliseconds.
29 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 29 required :duration, Integer |
#end_ ⇒ Time
The date and time when the meeting is scheduled to end, in ISO 8601 format.
35 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 35 required :end_, Time, api_name: :end |
#form_fields ⇒ Array<HubSpotSDK::Models::Scheduler::ExternalValidatedFormField>
40 41 42 43 44 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 40 required :form_fields, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Scheduler::ExternalValidatedFormField] }, api_name: :formFields |
#guest_emails ⇒ Array<String>
49 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 49 required :guest_emails, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :guestEmails |
#is_offline ⇒ Boolean
Whether the meeting was booked offline and no associated calendar event was created.
56 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 56 required :is_offline, HubSpotSDK::Internal::Type::Boolean, api_name: :isOffline |
#legal_consent_responses ⇒ Array<HubSpotSDK::Models::Scheduler::ExternalLegalConsentResponse>
61 62 63 64 65 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 61 required :legal_consent_responses, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Scheduler::ExternalLegalConsentResponse] }, api_name: :legalConsentResponses |
#locale ⇒ String?
The locale the meeting was booked with, used to determine date formatting in calendar event description.
84 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 84 optional :locale, String |
#location ⇒ String?
The physical or virtual location where the meeting will take place.
90 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 90 optional :location, String |
#start ⇒ Time
The date and time when the meeting is scheduled to start, in ISO 8601 format.
71 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 71 required :start, Time |
#subject ⇒ String
The title of the meeting and calendar event.
77 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 77 required :subject, String |
#web_conference_meeting_id ⇒ String?
The unique identifier for the web conference meeting.
96 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 96 optional :web_conference_meeting_id, String, api_name: :webConferenceMeetingId |
#web_conference_url ⇒ String?
The URL for accessing the meeting’s web conference.
102 |
# File 'lib/hubspot_sdk/models/scheduler/external_meeting_booking_response.rb', line 102 optional :web_conference_url, String, api_name: :webConferenceUrl |