Class: HubSpotSDK::Models::Scheduler::ExternalMeetingsWelcomeScreenInfo
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Scheduler::ExternalMeetingsWelcomeScreenInfo
- Defined in:
- lib/hubspot_sdk/models/scheduler/external_meetings_welcome_screen_info.rb
Instance Attribute Summary collapse
-
#description ⇒ String?
A brief description displayed the welcome screen below the title.
-
#logo_url ⇒ String?
The URL of the logo image to be displayed on the welcome screen, only used if ‘useCompanyLogo` is false.
-
#show_welcome_screen ⇒ Boolean?
Deprecated property.
-
#title ⇒ String?
The main heading displayed on the welcome screen.
-
#use_company_logo ⇒ Boolean?
Whether the company’s logo should be displayed on the welcome screen.
Instance Method Summary collapse
-
#initialize(description: nil, logo_url: nil, show_welcome_screen: nil, title: nil, use_company_logo: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalMeetingsWelcomeScreenInfo for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(description: nil, logo_url: nil, show_welcome_screen: nil, title: nil, use_company_logo: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Scheduler::ExternalMeetingsWelcomeScreenInfo for more details.
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_meetings_welcome_screen_info.rb', line 38
|
Instance Attribute Details
#description ⇒ String?
A brief description displayed the welcome screen below the title.
11 |
# File 'lib/hubspot_sdk/models/scheduler/external_meetings_welcome_screen_info.rb', line 11 optional :description, String |
#logo_url ⇒ String?
The URL of the logo image to be displayed on the welcome screen, only used if ‘useCompanyLogo` is false.
18 |
# File 'lib/hubspot_sdk/models/scheduler/external_meetings_welcome_screen_info.rb', line 18 optional :logo_url, String, api_name: :logoUrl |
#show_welcome_screen ⇒ Boolean?
Deprecated property. Value can be ignored but will always be false.
24 |
# File 'lib/hubspot_sdk/models/scheduler/external_meetings_welcome_screen_info.rb', line 24 optional :show_welcome_screen, HubSpotSDK::Internal::Type::Boolean, api_name: :showWelcomeScreen |
#title ⇒ String?
The main heading displayed on the welcome screen.
30 |
# File 'lib/hubspot_sdk/models/scheduler/external_meetings_welcome_screen_info.rb', line 30 optional :title, String |
#use_company_logo ⇒ Boolean?
Whether the company’s logo should be displayed on the welcome screen.
36 |
# File 'lib/hubspot_sdk/models/scheduler/external_meetings_welcome_screen_info.rb', line 36 optional :use_company_logo, HubSpotSDK::Internal::Type::Boolean, api_name: :useCompanyLogo |