Class: HubSpotSDK::Models::Scheduler::ExternalOption
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Scheduler::ExternalOption
- Defined in:
- lib/hubspot_sdk/models/scheduler/external_option.rb
Instance Attribute Summary collapse
-
#description ⇒ String
A brief description of the option.
-
#display_order ⇒ Integer
The order in which the option should be displayed.
-
#double_data ⇒ Float
Deprecated property.
-
#hidden ⇒ Boolean
Whether the option should be hidden from the user.
-
#label ⇒ String
The text label for the option.
-
#read_only ⇒ Boolean
Whether the option is read-only.
-
#value ⇒ String
The value associated with the option.
Instance Method Summary collapse
- #initialize(description:, display_order:, double_data:, hidden:, label:, read_only:, value:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(description:, display_order:, double_data:, hidden:, label:, read_only:, value:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_option.rb', line 49
|
Instance Attribute Details
#description ⇒ String
A brief description of the option.
11 |
# File 'lib/hubspot_sdk/models/scheduler/external_option.rb', line 11 required :description, String |
#display_order ⇒ Integer
The order in which the option should be displayed.
17 |
# File 'lib/hubspot_sdk/models/scheduler/external_option.rb', line 17 required :display_order, Integer, api_name: :displayOrder |
#double_data ⇒ Float
Deprecated property. Will always be 0.
23 |
# File 'lib/hubspot_sdk/models/scheduler/external_option.rb', line 23 required :double_data, Float, api_name: :doubleData |
#hidden ⇒ Boolean
Whether the option should be hidden from the user.
29 |
# File 'lib/hubspot_sdk/models/scheduler/external_option.rb', line 29 required :hidden, HubSpotSDK::Internal::Type::Boolean |
#label ⇒ String
The text label for the option.
35 |
# File 'lib/hubspot_sdk/models/scheduler/external_option.rb', line 35 required :label, String |
#read_only ⇒ Boolean
Whether the option is read-only.
41 |
# File 'lib/hubspot_sdk/models/scheduler/external_option.rb', line 41 required :read_only, HubSpotSDK::Internal::Type::Boolean, api_name: :readOnly |
#value ⇒ String
The value associated with the option.
47 |
# File 'lib/hubspot_sdk/models/scheduler/external_option.rb', line 47 required :value, String |