Class: HubSpotSDK::Models::Scheduler::ExternalValidatedFormField
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Scheduler::ExternalValidatedFormField
- Defined in:
- lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb
Instance Attribute Summary collapse
-
#field_type ⇒ String?
The specific input type of the form field.
-
#is_custom ⇒ Boolean
Whether the form field is a custom field.
-
#label ⇒ String
The text label associated with the form field.
-
#name ⇒ String
The name identifier for the form field, includes underscores in place of spaces (e.g., the label ‘my form` is converted to `my_form`).
-
#translated_label ⇒ String?
The translated text label for the form field.
-
#value ⇒ String
The value associated with the form field.
-
#value_label ⇒ String?
The text label associated to a form field selection or option.
Instance Method Summary collapse
-
#initialize(is_custom:, label:, name:, value:, field_type: nil, translated_label: nil, value_label: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExternalValidatedFormField for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(is_custom:, label:, name:, value:, field_type: nil, translated_label: nil, value_label: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Scheduler::ExternalValidatedFormField for more details.
|
|
# File 'lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb', line 51
|
Instance Attribute Details
#field_type ⇒ String?
The specific input type of the form field. Corresponds to property types (e.g., ‘select`, `radio`, `date`, etc).
37 |
# File 'lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb', line 37 optional :field_type, String, api_name: :fieldType |
#is_custom ⇒ Boolean
Whether the form field is a custom field.
11 |
# File 'lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb', line 11 required :is_custom, HubSpotSDK::Internal::Type::Boolean, api_name: :isCustom |
#label ⇒ String
The text label associated with the form field.
17 |
# File 'lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb', line 17 required :label, String |
#name ⇒ String
The name identifier for the form field, includes underscores in place of spaces (e.g., the label ‘my form` is converted to `my_form`).
24 |
# File 'lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb', line 24 required :name, String |
#translated_label ⇒ String?
The translated text label for the form field.
43 |
# File 'lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb', line 43 optional :translated_label, String, api_name: :translatedLabel |
#value ⇒ String
The value associated with the form field.
30 |
# File 'lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb', line 30 required :value, String |
#value_label ⇒ String?
The text label associated to a form field selection or option.
49 |
# File 'lib/hubspot_sdk/models/scheduler/external_validated_form_field.rb', line 49 optional :value_label, String, api_name: :valueLabel |