Class: HubSpotSDK::Models::Scheduler::Meetings::BasicListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Scheduler::Meetings::BasicListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/hubspot_sdk/models/scheduler/meetings/basic_list_params.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
-
#limit ⇒ Integer?
The maximum number of results to display per page.
- #name ⇒ String?
- #organizer_user_id ⇒ String?
- #type ⇒ Symbol, ...
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#after ⇒ String?
The paging cursor token of the last successfully read resource will be returned as the ‘paging.next.after` JSON property of a paged response containing more results.
18 |
# File 'lib/hubspot_sdk/models/scheduler/meetings/basic_list_params.rb', line 18 optional :after, String |
#limit ⇒ Integer?
The maximum number of results to display per page.
24 |
# File 'lib/hubspot_sdk/models/scheduler/meetings/basic_list_params.rb', line 24 optional :limit, Integer |
#name ⇒ String?
29 |
# File 'lib/hubspot_sdk/models/scheduler/meetings/basic_list_params.rb', line 29 optional :name, String |
#organizer_user_id ⇒ String?
34 |
# File 'lib/hubspot_sdk/models/scheduler/meetings/basic_list_params.rb', line 34 optional :organizer_user_id, String |
#type ⇒ Symbol, ...
39 |
# File 'lib/hubspot_sdk/models/scheduler/meetings/basic_list_params.rb', line 39 optional :type, enum: -> { HubSpotSDK::Scheduler::Meetings::BasicListParams::Type } |