Class: HubSpotSDK::Models::Settings::ExchangeRate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Settings::ExchangeRate
- Defined in:
- lib/hubspot_sdk/models/settings/exchange_rate.rb
Defined Under Namespace
Modules: FromCurrencyCode, ToCurrencyCode
Instance Attribute Summary collapse
-
#conversion_rate ⇒ Float
The conversion rate between the to and from currency code of this exchange rate.
-
#created_at ⇒ Time
The date the exchange rate was created.
-
#effective_at ⇒ Time
The date the exchange rate is in effect.
-
#from_currency_code ⇒ Symbol, HubSpotSDK::Models::Settings::ExchangeRate::FromCurrencyCode
This represents the three-letter currency code (such as USD for US Dollar) of the currency you are converting from.
-
#id ⇒ String
A unique identifier for the exchange rate.
-
#to_currency_code ⇒ Symbol, HubSpotSDK::Models::Settings::ExchangeRate::ToCurrencyCode
This represents the three-letter currency code (such as USD for US Dollar) of the currency you are converting to.
-
#updated_at ⇒ Time
The date the exchange rate was last updated.
-
#visible_in_ui ⇒ Boolean
This indicates if the exchange rate is shown in the MultiCurrency settings page.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, conversion_rate:, created_at:, effective_at:, from_currency_code:, to_currency_code:, updated_at:, visible_in_ui:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExchangeRate for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, conversion_rate:, created_at:, effective_at:, from_currency_code:, to_currency_code:, updated_at:, visible_in_ui:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Settings::ExchangeRate for more details.
|
|
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 61
|
Instance Attribute Details
#conversion_rate ⇒ Float
The conversion rate between the to and from currency code of this exchange rate.
17 |
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 17 required :conversion_rate, Float, api_name: :conversionRate |
#created_at ⇒ Time
The date the exchange rate was created.
23 |
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 23 required :created_at, Time, api_name: :createdAt |
#effective_at ⇒ Time
The date the exchange rate is in effect.
29 |
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 29 required :effective_at, Time, api_name: :effectiveAt |
#from_currency_code ⇒ Symbol, HubSpotSDK::Models::Settings::ExchangeRate::FromCurrencyCode
This represents the three-letter currency code (such as USD for US Dollar) of the currency you are converting from.
36 37 38 |
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 36 required :from_currency_code, enum: -> { HubSpotSDK::Settings::ExchangeRate::FromCurrencyCode }, api_name: :fromCurrencyCode |
#id ⇒ String
A unique identifier for the exchange rate
11 |
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 11 required :id, String |
#to_currency_code ⇒ Symbol, HubSpotSDK::Models::Settings::ExchangeRate::ToCurrencyCode
This represents the three-letter currency code (such as USD for US Dollar) of the currency you are converting to.
45 46 47 |
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 45 required :to_currency_code, enum: -> { HubSpotSDK::Settings::ExchangeRate::ToCurrencyCode }, api_name: :toCurrencyCode |
#updated_at ⇒ Time
The date the exchange rate was last updated.
53 |
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 53 required :updated_at, Time, api_name: :updatedAt |
#visible_in_ui ⇒ Boolean
This indicates if the exchange rate is shown in the MultiCurrency settings page.
59 |
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 59 required :visible_in_ui, HubSpotSDK::Internal::Type::Boolean, api_name: :visibleInUI |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/settings/exchange_rate.rb', line 265
|