Class: HubSpotSDK::Models::Settings::PublicTaxRateGroup
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Settings::PublicTaxRateGroup
- Defined in:
- lib/hubspot_sdk/models/settings/public_tax_rate_group.rb
Overview
Instance Attribute Summary collapse
-
#active ⇒ Boolean
Indicates whether the tax rate group is currently active.
-
#created_at ⇒ Time
The date and time when the tax rate was created.
-
#id ⇒ String
The unique identifier for the tax rate.
-
#label ⇒ String
The display label for the tax rate.
-
#name ⇒ String
The name of the tax rate.
-
#percentage_rate ⇒ Float
The percentage rate applied.
-
#updated_at ⇒ Time
The date and time when the tax rate was last updated.
Instance Method Summary collapse
- #initialize(id:, active:, created_at:, label:, name:, percentage_rate:, updated_at:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, active:, created_at:, label:, name:, percentage_rate:, updated_at:) ⇒ Object
|
|
# File 'lib/hubspot_sdk/models/settings/public_tax_rate_group.rb', line 50
|
Instance Attribute Details
#active ⇒ Boolean
Indicates whether the tax rate group is currently active.
18 |
# File 'lib/hubspot_sdk/models/settings/public_tax_rate_group.rb', line 18 required :active, HubSpotSDK::Internal::Type::Boolean |
#created_at ⇒ Time
The date and time when the tax rate was created.
24 |
# File 'lib/hubspot_sdk/models/settings/public_tax_rate_group.rb', line 24 required :created_at, Time, api_name: :createdAt |
#id ⇒ String
The unique identifier for the tax rate.
12 |
# File 'lib/hubspot_sdk/models/settings/public_tax_rate_group.rb', line 12 required :id, String |
#label ⇒ String
The display label for the tax rate.
30 |
# File 'lib/hubspot_sdk/models/settings/public_tax_rate_group.rb', line 30 required :label, String |
#name ⇒ String
The name of the tax rate.
36 |
# File 'lib/hubspot_sdk/models/settings/public_tax_rate_group.rb', line 36 required :name, String |
#percentage_rate ⇒ Float
The percentage rate applied.
42 |
# File 'lib/hubspot_sdk/models/settings/public_tax_rate_group.rb', line 42 required :percentage_rate, Float, api_name: :percentageRate |
#updated_at ⇒ Time
The date and time when the tax rate was last updated.
48 |
# File 'lib/hubspot_sdk/models/settings/public_tax_rate_group.rb', line 48 required :updated_at, Time, api_name: :updatedAt |