Class: HubSpotSDK::Models::Webhooks::BatchResponseSubscriptionResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Webhooks::BatchResponseSubscriptionResponse
- Defined in:
- lib/hubspot_sdk/models/webhooks/batch_response_subscription_response.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#completed_at ⇒ Time
The date and time when the batch operation was completed.
-
#links ⇒ Hash{Symbol=>String}?
A collection of related links associated with the batch operation.
-
#requested_at ⇒ Time?
The date and time when the batch operation was requested.
-
#results ⇒ Array<HubSpotSDK::Models::Webhooks::SubscriptionResponse>
The list of results from the batch operation.
-
#started_at ⇒ Time
The date and time when the batch operation started.
-
#status ⇒ Symbol, HubSpotSDK::Models::Webhooks::BatchResponseSubscriptionResponse::Status
The current status of the batch operation, which can be PENDING, PROCESSING, CANCELED, or COMPLETE.
Instance Method Summary collapse
-
#initialize(completed_at:, results:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BatchResponseSubscriptionResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(completed_at:, results:, started_at:, status:, links: nil, requested_at: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::BatchResponseSubscriptionResponse for more details.
|
|
# File 'lib/hubspot_sdk/models/webhooks/batch_response_subscription_response.rb', line 45
|
Instance Attribute Details
#completed_at ⇒ Time
The date and time when the batch operation was completed.
12 |
# File 'lib/hubspot_sdk/models/webhooks/batch_response_subscription_response.rb', line 12 required :completed_at, Time, api_name: :completedAt |
#links ⇒ Hash{Symbol=>String}?
A collection of related links associated with the batch operation.
37 |
# File 'lib/hubspot_sdk/models/webhooks/batch_response_subscription_response.rb', line 37 optional :links, HubSpotSDK::Internal::Type::HashOf[String] |
#requested_at ⇒ Time?
The date and time when the batch operation was requested.
43 |
# File 'lib/hubspot_sdk/models/webhooks/batch_response_subscription_response.rb', line 43 optional :requested_at, Time, api_name: :requestedAt |
#results ⇒ Array<HubSpotSDK::Models::Webhooks::SubscriptionResponse>
The list of results from the batch operation.
18 |
# File 'lib/hubspot_sdk/models/webhooks/batch_response_subscription_response.rb', line 18 required :results, -> { HubSpotSDK::Internal::Type::ArrayOf[HubSpotSDK::Webhooks::SubscriptionResponse] } |
#started_at ⇒ Time
The date and time when the batch operation started.
24 |
# File 'lib/hubspot_sdk/models/webhooks/batch_response_subscription_response.rb', line 24 required :started_at, Time, api_name: :startedAt |
#status ⇒ Symbol, HubSpotSDK::Models::Webhooks::BatchResponseSubscriptionResponse::Status
The current status of the batch operation, which can be PENDING, PROCESSING, CANCELED, or COMPLETE.
31 |
# File 'lib/hubspot_sdk/models/webhooks/batch_response_subscription_response.rb', line 31 required :status, enum: -> { HubSpotSDK::Webhooks::BatchResponseSubscriptionResponse::Status } |