Class: HubSpotSDK::Models::Webhooks::Condition

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/webhooks/condition.rb

Defined Under Namespace

Modules: FilterType, Operator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(filter_type:, operator:, property:, value: nil, values: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::Condition for more details.

Parameters:

  • filter_type (Symbol, HubSpotSDK::Models::Webhooks::Condition::FilterType)

    A string representing the type of filter. Valid value is ‘CRM_OBJECT_PROPERTY’.

  • operator (Symbol, HubSpotSDK::Models::Webhooks::Condition::Operator)

    A string indicating the operation to apply for filtering. Valid values include ‘

  • property (String)

    A string specifying the property of the CRM object to be filtered.

  • value (String) (defaults to: nil)

    A string representing the value to compare against the specified property when f

  • values (Array<String>) (defaults to: nil)

    An array of strings, each representing a value to be used in the filtering opera



# File 'lib/hubspot_sdk/models/webhooks/condition.rb', line 41

Instance Attribute Details

#filter_typeSymbol, HubSpotSDK::Models::Webhooks::Condition::FilterType

A string representing the type of filter. Valid value is ‘CRM_OBJECT_PROPERTY’.



11
# File 'lib/hubspot_sdk/models/webhooks/condition.rb', line 11

required :filter_type, enum: -> { HubSpotSDK::Webhooks::Condition::FilterType }, api_name: :filterType

#operatorSymbol, HubSpotSDK::Models::Webhooks::Condition::Operator

A string indicating the operation to apply for filtering. Valid values include ‘EQ’, ‘N_EQ’, ‘LT’, ‘GT’, ‘LTE’, ‘GTE’, ‘CONTAINS’, ‘STARTS_WITH’, ‘ENDS_WITH’, ‘IN’, ‘NOT_IN’, ‘IS_EMPTY’, and ‘IS_NOT_EMPTY’.



19
# File 'lib/hubspot_sdk/models/webhooks/condition.rb', line 19

required :operator, enum: -> { HubSpotSDK::Webhooks::Condition::Operator }

#propertyString

A string specifying the property of the CRM object to be filtered.

Returns:

  • (String)


25
# File 'lib/hubspot_sdk/models/webhooks/condition.rb', line 25

required :property, String

#valueString?

A string representing the value to compare against the specified property when filtering.

Returns:

  • (String, nil)


32
# File 'lib/hubspot_sdk/models/webhooks/condition.rb', line 32

optional :value, String

#valuesArray<String>?

An array of strings, each representing a value to be used in the filtering operation.

Returns:

  • (Array<String>, nil)


39
# File 'lib/hubspot_sdk/models/webhooks/condition.rb', line 39

optional :values, HubSpotSDK::Internal::Type::ArrayOf[String]

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/webhooks/condition.rb', line 63