Class: HubSpotSDK::Models::Webhooks::CrmObjectSnapshotResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/webhooks/crm_object_snapshot_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(object_id_:, object_type_id:, portal_id:, snapshot_status_id:) ⇒ Object

Parameters:

  • object_id_ (Integer)

    An integer representing the unique identifier for the CRM object.

  • object_type_id (String)

    A string representing the type identifier of the CRM object.

  • portal_id (Integer)

    An integer representing the unique identifier for the HubSpot portal.

  • snapshot_status_id (String)

    A UUID string representing the status identifier of the snapshot.



# File 'lib/hubspot_sdk/models/webhooks/crm_object_snapshot_response.rb', line 31

Instance Attribute Details

#object_id_Integer

An integer representing the unique identifier for the CRM object.

Returns:

  • (Integer)


11
# File 'lib/hubspot_sdk/models/webhooks/crm_object_snapshot_response.rb', line 11

required :object_id_, Integer, api_name: :objectId

#object_type_idString

A string representing the type identifier of the CRM object.

Returns:

  • (String)


17
# File 'lib/hubspot_sdk/models/webhooks/crm_object_snapshot_response.rb', line 17

required :object_type_id, String, api_name: :objectTypeId

#portal_idInteger

An integer representing the unique identifier for the HubSpot portal.

Returns:

  • (Integer)


23
# File 'lib/hubspot_sdk/models/webhooks/crm_object_snapshot_response.rb', line 23

required :portal_id, Integer, api_name: :portalId

#snapshot_status_idString

A UUID string representing the status identifier of the snapshot.

Returns:

  • (String)


29
# File 'lib/hubspot_sdk/models/webhooks/crm_object_snapshot_response.rb', line 29

required :snapshot_status_id, String, api_name: :snapshotStatusId