Class: HubSpotSDK::Models::Webhooks::JournalFetchResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Webhooks::JournalFetchResponse
- Defined in:
- lib/hubspot_sdk/models/webhooks/journal_fetch_response.rb
Instance Attribute Summary collapse
-
#current_offset ⇒ String
A UUID string indicating the current offset in the journal data, used for pagination.
-
#expires_at ⇒ Time
The date and time when the URL will expire, in ISO 8601 format.
-
#url ⇒ String
A string representing the URL where the fetched journal data can be accessed.
Instance Method Summary collapse
-
#initialize(current_offset:, expires_at:, url:) ⇒ Object
constructor
Some parameter documentations has been truncated, see JournalFetchResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(current_offset:, expires_at:, url:) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::JournalFetchResponse for more details.
|
|
# File 'lib/hubspot_sdk/models/webhooks/journal_fetch_response.rb', line 26
|
Instance Attribute Details
#current_offset ⇒ String
A UUID string indicating the current offset in the journal data, used for pagination.
12 |
# File 'lib/hubspot_sdk/models/webhooks/journal_fetch_response.rb', line 12 required :current_offset, String, api_name: :currentOffset |
#expires_at ⇒ Time
The date and time when the URL will expire, in ISO 8601 format.
18 |
# File 'lib/hubspot_sdk/models/webhooks/journal_fetch_response.rb', line 18 required :expires_at, Time, api_name: :expiresAt |
#url ⇒ String
A string representing the URL where the fetched journal data can be accessed.
24 |
# File 'lib/hubspot_sdk/models/webhooks/journal_fetch_response.rb', line 24 required :url, String |