Class: HubSpotSDK::Models::Webhooks::SnapshotStatusResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Webhooks::SnapshotStatusResponse
- Defined in:
- lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#completed_at ⇒ Integer?
The timestamp indicating when the snapshot operation was completed, represented as a Unix timestamp in milliseconds.
-
#error_code ⇒ Symbol, ...
A code representing the error that occurred, if any.
-
#id ⇒ String
The unique identifier for the snapshot operation, represented as a UUID.
-
#initiated_at ⇒ Integer
The timestamp indicating when the snapshot operation was initiated, represented as a Unix timestamp in milliseconds.
-
#message ⇒ String?
A descriptive message providing additional information about the snapshot operation or error.
-
#status ⇒ Symbol, HubSpotSDK::Models::Webhooks::SnapshotStatusResponse::Status
The current status of the snapshot.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, initiated_at:, status:, completed_at: nil, error_code: nil, message: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SnapshotStatusResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, initiated_at:, status:, completed_at: nil, error_code: nil, message: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::SnapshotStatusResponse for more details.
|
|
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 51
|
Instance Attribute Details
#completed_at ⇒ Integer?
The timestamp indicating when the snapshot operation was completed, represented as a Unix timestamp in milliseconds.
33 |
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 33 optional :completed_at, Integer, api_name: :completedAt |
#error_code ⇒ Symbol, ...
A code representing the error that occurred, if any. Possible values are ‘TIMEOUT’, ‘VALIDATION_ERROR’, ‘INTERNAL_ERROR’, and ‘PERMISSION_DENIED’.
40 41 42 |
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 40 optional :error_code, enum: -> { HubSpotSDK::Webhooks::SnapshotStatusResponse::ErrorCode }, api_name: :errorCode |
#id ⇒ String
The unique identifier for the snapshot operation, represented as a UUID.
12 |
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 12 required :id, String |
#initiated_at ⇒ Integer
The timestamp indicating when the snapshot operation was initiated, represented as a Unix timestamp in milliseconds.
19 |
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 19 required :initiated_at, Integer, api_name: :initiatedAt |
#message ⇒ String?
A descriptive message providing additional information about the snapshot operation or error.
49 |
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 49 optional :message, String |
#status ⇒ Symbol, HubSpotSDK::Models::Webhooks::SnapshotStatusResponse::Status
The current status of the snapshot. Valid values include ‘PENDING’, ‘IN_PROGRESS’, ‘COMPLETED’, ‘FAILED’, and ‘EXPIRED’.
26 |
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 26 required :status, enum: -> { HubSpotSDK::Webhooks::SnapshotStatusResponse::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 80
|