Class: HubSpotSDK::Models::Webhooks::SnapshotStatusResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb

Overview

Defined Under Namespace

Modules: ErrorCode, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, initiated_at:, status:, completed_at: nil, error_code: nil, message: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::SnapshotStatusResponse for more details.

Parameters:

  • id (String)

    The unique identifier for the snapshot operation, formatted as a UUID.

  • initiated_at (Integer)

    A Unix timestamp in milliseconds indicating when the snapshot operation was init

  • status (Symbol, HubSpotSDK::Models::Webhooks::SnapshotStatusResponse::Status)

    The current status of the snapshot operation. Valid values include ‘PENDING’, ‘I

  • completed_at (Integer) (defaults to: nil)

    A Unix timestamp in milliseconds indicating when the snapshot operation was comp

  • error_code (Symbol, HubSpotSDK::Models::Webhooks::SnapshotStatusResponse::ErrorCode) (defaults to: nil)

    The code representing any error that occurred during the snapshot operation. Pos

  • message (String) (defaults to: nil)

    A descriptive message providing additional information about the snapshot operat



# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 52

Instance Attribute Details

#completed_atInteger?

A Unix timestamp in milliseconds indicating when the snapshot operation was completed.

Returns:

  • (Integer, nil)


33
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 33

optional :completed_at, Integer, api_name: :completedAt

#error_codeSymbol, ...

The code representing any error that occurred during the snapshot operation. Possible values are ‘TIMEOUT’, ‘VALIDATION_ERROR’, ‘INTERNAL_ERROR’, and ‘PERMISSION_DENIED’.



41
42
43
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 41

optional :error_code,
enum: -> { HubSpotSDK::Webhooks::SnapshotStatusResponse::ErrorCode },
api_name: :errorCode

#idString

The unique identifier for the snapshot operation, formatted as a UUID.

Returns:

  • (String)


12
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 12

required :id, String

#initiated_atInteger

A Unix timestamp in milliseconds indicating when the snapshot operation was initiated.

Returns:

  • (Integer)


19
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 19

required :initiated_at, Integer, api_name: :initiatedAt

#messageString?

A descriptive message providing additional information about the snapshot operation or any errors encountered.

Returns:

  • (String, nil)


50
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 50

optional :message, String

#statusSymbol, HubSpotSDK::Models::Webhooks::SnapshotStatusResponse::Status

The current status of the snapshot operation. Valid values include ‘PENDING’, ‘IN_PROGRESS’, ‘COMPLETED’, ‘FAILED’, and ‘EXPIRED’.



26
# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 26

required :status, enum: -> { HubSpotSDK::Webhooks::SnapshotStatusResponse::Status }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/hubspot_sdk/models/webhooks/snapshot_status_response.rb', line 81