Class: HubSpotSDK::Models::Webhooks::SubscriptionCreateRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/hubspot_sdk/models/webhooks/subscription_create_request.rb

Direct Known Subclasses

WebhookCreateSubscriptionParams

Defined Under Namespace

Modules: EventType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(active:, event_type:, event_type_name: nil, object_type_id: nil, property_name: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::SubscriptionCreateRequest for more details.

Parameters:

  • active (Boolean)

    Determines if the subscription is active or paused. Defaults to false.

  • event_type (Symbol, HubSpotSDK::Models::Webhooks::SubscriptionCreateRequest::EventType)

    Type of event to listen for. Can be one of ‘create`, `delete`, `deletedForPrivac

  • event_type_name (String) (defaults to: nil)

    The name of the event to listen for. This is used with custom objects to specify

  • object_type_id (String) (defaults to: nil)

    The ID of the object type for the subscription. This can be a standard CRM objec

  • property_name (String) (defaults to: nil)

    The internal name of the property to monitor for changes. Only applies when ‘eve



# File 'lib/hubspot_sdk/models/webhooks/subscription_create_request.rb', line 44

Instance Attribute Details

#activeBoolean

Determines if the subscription is active or paused. Defaults to false.

Returns:

  • (Boolean)


11
# File 'lib/hubspot_sdk/models/webhooks/subscription_create_request.rb', line 11

required :active, HubSpotSDK::Internal::Type::Boolean

#event_typeSymbol, HubSpotSDK::Models::Webhooks::SubscriptionCreateRequest::EventType

Type of event to listen for. Can be one of ‘create`, `delete`, `deletedForPrivacy`, or `propertyChange`.



18
19
20
# File 'lib/hubspot_sdk/models/webhooks/subscription_create_request.rb', line 18

required :event_type,
enum: -> { HubSpotSDK::Webhooks::SubscriptionCreateRequest::EventType },
api_name: :eventType

#event_type_nameString?

The name of the event to listen for. This is used with custom objects to specify custom event types beyond the standard eventType enum values.

Returns:

  • (String, nil)


27
# File 'lib/hubspot_sdk/models/webhooks/subscription_create_request.rb', line 27

optional :event_type_name, String, api_name: :eventTypeName

#object_type_idString?

The ID of the object type for the subscription. This can be a standard CRM object (e.g., ‘contact’, ‘company’, ‘deal’) or a custom object ID for custom object subscriptions.

Returns:

  • (String, nil)


35
# File 'lib/hubspot_sdk/models/webhooks/subscription_create_request.rb', line 35

optional :object_type_id, String, api_name: :objectTypeId

#property_nameString?

The internal name of the property to monitor for changes. Only applies when ‘eventType` is `propertyChange`.

Returns:

  • (String, nil)


42
# File 'lib/hubspot_sdk/models/webhooks/subscription_create_request.rb', line 42

optional :property_name, String, api_name: :propertyName