Class: HubSpotSDK::Models::Webhooks::SubscriptionResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Webhooks::SubscriptionResponse
- Defined in:
- lib/hubspot_sdk/models/webhooks/subscription_response.rb
Overview
Defined Under Namespace
Modules: EventType
Instance Attribute Summary collapse
-
#active ⇒ Boolean
Whether the subscription is active or paused.
-
#created_at ⇒ Time
The timestamp when the webhook subscription was created, in ISO 8601 format (e.g., 2020-02-29T12:30:00Z).
-
#event_type ⇒ Symbol, HubSpotSDK::Models::Webhooks::SubscriptionResponse::EventType
The type of event to listen for.
-
#event_type_name ⇒ String?
The name of the event to listen for.
-
#id ⇒ String
The unique ID of the webhook subscription.
-
#object_type_id ⇒ String?
The ID of the object type for the subscription.
-
#property_name ⇒ String?
The internal name of the property to monitor for changes.
-
#updated_at ⇒ Time?
The timestamp when the webhook subscription was last updated, in ISO 8601 format (e.g., 2020-02-29T12:30:00Z).
Instance Method Summary collapse
-
#initialize(id:, active:, created_at:, event_type:, event_type_name: nil, object_type_id: nil, property_name: nil, updated_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SubscriptionResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, active:, created_at:, event_type:, event_type_name: nil, object_type_id: nil, property_name: nil, updated_at: nil) ⇒ Object
Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::SubscriptionResponse for more details.
|
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 68
|
Instance Attribute Details
#active ⇒ Boolean
Whether the subscription is active or paused. If true, the subscription will send webhook notifications. If false, the subscription is paused and will not send notifications.
20 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 20 required :active, HubSpotSDK::Internal::Type::Boolean |
#created_at ⇒ Time
The timestamp when the webhook subscription was created, in ISO 8601 format (e.g., 2020-02-29T12:30:00Z).
27 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 27 required :created_at, Time, api_name: :createdAt |
#event_type ⇒ Symbol, HubSpotSDK::Models::Webhooks::SubscriptionResponse::EventType
The type of event to listen for. Accepted values include contact.creation, contact.deletion, contact.propertyChange, and similar event types for other CRM objects and custom objects.
35 36 37 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 35 required :event_type, enum: -> { HubSpotSDK::Webhooks::SubscriptionResponse::EventType }, api_name: :eventType |
#event_type_name ⇒ String?
The name of the event to listen for. This is used with custom objects to specify custom event types beyond the standard eventType enum values.
44 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 44 optional :event_type_name, String, api_name: :eventTypeName |
#id ⇒ String
The unique ID of the webhook subscription.
12 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 12 required :id, String |
#object_type_id ⇒ String?
The ID of the object type for the subscription. This can be a standard CRM object (e.g., ‘contact’, ‘company’, ‘deal’) or a custom object ID for custom object subscriptions.
52 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 52 optional :object_type_id, String, api_name: :objectTypeId |
#property_name ⇒ String?
The internal name of the property to monitor for changes. Only applies when eventType is propertyChange.
59 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 59 optional :property_name, String, api_name: :propertyName |
#updated_at ⇒ Time?
The timestamp when the webhook subscription was last updated, in ISO 8601 format (e.g., 2020-02-29T12:30:00Z).
66 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response.rb', line 66 optional :updated_at, Time, api_name: :updatedAt |