Class: HubSpotSDK::Models::Webhooks::SubscriptionResponse1
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::Webhooks::SubscriptionResponse1
- Defined in:
- lib/hubspot_sdk/models/webhooks/subscription_response_1.rb
Overview
Defined Under Namespace
Modules: Action, SubscriptionType
Instance Attribute Summary collapse
-
#action_overrides ⇒ Hash{Symbol=>HubSpotSDK::Models::Webhooks::ActionOverrideRequest}?
An object containing action overrides, where each key is an action and the value is an ActionOverrideRequest object.
-
#actions ⇒ Array<Symbol, HubSpotSDK::Models::Webhooks::SubscriptionResponse1::Action>
An array of actions that trigger the subscription, such as ‘CREATE’, ‘UPDATE’, ‘DELETE’, ‘MERGE’, ‘RESTORE’, ‘ASSOCIATION_ADDED’, ‘ASSOCIATION_REMOVED’, ‘SNAPSHOT’, ‘APP_INSTALL’, ‘APP_UNINSTALL’, ‘ADDED_TO_LIST’, ‘REMOVED_FROM_LIST’, and ‘GDPR_DELETE’.
-
#app_id ⇒ Integer
The unique identifier for the app associated with the subscription, represented as an integer.
-
#associated_object_type_ids ⇒ Array<String>?
An array of strings representing the associated object type IDs for the subscription.
-
#created_at ⇒ Time
The date and time when the subscription was created, in ISO 8601 format.
-
#created_by ⇒ Integer?
The unique identifier for the user who created the subscription, represented as an integer.
-
#deleted_at ⇒ Time?
The date and time when the subscription was deleted, in ISO 8601 format.
-
#id ⇒ Integer
The unique identifier for the subscription, represented as an integer.
-
#list_ids ⇒ Array<Integer>?
An array of integers representing the list IDs associated with the subscription.
-
#object_ids ⇒ Array<Integer>?
An array of integers representing the object IDs associated with the subscription.
-
#object_type_id ⇒ String
The identifier for the object type associated with the subscription, represented as a string.
-
#portal_id ⇒ Integer?
The unique identifier for the portal associated with the subscription, represented as an integer.
-
#properties ⇒ Array<String>?
An array of strings representing the properties associated with the subscription.
-
#subscription_type ⇒ Symbol, HubSpotSDK::Models::Webhooks::SubscriptionResponse1::SubscriptionType
The type of subscription, which can be one of ‘OBJECT’, ‘ASSOCIATION’, ‘EVENT’, ‘APP_LIFECYCLE_EVENT’, ‘LIST_MEMBERSHIP’, or ‘GDPR_PRIVACY_DELETION’.
-
#updated_at ⇒ Time
The date and time when the subscription was last updated, in ISO 8601 format.
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#action_overrides ⇒ Hash{Symbol=>HubSpotSDK::Models::Webhooks::ActionOverrideRequest}?
An object containing action overrides, where each key is an action and the value is an ActionOverrideRequest object.
64 65 66 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 64 optional :action_overrides, -> { HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::Webhooks::ActionOverrideRequest] }, api_name: :actionOverrides |
#actions ⇒ Array<Symbol, HubSpotSDK::Models::Webhooks::SubscriptionResponse1::Action>
An array of actions that trigger the subscription, such as ‘CREATE’, ‘UPDATE’, ‘DELETE’, ‘MERGE’, ‘RESTORE’, ‘ASSOCIATION_ADDED’, ‘ASSOCIATION_REMOVED’, ‘SNAPSHOT’, ‘APP_INSTALL’, ‘APP_UNINSTALL’, ‘ADDED_TO_LIST’, ‘REMOVED_FROM_LIST’, and ‘GDPR_DELETE’.
21 22 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 21 required :actions, -> { HubSpotSDK::Internal::Type::ArrayOf[enum: HubSpotSDK::Webhooks::SubscriptionResponse1::Action] } |
#app_id ⇒ Integer
The unique identifier for the app associated with the subscription, represented as an integer.
29 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 29 required :app_id, Integer, api_name: :appId |
#associated_object_type_ids ⇒ Array<String>?
An array of strings representing the associated object type IDs for the subscription.
73 74 75 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 73 optional :associated_object_type_ids, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :associatedObjectTypeIds |
#created_at ⇒ Time
The date and time when the subscription was created, in ISO 8601 format.
35 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 35 required :created_at, Time, api_name: :createdAt |
#created_by ⇒ Integer?
The unique identifier for the user who created the subscription, represented as an integer.
82 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 82 optional :created_by, Integer, api_name: :createdBy |
#deleted_at ⇒ Time?
The date and time when the subscription was deleted, in ISO 8601 format.
88 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 88 optional :deleted_at, Time, api_name: :deletedAt |
#id ⇒ Integer
The unique identifier for the subscription, represented as an integer.
12 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 12 required :id, Integer |
#list_ids ⇒ Array<Integer>?
An array of integers representing the list IDs associated with the subscription.
94 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 94 optional :list_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :listIds |
#object_ids ⇒ Array<Integer>?
An array of integers representing the object IDs associated with the subscription.
101 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 101 optional :object_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :objectIds |
#object_type_id ⇒ String
The identifier for the object type associated with the subscription, represented as a string.
42 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 42 required :object_type_id, String, api_name: :objectTypeId |
#portal_id ⇒ Integer?
The unique identifier for the portal associated with the subscription, represented as an integer.
108 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 108 optional :portal_id, Integer, api_name: :portalId |
#properties ⇒ Array<String>?
An array of strings representing the properties associated with the subscription.
115 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 115 optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String] |
#subscription_type ⇒ Symbol, HubSpotSDK::Models::Webhooks::SubscriptionResponse1::SubscriptionType
The type of subscription, which can be one of ‘OBJECT’, ‘ASSOCIATION’, ‘EVENT’, ‘APP_LIFECYCLE_EVENT’, ‘LIST_MEMBERSHIP’, or ‘GDPR_PRIVACY_DELETION’.
49 50 51 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 49 required :subscription_type, enum: -> { HubSpotSDK::Webhooks::SubscriptionResponse1::SubscriptionType }, api_name: :subscriptionType |
#updated_at ⇒ Time
The date and time when the subscription was last updated, in ISO 8601 format.
57 |
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 57 required :updated_at, Time, api_name: :updatedAt |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 168
|