Class: HubSpotSDK::Models::Webhooks::SubscriptionResponse1
Overview
Defined Under Namespace
Modules: Action, SubscriptionType
Instance Attribute Summary collapse
Class Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Instance Attribute Details
#app_id ⇒ Integer
23
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 23
required :app_id, Integer, api_name: :appId
|
#associated_object_type_ids ⇒ Array<String>?
64
65
66
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 64
optional :associated_object_type_ids,
HubSpotSDK::Internal::Type::ArrayOf[String],
api_name: :associatedObjectTypeIds
|
#created_at ⇒ Time
The timestamp when the webhook subscription was created, in ISO 8601 format (e.g., 2020-02-29T12:30:00Z).
30
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 30
required :created_at, Time, api_name: :createdAt
|
#created_by ⇒ Integer?
71
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 71
optional :created_by, Integer, api_name: :createdBy
|
#deleted_at ⇒ Time?
76
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 76
optional :deleted_at, Time, api_name: :deletedAt
|
#id ⇒ Integer
The unique ID of the webhook subscription.
12
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 12
required :id, Integer
|
#list_ids ⇒ Array<Integer>?
81
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 81
optional :list_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :listIds
|
#object_ids ⇒ Array<Integer>?
86
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 86
optional :object_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :objectIds
|
#object_type_id ⇒ String
The ID of the object type for the subscription. This can be a standard CRM object (e.g., ‘contact’, ‘company’, ‘deal’) or a custom object ID for custom object subscriptions.
38
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 38
required :object_type_id, String, api_name: :objectTypeId
|
#portal_id ⇒ Integer?
91
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 91
optional :portal_id, Integer, api_name: :portalId
|
#properties ⇒ Array<String>?
96
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 96
optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String]
|
43
44
45
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 43
required :subscription_type,
enum: -> { HubSpotSDK::Webhooks::SubscriptionResponse1::SubscriptionType },
api_name: :subscriptionType
|
#updated_at ⇒ Time
The timestamp when the webhook subscription was last updated, in ISO 8601 format (e.g., 2020-02-29T12:30:00Z).
52
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 52
required :updated_at, Time, api_name: :updatedAt
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 148
|