Module: HubSpotSDK::Models::Webhooks::SubscriptionResponse1::Action

Extended by:
Internal::Type::Enum
Defined in:
lib/hubspot_sdk/models/webhooks/subscription_response_1.rb

Constant Summary collapse

CREATE =
:CREATE
UPDATE =
:UPDATE
DELETE =
:DELETE
MERGE =
:MERGE
RESTORE =
:RESTORE
ASSOCIATION_ADDED =
:ASSOCIATION_ADDED
ASSOCIATION_REMOVED =
:ASSOCIATION_REMOVED
SNAPSHOT =
:SNAPSHOT
APP_INSTALL =
:APP_INSTALL
APP_UNINSTALL =
:APP_UNINSTALL
ADDED_TO_LIST =
:ADDED_TO_LIST
REMOVED_FROM_LIST =
:REMOVED_FROM_LIST

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(id:, actions:, app_id:, created_at:, object_type_id:, subscription_type:, updated_at:, action_overrides: nil, associated_object_type_ids: nil, created_by: nil, deleted_at: nil, list_ids: nil, object_ids: nil, portal_id: nil, properties: nil) ⇒ Object

Some parameter documentations has been truncated, see HubSpotSDK::Models::Webhooks::SubscriptionResponse1 for more details.

Parameters:

  • id (Integer)

    The unique ID of the webhook subscription.

  • actions (Array<Symbol, HubSpotSDK::Models::Webhooks::SubscriptionResponse1::Action>)
  • app_id (Integer)
  • created_at (Time)

    The timestamp when the webhook subscription was created, in ISO 8601 format (e.g

  • object_type_id (String)

    The ID of the object type for the subscription. This can be a standard CRM objec

  • subscription_type (Symbol, HubSpotSDK::Models::Webhooks::SubscriptionResponse1::SubscriptionType)
  • updated_at (Time)

    The timestamp when the webhook subscription was last updated, in ISO 8601 format

  • action_overrides (Hash{Symbol=>HubSpotSDK::Models::Webhooks::ActionOverrideRequest}) (defaults to: nil)
  • associated_object_type_ids (Array<String>) (defaults to: nil)
  • created_by (Integer) (defaults to: nil)
  • deleted_at (Time) (defaults to: nil)
  • list_ids (Array<Integer>) (defaults to: nil)
  • object_ids (Array<Integer>) (defaults to: nil)
  • portal_id (Integer) (defaults to: nil)
  • properties (Array<String>) (defaults to: nil)


132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/hubspot_sdk/models/webhooks/subscription_response_1.rb', line 132

module Action
  extend HubSpotSDK::Internal::Type::Enum

  CREATE = :CREATE
  UPDATE = :UPDATE
  DELETE = :DELETE
  MERGE = :MERGE
  RESTORE = :RESTORE
  ASSOCIATION_ADDED = :ASSOCIATION_ADDED
  ASSOCIATION_REMOVED = :ASSOCIATION_REMOVED
  SNAPSHOT = :SNAPSHOT
  APP_INSTALL = :APP_INSTALL
  APP_UNINSTALL = :APP_UNINSTALL
  ADDED_TO_LIST = :ADDED_TO_LIST
  REMOVED_FROM_LIST = :REMOVED_FROM_LIST

  # @!method self.values
  #   @return [Array<Symbol>]
end