Class: HubSpotSDK::Models::WebhooksJournal::JournalSubscriptionResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- HubSpotSDK::Models::WebhooksJournal::JournalSubscriptionResponse
- Defined in:
- lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb
Defined Under Namespace
Modules: Action, SubscriptionType
Instance Attribute Summary collapse
-
#action_overrides ⇒ Hash{Symbol=>HubSpotSDK::Models::ActionOverrideRequest}?
An object containing overrides for actions, where each key is an action and the value is an ActionOverrideRequest object.
-
#actions ⇒ Array<Symbol, HubSpotSDK::Models::WebhooksJournal::JournalSubscriptionResponse::Action>
An array of actions associated with the subscription.
-
#app_id ⇒ Integer
The unique identifier for the app associated with the subscription, represented as an integer.
-
#associated_object_type_ids ⇒ Array<String>?
An array of strings representing the IDs of associated object types.
-
#created_at ⇒ Time
The date and time when the subscription was created, in ISO 8601 format.
-
#created_by ⇒ Integer?
The unique identifier of the user who created the subscription, represented as an integer.
-
#deleted_at ⇒ Time?
The date and time when the subscription was deleted, in ISO 8601 format, if applicable.
-
#id ⇒ Integer
The unique identifier for the subscription, represented as an integer.
-
#list_ids ⇒ Array<Integer>?
An array of integers representing the IDs of lists associated with the subscription.
-
#object_ids ⇒ Array<Integer>?
An array of integers representing the IDs of objects associated with the subscription.
-
#object_type_id ⇒ String
The identifier for the type of object associated with the subscription, represented as a string.
-
#portal_id ⇒ Integer?
The unique identifier for the portal associated with the subscription, represented as an integer.
-
#properties ⇒ Array<String>?
An array of strings representing the properties associated with the subscription.
-
#subscription_type ⇒ Symbol, HubSpotSDK::Models::WebhooksJournal::JournalSubscriptionResponse::SubscriptionType
The type of subscription, indicating the nature of events it pertains to.
-
#updated_at ⇒ Time
The date and time when the subscription was last updated, in ISO 8601 format.
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from HubSpotSDK::Internal::Type::BaseModel
Instance Attribute Details
#action_overrides ⇒ Hash{Symbol=>HubSpotSDK::Models::ActionOverrideRequest}?
An object containing overrides for actions, where each key is an action and the value is an ActionOverrideRequest object.
64 65 66 |
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 64 optional :action_overrides, -> { HubSpotSDK::Internal::Type::HashOf[HubSpotSDK::ActionOverrideRequest] }, api_name: :actionOverrides |
#actions ⇒ Array<Symbol, HubSpotSDK::Models::WebhooksJournal::JournalSubscriptionResponse::Action>
An array of actions associated with the subscription. Valid actions include ‘CREATE’, ‘UPDATE’, ‘DELETE’, ‘MERGE’, ‘RESTORE’, ‘ASSOCIATION_ADDED’, ‘ASSOCIATION_REMOVED’, ‘SNAPSHOT’, ‘APP_INSTALL’, ‘APP_UNINSTALL’, ‘ADDED_TO_LIST’, ‘REMOVED_FROM_LIST’, and ‘GDPR_DELETE’.
20 21 |
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 20 required :actions, -> { HubSpotSDK::Internal::Type::ArrayOf[enum: HubSpotSDK::WebhooksJournal::JournalSubscriptionResponse::Action] } |
#app_id ⇒ Integer
The unique identifier for the app associated with the subscription, represented as an integer.
28 |
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 28 required :app_id, Integer, api_name: :appId |
#associated_object_type_ids ⇒ Array<String>?
An array of strings representing the IDs of associated object types.
72 73 74 |
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 72 optional :associated_object_type_ids, HubSpotSDK::Internal::Type::ArrayOf[String], api_name: :associatedObjectTypeIds |
#created_at ⇒ Time
The date and time when the subscription was created, in ISO 8601 format.
34 |
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 34 required :created_at, Time, api_name: :createdAt |
#created_by ⇒ Integer?
The unique identifier of the user who created the subscription, represented as an integer.
81 |
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 81 optional :created_by, Integer, api_name: :createdBy |
#deleted_at ⇒ Time?
The date and time when the subscription was deleted, in ISO 8601 format, if applicable.
88 |
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 88 optional :deleted_at, Time, api_name: :deletedAt |
#id ⇒ Integer
The unique identifier for the subscription, represented as an integer.
11 |
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 11 required :id, Integer |
#list_ids ⇒ Array<Integer>?
An array of integers representing the IDs of lists associated with the subscription.
95 |
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 95 optional :list_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :listIds |
#object_ids ⇒ Array<Integer>?
An array of integers representing the IDs of objects associated with the subscription.
102 |
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 102 optional :object_ids, HubSpotSDK::Internal::Type::ArrayOf[Integer], api_name: :objectIds |
#object_type_id ⇒ String
The identifier for the type of object associated with the subscription, represented as a string.
41 |
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 41 required :object_type_id, String, api_name: :objectTypeId |
#portal_id ⇒ Integer?
The unique identifier for the portal associated with the subscription, represented as an integer.
109 |
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 109 optional :portal_id, Integer, api_name: :portalId |
#properties ⇒ Array<String>?
An array of strings representing the properties associated with the subscription.
116 |
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 116 optional :properties, HubSpotSDK::Internal::Type::ArrayOf[String] |
#subscription_type ⇒ Symbol, HubSpotSDK::Models::WebhooksJournal::JournalSubscriptionResponse::SubscriptionType
The type of subscription, indicating the nature of events it pertains to. Valid values include ‘OBJECT’, ‘ASSOCIATION’, ‘EVENT’, ‘APP_LIFECYCLE_EVENT’, ‘LIST_MEMBERSHIP’, and ‘GDPR_PRIVACY_DELETION’.
49 50 51 |
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 49 required :subscription_type, enum: -> { HubSpotSDK::WebhooksJournal::JournalSubscriptionResponse::SubscriptionType }, api_name: :subscriptionType |
#updated_at ⇒ Time
The date and time when the subscription was last updated, in ISO 8601 format.
57 |
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 57 required :updated_at, Time, api_name: :updatedAt |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/hubspot_sdk/models/webhooks_journal/journal_subscription_response.rb', line 170
|