Class: HubSpotSDK::Resources::Crm::Extensions::Calling
- Inherits:
-
Object
- Object
- HubSpotSDK::Resources::Crm::Extensions::Calling
- Defined in:
- lib/hubspot_sdk/resources/crm/extensions/calling.rb,
lib/hubspot_sdk/resources/crm/extensions/calling/transcripts.rb
Defined Under Namespace
Classes: Transcripts
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#create_channel_connection_settings(app_id, is_ready:, url:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::ChannelConnectionSettingsResponse
Establish new channel connection settings for the specified app.
-
#create_inbound_call(create_engagement:, engagement_properties:, external_call_id:, final_call_status:, from_number:, potential_recipient_user_ids:, to_number:, call_started_timestamp: nil, duration_seconds: nil, user_id: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::CompletedThirdPartyCallResponse
Some parameter documentations has been truncated, see Models::Crm::Extensions::CallingCreateInboundCallParams for more details.
-
#create_recording_ready(engagement_id:, request_options: {}) ⇒ nil
This endpoint is used to mark a call recording as ready.
-
#create_recording_settings(app_id, url_to_retrieve_authed_recording:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::RecordingSettingsResponse
Create new recording settings for a specific app using the provided app ID.
-
#create_settings(app_id, height:, is_ready:, name:, supports_custom_objects:, supports_inbound_calling:, url:, uses_calling_window:, uses_remote:, width:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::SettingsResponse
Create new settings for the calling extension associated with the specified appId.
-
#delete_channel_connection_settings(app_id, request_options: {}) ⇒ nil
Delete the channel connection settings associated with the specified app.
-
#delete_settings(app_id, request_options: {}) ⇒ nil
Remove the calling extension settings associated with the specified appId.
-
#get_channel_connection_settings(app_id, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::ChannelConnectionSettingsResponse
Access the current channel connection settings for the specified app.
-
#get_recording_settings(app_id, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::RecordingSettingsResponse
Retrieve the current recording settings for a specific app using the provided app ID.
-
#get_settings(app_id, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::SettingsResponse
Retrieve the current settings of the calling extension for the specified appId.
-
#initialize(client:) ⇒ Calling
constructor
private
A new instance of Calling.
-
#update_channel_connection_settings(app_id, is_ready: nil, url: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::ChannelConnectionSettingsResponse
Modify the existing channel connection settings for the specified app.
-
#update_recording_settings(app_id, url_to_retrieve_authed_recording: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::RecordingSettingsResponse
Update the recording settings for a specific app using the provided app ID.
-
#update_settings(app_id, height: nil, is_ready: nil, name: nil, supports_custom_objects: nil, supports_inbound_calling: nil, url: nil, uses_calling_window: nil, uses_remote: nil, width: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::SettingsResponse
Modify existing calling extension settings for the specified appId.
Constructor Details
#initialize(client:) ⇒ Calling
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Calling.
360 361 362 363 |
# File 'lib/hubspot_sdk/resources/crm/extensions/calling.rb', line 360 def initialize(client:) @client = client @transcripts = HubSpotSDK::Resources::Crm::Extensions::Calling::Transcripts.new(client: client) end |
Instance Attribute Details
#transcripts ⇒ HubSpotSDK::Resources::Crm::Extensions::Calling::Transcripts (readonly)
9 10 11 |
# File 'lib/hubspot_sdk/resources/crm/extensions/calling.rb', line 9 def transcripts @transcripts end |
Instance Method Details
#create_channel_connection_settings(app_id, is_ready:, url:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::ChannelConnectionSettingsResponse
Establish new channel connection settings for the specified app.
26 27 28 29 30 31 32 33 34 35 36 |
# File 'lib/hubspot_sdk/resources/crm/extensions/calling.rb', line 26 def create_channel_connection_settings(app_id, params) parsed, = HubSpotSDK::Crm::Extensions::CallingCreateChannelConnectionSettingsParams.dump_request(params) @client.request( method: :post, path: ["crm/extensions/calling/2026-03/%1$s/settings/channel-connection", app_id], body: parsed, model: HubSpotSDK::Crm::Extensions::ChannelConnectionSettingsResponse, options: ) end |
#create_inbound_call(create_engagement:, engagement_properties:, external_call_id:, final_call_status:, from_number:, potential_recipient_user_ids:, to_number:, call_started_timestamp: nil, duration_seconds: nil, user_id: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::CompletedThirdPartyCallResponse
Some parameter documentations has been truncated, see Models::Crm::Extensions::CallingCreateInboundCallParams for more details.
69 70 71 72 73 74 75 76 77 78 |
# File 'lib/hubspot_sdk/resources/crm/extensions/calling.rb', line 69 def create_inbound_call(params) parsed, = HubSpotSDK::Crm::Extensions::CallingCreateInboundCallParams.dump_request(params) @client.request( method: :post, path: "crm/extensions/calling/2026-03/inbound-call", body: parsed, model: HubSpotSDK::Crm::Extensions::CompletedThirdPartyCallResponse, options: ) end |
#create_recording_ready(engagement_id:, request_options: {}) ⇒ nil
This endpoint is used to mark a call recording as ready. It requires the engagementId to identify the specific recording.
92 93 94 95 96 97 98 99 100 101 |
# File 'lib/hubspot_sdk/resources/crm/extensions/calling.rb', line 92 def create_recording_ready(params) parsed, = HubSpotSDK::Crm::Extensions::CallingCreateRecordingReadyParams.dump_request(params) @client.request( method: :post, path: "crm/extensions/calling/2026-03/recordings/ready", body: parsed, model: NilClass, options: ) end |
#create_recording_settings(app_id, url_to_retrieve_authed_recording:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::RecordingSettingsResponse
Create new recording settings for a specific app using the provided app ID.
116 117 118 119 120 121 122 123 124 125 |
# File 'lib/hubspot_sdk/resources/crm/extensions/calling.rb', line 116 def create_recording_settings(app_id, params) parsed, = HubSpotSDK::Crm::Extensions::CallingCreateRecordingSettingsParams.dump_request(params) @client.request( method: :post, path: ["crm/extensions/calling/2026-03/%1$s/settings/recording", app_id], body: parsed, model: HubSpotSDK::Crm::Extensions::RecordingSettingsResponse, options: ) end |
#create_settings(app_id, height:, is_ready:, name:, supports_custom_objects:, supports_inbound_calling:, url:, uses_calling_window:, uses_remote:, width:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::SettingsResponse
Create new settings for the calling extension associated with the specified appId.
157 158 159 160 161 162 163 164 165 166 |
# File 'lib/hubspot_sdk/resources/crm/extensions/calling.rb', line 157 def create_settings(app_id, params) parsed, = HubSpotSDK::Crm::Extensions::CallingCreateSettingsParams.dump_request(params) @client.request( method: :post, path: ["crm/extensions/calling/2026-03/%1$s/settings", app_id], body: parsed, model: HubSpotSDK::Crm::Extensions::SettingsResponse, options: ) end |
#delete_channel_connection_settings(app_id, request_options: {}) ⇒ nil
Delete the channel connection settings associated with the specified app.
178 179 180 181 182 183 184 185 |
# File 'lib/hubspot_sdk/resources/crm/extensions/calling.rb', line 178 def delete_channel_connection_settings(app_id, params = {}) @client.request( method: :delete, path: ["crm/extensions/calling/2026-03/%1$s/settings/channel-connection", app_id], model: NilClass, options: params[:request_options] ) end |
#delete_settings(app_id, request_options: {}) ⇒ nil
Remove the calling extension settings associated with the specified appId. This action cannot be undone.
198 199 200 201 202 203 204 205 |
# File 'lib/hubspot_sdk/resources/crm/extensions/calling.rb', line 198 def delete_settings(app_id, params = {}) @client.request( method: :delete, path: ["crm/extensions/calling/2026-03/%1$s/settings", app_id], model: NilClass, options: params[:request_options] ) end |
#get_channel_connection_settings(app_id, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::ChannelConnectionSettingsResponse
Access the current channel connection settings for the specified app.
217 218 219 220 221 222 223 224 |
# File 'lib/hubspot_sdk/resources/crm/extensions/calling.rb', line 217 def get_channel_connection_settings(app_id, params = {}) @client.request( method: :get, path: ["crm/extensions/calling/2026-03/%1$s/settings/channel-connection", app_id], model: HubSpotSDK::Crm::Extensions::ChannelConnectionSettingsResponse, options: params[:request_options] ) end |
#get_recording_settings(app_id, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::RecordingSettingsResponse
Retrieve the current recording settings for a specific app using the provided app ID.
237 238 239 240 241 242 243 244 |
# File 'lib/hubspot_sdk/resources/crm/extensions/calling.rb', line 237 def get_recording_settings(app_id, params = {}) @client.request( method: :get, path: ["crm/extensions/calling/2026-03/%1$s/settings/recording", app_id], model: HubSpotSDK::Crm::Extensions::RecordingSettingsResponse, options: params[:request_options] ) end |
#get_settings(app_id, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::SettingsResponse
Retrieve the current settings of the calling extension for the specified appId.
256 257 258 259 260 261 262 263 |
# File 'lib/hubspot_sdk/resources/crm/extensions/calling.rb', line 256 def get_settings(app_id, params = {}) @client.request( method: :get, path: ["crm/extensions/calling/2026-03/%1$s/settings", app_id], model: HubSpotSDK::Crm::Extensions::SettingsResponse, options: params[:request_options] ) end |
#update_channel_connection_settings(app_id, is_ready: nil, url: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::ChannelConnectionSettingsResponse
Modify the existing channel connection settings for the specified app.
280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/hubspot_sdk/resources/crm/extensions/calling.rb', line 280 def update_channel_connection_settings(app_id, params = {}) parsed, = HubSpotSDK::Crm::Extensions::CallingUpdateChannelConnectionSettingsParams.dump_request(params) @client.request( method: :patch, path: ["crm/extensions/calling/2026-03/%1$s/settings/channel-connection", app_id], body: parsed, model: HubSpotSDK::Crm::Extensions::ChannelConnectionSettingsResponse, options: ) end |
#update_recording_settings(app_id, url_to_retrieve_authed_recording: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::RecordingSettingsResponse
Update the recording settings for a specific app using the provided app ID.
305 306 307 308 309 310 311 312 313 314 |
# File 'lib/hubspot_sdk/resources/crm/extensions/calling.rb', line 305 def update_recording_settings(app_id, params = {}) parsed, = HubSpotSDK::Crm::Extensions::CallingUpdateRecordingSettingsParams.dump_request(params) @client.request( method: :patch, path: ["crm/extensions/calling/2026-03/%1$s/settings/recording", app_id], body: parsed, model: HubSpotSDK::Crm::Extensions::RecordingSettingsResponse, options: ) end |
#update_settings(app_id, height: nil, is_ready: nil, name: nil, supports_custom_objects: nil, supports_inbound_calling: nil, url: nil, uses_calling_window: nil, uses_remote: nil, width: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::Extensions::SettingsResponse
Modify existing calling extension settings for the specified appId. Only the fields provided in the request will be updated.
346 347 348 349 350 351 352 353 354 355 |
# File 'lib/hubspot_sdk/resources/crm/extensions/calling.rb', line 346 def update_settings(app_id, params = {}) parsed, = HubSpotSDK::Crm::Extensions::CallingUpdateSettingsParams.dump_request(params) @client.request( method: :patch, path: ["crm/extensions/calling/2026-03/%1$s/settings", app_id], body: parsed, model: HubSpotSDK::Crm::Extensions::SettingsResponse, options: ) end |