Class: HubSpotSDK::Resources::Crm::ObjectSchemas::Batch
- Inherits:
-
Object
- Object
- HubSpotSDK::Resources::Crm::ObjectSchemas::Batch
- Defined in:
- lib/hubspot_sdk/resources/crm/object_schemas/batch.rb
Instance Method Summary collapse
-
#get(include_association_definitions:, include_audit_metadata:, include_property_definitions:, inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseObjectSchemaNoPaging
Retrieve details of multiple custom object schemas by providing a batch request with specified inputs.
-
#initialize(client:) ⇒ Batch
constructor
private
A new instance of Batch.
Constructor Details
#initialize(client:) ⇒ Batch
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Batch.
42 43 44 |
# File 'lib/hubspot_sdk/resources/crm/object_schemas/batch.rb', line 42 def initialize(client:) @client = client end |
Instance Method Details
#get(include_association_definitions:, include_audit_metadata:, include_property_definitions:, inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseObjectSchemaNoPaging
Retrieve details of multiple custom object schemas by providing a batch request with specified inputs. This operation allows you to fetch schema information, including properties and associations, for multiple custom objects in a single API call.
28 29 30 31 32 33 34 35 36 37 |
# File 'lib/hubspot_sdk/resources/crm/object_schemas/batch.rb', line 28 def get(params) parsed, = HubSpotSDK::Crm::ObjectSchemas::BatchGetParams.dump_request(params) @client.request( method: :post, path: "crm-object-schemas/2026-03/schemas/batch/read", body: parsed, model: HubSpotSDK::Crm::CollectionResponseObjectSchemaNoPaging, options: ) end |