Class: HubSpotSDK::Resources::Crm::Objects::Meetings::Batch
- Inherits:
-
Object
- Object
- HubSpotSDK::Resources::Crm::Objects::Meetings::Batch
- Defined in:
- lib/hubspot_sdk/resources/crm/objects/meetings/batch.rb
Instance Method Summary collapse
-
#create(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Create a batch of meetings.
-
#delete(inputs:, request_options: {}) ⇒ nil
Delete a batch of meetings by ID.
-
#get(inputs:, properties:, properties_with_history:, archived: nil, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::Meetings::BatchGetParams for more details.
-
#initialize(client:) ⇒ Batch
constructor
private
A new instance of Batch.
-
#update(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Update a batch of meetings by ID (‘objectId`) or unique property value (`idProperty`).
-
#upsert(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject
Create or update records identified by a unique property value as specified by the ‘idProperty` query param.
Constructor Details
#initialize(client:) ⇒ Batch
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Batch.
140 141 142 |
# File 'lib/hubspot_sdk/resources/crm/objects/meetings/batch.rb', line 140 def initialize(client:) @client = client end |
Instance Method Details
#create(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Create a batch of meetings. The ‘inputs` array can contain a `properties` object to define property values for the record, along with an `associations` array to define relationships with other object records.
21 22 23 24 25 26 27 28 29 30 |
# File 'lib/hubspot_sdk/resources/crm/objects/meetings/batch.rb', line 21 def create(params) parsed, = HubSpotSDK::Crm::Objects::Meetings::BatchCreateParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/meetings/batch/create", body: parsed, model: HubSpotSDK::Crm::BatchResponseSimplePublicObject, options: ) end |
#delete(inputs:, request_options: {}) ⇒ nil
Delete a batch of meetings by ID.
66 67 68 69 70 71 72 73 74 75 |
# File 'lib/hubspot_sdk/resources/crm/objects/meetings/batch.rb', line 66 def delete(params) parsed, = HubSpotSDK::Crm::Objects::Meetings::BatchDeleteParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/meetings/batch/archive", body: parsed, model: NilClass, options: ) end |
#get(inputs:, properties:, properties_with_history:, archived: nil, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::Meetings::BatchGetParams for more details.
Retrieve records by record ID or include the ‘idProperty` parameter to retrieve records by a custom unique value property.
100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/hubspot_sdk/resources/crm/objects/meetings/batch.rb', line 100 def get(params) query_params = [:archived] parsed, = HubSpotSDK::Crm::Objects::Meetings::BatchGetParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params)) @client.request( method: :post, path: "crm/objects/2026-03/meetings/batch/read", query: query, body: parsed.except(*query_params), model: HubSpotSDK::Crm::BatchResponseSimplePublicObject, options: ) end |
#update(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Update a batch of meetings by ID (‘objectId`) or unique property value (`idProperty`). Provided property values will be overwritten. Read-only and non-existent properties will result in an error. Properties values can be cleared by passing an empty string.
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/hubspot_sdk/resources/crm/objects/meetings/batch.rb', line 45 def update(params) parsed, = HubSpotSDK::Crm::Objects::Meetings::BatchUpdateParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/meetings/batch/update", body: parsed, model: HubSpotSDK::Crm::BatchResponseSimplePublicObject, options: ) end |
#upsert(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject
Create or update records identified by a unique property value as specified by the ‘idProperty` query param. `idProperty` query param refers to a property whose values are unique for the object.
126 127 128 129 130 131 132 133 134 135 |
# File 'lib/hubspot_sdk/resources/crm/objects/meetings/batch.rb', line 126 def upsert(params) parsed, = HubSpotSDK::Crm::Objects::Meetings::BatchUpsertParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/meetings/batch/upsert", body: parsed, model: HubSpotSDK::Crm::BatchResponseSimplePublicUpsertObject, options: ) end |