Class: HubSpotSDK::Resources::Crm::Objects::Quotes
- Inherits:
-
Object
- Object
- HubSpotSDK::Resources::Crm::Objects::Quotes
- Defined in:
- lib/hubspot_sdk/resources/crm/objects/quotes.rb,
lib/hubspot_sdk/resources/crm/objects/quotes/batch.rb
Defined Under Namespace
Classes: Batch
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#create(associations:, properties:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Create a quote with the given properties and return a copy of the object, including the ID.
-
#delete(quote_id, request_options: {}) ⇒ nil
Move an Object identified by ‘quoteId` to the recycling bin.
-
#get(quote_id, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations
Some parameter documentations has been truncated, see Models::Crm::Objects::QuoteGetParams for more details.
-
#initialize(client:) ⇒ Quotes
constructor
private
A new instance of Quotes.
-
#list(after: nil, archived: nil, associations: nil, limit: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Internal::Page<HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations>
Some parameter documentations has been truncated, see Models::Crm::Objects::QuoteListParams for more details.
-
#search(after:, filter_groups:, limit:, properties:, sorts:, query: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseWithTotalSimplePublicObject
Execute a search for quotes based on the criteria defined in the request body, such as filters, properties, and sorting options.
-
#update(quote_id, properties:, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::QuoteUpdateParams for more details.
Constructor Details
#initialize(client:) ⇒ Quotes
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Quotes.
210 211 212 213 |
# File 'lib/hubspot_sdk/resources/crm/objects/quotes.rb', line 210 def initialize(client:) @client = client @batch = HubSpotSDK::Resources::Crm::Objects::Quotes::Batch.new(client: client) end |
Instance Attribute Details
#batch ⇒ HubSpotSDK::Resources::Crm::Objects::Quotes::Batch (readonly)
9 10 11 |
# File 'lib/hubspot_sdk/resources/crm/objects/quotes.rb', line 9 def batch @batch end |
Instance Method Details
#create(associations:, properties:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Create a quote with the given properties and return a copy of the object, including the ID. Documentation and examples for creating standard quotes is provided.
26 27 28 29 30 31 32 33 34 35 |
# File 'lib/hubspot_sdk/resources/crm/objects/quotes.rb', line 26 def create(params) parsed, = HubSpotSDK::Crm::Objects::QuoteCreateParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/quotes", body: parsed, model: HubSpotSDK::Crm::SimplePublicObject, options: ) end |
#delete(quote_id, request_options: {}) ⇒ nil
Move an Object identified by ‘quoteId` to the recycling bin.
122 123 124 125 126 127 128 129 |
# File 'lib/hubspot_sdk/resources/crm/objects/quotes.rb', line 122 def delete(quote_id, params = {}) @client.request( method: :delete, path: ["crm/objects/2026-03/quotes/%1$s", quote_id], model: NilClass, options: params[:request_options] ) end |
#get(quote_id, archived: nil, associations: nil, id_property: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations
Some parameter documentations has been truncated, see Models::Crm::Objects::QuoteGetParams for more details.
Read an Object identified by ‘quoteId`. `quoteId` refers to the internal object ID by default, or optionally any unique property value as specified by the `idProperty` query param. Control what is returned via the `properties` query param.
158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/hubspot_sdk/resources/crm/objects/quotes.rb', line 158 def get(quote_id, params = {}) parsed, = HubSpotSDK::Crm::Objects::QuoteGetParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["crm/objects/2026-03/quotes/%1$s", quote_id], query: query.transform_keys( id_property: "idProperty", properties_with_history: "propertiesWithHistory" ), model: HubSpotSDK::Crm::SimplePublicObjectWithAssociations, options: ) end |
#list(after: nil, archived: nil, associations: nil, limit: nil, properties: nil, properties_with_history: nil, request_options: {}) ⇒ HubSpotSDK::Internal::Page<HubSpotSDK::Models::Crm::SimplePublicObjectWithAssociations>
Some parameter documentations has been truncated, see Models::Crm::Objects::QuoteListParams for more details.
Read a page of quotes. Control what is returned via the ‘properties` query param.
99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/hubspot_sdk/resources/crm/objects/quotes.rb', line 99 def list(params = {}) parsed, = HubSpotSDK::Crm::Objects::QuoteListParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "crm/objects/2026-03/quotes", query: query.transform_keys(properties_with_history: "propertiesWithHistory"), page: HubSpotSDK::Internal::Page, model: HubSpotSDK::Crm::SimplePublicObjectWithAssociations, options: ) end |
#search(after:, filter_groups:, limit:, properties:, sorts:, query: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::CollectionResponseWithTotalSimplePublicObject
Execute a search for quotes based on the criteria defined in the request body, such as filters, properties, and sorting options. This endpoint allows for detailed querying of quote records to retrieve specific data sets.
196 197 198 199 200 201 202 203 204 205 |
# File 'lib/hubspot_sdk/resources/crm/objects/quotes.rb', line 196 def search(params) parsed, = HubSpotSDK::Crm::Objects::QuoteSearchParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/quotes/search", body: parsed, model: HubSpotSDK::Crm::CollectionResponseWithTotalSimplePublicObject, options: ) end |
#update(quote_id, properties:, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::SimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::QuoteUpdateParams for more details.
Perform a partial update of an Object identified by ‘quoteId`or optionally a unique property value as specified by the `idProperty` query param. `quoteId` refers to the internal object ID by default, and the `idProperty` query param refers to a property whose values are unique for the object. Provided property values will be overwritten. Read-only and non-existent properties will result in an error. Properties values can be cleared by passing an empty string.
60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/hubspot_sdk/resources/crm/objects/quotes.rb', line 60 def update(quote_id, params) query_params = [:id_property] parsed, = HubSpotSDK::Crm::Objects::QuoteUpdateParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params)) @client.request( method: :patch, path: ["crm/objects/2026-03/quotes/%1$s", quote_id], query: query.transform_keys(id_property: "idProperty"), body: parsed.except(*query_params), model: HubSpotSDK::Crm::SimplePublicObject, options: ) end |