Class: HubSpotSDK::Resources::Crm::Objects::Taxes::Batch
- Inherits:
-
Object
- Object
- HubSpotSDK::Resources::Crm::Objects::Taxes::Batch
- Defined in:
- lib/hubspot_sdk/resources/crm/objects/taxes/batch.rb
Instance Method Summary collapse
-
#create(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Create multiple tax records in a single request, each with specified properties and optional associations, and receive a response with details of the created objects.
-
#delete(inputs:, request_options: {}) ⇒ nil
Archive multiple taxes by their IDs in a single request.
-
#get(inputs:, properties:, properties_with_history:, archived: nil, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::Taxes::BatchGetParams for more details.
-
#initialize(client:) ⇒ Batch
constructor
private
A new instance of Batch.
-
#update(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Update multiple tax records using their internal IDs or unique property values.
-
#upsert(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject
Create or update records identified by a unique property value as specified by the ‘idProperty` query param.
Constructor Details
#initialize(client:) ⇒ Batch
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Batch.
139 140 141 |
# File 'lib/hubspot_sdk/resources/crm/objects/taxes/batch.rb', line 139 def initialize(client:) @client = client end |
Instance Method Details
#create(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Create multiple tax records in a single request, each with specified properties and optional associations, and receive a response with details of the created objects.
21 22 23 24 25 26 27 28 29 30 |
# File 'lib/hubspot_sdk/resources/crm/objects/taxes/batch.rb', line 21 def create(params) parsed, = HubSpotSDK::Crm::Objects::Taxes::BatchCreateParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/taxes/batch/create", body: parsed, model: HubSpotSDK::Crm::BatchResponseSimplePublicObject, options: ) end |
#delete(inputs:, request_options: {}) ⇒ nil
Archive multiple taxes by their IDs in a single request.
65 66 67 68 69 70 71 72 73 74 |
# File 'lib/hubspot_sdk/resources/crm/objects/taxes/batch.rb', line 65 def delete(params) parsed, = HubSpotSDK::Crm::Objects::Taxes::BatchDeleteParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/taxes/batch/archive", body: parsed, model: NilClass, options: ) end |
#get(inputs:, properties:, properties_with_history:, archived: nil, id_property: nil, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Some parameter documentations has been truncated, see Models::Crm::Objects::Taxes::BatchGetParams for more details.
Retrieve records by record ID or include the ‘idProperty` parameter to retrieve records by a custom unique value property.
99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/hubspot_sdk/resources/crm/objects/taxes/batch.rb', line 99 def get(params) query_params = [:archived] parsed, = HubSpotSDK::Crm::Objects::Taxes::BatchGetParams.dump_request(params) query = HubSpotSDK::Internal::Util.encode_query_params(parsed.slice(*query_params)) @client.request( method: :post, path: "crm/objects/2026-03/taxes/batch/read", query: query, body: parsed.except(*query_params), model: HubSpotSDK::Crm::BatchResponseSimplePublicObject, options: ) end |
#update(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicObject
Update multiple tax records using their internal IDs or unique property values. This operation allows for batch processing of updates to tax objects, ensuring efficient management of tax data in bulk.
44 45 46 47 48 49 50 51 52 53 |
# File 'lib/hubspot_sdk/resources/crm/objects/taxes/batch.rb', line 44 def update(params) parsed, = HubSpotSDK::Crm::Objects::Taxes::BatchUpdateParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/taxes/batch/update", body: parsed, model: HubSpotSDK::Crm::BatchResponseSimplePublicObject, options: ) end |
#upsert(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Crm::BatchResponseSimplePublicUpsertObject
Create or update records identified by a unique property value as specified by the ‘idProperty` query param. `idProperty` query param refers to a property whose values are unique for the object.
125 126 127 128 129 130 131 132 133 134 |
# File 'lib/hubspot_sdk/resources/crm/objects/taxes/batch.rb', line 125 def upsert(params) parsed, = HubSpotSDK::Crm::Objects::Taxes::BatchUpsertParams.dump_request(params) @client.request( method: :post, path: "crm/objects/2026-03/taxes/batch/upsert", body: parsed, model: HubSpotSDK::Crm::BatchResponseSimplePublicUpsertObject, options: ) end |