Class: HubSpotSDK::Resources::Settings::Currencies::ExchangeRates::Batch
- Inherits:
-
Object
- Object
- HubSpotSDK::Resources::Settings::Currencies::ExchangeRates::Batch
- Defined in:
- lib/hubspot_sdk/resources/settings/currencies/exchange_rates/batch.rb
Instance Method Summary collapse
-
#create(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Settings::BatchResponseExchangeRate
Create multiple exchange rates in a single request.
-
#get(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Settings::BatchResponseExchangeRate
Retrieve the details of multiple exchange rates in a single request, specified by their IDs.
-
#initialize(client:) ⇒ Batch
constructor
private
A new instance of Batch.
-
#update(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Settings::BatchResponseExchangeRate
Update the conversion rates for multiple exchange rates in a batch operation.
Constructor Details
#initialize(client:) ⇒ Batch
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Batch.
77 78 79 |
# File 'lib/hubspot_sdk/resources/settings/currencies/exchange_rates/batch.rb', line 77 def initialize(client:) @client = client end |
Instance Method Details
#create(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Settings::BatchResponseExchangeRate
Create multiple exchange rates in a single request.
19 20 21 22 23 24 25 26 27 28 |
# File 'lib/hubspot_sdk/resources/settings/currencies/exchange_rates/batch.rb', line 19 def create(params) parsed, = HubSpotSDK::Settings::Currencies::ExchangeRates::BatchCreateParams.dump_request(params) @client.request( method: :post, path: "settings/currencies/2026-03/exchange-rates/batch/create", body: parsed, model: HubSpotSDK::Settings::BatchResponseExchangeRate, options: ) end |
#get(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Settings::BatchResponseExchangeRate
Retrieve the details of multiple exchange rates in a single request, specified by their IDs.
63 64 65 66 67 68 69 70 71 72 |
# File 'lib/hubspot_sdk/resources/settings/currencies/exchange_rates/batch.rb', line 63 def get(params) parsed, = HubSpotSDK::Settings::Currencies::ExchangeRates::BatchGetParams.dump_request(params) @client.request( method: :post, path: "settings/currencies/2026-03/exchange-rates/batch/read", body: parsed, model: HubSpotSDK::Settings::BatchResponseExchangeRate, options: ) end |
#update(inputs:, request_options: {}) ⇒ HubSpotSDK::Models::Settings::BatchResponseExchangeRate
Update the conversion rates for multiple exchange rates in a batch operation.
40 41 42 43 44 45 46 47 48 49 |
# File 'lib/hubspot_sdk/resources/settings/currencies/exchange_rates/batch.rb', line 40 def update(params) parsed, = HubSpotSDK::Settings::Currencies::ExchangeRates::BatchUpdateParams.dump_request(params) @client.request( method: :post, path: "settings/currencies/2026-03/exchange-rates/batch/update", body: parsed, model: HubSpotSDK::Settings::BatchResponseExchangeRate, options: ) end |